@@ -13,12 +13,10 @@
 
 =========================================================================*/
 // Instantiate superclass first to give the template a DLL interface.
-#include "vtkDataArrayTemplate.txx"
-VTK_DATA_ARRAY_TEMPLATE_INSTANTIATE(long long);
-#include "vtkArrayIteratorTemplate.txx"
-VTK_ARRAY_ITERATOR_TEMPLATE_INSTANTIATE(long long);
+#define VTK_AOS_DATA_ARRAY_TEMPLATE_INSTANTIATING
+#include "vtkAOSDataArrayTemplate.txx"
+VTK_AOS_DATA_ARRAY_TEMPLATE_INSTANTIATE(long long);
 
-#define vtkLongLongArray_cxx
 #include "vtkLongLongArray.h"
 
 #include "vtkObjectFactory.h"
