@@ -3,8 +3,6 @@
   Program:   Visualization Toolkit
   Module:    vtkStringArray.cxx
   Language:  C++
-  Date:      $Date$
-  Version:   $Revision$
 
   Copyright 2004 Sandia Corporation.
   Under the terms of Contract DE-AC04-94AL85000, there is a non-exclusive
@@ -15,8 +13,6 @@
 
 =========================================================================*/
 
-
-
 // We do not provide a definition for the copy constructor or
 // operator=.  Block the warning.
 #ifdef _MSC_VER
@@ -25,9 +21,6 @@
 
 #include "vtkStdString.h"
 
-#include "vtkArrayIteratorTemplate.txx"
-VTK_ARRAY_ITERATOR_TEMPLATE_INSTANTIATE(vtkStdString);
-
 #include "vtkStringArray.h"
 
 #include "vtkArrayIteratorTemplate.h"
@@ -51,23 +44,23 @@ class vtkStringArrayLookup
 {
 public:
   vtkStringArrayLookup() : Rebuild(true)
-    {
+  {
     this->SortedArray = NULL;
     this->IndexArray = NULL;
-    }
+  }
   ~vtkStringArrayLookup()
-    {
+  {
     if (this->SortedArray)
-      {
+    {
       this->SortedArray->Delete();
       this->SortedArray = NULL;
-      }
+    }
     if (this->IndexArray)
-      {
+    {
       this->IndexArray->Delete();
       this->IndexArray = NULL;
-      }
     }
+  }
   vtkStringArray* SortedArray;
   vtkIdList* IndexArray;
   vtkStringCachedUpdates CachedUpdates;
@@ -89,10 +82,10 @@ vtkStringArray::vtkStringArray()
 
 vtkStringArray::~vtkStringArray()
 {
-  if ((this->Array) && (!this->SaveUserArray))
-    {
+  if (!this->SaveUserArray)
+  {
     delete [] this->Array;
-    }
+  }
   delete this->Lookup;
 }
 
@@ -116,14 +109,14 @@ vtkArrayIterator* vtkStringArray::NewIterator()
 void vtkStringArray::SetArray(vtkStdString *array, vtkIdType size, int save)
 {
   if ((this->Array) && (!this->SaveUserArray))
-    {
+  {
     vtkDebugMacro (<< "Deleting the array...");
     delete [] this->Array;
-    }
+  }
   else
-    {
+  {
     vtkDebugMacro (<<"Warning, array not deleted, but will point to new array.");
-    }
+  }
 
   vtkDebugMacro(<<"Setting array to: " << array);
 
@@ -140,20 +133,20 @@ void vtkStringArray::SetArray(vtkStdString *array, vtkIdType size, int save)
 int vtkStringArray::Allocate(vtkIdType sz, vtkIdType)
 {
   if(sz > this->Size)
+  {
+    if(!this->SaveUserArray)
     {
-    if(this->Array && !this->SaveUserArray)
-      {
       delete [] this->Array;
-      }
+    }
 
     this->Size = ( sz > 0 ? sz : 1);
     this->Array = new vtkStdString[this->Size];
     if(!this->Array)
-      {
+    {
       return 0;
-      }
-    this->SaveUserArray = 0;
     }
+    this->SaveUserArray = 0;
+  }
 
   this->MaxId = -1;
   this->DataChanged();
@@ -166,10 +159,10 @@ int vtkStringArray::Allocate(vtkIdType sz, vtkIdType)
 
 void vtkStringArray::Initialize()
 {
-  if(this->Array && !this->SaveUserArray)
-    {
+  if(!this->SaveUserArray)
+  {
     delete [] this->Array;
-    }
+  }
   this->Array = 0;
   this->Size = 0;
   this->MaxId = -1;
@@ -184,37 +177,37 @@ void vtkStringArray::DeepCopy(vtkAbstractArray* aa)
 {
   // Do nothing on a NULL input.
   if(!aa)
-    {
+  {
     return;
-    }
+  }
 
   // Avoid self-copy.
   if(this == aa)
-    {
+  {
     return;
-    }
+  }
 
   // If data type does not match, we can't copy.
   if(aa->GetDataType() != this->GetDataType())
-    {
+  {
     vtkErrorMacro(<< "Incompatible types: tried to copy an array of type "
                   << aa->GetDataTypeAsString()
                   << " into a string array ");
     return;
-    }
+  }
 
-  vtkStringArray *fa = vtkStringArray::SafeDownCast( aa );
+  vtkStringArray *fa = vtkArrayDownCast<vtkStringArray>( aa );
   if ( fa == NULL )
-    {
+  {
     vtkErrorMacro(<< "Shouldn't Happen: Couldn't downcast array into a vtkStringArray." );
     return;
-    }
+  }
 
   // Free our previous memory.
-  if(this->Array && !this->SaveUserArray)
-    {
+  if(!this->SaveUserArray)
+  {
     delete [] this->Array;
-    }
+  }
 
   // Copy the given array into new memory.
   this->MaxId = fa->GetMaxId();
@@ -223,9 +216,9 @@ void vtkStringArray::DeepCopy(vtkAbstractArray* aa)
   this->Array = new vtkStdString[this->Size];
 
   for (int i = 0; i < this->Size; ++i)
-    {
+  {
     this->Array[i] = fa->Array[i];
-    }
+  }
   this->DataChanged();
 }
 
@@ -237,17 +230,17 @@ void vtkStringArray::InterpolateTuple(vtkIdType i, vtkIdList *ptIndices,
     vtkAbstractArray* source,  double* weights)
 {
   if (this->GetDataType() != source->GetDataType())
-    {
+  {
     vtkErrorMacro("Cannot CopyValue from array of type "
       << source->GetDataTypeAsString());
     return;
-    }
+  }
 
   if (ptIndices->GetNumberOfIds() == 0)
-    {
+  {
     // nothing to do.
     return;
-    }
+  }
 
   // We use nearest neighbour for interpolating strings.
   // First determine which is the nearest neighbour using the weights-
@@ -255,13 +248,13 @@ void vtkStringArray::InterpolateTuple(vtkIdType i, vtkIdList *ptIndices,
   vtkIdType nearest = ptIndices->GetId(0);
   double max_weight = weights[0];
   for (int k=1; k < ptIndices->GetNumberOfIds(); k++)
-    {
+  {
     if (weights[k] > max_weight)
-      {
+    {
       nearest = ptIndices->GetId(k);
       max_weight = weights[k];
-      }
     }
+  }
 
   this->InsertTuple(i, nearest, source);
 }
@@ -278,21 +271,21 @@ void vtkStringArray::InterpolateTuple(vtkIdType i, vtkIdType id1,
 {
   if (source1->GetDataType() != VTK_STRING ||
     source2->GetDataType() != VTK_STRING)
-    {
+  {
     vtkErrorMacro("All arrays to InterpolateValue() must be of same type.");
     return;
-    }
+  }
 
   if (t >= 0.5)
-    {
+  {
     // Use p2
     this->InsertTuple(i, id2, source2);
-    }
+  }
   else
-    {
+  {
     // Use p1.
     this->InsertTuple(i, id1, source1);
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -300,13 +293,13 @@ void vtkStringArray::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os,indent);
   if(this->Array)
-    {
+  {
     os << indent << "Array: " << this->Array << "\n";
-    }
+  }
   else
-    {
+  {
     os << indent << "Array: (null)\n";
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -318,55 +311,55 @@ vtkStdString * vtkStringArray::ResizeAndExtend(vtkIdType sz)
   vtkIdType newSize;
 
   if(sz > this->Size)
-    {
+  {
     // Requested size is bigger than current size.  Allocate enough
     // memory to fit the requested size and be more than double the
     // currently allocated memory.
     newSize = this->Size + sz;
-    }
+  }
   else if (sz == this->Size)
-    {
+  {
     // Requested size is equal to current size.  Do nothing.
     return this->Array;
-    }
+  }
   else
-    {
+  {
     // Requested size is smaller than current size.  Squeeze the
     // memory.
     newSize = sz;
-    }
+  }
 
   if(newSize <= 0)
-    {
+  {
     this->Initialize();
     return 0;
-    }
+  }
 
   newArray = new vtkStdString[newSize];
   if(!newArray)
-    {
+  {
     vtkErrorMacro("Cannot allocate memory\n");
     return 0;
-    }
+  }
 
   if(this->Array)
-    {
+  {
     // can't use memcpy here
     vtkIdType numCopy = (newSize < this->Size ? newSize : this->Size);
     for (vtkIdType i = 0; i < numCopy; ++i)
-      {
+    {
       newArray[i] = this->Array[i];
-      }
-    if(!this->SaveUserArray)
-      {
-      delete [] this->Array;
-      }
     }
+    if(!this->SaveUserArray)
+    {
+      delete [] this->Array;
+    }
+  }
 
   if(newSize < this->Size)
-    {
+  {
     this->MaxId = newSize-1;
-    }
+  }
   this->Size = newSize;
   this->Array = newArray;
   this->SaveUserArray = 0;
@@ -382,42 +375,42 @@ int vtkStringArray::Resize(vtkIdType sz)
   vtkIdType newSize = sz;
 
   if(newSize == this->Size)
-    {
+  {
     return 1;
-    }
+  }
 
   if(newSize <= 0)
-    {
+  {
     this->Initialize();
     return 1;
-    }
+  }
 
   newArray = new vtkStdString[newSize];
   if(!newArray)
-    {
+  {
     vtkErrorMacro(<< "Cannot allocate memory\n");
     return 0;
-    }
+  }
 
   if(this->Array)
-    {
+  {
     vtkIdType numCopy = (newSize < this->Size ? newSize : this->Size);
 
     for (vtkIdType i = 0; i < numCopy; ++i)
-      {
+    {
       newArray[i] = this->Array[i];
-      }
+    }
 
     if(!this->SaveUserArray)
-      {
+    {
       delete[] this->Array;
-      }
     }
+  }
 
   if(newSize < this->Size)
-    {
+  {
     this->MaxId = newSize-1;
-    }
+  }
   this->Size = newSize;
   this->Array = newArray;
   this->SaveUserArray = 0;
@@ -440,13 +433,13 @@ vtkStdString * vtkStringArray::WritePointer(vtkIdType id,
 {
   vtkIdType newSize=id+number;
   if ( newSize > this->Size )
-    {
+  {
     this->ResizeAndExtend(newSize);
-    }
+  }
   if ( (--newSize) > this->MaxId )
-    {
+  {
     this->MaxId = newSize;
-    }
+  }
   this->DataChanged();
   return this->Array + id;
 }
@@ -455,14 +448,17 @@ vtkStdString * vtkStringArray::WritePointer(vtkIdType id,
 void vtkStringArray::InsertValue(vtkIdType id, vtkStdString f)
 {
   if ( id >= this->Size )
+  {
+    if (!this->ResizeAndExtend(id+1))
     {
-    this->ResizeAndExtend(id+1);
+      return;
     }
+  }
   this->Array[id] = f;
   if ( id > this->MaxId )
-    {
+  {
     this->MaxId = id;
-    }
+  }
   this->DataElementChanged(id);
 }
 
@@ -487,13 +483,13 @@ unsigned long vtkStringArray::GetActualMemorySize( void )
   size_t  numPrims = static_cast<size_t>(this->GetSize());
 
   for (size_t i = 0; i < numPrims; ++i)
-    {
+  {
     totalSize += sizeof( vtkStdString );
     totalSize += this->Array[i].size() *sizeof( vtkStdString::value_type );
-    }
+  }
 
   return static_cast<unsigned long>(
-    ceil(static_cast<double>(totalSize) / 1024.0 )); // kilobytes
+    ceil(static_cast<double>(totalSize) / 1024.0 )); // kibibytes
 }
 
 // ----------------------------------------------------------------------------
@@ -502,10 +498,10 @@ vtkIdType vtkStringArray::GetDataSize()
   size_t size = 0;
   size_t numStrs = static_cast<size_t>(this->GetMaxId() + 1);
   for(size_t i=0; i < numStrs; i++)
-    {
+  {
     size += this->Array[i].size() + 1;
     // (+1) for termination character.
-    }
+  }
   return static_cast<vtkIdType>(size);
 }
 
@@ -517,19 +513,19 @@ vtkIdType vtkStringArray::GetDataSize()
 void vtkStringArray::SetTuple(vtkIdType i, vtkIdType j,
   vtkAbstractArray* source)
 {
-  vtkStringArray* sa = vtkStringArray::SafeDownCast(source);
+  vtkStringArray* sa = vtkArrayDownCast<vtkStringArray>(source);
   if (!sa)
-    {
+  {
     vtkWarningMacro("Input and outputs array data types do not match.");
     return ;
-    }
+  }
 
   vtkIdType loci = i * this->NumberOfComponents;
   vtkIdType locj = j * sa->GetNumberOfComponents();
   for (vtkIdType cur = 0; cur < this->NumberOfComponents; cur++)
-    {
+  {
     this->SetValue(loci + cur, sa->GetValue(locj + cur));
-    }
+  }
   this->DataChanged();
 }
 
@@ -539,19 +535,19 @@ void vtkStringArray::SetTuple(vtkIdType i, vtkIdType j,
 void vtkStringArray::InsertTuple(vtkIdType i, vtkIdType j,
   vtkAbstractArray* source)
 {
-  vtkStringArray* sa = vtkStringArray::SafeDownCast(source);
+  vtkStringArray* sa = vtkArrayDownCast<vtkStringArray>(source);
   if (!sa)
-    {
+  {
     vtkWarningMacro("Input and outputs array data types do not match.");
     return ;
-    }
+  }
 
   vtkIdType loci = i * this->NumberOfComponents;
   vtkIdType locj = j * sa->GetNumberOfComponents();
   for (vtkIdType cur = 0; cur < this->NumberOfComponents; cur++)
-    {
+  {
     this->InsertValue(loci + cur, sa->GetValue(locj + cur));
-    }
+  }
   this->DataChanged();
 }
 
@@ -559,36 +555,36 @@ void vtkStringArray::InsertTuple(vtkIdType i, vtkIdType j,
 void vtkStringArray::InsertTuples(vtkIdList *dstIds, vtkIdList *srcIds,
                                   vtkAbstractArray *source)
 {
-  vtkStringArray* sa = vtkStringArray::SafeDownCast(source);
+  vtkStringArray* sa = vtkArrayDownCast<vtkStringArray>(source);
   if (!sa)
-    {
+  {
     vtkWarningMacro("Input and outputs array data types do not match.");
     return ;
-    }
+  }
 
   if (this->NumberOfComponents != source->GetNumberOfComponents())
-    {
+  {
     vtkWarningMacro("Input and output component sizes do not match.");
     return;
-    }
+  }
 
   vtkIdType numIds = dstIds->GetNumberOfIds();
   if (srcIds->GetNumberOfIds() != numIds)
-    {
+  {
     vtkWarningMacro("Input and output id array sizes do not match.");
     return;
-    }
+  }
 
   for (vtkIdType idIndex = 0; idIndex < numIds; ++idIndex)
-    {
+  {
     vtkIdType numComp = this->NumberOfComponents;
     vtkIdType srcLoc = srcIds->GetId(idIndex) * this->NumberOfComponents;
     vtkIdType dstLoc = dstIds->GetId(idIndex) * this->NumberOfComponents;
     while (numComp-- > 0)
-      {
+    {
       this->InsertValue(dstLoc++, sa->GetValue(srcLoc++));
-      }
     }
+  }
 
   this->DataChanged();
 }
@@ -597,38 +593,38 @@ void vtkStringArray::InsertTuples(vtkIdList *dstIds, vtkIdList *srcIds,
 void vtkStringArray::InsertTuples(vtkIdType dstStart, vtkIdType n,
                                   vtkIdType srcStart, vtkAbstractArray *source)
 {
-  vtkStringArray* sa = vtkStringArray::SafeDownCast(source);
+  vtkStringArray* sa = vtkArrayDownCast<vtkStringArray>(source);
   if (!sa)
-    {
+  {
     vtkWarningMacro("Input and outputs array data types do not match.");
     return ;
-    }
+  }
 
   if (this->NumberOfComponents != source->GetNumberOfComponents())
-    {
+  {
     vtkWarningMacro("Input and output component sizes do not match.");
     return;
-    }
+  }
 
   vtkIdType srcEnd = srcStart + n;
   if (srcEnd > source->GetNumberOfTuples())
-    {
+  {
     vtkWarningMacro("Source range exceeds array size (srcStart=" << srcStart
                     << ", n=" << n << ", numTuples="
                     << source->GetNumberOfTuples() << ").");
     return;
-    }
+  }
 
   for (vtkIdType i = 0; i < n; ++i)
-    {
+  {
     vtkIdType numComp = this->NumberOfComponents;
     vtkIdType srcLoc = (srcStart + i) * this->NumberOfComponents;
     vtkIdType dstLoc = (dstStart + i) * this->NumberOfComponents;
     while (numComp-- > 0)
-      {
+    {
       this->InsertValue(dstLoc++, sa->GetValue(srcLoc++));
-      }
     }
+  }
 
   this->DataChanged();
 }
@@ -640,18 +636,18 @@ void vtkStringArray::InsertTuples(vtkIdType dstStart, vtkIdType n,
 vtkIdType vtkStringArray::InsertNextTuple(vtkIdType j,
                                           vtkAbstractArray* source)
 {
-  vtkStringArray* sa = vtkStringArray::SafeDownCast(source);
+  vtkStringArray* sa = vtkArrayDownCast<vtkStringArray>(source);
   if (!sa)
-    {
+  {
     vtkWarningMacro("Input and outputs array data types do not match.");
     return -1;
-    }
+  }
 
   vtkIdType locj = j * sa->GetNumberOfComponents();
   for (vtkIdType cur = 0; cur < this->NumberOfComponents; cur++)
-    {
+  {
     this->InsertNextValue(sa->GetValue(locj + cur));
-    }
+  }
   this->DataChanged();
   return (this->GetNumberOfTuples()-1);
 }
@@ -666,25 +662,25 @@ vtkStdString& vtkStringArray::GetValue( vtkIdType id )
 void vtkStringArray::GetTuples(vtkIdList *indices, vtkAbstractArray *aa)
 {
   if (aa == NULL)
-    {
+  {
     vtkErrorMacro(<<"GetTuples: Output array is null!");
     return;
-    }
+  }
 
-  vtkStringArray *output = vtkStringArray::SafeDownCast(aa);
+  vtkStringArray *output = vtkArrayDownCast<vtkStringArray>(aa);
 
   if (output == NULL)
-    {
+  {
     vtkErrorMacro(<< "Can't copy values from a string array into an array "
                   << "of type " << aa->GetDataTypeAsString());
     return;
-    }
+  }
 
   for (vtkIdType i = 0; i < indices->GetNumberOfIds(); ++i)
-    {
+  {
     vtkIdType index = indices->GetId(i);
     output->SetValue(i, this->GetValue(index));
-    }
+  }
 }
 
 // ----------------------------------------------------------------------------
@@ -693,38 +689,38 @@ void vtkStringArray::GetTuples(vtkIdType startIndex,
                           vtkAbstractArray *aa)
 {
   if (aa == NULL)
-    {
+  {
     vtkErrorMacro(<<"GetTuples: Output array is null!");
     return;
-    }
+  }
 
-  vtkStringArray *output = vtkStringArray::SafeDownCast(aa);
+  vtkStringArray *output = vtkArrayDownCast<vtkStringArray>(aa);
 
   if (output == NULL)
-    {
+  {
     vtkErrorMacro(<< "Can't copy values from a string array into an array "
                   << "of type " << aa->GetDataTypeAsString());
     return;
-    }
+  }
 
   for (vtkIdType i = 0; i < (endIndex - startIndex) + 1; ++i)
-    {
+  {
     vtkIdType index = startIndex + i;
     output->SetValue(i, this->GetValue(index));
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
 void vtkStringArray::UpdateLookup()
 {
   if (!this->Lookup)
-    {
+  {
     this->Lookup = new vtkStringArrayLookup();
     this->Lookup->SortedArray = vtkStringArray::New();
     this->Lookup->IndexArray = vtkIdList::New();
-    }
+  }
   if (this->Lookup->Rebuild)
-    {
+  {
     int numComps = this->GetNumberOfComponents();
     vtkIdType numTuples = this->GetNumberOfTuples();
     this->Lookup->SortedArray->Initialize();
@@ -733,18 +729,18 @@ void vtkStringArray::UpdateLookup()
     this->Lookup->IndexArray->SetNumberOfIds(numComps*numTuples);
     std::vector<std::pair<vtkStdString, vtkIdType> > v;
     for (vtkIdType i = 0; i < numComps*numTuples; i++)
-      {
+    {
       v.push_back(std::pair<vtkStdString, vtkIdType>(this->Array[i], i));
-      }
+    }
     std::sort(v.begin(), v.end());
     for (vtkIdType i = 0; i < numComps*numTuples; i++)
-      {
+    {
       this->Lookup->SortedArray->SetValue(i, v[i].first);
       this->Lookup->IndexArray->SetId(i, v[i].second);
-      }
+    }
     this->Lookup->Rebuild = false;
     this->Lookup->CachedUpdates.clear();
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -773,25 +769,25 @@ vtkIdType vtkStringArray::LookupValue(vtkStdString value)
   CacheIterator cached    = this->Lookup->CachedUpdates.lower_bound(value),
                 cachedEnd = this->Lookup->CachedUpdates.end();
   while (cached != cachedEnd)
-    {
+  {
     // Check that we are still in the same equivalence class as the
     // value.
     if (value == cached->first)
-      {
+    {
       // Check that the value in the original array hasn't changed.
       vtkStdString currentValue = this->GetValue(cached->second);
       if (value == currentValue)
-        {
-        return cached->second;
-        }
-      }
-    else
       {
-      break;
+        return cached->second;
       }
+    }
+    else
+    {
+      break;
+    }
 
     ++cached;
-    }
+  }
 
   int numComps = this->Lookup->SortedArray->GetNumberOfComponents();
   vtkIdType numTuples = this->Lookup->SortedArray->GetNumberOfTuples();
@@ -804,7 +800,7 @@ vtkIdType vtkStringArray::LookupValue(vtkStdString value)
   // changed (so the sorted array is out-of-date).
   vtkIdType offset = static_cast<vtkIdType>(found - ptr);
   while (found != ptrEnd)
-    {
+  {
     // Check whether we still have a value equivalent to what we're
     // looking for.
       if (value == *found)
@@ -813,18 +809,18 @@ vtkIdType vtkStringArray::LookupValue(vtkStdString value)
       vtkIdType index = this->Lookup->IndexArray->GetId(offset);
       vtkStdString currentValue = this->GetValue(index);
       if (value == currentValue)
-        {
+      {
         return index;
-        }
+      }
       }
     else
-      {
+    {
       break;
-      }
+    }
 
     ++found;
     ++offset;
-    }
+  }
 
   return -1;
 }
@@ -844,16 +840,16 @@ void vtkStringArray::LookupValue(vtkStdString value, vtkIdList* ids)
   std::pair<CacheIterator, CacheIterator> cached
     = this->Lookup->CachedUpdates.equal_range(value);
   while (cached.first != cached.second)
-    {
+  {
     // Check that the value in the original array hasn't changed.
     vtkStdString currentValue = this->GetValue(cached.first->second);
     if (cached.first->first == currentValue)
-      {
+    {
       ids->InsertNextId(cached.first->second);
-      }
+    }
 
     ++cached.first;
-    }
+  }
 
   // Perform a binary search of the sorted array using STL equal_range.
   int numComps = this->GetNumberOfComponents();
@@ -865,54 +861,54 @@ void vtkStringArray::LookupValue(vtkStdString value, vtkIdList* ids)
   // Add the indices of the found items to the ID list.
   vtkIdType offset = static_cast<vtkIdType>(found.first - ptr);
   while (found.first != found.second)
-    {
+  {
     // Check that the value in the original array hasn't changed.
     vtkIdType index = this->Lookup->IndexArray->GetId(offset);
     vtkStdString currentValue = this->GetValue(index);
     if (*found.first == currentValue)
-      {
+    {
       ids->InsertNextId(index);
-      }
+    }
 
     ++found.first;
     ++offset;
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
 void vtkStringArray::DataChanged()
 {
   if (this->Lookup)
-    {
+  {
     this->Lookup->Rebuild = true;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkStringArray::DataElementChanged(vtkIdType id)
 {
   if (this->Lookup)
-    {
+  {
       if (this->Lookup->Rebuild)
-        {
+      {
         // We're already going to rebuild the lookup table. Do nothing.
         return;
-        }
+      }
 
       if (this->Lookup->CachedUpdates.size() >
           static_cast<size_t>(this->GetNumberOfTuples()/10))
-        {
+      {
         // At this point, just rebuild the full table.
         this->Lookup->Rebuild = true;
-        }
+      }
       else
-        {
+      {
         // Insert this change into the set of cached updates
         std::pair<const vtkStdString, vtkIdType>
           value(this->GetValue(id), id);
         this->Lookup->CachedUpdates.insert(value);
-        }
-    }
+      }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -937,17 +933,17 @@ void vtkStringArray::ClearLookup()
 void vtkStringArray::SetValue( vtkIdType id, const char *value )
 {
   if( value )
-    {
+  {
     this->SetValue( id, vtkStdString(value) );
-    }
+  }
 }
 
 void vtkStringArray::InsertValue( vtkIdType id, const char *value )
 {
   if( value )
-    {
+  {
     this->InsertValue( id, vtkStdString( value ) );
-    }
+  }
 }
 
 void vtkStringArray::SetVariantValue( vtkIdType id, vtkVariant value )
@@ -955,31 +951,36 @@ void vtkStringArray::SetVariantValue( vtkIdType id, vtkVariant value )
   this->SetValue( id, value.ToString() );
 }
 
+void vtkStringArray::InsertVariantValue( vtkIdType id, vtkVariant value )
+{
+  this->InsertValue( id, value.ToString() );
+}
+
 vtkIdType vtkStringArray::InsertNextValue( const char *value )
 {
   if( value )
-    {
+  {
     return this->InsertNextValue( vtkStdString( value ) );
-    }
+  }
   return this->MaxId;
 }
 
 vtkIdType vtkStringArray::LookupValue( const char *value )
 {
   if( value )
-    {
+  {
     return this->LookupValue( vtkStdString( value ) );
-    }
+  }
   return -1;
 }
 
 void vtkStringArray::LookupValue( const char *value, vtkIdList* ids)
 {
   if( value )
-    {
+  {
     this->LookupValue( vtkStdString( value ), ids);
     return;
-    }
+  }
   ids->Reset();
 }
 
