@@ -46,40 +46,40 @@ namespace
   {
   public:
     SortPoints( int N )
-      {
+    {
         this->NumberPoints = 0;
         this->NumRequested = N;
         this->LargestDist2 = VTK_DOUBLE_MAX;
-      }
+    }
 
     void InsertPoint( double dist2, vtkIdType pntId )
-      {
+    {
         // a new pair may be inserted as long as the squared distance is less
         // than the largest one of the current map OR the number of inserted
         // points is still less than that of requested points
         if (    dist2 <= this->LargestDist2
              || this->NumberPoints < this->NumRequested
            )
-          {
+        {
           this->NumberPoints ++;
           std::map<  double,  std::list< vtkIdType >  >::iterator
             it = this->dist2ToIds.find( dist2 );
 
           if ( it == this->dist2ToIds.end() )
-            {
+          {
             // no any entry corresponds to this squared distance
             std::list< vtkIdType >   idset;
             idset.push_back( pntId );
             this->dist2ToIds[ dist2 ] = idset;
-            }
+          }
           else
-            {
+          {
             // there is an entry corresponding to this squared distance
             it->second.push_back( pntId );
-            }
+          }
 
           if ( this->NumberPoints > this->NumRequested )
-            {
+          {
             // we need to go to the very last entry
             it = this->dist2ToIds.end();
             it --;
@@ -92,20 +92,20 @@ namespace
             if (   this->NumberPoints - it->second.size()
                  > this->NumRequested
                )
-              {
+            {
               this->NumberPoints -= it->second.size();
               std::map<  double,  std::list< vtkIdType >  >::iterator
                 it2 = it;
               it2 --;
               this->LargestDist2 = it2->first;
               this->dist2ToIds.erase( it );
-              }
             }
           }
-      }
+        }
+    }
 
     void GetSortedIds( vtkIdList * idList )
-      {
+    {
         // determine how many points will be actually exported
         idList->Reset();
         vtkIdType numIds = ( this->NumRequested < this->NumberPoints )
@@ -120,24 +120,24 @@ namespace
 
         // export the point indices
         while ( counter < numIds && it != this->dist2ToIds.end() )
-          {
+        {
           std::list<vtkIdType>::iterator lit = it->second.begin();
 
           while ( counter < numIds && lit != it->second.end() )
-            {
+          {
             idList->InsertId( counter, *lit );
             counter ++;
             lit ++;
-            }
+          }
 
           it ++;
-          }
-      }
+        }
+    }
 
     double GetLargestDist2()
-      {
+    {
         return this->LargestDist2;
-      }
+    }
 
   private:
     size_t  NumRequested;
@@ -174,33 +174,33 @@ void vtkIncrementalOctreePointLocator::DeleteAllDescendants
   ( vtkIncrementalOctreeNode * node )
 {
   if ( node->IsLeaf() == 0 )
-    {
+  {
     for ( int i = 0; i < 8; i ++ )
-      {
+    {
       vtkIncrementalOctreeNode * child = node->GetChild( i );
       vtkIncrementalOctreePointLocator::DeleteAllDescendants( child );
       child = NULL;
-      }
-    node->DeleteChildNodes();
     }
+    node->DeleteChildNodes();
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkIncrementalOctreePointLocator::FreeSearchStructure()
 {
   if ( this->OctreeRootNode )
-    {
+  {
     vtkIncrementalOctreePointLocator::DeleteAllDescendants
                                       ( this->OctreeRootNode );
     this->OctreeRootNode->Delete();
     this->OctreeRootNode = NULL;
-    }
+  }
 
   if ( this->LocatorPoints )
-    {
+  {
     this->LocatorPoints->UnRegister( this );
     this->LocatorPoints = NULL;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -215,7 +215,7 @@ int vtkIncrementalOctreePointLocator::GetNumberOfPoints()
 void vtkIncrementalOctreePointLocator::GetBounds( double * bounds )
 {
   if ( this->OctreeRootNode )
-    {
+  {
     double *    minBounds = this->OctreeRootNode->GetMinBounds();
     double *    maxBounds = this->OctreeRootNode->GetMaxBounds();
     bounds[0] = minBounds[0];
@@ -225,7 +225,7 @@ void vtkIncrementalOctreePointLocator::GetBounds( double * bounds )
     bounds[4] = minBounds[2];
     bounds[5] = maxBounds[2];
     minBounds = maxBounds = NULL;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -247,34 +247,32 @@ vtkIdType vtkIncrementalOctreePointLocator::FindClosestInsertedPoint
        this->OctreeRootNode->GetNumberOfPoints() == 0 ||
        this->OctreeRootNode->ContainsPoint( x )  == 0
      )
-    {
+  {
     return -1;
-    }
+  }
 
   double    miniDist2 = this->OctreeMaxDimSize * this->OctreeMaxDimSize * 4.0;
   double    elseDist2;      // inter-node search
   vtkIdType elsePntId;      // inter-node search
-  vtkIdType pointIndx = -1;
-  vtkIncrementalOctreeNode * pLeafNode = NULL;
 
-  pLeafNode = this->GetLeafContainer( this->OctreeRootNode, x );
-  pointIndx = this->FindClosestPointInLeafNode( pLeafNode, x, &miniDist2 );
+  vtkIncrementalOctreeNode * pLeafNode = this->GetLeafContainer( this->OctreeRootNode, x );
+  vtkIdType pointIndx = this->FindClosestPointInLeafNode( pLeafNode, x, &miniDist2 );
 
   if ( miniDist2 > 0.0 )
-    {
+  {
     if (   pLeafNode->GetDistance2ToInnerBoundary( x, this->OctreeRootNode )
          < miniDist2
        )
-      {
+    {
       elsePntId = this->FindClosestPointInSphereWithoutTolerance
                         ( x, miniDist2, pLeafNode, &elseDist2 );
       if ( elseDist2 < miniDist2 )
-        {
+      {
         pointIndx = elsePntId;
         miniDist2 = elseDist2;
-        }
       }
     }
+  }
 
   pLeafNode = NULL;
   return pointIndx;
@@ -299,11 +297,11 @@ void vtkIncrementalOctreePointLocator::GenerateRepresentation
   ( int nodeLevel, vtkPolyData * polysData )
 {
   if ( this->OctreeRootNode == NULL )
-    {
+  {
     vtkErrorMacro( "vtkIncrementalOctreePointLocator::GenerateRepresentation" );
     vtkErrorMacro( "(): the octree is not yet available" );
     return;
-    }
+  }
 
   int            tempLevel;
   vtkPoints    * thePoints = NULL;
@@ -315,27 +313,27 @@ void vtkIncrementalOctreePointLocator::GenerateRepresentation
   // recursively process the nodes in the octree
   pairQueue.push(  std::make_pair( this->OctreeRootNode, 0 )  );
   while ( !pairQueue.empty() )
-    {
+  {
     pTempNode = pairQueue.front().first;
     tempLevel = pairQueue.front().second;
     pairQueue.pop();
 
     if ( tempLevel == nodeLevel )
-      {
+    {
       nodesList.push_back( pTempNode );
-      }
+    }
     else
     if ( !pTempNode->IsLeaf() )
-      {
+    {
       for ( int i = 0; i < 8; i ++ )
-        {
+      {
         pairQueue.push(    std::make_pair(  pTempNode->GetChild( i ),
                                                nodeLevel + 1
                                             )
                       );
-        }
       }
     }
+  }
 
   // collect the vertices and quads of each node
   thePoints = vtkPoints::New();
@@ -344,9 +342,9 @@ void vtkIncrementalOctreePointLocator::GenerateRepresentation
   nodeQuads->Allocate(  6  *  static_cast < int > ( nodesList.size() )  );
   for ( std::list< vtkIncrementalOctreeNode * >::iterator
         lit = nodesList.begin(); lit != nodesList.end(); lit ++ )
-    {
+  {
     vtkIncrementalOctreePointLocator::AddPolys( *lit, thePoints, nodeQuads );
-    }
+  }
 
   // attach points and quads
   polysData->SetPoints( thePoints );
@@ -378,21 +376,21 @@ void vtkIncrementalOctreePointLocator::AddPolys
 
   node->GetBounds( bounds );
   for ( i = 0; i < 8; i ++ )
-    {
+  {
     ptCord[0] = bounds[ i & 1 ];
     ptCord[1] = bounds[ i & 2 ];
     ptCord[2] = bounds[ i & 4 ];
     pntIds[i] = points->InsertNextPoint( ptCord );
-    }
+  }
 
   for ( i = 0; i < 6; i ++ )
-    {
+  {
     idList[0] = pntIds[ OCTREE_NODE_FACES_LUT[i][0] ];
     idList[1] = pntIds[ OCTREE_NODE_FACES_LUT[i][1] ];
     idList[2] = pntIds[ OCTREE_NODE_FACES_LUT[i][2] ];
     idList[3] = pntIds[ OCTREE_NODE_FACES_LUT[i][3] ];
     polygs->InsertNextCell( 4, idList );
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -406,9 +404,9 @@ vtkIdType vtkIncrementalOctreePointLocator::FindClosestPointInLeafNode
   *dist2 = VTK_DOUBLE_MAX;
 
   if ( leafNode->GetPointIdSet() == NULL )
-    {
+  {
     return -1;
-    }
+  }
 
   int         numPts = 0;
   double      tmpDst = 0.0;
@@ -421,21 +419,21 @@ vtkIdType vtkIncrementalOctreePointLocator::FindClosestPointInLeafNode
   numPts = idList->GetNumberOfIds( );
 
   for ( int i = 0; i < numPts; i ++ )
-    {
+  {
     tmpIdx  = idList->GetId( i );
     this->LocatorPoints->GetPoint( tmpIdx, tmpPnt );
     tmpDst  = vtkMath::Distance2BetweenPoints( tmpPnt, point );
     if (  tmpDst  <  ( *dist2 )  )
-      {
+    {
       *dist2  = tmpDst;
       pntIdx  = tmpIdx;
-      }
+    }
 
     if (  ( *dist2 )  ==  0.0  )
-      {
+    {
       break;
-      }
     }
+  }
 
   idList = NULL;
 
@@ -452,14 +450,14 @@ vtkIdType vtkIncrementalOctreePointLocator::FindClosestPointInSphere
   nodesBase.push( this->OctreeRootNode );
 
   while ( !nodesBase.empty() && ( *minDist2 ) > 0.0 )
-    {
+  {
     vtkIncrementalOctreeNode * checkNode = nodesBase.top();
     nodesBase.pop();
 
     if ( !checkNode->IsLeaf() )
-      {
+    {
       for ( int i = 0; i < 8; i ++ )
-        {
+      {
         vtkIncrementalOctreeNode * childNode = checkNode->GetChild( i );
 
         // use ( radius2 + radius2 ) to skip empty nodes
@@ -477,15 +475,15 @@ vtkIdType vtkIncrementalOctreePointLocator::FindClosestPointInSphere
                   || (  childNode->ContainsPoint( point )  ==  1  )
                 )
            )
-          {
+        {
           nodesBase.push( childNode );
-          }
+        }
 
         childNode = NULL;
-        }
       }
+    }
     else
-      {
+    {
       // now that the node under check is a leaf, let's find the closest
       // point therein and the minimum distance
       double tempDist2;
@@ -493,14 +491,14 @@ vtkIdType vtkIncrementalOctreePointLocator::FindClosestPointInSphere
                                ( checkNode, point, &tempDist2 );
 
       if (  tempDist2  <  ( *minDist2 )  )
-        {
+      {
         *minDist2 = tempDist2;
         pointIndx = tempPntId;
-        }
       }
+    }
 
     checkNode = NULL;
-    }
+  }
 
   return  (  ( *minDist2 )  <=  radius2  )  ?  pointIndx  :  -1;
 }
@@ -514,28 +512,28 @@ void vtkIncrementalOctreePointLocator::BuildLocator()
 {
   // assume point location is necessary for vtkPointSet data only
   if ( !this->DataSet || !this->DataSet->IsA( "vtkPointSet" ) )
-    {
+  {
     vtkErrorMacro( "Dataset is NULL or it is not of type vtkPointSet" );
     return;
-    }
+  }
 
   int  numPoints = this->DataSet->GetNumberOfPoints();
   if ( numPoints < 1 || numPoints >= VTK_INT_MAX )
-    {
+  {
     // current implementation does not support 64-bit point indices
     // due to performance consideration
     vtkErrorMacro( << "No points to build an octree with or " );
     vtkErrorMacro( << "failure to support 64-bit point ids"  );
     return;
-    }
+  }
 
   // construct an octree only if necessary
   if (    ( this->BuildTime > this->MTime )
        && ( this->BuildTime > this->DataSet->GetMTime() )
      )
-    {
+  {
     return;
-    }
+  }
   vtkDebugMacro( << "Creating an incremental octree" );
 
   // build an octree by populating it with check-free insertion of point ids
@@ -548,14 +546,14 @@ void vtkIncrementalOctreePointLocator::BuildLocator()
   this->InitPointInsertion( thePoints, theBounds );
 
   for ( pointIndx = 0; pointIndx < numPoints; pointIndx ++ )
-    {
+  {
     thePoints->GetPoint( pointIndx, theCoords );
 
     // the 3D point coordinate is actually not inserted to vtkPoints at all
     // while only the point index is inserted to the vtkIdList of the
     // container leaf
     this->InsertPointWithoutChecking( theCoords, pointIndx, 0 );
-    }
+  }
   thePoints = NULL;
 
   this->BuildTime.Modified();
@@ -608,9 +606,9 @@ vtkIdType vtkIncrementalOctreePointLocator::FindClosestPoint
   if ( this->OctreeRootNode == NULL ||
        this->OctreeRootNode->GetNumberOfPoints() == 0
      )
-    {
+  {
     return -1;
-    }
+  }
 
   double    elseDist2;      // inter-node search
   vtkIdType elsePntId;      // inter-node search
@@ -618,28 +616,28 @@ vtkIdType vtkIncrementalOctreePointLocator::FindClosestPoint
   vtkIncrementalOctreeNode * pLeafNode = NULL;
 
   if (  this->OctreeRootNode->ContainsPoint( x )  )
-    {  // the point is inside the octree
+  {  // the point is inside the octree
     pLeafNode = this->GetLeafContainer( this->OctreeRootNode, x );
     pointIndx = this->FindClosestPointInLeafNode( pLeafNode, x, miniDist2 );
 
     if (  ( *miniDist2 )  >  0.0  )
-      {
+    {
       if (   pLeafNode->GetDistance2ToInnerBoundary( x, this->OctreeRootNode )
            < ( *miniDist2 )
          )
-        {
+      {
         elsePntId = this->FindClosestPointInSphereWithoutTolerance
                           ( x, *miniDist2, pLeafNode, &elseDist2 );
         if (  elseDist2  <  ( *miniDist2)  )
-          {
+        {
           pointIndx  = elsePntId;
           *miniDist2 = elseDist2;
-          }
         }
       }
     }
+  }
   else // the point is outside the octree
-    {
+  {
     double   initialPt[3];
     double * minBounds = this->OctreeRootNode->GetMinBounds();
     double * maxBounds = this->OctreeRootNode->GetMaxBounds();
@@ -648,34 +646,34 @@ vtkIdType vtkIncrementalOctreePointLocator::FindClosestPoint
 
     // This initial (closest) point might be outside the octree a little bit
     if ( initialPt[0] <= minBounds[0] )
-      {
+    {
       initialPt[0] = minBounds[0] + this->FudgeFactor;
-      }
+    }
     else
     if ( initialPt[0] >= maxBounds[0] )
-      {
+    {
       initialPt[0] = maxBounds[0] - this->FudgeFactor;
-      }
+    }
 
     if ( initialPt[1] <= minBounds[1] )
-      {
+    {
       initialPt[1] = minBounds[1] + this->FudgeFactor;
-      }
+    }
     else
     if ( initialPt[1] >= maxBounds[1] )
-      {
+    {
       initialPt[1] = maxBounds[1] - this->FudgeFactor;
-      }
+    }
 
     if ( initialPt[2] <= minBounds[2] )
-      {
+    {
       initialPt[2] = minBounds[2] + this->FudgeFactor;
-      }
+    }
     else
     if ( initialPt[2] >= maxBounds[2] )
-      {
+    {
       initialPt[2] = maxBounds[2] - this->FudgeFactor;
-      }
+    }
 
     pLeafNode = this->GetLeafContainer( this->OctreeRootNode, initialPt );
     pointIndx = this->FindClosestPointInLeafNode( pLeafNode, x, miniDist2 );
@@ -683,13 +681,13 @@ vtkIdType vtkIncrementalOctreePointLocator::FindClosestPoint
                       ( x, *miniDist2,  pLeafNode, &elseDist2 );
 
     if (  elseDist2  <  ( *miniDist2 )  )
-      {
+    {
       pointIndx  = elsePntId;
       *miniDist2 = elseDist2;
-      }
+    }
 
     minBounds = maxBounds = NULL;
-    }
+  }
 
   pLeafNode = NULL;
   return pointIndx;
@@ -734,74 +732,74 @@ void vtkIncrementalOctreePointLocator::FindPointsWithinSquaredRadius
   node->GetBounds( nodeBounds );
 
   for ( i = 0; i < 3; i ++ ) // for each axis
-    {
+  {
     j = ( i << 1 );
     tempValue0 = point[i] - nodeBounds[j];
     tempValue1 = nodeBounds[ j + 1 ] - point[i];
 
     if ( tempValue0 < 0.0 )
-      {
+    {
       outMinDst2 += tempValue0 * tempValue0;
       maximDist2 += tempValue1 * tempValue1;
-      }
+    }
     else
     if ( tempValue1 < 0.0 )
-      {
+    {
       outMinDst2 += tempValue1 * tempValue1;
       maximDist2 += tempValue0 * tempValue0;
-      }
+    }
     else
     if ( tempValue1 > tempValue0 )
-      {
+    {
       maximDist2 += tempValue1 * tempValue1;
-      }
-    else
-      {
-      maximDist2 += tempValue0 * tempValue0;
-      }
     }
+    else
+    {
+      maximDist2 += tempValue0 * tempValue0;
+    }
+  }
 
   if ( outMinDst2 > radius2 )
-    {
+  {
     // the node is totally outside the search sphere
     return;
-    }
+  }
 
   if ( maximDist2 <= radius2 )
-    {
+  {
     // the node is totally inside the search sphere
     node->ExportAllPointIdsByInsertion( idList );
     return;
-    }
+  }
 
   // the node intersects with, but is not totally inside, the search sphere
   if ( node->IsLeaf() )
-    {
+  {
     numberPnts = node->GetNumberOfPoints();
     nodePntIds = node->GetPointIdSet();
 
     for ( localIndex = 0; localIndex < numberPnts; localIndex ++ )
-      {
+    {
       pointIndex = nodePntIds->GetId( localIndex );
       this->LocatorPoints->GetPoint( pointIndex, pointCoord );
 
       pt2PtDist2 = vtkMath::Distance2BetweenPoints( pointCoord, point );
       if ( pt2PtDist2 <= radius2 )
-        {
+      {
         idList->InsertNextId( pointIndex );
-        }
       }
+    }
 
     nodePntIds = NULL;
-    }
+  }
   else
-    {
+  {
     for ( i = 0; i < 8; i ++ )
-      {
+    {
       this->FindPointsWithinSquaredRadius(  node->GetChild( i ),
                                             radius2,  point,  idList  );
-      }
     }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -833,16 +831,16 @@ void vtkIncrementalOctreePointLocator::FindClosestNPoints
   int  totalPnts = this->OctreeRootNode->GetNumberOfPoints(); // possibly 0
 
   if ( N > totalPnts )
-    {
+  {
     N = totalPnts;
     vtkWarningMacro( "Number of requested points > that of available points" );
-    }
+  }
 
   if ( N <= 0 )
-    {
+  {
     vtkWarningMacro( "invalid N or the octree is still empty" );
     return;
-    }
+  }
 
 
   // We are going to find the lowest-possible node to start with, startNode,
@@ -883,24 +881,24 @@ void vtkIncrementalOctreePointLocator::FindClosestNPoints
   beenFound = 0;
   numPoints = pThisNode->GetNumberOfPoints();
   while ( beenFound == 0 )
-    {
+  {
     if (  pThisNode->ContainsPoint( x )  )      // point inside the node
-      {
+    {
       while (  !pThisNode->IsLeaf()  &&  numPoints > N  )
-        {
+      {
         theParent = pThisNode;
         pThisNode = pThisNode->GetChild(  pThisNode->GetChildIndex( x )  );
         numPoints = pThisNode->GetNumberOfPoints();
-        }
+      }
 
       if ( numPoints )
-        {
+      {
         // The point is still inside pThisNode
         beenFound = 1;
         pThisNode = ( numPoints >= N ) ? pThisNode : theParent;
-        }
+      }
       else
-        {
+      {
         // The point is inside an empty node (pThisNode), but outside the node
         // with closest points --- the closest node (a sibling of pThisNode).
         // We need to locate this closest node via the parent node and proceed
@@ -908,47 +906,47 @@ void vtkIncrementalOctreePointLocator::FindClosestNPoints
         // means of the other case (point outside the node).
         miniDist2 = VTK_DOUBLE_MAX;
         for ( i = 0; i < 8; i ++ )
-          {
+        {
           pTheChild = theParent->GetChild( i );
           tempDist2 = pTheChild->GetDistance2ToBoundary
                                  ( x, this->OctreeRootNode, 1 );
           if ( tempDist2 < miniDist2 )
-            {
+          {
             miniDist2 = tempDist2;
             pThisNode = pTheChild;
-            }
           }
         }
       }
+    }
     else                                        // point outside the node
-      {
+    {
       while (  !pThisNode->IsLeaf()  &&  numPoints  >  N  )
-        {
+      {
         // find the child closest (in terms of data) to the given point
         theParent = pThisNode;
         miniDist2 = VTK_DOUBLE_MAX;
         for ( i = 0; i < 8; i ++ )
-          {
+        {
           pTheChild = theParent->GetChild( i );
           tempDist2 = pTheChild->GetDistance2ToBoundary
                                  ( x, this->OctreeRootNode, 1 );
           if ( tempDist2 < miniDist2 )
-            {
+          {
             miniDist2 = tempDist2;
             pThisNode = pTheChild;
-            }
           }
-        numPoints = pThisNode->GetNumberOfPoints();
         }
+        numPoints = pThisNode->GetNumberOfPoints();
+      }
 
       beenFound = 1;
       pThisNode = ( numPoints >= N ) ? pThisNode : theParent;
-      }
+    }
 
     // update the number of points in the node in case of a switch from point-
     // inside-the-node to point-outside-the-node.
     numPoints = pThisNode->GetNumberOfPoints();
-    }
+  }
 
   // this is where we can get the really most compact starting node
   startNode = pThisNode;
@@ -963,47 +961,47 @@ void vtkIncrementalOctreePointLocator::FindClosestNPoints
   startNode->ExportAllPointIdsByDirectSet( &pointIndx, pntIdList );
 
   for ( i = 0; i < numPoints; i ++ )
-    {
+  {
     pointIndx = pntIdList->GetId( i );
     this->LocatorPoints->GetPoint( pointIndx, pntCoords );
     tempDist2 = vtkMath::Distance2BetweenPoints( x, pntCoords );
     ptsSorter.InsertPoint( tempDist2, pointIndx );
-    }
+  }
 
 
   // We still need to check other nodes in case they contain closer points
   nodeQueue.push( this->OctreeRootNode );
   maxiDist2 = ptsSorter.GetLargestDist2();
   while ( !nodeQueue.empty() )
-    {
+  {
     pThisNode = nodeQueue.front();
     nodeQueue.pop();
 
     // skip the start node as we have just processed it
     if ( pThisNode == startNode )
-      {
+    {
       continue;
-      }
+    }
 
     if ( !pThisNode->IsLeaf() )
-      {
+    {
       // this is a non-leaf node and we need to push some children if necessary
       for ( i = 0; i < 8; i ++ )
-        {
+      {
         pTheChild = pThisNode->GetChild( i );
         if (    pTheChild->ContainsPointByData( x ) == 1
              || pTheChild->GetDistance2ToBoundary( x, this->OctreeRootNode, 1 )
                 < maxiDist2
            )
-          {
+        {
           nodeQueue.push( pTheChild );
-          }
         }
       }
+    }
     else
     if (  pThisNode->GetDistance2ToBoundary( x, this->OctreeRootNode, 1 )
         < maxiDist2  )
-      {
+    {
       // This is a leaf node AND its data bounding box is close enough for us
       // to process the points inside the node. Note that the success of the
       // above distance check indicates that there is at least one point in
@@ -1019,17 +1017,17 @@ void vtkIncrementalOctreePointLocator::FindClosestNPoints
 
       // insert the points to the sorter if necessary
       for ( i = 0; i < numPoints; i ++ )
-        {
+      {
         pointIndx = pntIdList->GetId( i );
         this->LocatorPoints->GetPoint( pointIndx, pntCoords );
         tempDist2 = vtkMath::Distance2BetweenPoints( x, pntCoords );
         ptsSorter.InsertPoint( tempDist2, pointIndx );
-        }
+      }
 
       // as we might have inserted some points, we need to update maxiDist2
       maxiDist2 = ptsSorter.GetLargestDist2();
-      }
     }
+  }
 
 
   // obtain the point indices
@@ -1065,19 +1063,19 @@ int vtkIncrementalOctreePointLocator::InitPointInsertion( vtkPoints * points,
   double  dimDiff[3], tmpBbox[6];
 
   if ( points == NULL )
-    {
+  {
     vtkErrorMacro( << "a valid vtkPoints object required for point insertion" );
     return 0;
-    }
+  }
 
   // destroy the existing octree, if any
   this->FreeSearchStructure();
 
   // detach the old vtkPoints object, if any, before attaching a new one
   if ( this->LocatorPoints != NULL )
-    {
+  {
     this->LocatorPoints->UnRegister( this );
-    }
+  }
   this->LocatorPoints = points;
   this->LocatorPoints->Register( this );
 
@@ -1091,47 +1089,47 @@ int vtkIncrementalOctreePointLocator::InitPointInsertion( vtkPoints * points,
   //     "inside" range r = [r1, r2] if and only if r1 < p <= r2.
   this->OctreeMaxDimSize = 0.0;
   for ( i = 0; i < 3; i ++ )
-    {
+  {
     bbIndex = ( i << 1 );
     tmpBbox[ bbIndex     ] = bounds[ bbIndex     ];
     tmpBbox[ bbIndex + 1 ] = bounds[ bbIndex + 1 ];
     dimDiff[i] = tmpBbox[ bbIndex + 1 ] - tmpBbox[ bbIndex ];
     this->OctreeMaxDimSize = ( dimDiff[i] > this->OctreeMaxDimSize )
                              ? dimDiff[i] : this->OctreeMaxDimSize;
-    }
+  }
 
   if ( this->BuildCubicOctree )
-    {
+  {
     // make the bounding box a cube and hence descendant octants cubes too
     for ( i = 0; i < 3; i ++ )
-      {
+    {
       if ( dimDiff[i] != this->OctreeMaxDimSize )
-        {
+      {
         double delta = this->OctreeMaxDimSize - dimDiff[i];
         tmpBbox[   i << 1       ] -= 0.5 * delta;
         tmpBbox[ ( i << 1 ) + 1 ] += 0.5 * delta;
         dimDiff[i] = this->OctreeMaxDimSize;
-        }
       }
     }
+  }
 
   this->FudgeFactor  = this->OctreeMaxDimSize * 10e-6;
   double minSideSize = this->OctreeMaxDimSize * 10e-2;
 
   for ( i = 0; i < 3; i ++ )
-    {
+  {
     if ( dimDiff[i] < minSideSize ) // case (1) above
-      {
+    {
       bbIndex  =  ( i << 1 );
       double  tempVal = tmpBbox[ bbIndex ];
       tmpBbox[ bbIndex     ] = tmpBbox[ bbIndex + 1 ] - minSideSize;
       tmpBbox[ bbIndex + 1 ] = tempVal + minSideSize;
-      }
-    else                             // case (2) above
-      {
-      tmpBbox[ i << 1 ] -= this->FudgeFactor;
-      }
     }
+    else                             // case (2) above
+    {
+      tmpBbox[ i << 1 ] -= this->FudgeFactor;
+    }
+  }
 
   // init the octree with an empty leaf node
   this->OctreeRootNode = vtkIncrementalOctreeNode::New();
@@ -1176,7 +1174,7 @@ vtkIdType vtkIncrementalOctreePointLocator::FindDuplicateFloatTypePointInVisited
            ->GetPointer( 0 );
 
   for ( int i = 0; i < numPts; i ++ )
-    {
+  {
     tmpIdx = idList->GetId( i );
     tmpPnt = pFloat + (  ( tmpIdx << 1 )  +  tmpIdx  );
 
@@ -1184,11 +1182,11 @@ vtkIdType vtkIncrementalOctreePointLocator::FindDuplicateFloatTypePointInVisited
           ( thePnt[1] == tmpPnt[1] ) &&
           ( thePnt[2] == tmpPnt[2] )
        )
-      {
+    {
       pntIdx = tmpIdx;
       break;
-      }
     }
+  }
 
   pFloat = NULL;
   tmpPnt = NULL;
@@ -1214,7 +1212,7 @@ vtkIdType vtkIncrementalOctreePointLocator::FindDuplicateDoubleTypePointInVisite
            ->GetPointer( 0 );
 
   for ( int i = 0; i < numPts; i ++ )
-    {
+  {
     tmpIdx = idList->GetId( i );
     tmpPnt = pArray + (  ( tmpIdx << 1 )  +  tmpIdx  );
 
@@ -1222,11 +1220,11 @@ vtkIdType vtkIncrementalOctreePointLocator::FindDuplicateDoubleTypePointInVisite
           ( point[1] == tmpPnt[1] ) &&
           ( point[2] == tmpPnt[2] )
        )
-      {
+    {
       pntIdx = tmpIdx;
       break;
-      }
     }
+  }
 
   pArray = NULL;
   tmpPnt = NULL;
@@ -1240,9 +1238,9 @@ vtkIdType vtkIncrementalOctreePointLocator::FindDuplicatePointInLeafNode
   ( vtkIncrementalOctreeNode * leafNode, const double point[3] )
 {
   if ( leafNode->GetPointIdSet() == NULL )
-    {
+  {
     return -1;
-    }
+  }
 
   return ( this->LocatorPoints->GetDataType() == VTK_FLOAT )
          ? this->FindDuplicateFloatTypePointInVisitedLeafNode
@@ -1281,9 +1279,9 @@ vtkIdType vtkIncrementalOctreePointLocator::IsInsertedPointForNonZeroTolerance
                               ( *leafContainer, x, &minDist2 );
 
   if ( minDist2 == 0.0 )
-    {
+  {
     return pointIdx;
-    }
+  }
 
   // As no any 'duplicate' point exists in this leaf node, we need to expand
   // the search scope to capture possible closer points in other nodes.
@@ -1291,17 +1289,17 @@ vtkIdType vtkIncrementalOctreePointLocator::IsInsertedPointForNonZeroTolerance
                                  ( x, this->OctreeRootNode );
 
   if ( elseDst2 < this->InsertTolerance2 )
-    {
+  {
     // one or multiple closer points might exist in the neighboring nodes
     pntIdExt = this->FindClosestPointInSphereWithTolerance
                      (  x, this->InsertTolerance2, *leafContainer, &dist2Ext );
 
     if ( dist2Ext < minDist2 )
-      {
+    {
       minDist2 = dist2Ext;
       pointIdx = pntIdExt;
-      }
     }
+  }
 
   return  ( minDist2 <= this->InsertTolerance2 )  ?  pointIdx  :  -1;
 }
