@@ -39,10 +39,10 @@ vtkQuadraticPyramid::vtkQuadraticPyramid()
   this->Points->SetNumberOfPoints(14);
   this->PointIds->SetNumberOfIds(14);
   for (int i = 0; i < 14; i++)
-    {
+  {
     this->Points->SetPoint(i, 0.0, 0.0, 0.0);
     this->PointIds->SetId(i,0);
-    }
+  }
   this->Points->SetNumberOfPoints(13);
   this->PointIds->SetNumberOfIds(13);
 
@@ -115,10 +115,10 @@ vtkCell *vtkQuadraticPyramid::GetEdge(int edgeId)
   edgeId = (edgeId < 0 ? 0 : (edgeId > 7 ? 7 : edgeId ));
 
   for (int i=0; i<3; i++)
-    {
+  {
     this->Edge->PointIds->SetId(i,this->PointIds->GetId(PyramidEdges[edgeId][i]));
     this->Edge->Points->SetPoint(i,this->Points->GetPoint(PyramidEdges[edgeId][i]));
-    }
+  }
 
   return this->Edge;
 }
@@ -130,24 +130,25 @@ vtkCell *vtkQuadraticPyramid::GetFace(int faceId)
 
   // load point id's and coordinates
   // be careful with the first one:
+
   if(faceId > 0)
-    {
+  {
     for (int i=0; i<6; i++)
-      {
+    {
       this->TriangleFace->PointIds->SetId(i,this->PointIds->GetId(PyramidFaces[faceId][i]));
       this->TriangleFace->Points->SetPoint(i,this->Points->GetPoint(PyramidFaces[faceId][i]));
-      }
-    return this->TriangleFace;
     }
+    return this->TriangleFace;
+  }
   else
-    {
+  {
     for (int i=0; i<8; i++)
-      {
+    {
       this->Face->PointIds->SetId(i,this->PointIds->GetId(PyramidFaces[faceId][i]));
       this->Face->Points->SetPoint(i,this->Points->GetPoint(PyramidFaces[faceId][i]));
-      }
-    return this->Face;
     }
+    return this->Face;
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -160,10 +161,50 @@ int vtkQuadraticPyramid::EvaluatePosition(double* x,
                                           int& subId, double pcoords[3],
                                           double& dist2, double *weights)
 {
+  int i, j;
+  subId = 0;
+  // There are problems searching for the apex point so we check if
+  // we are there first before doing the full parametric inversion.
+  vtkPoints* points = this->GetPoints();
+  double apexPoint[3];
+  points->GetPoint(4, apexPoint);
+  dist2 = vtkMath::Distance2BetweenPoints(apexPoint, x);
+  double baseMidpoint[3];
+  points->GetPoint(0, baseMidpoint);
+  for(i=1;i<4;i++)
+  {
+    double tmp[3];
+    points->GetPoint(i, tmp);
+    for(j=0;j<3;j++)
+    {
+      baseMidpoint[j] += tmp[j];
+    }
+  }
+  for(i=0;i<3;i++)
+  {
+    baseMidpoint[i] /= 4.;
+  }
+
+  double length2 = vtkMath::Distance2BetweenPoints(apexPoint, baseMidpoint);
+  // we use .001 as the relative tolerance here since that is the same
+  // that is used for the interior cell check below but we need to
+  // square it here because we're looking at dist2^2.
+  if(dist2 == 0. || ( length2 != 0. && dist2/length2 < 1.e-6) )
+  {
+    pcoords[0] = pcoords[1] = 0;
+    pcoords[2] = 1;
+    this->InterpolationFunctions(pcoords, weights);
+    if(closestPoint)
+    {
+      memcpy(closestPoint, x, 3*sizeof(double));
+      dist2 = 0.;
+    }
+    return 1;
+  }
+
   int iteration, converged;
   double  params[3];
   double  fcol[3], rcol[3], scol[3], tcol[3];
-  int i, j;
   double  d, pt[3];
   double derivs[3*13];
 
@@ -174,39 +215,40 @@ int vtkQuadraticPyramid::EvaluatePosition(double* x,
   //  enter iteration loop
   for (iteration=converged=0;
        !converged && (iteration < VTK_PYRAMID_MAX_ITERATION);  iteration++)
-    {
+  {
     //  calculate element interpolation functions and derivatives
     this->InterpolationFunctions(pcoords, weights);
     this->InterpolationDerivs(pcoords, derivs);
 
     //  calculate newton functions
     for (i=0; i<3; i++)
-      {
+    {
       fcol[i] = rcol[i] = scol[i] = tcol[i] = 0.0;
-      }
+    }
     for (i=0; i<13; i++)
-      {
+    {
       this->Points->GetPoint(i, pt);
       for (j=0; j<3; j++)
-        {
+      {
         fcol[j] += pt[j] * weights[i];
         rcol[j] += pt[j] * derivs[i];
         scol[j] += pt[j] * derivs[i+13];
         tcol[j] += pt[j] * derivs[i+26];
-        }
       }
+    }
 
     for (i=0; i<3; i++)
-      {
+    {
       fcol[i] -= x[i];
-      }
+    }
 
     //  compute determinants and generate improvements
     d=vtkMath::Determinant3x3(rcol,scol,tcol);
     if ( fabs(d) < 1.e-20)
-      {
+    {
+      vtkDebugMacro (<<"Determinant incorrect, iteration " << iteration);
       return -1;
-      }
+    }
 
     pcoords[0] = params[0] - 0.5*vtkMath::Determinant3x3 (fcol,scol,tcol) / d;
     pcoords[1] = params[1] - 0.5*vtkMath::Determinant3x3 (rcol,fcol,tcol) / d;
@@ -216,73 +258,73 @@ int vtkQuadraticPyramid::EvaluatePosition(double* x,
     if ( ((fabs(pcoords[0]-params[0])) < VTK_PYRAMID_CONVERGED) &&
          ((fabs(pcoords[1]-params[1])) < VTK_PYRAMID_CONVERGED) &&
          ((fabs(pcoords[2]-params[2])) < VTK_PYRAMID_CONVERGED) )
-      {
+    {
       converged = 1;
-      }
+    }
 
     // Test for bad divergence (S.Hirschberg 11.12.2001)
     else if ((fabs(pcoords[0]) > VTK_DIVERGED) ||
              (fabs(pcoords[1]) > VTK_DIVERGED) ||
              (fabs(pcoords[2]) > VTK_DIVERGED))
-      {
+    {
       return -1;
-      }
+    }
 
     //  if not converged, repeat
     else
-      {
+    {
       params[0] = pcoords[0];
       params[1] = pcoords[1];
       params[2] = pcoords[2];
-      }
     }
+  }
 
   //  if not converged, set the parametric coordinates to arbitrary values
   //  outside of element
   if ( !converged )
-    {
+  {
     return -1;
-    }
+  }
 
   this->InterpolationFunctions(pcoords, weights);
 
   if ( pcoords[0] >= -0.001 && pcoords[0] <= 1.001 &&
        pcoords[1] >= -0.001 && pcoords[1] <= 1.001 &&
        pcoords[2] >= -0.001 && pcoords[2] <= 1.001 )
-    {
+  {
     if (closestPoint)
-      {
+    {
       closestPoint[0] = x[0]; closestPoint[1] = x[1]; closestPoint[2] = x[2];
       dist2 = 0.0; //inside pyramid
-      }
-    return 1;
     }
+    return 1;
+  }
   else
-    {
+  {
     double pc[3], w[13];
     if (closestPoint)
-      {
+    {
       for (i=0; i<3; i++) //only approximate, not really true for warped hexa
-        {
+      {
         if (pcoords[i] < 0.0)
-          {
+        {
           pc[i] = 0.0;
-          }
-        else if (pcoords[i] > 1.0)
-          {
-          pc[i] = 1.0;
-          }
-        else
-          {
-          pc[i] = pcoords[i];
-          }
         }
+        else if (pcoords[i] > 1.0)
+        {
+          pc[i] = 1.0;
+        }
+        else
+        {
+          pc[i] = pcoords[i];
+        }
+      }
       this->EvaluateLocation(subId, pc, closestPoint,
                              static_cast<double *>(w));
       dist2 = vtkMath::Distance2BetweenPoints(closestPoint,x);
-      }
-    return 0;
     }
+    return 0;
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -297,13 +339,13 @@ void vtkQuadraticPyramid::EvaluateLocation(int& vtkNotUsed(subId),
 
   x[0] = x[1] = x[2] = 0.0;
   for (i=0; i<13; i++)
-    {
+  {
     this->Points->GetPoint(i, pt);
     for (j=0; j<3; j++)
-      {
+    {
       x[j] += pt[j] * weights[i];
-      }
     }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -335,39 +377,39 @@ void vtkQuadraticPyramid::Subdivide(vtkPointData *inPd, vtkCellData *inCd,
   this->PointData->CopyAllocate(inPd,14);
   this->CellData->CopyAllocate(inCd,6);
   for (i=0; i<13; i++)
-    {
+  {
     this->PointData->CopyData(inPd,this->PointIds->GetId(i),i);
     this->CellScalars->SetValue( i, cellScalars->GetTuple1(i));
-    }
+  }
   for (i=0; i<6; i++)
-    {
+  {
     this->CellData->CopyData(inCd,cellId,i);
-    }
+  }
 
   //Interpolate new values
   double p[3];
   this->Points->Resize(14);
   this->CellScalars->Resize(14);
   for ( numMidPts=0; numMidPts < 1; numMidPts++ )
-    {
+  {
     this->InterpolationFunctions(MidPoints[numMidPts], weights);
 
     x[0] = x[1] = x[2] = 0.0;
     s = 0.0;
     for (i=0; i<13; i++)
-      {
+    {
       this->Points->GetPoint(i, p);
       for (j=0; j<3; j++)
-        {
+      {
         x[j] += p[j] * weights[i];
-        }
-      s += cellScalars->GetTuple1(i) * weights[i];
       }
+      s += cellScalars->GetTuple1(i) * weights[i];
+    }
     this->Points->SetPoint(13+numMidPts,x);
     this->CellScalars->SetValue(13+numMidPts,s);
     this->PointData->InterpolatePoint(inPd, 13+numMidPts,
                                       this->PointIds, weights);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -390,30 +432,30 @@ void vtkQuadraticPyramid::Contour(double value,
   //contour each linear pyramid separately
   this->Scalars->SetNumberOfTuples(5);  //num of vertices
   for (i=0; i<6; i++) //for each pyramid
-    {
+  {
     for (int j=0; j<5; j++) //for each point of pyramid
-      {
+    {
       this->Pyramid->Points->SetPoint(j,this->Points->GetPoint(LinearPyramids[i][j]));
       this->Pyramid->PointIds->SetId(j,LinearPyramids[i][j]);
       this->Scalars->SetValue(j,this->CellScalars->GetValue(LinearPyramids[i][j]));
-      }
-    this->Pyramid->Contour(value,this->Scalars,locator,verts,lines,polys,
-                           this->PointData,outPd,this->CellData,cellId,outCd);
     }
+    this->Pyramid->Contour(value,this->Scalars,locator,verts,lines,polys,
+                           this->PointData,outPd,this->CellData,i,outCd);
+  }
 
   //contour each linear tetra separately
   this->Scalars->SetNumberOfTuples(4);  //num of vertices
   for (i=6; i<10; i++) //for each tetra
-    {
+  {
     for (int j=0; j<4; j++) //for each point of tetra
-      {
+    {
       this->Tetra->Points->SetPoint(j,this->Points->GetPoint(LinearPyramids[i][j]));
       this->Tetra->PointIds->SetId(j,LinearPyramids[i][j]);
       this->Scalars->SetTuple(j,this->CellScalars->GetTuple(LinearPyramids[i][j]));
-      }
+    }
     this->Tetra->Contour(value,this->Scalars,locator,verts,lines,polys,
                          this->PointData,outPd,this->CellData,cellId,outCd);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -431,39 +473,42 @@ int vtkQuadraticPyramid::IntersectWithLine(double* p1, double* p2,
   int inter;
 
   t = VTK_DOUBLE_MAX;
+  this->TriangleFace->GetPoints()->ShallowCopy(this->GetPoints());
   for (faceNum=0; faceNum<5; faceNum++)
-    {
+  {
     // We have 8 nodes on rect face
     // and 6 on triangle faces
     if(faceNum > 0)
-      {
+    {
       for (int i=0; i<6; i++)
-        {
+      {
         this->TriangleFace->PointIds->SetId(i,
               this->PointIds->GetId(PyramidFaces[faceNum][i]));
-        }
+      }
       inter = this->TriangleFace->IntersectWithLine(p1, p2, tol, tTemp,
                                                     xTemp, pc, subId);
-      }
+    }
     else
-      {
+    {
+      // No need to set the PointIds. They are set in the Face constructor
+      // Points need to be set to correspond with the contructor's PointIds.
       for (int i=0; i<8; i++)
-        {
+      {
         this->Face->Points->SetPoint(i,
               this->Points->GetPoint(PyramidFaces[faceNum][i]));
-        }
+      }
       inter = this->Face->IntersectWithLine(p1, p2, tol, tTemp,
                                             xTemp, pc, subId);
-      }
+    }
     if ( inter )
-      {
+    {
       intersection = 1;
       if ( tTemp < t )
-        {
+      {
         t = tTemp;
         x[0] = xTemp[0]; x[1] = xTemp[1]; x[2] = xTemp[2];
         switch (faceNum)
-          {
+        {
           case 0:
             pcoords[0] = 0.0; pcoords[1] = pc[1]; pcoords[2] = pc[0];
             break;
@@ -487,10 +532,10 @@ int vtkQuadraticPyramid::IntersectWithLine(double* p1, double* p2,
           case 5:
             pcoords[0] = pc[0]; pcoords[1] = pc[1]; pcoords[2] = 1.0;
             break;
-          }
         }
       }
     }
+  }
   return intersection;
 }
 
@@ -504,22 +549,22 @@ int vtkQuadraticPyramid::Triangulate(int vtkNotUsed(index), vtkIdList *ptIds,
   ptIds->Reset();
 
   for (i=0; i < 6; i++)
-    {
+  {
     for ( int j=0; j < 5; j++)
-      {
+    {
       ptIds->InsertId(5*i+j,this->PointIds->GetId(LinearPyramids[i][j]));
       pts->InsertPoint(5*i+j,this->Points->GetPoint(LinearPyramids[i][j]));
-      }
     }
+  }
 
   for (ii=0, i=6 ; i < 10; i++, ii++)
-    {
+  {
     for ( int j=0; j < 4; j++)
-      {
+    {
       ptIds->InsertId(4*ii+j+30,this->PointIds->GetId(LinearPyramids[i][j]));
       pts->InsertPoint(4*ii+j+30,this->Points->GetPoint(LinearPyramids[i][j]));
-      }
     }
+  }
 
   return 1;
 }
@@ -542,27 +587,27 @@ void vtkQuadraticPyramid::JacobianInverse(double pcoords[3], double **inverse,
   // create Jacobian matrix
   m[0] = m0; m[1] = m1; m[2] = m2;
   for (i=0; i < 3; i++) //initialize matrix
-    {
+  {
     m0[i] = m1[i] = m2[i] = 0.0;
-    }
+  }
 
   for ( j=0; j < 13; j++ )
-    {
+  {
     this->Points->GetPoint(j, x);
     for ( i=0; i < 3; i++ )
-      {
+    {
       m0[i] += x[i] * derivs[j];
       m1[i] += x[i] * derivs[13 + j];
       m2[i] += x[i] * derivs[26 + j];
-      }
     }
+  }
 
   // now find the inverse
   if ( vtkMath::InvertMatrix(m,inverse,3) == 0 )
-    {
+  {
     vtkErrorMacro(<<"Jacobian inverse not found");
     return;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -580,19 +625,19 @@ void vtkQuadraticPyramid::Derivatives(int vtkNotUsed(subId),
 
   // now compute derivates of values provided
   for (k=0; k < dim; k++) //loop over values per vertex
-    {
+  {
     sum[0] = sum[1] = sum[2] = 0.0;
     for ( i=0; i < 13; i++) //loop over interp. function derivatives
-      {
+    {
       sum[0] += functionDerivs[i] * values[dim*i + k];
       sum[1] += functionDerivs[13 + i] * values[dim*i + k];
       sum[2] += functionDerivs[26 + i] * values[dim*i + k];
-      }
-    for (j=0; j < 3; j++) //loop over derivative directions
-      {
-      derivs[3*k + j] = sum[0]*jI[j][0] + sum[1]*jI[j][1] + sum[2]*jI[j][2];
-      }
     }
+    for (j=0; j < 3; j++) //loop over derivative directions
+    {
+      derivs[3*k + j] = sum[0]*jI[j][0] + sum[1]*jI[j][1] + sum[2]*jI[j][2];
+    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -612,29 +657,29 @@ void vtkQuadraticPyramid::Clip(double value, vtkDataArray* cellScalars,
   //contour each linear pyramid separately
   this->Scalars->SetNumberOfTuples(5);  //num of vertices
   for (i=0; i<6; i++) //for each subdivided pyramid
-    {
+  {
     for (int j=0; j<5; j++) //for each of the five vertices of the pyramid
-      {
+    {
       this->Pyramid->Points->SetPoint(j,this->Points->GetPoint(LinearPyramids[i][j]));
       this->Pyramid->PointIds->SetId(j,LinearPyramids[i][j]);
       this->Scalars->SetValue(j,this->CellScalars->GetValue(LinearPyramids[i][j]));
-      }
+    }
     this->Pyramid->Clip(value,this->Scalars,locator,tets,this->PointData,outPd,
                     this->CellData,cellId,outCd,insideOut);
-    }
+  }
 
   this->Scalars->SetNumberOfTuples(4);  //num of vertices
   for (i=6; i<10; i++) //for each subdivided tetra
-    {
+  {
     for (int j=0; j<4; j++) //for each of the four vertices of the tetra
-      {
+    {
       this->Tetra->Points->SetPoint(j,this->Points->GetPoint(LinearPyramids[i][j]));
       this->Tetra->PointIds->SetId(j,LinearPyramids[i][j]);
       this->Scalars->SetValue(j,this->CellScalars->GetValue(LinearPyramids[i][j]));
-      }
+    }
     this->Tetra->Clip(value,this->Scalars,locator,tets,this->PointData,outPd,
                     this->CellData,cellId,outCd,insideOut);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -646,39 +691,30 @@ void vtkQuadraticPyramid::InterpolationFunctions(double pcoords[3],
   // VTK needs parametric coordinates to be between (0,1). Isoparametric
   // shape functions are formulated between (-1,1). Here we do a
   // coordinate system conversion from (0,1) to (-1,1).
-  const double r = 2*pcoords[0] - 1;
-  const double s = 2*pcoords[1] - 1;
-  const double t = 2*pcoords[2] - 1;
+  const double r = 2.0*(pcoords[0] - 0.5);
+  const double s = 2.0*(pcoords[1] - 0.5);
+  const double t = 2.0*(pcoords[2] - 0.5);
+  const double r2 = r*r;
+  const double s2 = s*s;
+  const double t2 = t*t;
 
-  const double rm = 1.0 - r;
-  const double rp = 1.0 + r;
-  const double sm = 1.0 - s;
-  const double sp = 1.0 + s;
-  const double tm = 1.0 - t;
-  const double tp = 1.0 + t;
-  const double r2 = 1.0 - r*r;
-  const double s2 = 1.0 - s*s;
-  const double t2 = 1.0 - t*t;
+  weights[0] = -(1 - r) * (1 - s) * (1 - t) * (4 + 3*r + 3*s + 2*r*s + 2*t + r*t + s*t + 2*r*s*t) / 16.0;
+  weights[1] = -(1 + r) * (1 - s) * (1 - t) * (4 - 3*r + 3*s - 2*r*s + 2*t - r*t + s*t - 2*r*s*t) / 16.0;
+  weights[2] = -(1 + r) * (1 + s) * (1 - t) * (4 - 3*r - 3*s + 2*r*s + 2*t - r*t - s*t + 2*r*s*t) / 16.0;
+  weights[3] = -(1 - r) * (1 + s) * (1 - t) * (4 + 3*r - 3*s - 2*r*s + 2*t + r*t - s*t - 2*r*s*t) / 16.0;
 
-  // corners
-  weights[0] = 0.125 * rm * sm * tm * (-r - s - t - 2.0);
-  weights[1] = 0.125 * rp * sm * tm * ( r - s - t - 2.0);
-  weights[2] = 0.125 * rp * sp * tm * ( r + s - t - 2.0);
-  weights[3] = 0.125 * rm * sp * tm * (-r + s - t - 2.0);
-  weights[4] = 0.5   * t  * tp;
+  weights[4] = t * (1 + t) / 2.0;
 
-  // midsides of rectangles
-  weights[5] = 0.25 * r2 * sm * tm;
-  weights[6] = 0.25 * s2 * rp * tm;
-  weights[7] = 0.25 * r2 * sp * tm;
-  weights[8] = 0.25 * s2 * rm * tm;
+  weights[5] = (1 - r2) * (1 - s) * (1 - t) * (2 + s + s*t) / 8.0;
+  weights[6] = (1 + r) * (1 - s2) * (1 - t) * (2 - r - r*t) / 8.0;
+  weights[7] = (1 - r2) * (1 + s) * (1 - t) * (2 - s - s*t) / 8.0;
+  weights[8] = (1 - r) * (1 - s2) * (1 - t) * (2 + r + r*t) / 8.0;
 
+  weights[9] = (1 - r) * (1 - s) * (1 - t2) / 4.0;
+  weights[10] = (1 + r) * (1 - s) * (1 - t2) / 4.0;
+  weights[11] = (1 + r) * (1 + s) * (1 - t2) / 4.0;
+  weights[12] = (1 - r) * (1 + s) * (1 - t2) / 4.0;
 
-  // midsides of triangles
-  weights[9]  = 0.25 * ( 1 - r ) * (1 - s ) * t2;
-  weights[10] = 0.25 * ( 1 + r ) * (1 - s ) * t2;
-  weights[11] = 0.25 * ( 1 + r ) * (1 + s ) * t2;
-  weights[12] = 0.25 * ( 1 - r ) * (1 + s ) * t2;
 }
 
 //----------------------------------------------------------------------------
