@@ -118,23 +118,23 @@ int vtkCompositeDataPipeline::ExecuteDataObject(
   int compositePort;
   bool shouldIterate = this->ShouldIterateOverInput(inInfoVec, compositePort);
   if (!shouldIterate)
-    {
+  {
     // Invoke the request on the algorithm.
     result = this->CallAlgorithm(request, vtkExecutive::RequestDownstream,
                                  inInfoVec, outInfoVec);
     if (!result)
-      {
+    {
       return result;
-      }
     }
+  }
 
   int i;
   // Make sure a valid data object exists for all output ports.
   for(i=0; result && i < this->Algorithm->GetNumberOfOutputPorts(); ++i)
-    {
+  {
     vtkDebugMacro(<< "ExecuteDataObject calling CheckCompositeData");
     result = this->CheckCompositeData(request, i, inInfoVec, outInfoVec);
-    }
+  }
 
   return result;
 }
@@ -161,22 +161,22 @@ int vtkCompositeDataPipeline::ExecuteData(vtkInformation* request,
   bool composite = this->ShouldIterateOverInput(inInfoVec, compositePort);
 
   if ( composite)
-    {
+  {
     if (this->GetNumberOfOutputPorts())
-      {
+    {
       this->ExecuteSimpleAlgorithm(request, inInfoVec, outInfoVec, compositePort);
-      }
+    }
     else
-      {
+    {
        vtkErrorMacro("Can not execute simple alorithm without output ports");
        return 0;
-      }
     }
+  }
   else
-    {
+  {
     vtkDebugMacro(<< "  Superclass::ExecuteData");
     result = this->Superclass::ExecuteData(request,inInfoVec,outInfoVec);
-    }
+  }
 
   return result;
 }
@@ -186,25 +186,25 @@ int vtkCompositeDataPipeline::InputTypeIsValid(
   int port, int index,vtkInformationVector **inInfoVec)
 {
   if (this->InLocalLoop)
-    {
+  {
     return this->Superclass::InputTypeIsValid(port, index, inInfoVec);
-    }
+  }
   if (!inInfoVec[port])
-    {
+  {
     return 0;
-    }
+  }
 
   // If we will be iterating over the input on this port, assume that we
   // can handle any input type. The input type will be checked again during
   // each step of the iteration.
   int compositePort;
   if (this->ShouldIterateOverInput(inInfoVec, compositePort))
-    {
+  {
     if (compositePort == port)
-      {
+    {
       return 1;
-      }
     }
+  }
 
   // Otherwise, let superclass handle it.
   return this->Superclass::InputTypeIsValid(port, index, inInfoVec);
@@ -221,16 +221,16 @@ bool vtkCompositeDataPipeline::ShouldIterateOverInput(vtkInformationVector** inI
   // connection.
   int numInputPorts = this->Algorithm->GetNumberOfInputPorts();
   for(int i=0; i < numInputPorts; ++i)
-    {
+  {
     int numInConnections = this->Algorithm->GetNumberOfInputConnections(i);
     // If there is 1 connection
     if (numInConnections == 1)
-      {
+    {
       vtkInformation* inPortInfo =
         this->Algorithm->GetInputPortInformation(i);
       if (inPortInfo->Has(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE())
           && inPortInfo->Length(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE()) > 0)
-        {
+      {
         const char* inputType = inPortInfo->Get(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), 0);
         // the filter upstream will iterate
 
@@ -239,40 +239,40 @@ bool vtkCompositeDataPipeline::ShouldIterateOverInput(vtkInformationVector** inI
             strcmp(inputType, "vtkOverlappingAMR") == 0 ||
             strcmp(inputType, "vtkNonOverlappingAMR") == 0 ||
             strcmp(inputType, "vtkMultiBlockDataSet") == 0)
-          {
+        {
           vtkDebugMacro(<< "ShouldIterateOverInput return 0 (Composite)");
           return false;
-          }
+        }
 
         vtkInformation* inInfo = inInfoVec[i]->GetInformationObject(0);
         vtkDataObject* input = inInfo->Get(vtkDataObject::DATA_OBJECT());
         // If input does not match a required input type
         bool foundMatch = false;
         if(input)
-          {
+        {
           int size = inPortInfo->Length(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE());
           for(int j = 0; j < size; ++j)
-            {
+          {
             if(input->IsA(inPortInfo->Get(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), j)))
-              {
+            {
               foundMatch = true;
-              }
             }
           }
+        }
         if (input && !foundMatch)
-          {
+        {
           // If input is composite
           if (vtkCompositeDataSet::SafeDownCast(input))
-            {
+          {
             // Assume that we have to iterate over input
             compositePort = i;
             vtkDebugMacro(<< "ShouldIterateOverInput returns 1 (input composite)");
             return true;
-            }
           }
         }
       }
     }
+  }
   vtkDebugMacro(<< "ShouldIterateOverInput returns 0 (default)");
   return false;
 }
@@ -290,10 +290,10 @@ void vtkCompositeDataPipeline::ExecuteEach(vtkCompositeDataIterator* iter,
   vtkInformation* outInfo = outInfoVec->GetInformationObject(0); //assumed to be 0
 
   for (iter->InitTraversal(); !iter->IsDoneWithTraversal(); iter->GoToNextItem())
-    {
+  {
     vtkDataObject* dobj = iter->GetCurrentDataObject();
     if (dobj)
-      {
+    {
       // Note that since VisitOnlyLeaves is ON on the iterator,
       // this method is called only for leaves, hence, we are assured that
       // neither dobj nor outObj are vtkCompositeDataSet subclasses.
@@ -305,12 +305,12 @@ void vtkCompositeDataPipeline::ExecuteEach(vtkCompositeDataIterator* iter,
                                              request,
                                              dobj);
       if (outObj)
-        {
+      {
         compositeOutput->SetDataSet(iter, outObj);
         outObj->FastDelete();
-        }
       }
     }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -330,21 +330,25 @@ void vtkCompositeDataPipeline::ExecuteSimpleAlgorithm(
   vtkInformation* outInfo = 0;
 
   if (this->GetNumberOfOutputPorts() > 0)
-    {
+  {
     outInfo = outInfoVec->GetInformationObject(0);
-    }
+  }
+  if (!outInfo)
+  {
+    return;
+  }
 
   // Make sure a valid composite data object exists for all output ports.
   for(int i=0; i < this->Algorithm->GetNumberOfOutputPorts(); ++i)
-    {
+  {
     this->CheckCompositeData(request, i, inInfoVec, outInfoVec);
-    }
+  }
 
   // if we have no composite inputs
   if (compositePort==-1)
-    {
+  {
     return;
-    }
+  }
 
   // Loop using the first input on the first port.
   // This might not be valid for all cases but it is a decent
@@ -359,7 +363,7 @@ void vtkCompositeDataPipeline::ExecuteSimpleAlgorithm(
       outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
   if (input && compositeOutput)
-    {
+  {
     compositeOutput->PrepareForNewData();
     compositeOutput->CopyStructure(input);
 
@@ -406,16 +410,16 @@ void vtkCompositeDataPipeline::ExecuteSimpleAlgorithm(
 
     vtkDataObject* curInput = inInfo->Get(vtkDataObject::DATA_OBJECT());
     if (curInput != input)
-      {
+    {
       inInfo->Remove(vtkDataObject::DATA_OBJECT());
       inInfo->Set(vtkDataObject::DATA_OBJECT(), input);
-      }
+    }
     vtkDataObject* curOutput = outInfo->Get(vtkDataObject::DATA_OBJECT());
     if (curOutput != compositeOutput.GetPointer())
-      {
+    {
       outInfo->Set(vtkDataObject::DATA_OBJECT(), compositeOutput);
-      }
     }
+  }
   this->ExecuteDataEnd(request,inInfoVec,outInfoVec);
 }
 
@@ -431,22 +435,22 @@ vtkDataObject* vtkCompositeDataPipeline::ExecuteSimpleAlgorithmForBlock(
   vtkDebugMacro(<< "ExecuteSimpleAlgorithmForBlock");
 
   if (dobj && dobj->IsA("vtkCompositeDataSet"))
-    {
+  {
     vtkErrorMacro("ExecuteSimpleAlgorithmForBlock cannot be called "
       "for a vtkCompositeDataSet");
     return 0;
-    }
+  }
 
   // There must be a bug somehwere. If this Remove()
   // is not called, the following Set() has the effect
   // of removing (!) the key.
   if (inInfo)
-    {
+  {
     inInfo->Remove(vtkDataObject::DATA_OBJECT());
     inInfo->Set(vtkDataObject::DATA_OBJECT(), dobj);
 
     vtkTrivialProducer::FillOutputDataInformation(dobj, inInfo);
-    }
+  }
 
   request->Set(REQUEST_DATA_OBJECT());
   outInfo->Set(SUPPRESS_RESET_PI(), 1);
@@ -462,12 +466,12 @@ vtkDataObject* vtkCompositeDataPipeline::ExecuteSimpleAlgorithmForBlock(
   int storedPiece = -1;
   int storedNumPieces = -1;
   for(int m=0; m < this->Algorithm->GetNumberOfOutputPorts(); ++m)
-    {
+  {
     vtkInformation* info = outInfoVec->GetInformationObject(m);
     // Update the whole thing
     if (info->Has(
                   vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT()))
-      {
+    {
       int extent[6] = {0,-1,0,-1,0,-1};
       info->Get(
         vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(),
@@ -476,9 +480,6 @@ vtkDataObject* vtkCompositeDataPipeline::ExecuteSimpleAlgorithmForBlock(
         vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT(),
         extent,
         6);
-      info->Set(
-        vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT_INITIALIZED(),
-        1);
       storedPiece =
         info->Get(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER());
       storedNumPieces=
@@ -489,8 +490,8 @@ vtkDataObject* vtkCompositeDataPipeline::ExecuteSimpleAlgorithmForBlock(
       vtkDebugMacro(<< "UPDATE_PIECE_NUMBER() 0"  << " " << info);
       info->Set(
         vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(), 0);
-      }
     }
+  }
 
   request->Set(REQUEST_UPDATE_EXTENT());
   this->CallAlgorithm(request, vtkExecutive::RequestUpstream,
@@ -502,10 +503,10 @@ vtkDataObject* vtkCompositeDataPipeline::ExecuteSimpleAlgorithmForBlock(
   request->Remove(REQUEST_DATA());
 
   for(int m=0; m < this->Algorithm->GetNumberOfOutputPorts(); ++m)
-    {
+  {
     vtkInformation* info = outInfoVec->GetInformationObject(m);
     if (storedPiece!=-1)
-      {
+    {
       info->Set(
         vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(),
         storedNumPieces);
@@ -513,14 +514,14 @@ vtkDataObject* vtkCompositeDataPipeline::ExecuteSimpleAlgorithmForBlock(
       info->Set(
         vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(),
         storedPiece);
-      }
     }
+  }
 
   vtkDataObject* output = outInfo->Get(vtkDataObject::DATA_OBJECT());
   if (!output)
-    {
+  {
     return 0;
-    }
+  }
   vtkDataObject* outputCopy = output->NewInstance();
   outputCopy->ShallowCopy(output);
   return outputCopy;
@@ -535,17 +536,17 @@ int vtkCompositeDataPipeline::NeedToExecuteData(
 {
   // Has the algorithm asked to be executed again?
   if(this->ContinueExecuting)
-    {
+  {
     return 1;
-    }
+  }
 
   // If no port is specified, check all ports.  This behavior is
   // implemented by the superclass.
   if(outputPort < 0)
-    {
+  {
     return this->Superclass::NeedToExecuteData(outputPort,
                                                inInfoVec,outInfoVec);
-    }
+  }
 
   // We need to check the requested update extent.  Get the output
   // port information and data information.  We do not need to check
@@ -557,17 +558,17 @@ int vtkCompositeDataPipeline::NeedToExecuteData(
   // If the output is not a composite dataset, let the superclass handle
   // NeedToExecuteData
   if (!vtkCompositeDataSet::SafeDownCast(dataObject))
-    {
+  {
     return this->Superclass::NeedToExecuteData(outputPort,
                                                inInfoVec,outInfoVec);
-    }
+  }
 
   // First do the basic checks.
   if(this->vtkDemandDrivenPipeline::NeedToExecuteData(
        outputPort,inInfoVec,outInfoVec))
-    {
+  {
     return 1;
-    }
+  }
 
   // Now handle composite stuff.
 
@@ -578,34 +579,34 @@ int vtkCompositeDataPipeline::NeedToExecuteData(
   int updateNumberOfPieces = outInfo->Get(UPDATE_NUMBER_OF_PIECES());
   int dataNumberOfPieces = dataInfo->Get(vtkDataObject::DATA_NUMBER_OF_PIECES());
   if(dataNumberOfPieces != updateNumberOfPieces)
-    {
+  {
     return 1;
-    }
+  }
   int dataGhostLevel = dataInfo->Get(vtkDataObject::DATA_NUMBER_OF_GHOST_LEVELS());
   int updateGhostLevel = outInfo->Get(UPDATE_NUMBER_OF_GHOST_LEVELS());
-  if(dataGhostLevel < updateGhostLevel)
-    {
+  if(updateNumberOfPieces > 1 && dataGhostLevel < updateGhostLevel)
+  {
     return 1;
-    }
+  }
   if (dataNumberOfPieces != 1)
-    {
+  {
     int dataPiece = dataInfo->Get(vtkDataObject::DATA_PIECE_NUMBER());
     int updatePiece = outInfo->Get(UPDATE_PIECE_NUMBER());
     if (dataPiece != updatePiece)
-      {
+    {
       return 1;
-      }
     }
+  }
 
   if (this->NeedToExecuteBasedOnTime(outInfo, dataObject))
-    {
+  {
     return 1;
-    }
+  }
 
   if (this->NeedToExecuteBasedOnCompositeIndices(outInfo))
-    {
+  {
     return 1;
-    }
+  }
 
   // We do not need to execute.
   return 0;
@@ -615,11 +616,11 @@ int vtkCompositeDataPipeline::NeedToExecuteData(
 int vtkCompositeDataPipeline::NeedToExecuteBasedOnCompositeIndices(vtkInformation* outInfo)
 {
   if (outInfo->Has(UPDATE_COMPOSITE_INDICES()))
-    {
+  {
     if (!outInfo->Has(DATA_COMPOSITE_INDICES()))
-      {
+    {
       return 1;
-      }
+    }
     unsigned int* requested_ids = reinterpret_cast<unsigned int*>(
       outInfo->Get(UPDATE_COMPOSITE_INDICES()));
     unsigned int* existing_ids = reinterpret_cast<unsigned int*>(
@@ -628,40 +629,40 @@ int vtkCompositeDataPipeline::NeedToExecuteBasedOnCompositeIndices(vtkInformatio
     int length_ex = outInfo->Length(DATA_COMPOSITE_INDICES());
 
     if (length_req > length_ex)
-      {
+    {
       // we are requesting more blocks than those generated.
       return 1;
-      }
+    }
     int ri=0, ei=0;
     // NOTE: We are relying on the fact that both these id lists are sorted to
     // do a more efficient comparison.
     for (; ri < length_req; ri++)
-      {
+    {
       while (ei < length_ex &&
         existing_ids[ei] < requested_ids[ri])
-        {
+      {
         ei++;
-        }
+      }
       if (ei >= length_ex)
-        {
+      {
         // we ran beyond the existing length.
         return 1;
-        }
+      }
       if (existing_ids[ei] != requested_ids[ri])
-        {
+      {
         return 1;
-        }
       }
     }
+  }
   else
-    {
+  {
     if (outInfo->Has(DATA_COMPOSITE_INDICES()))
-      {
+    {
       // earlier request asked for a some blocks, but the new request is asking
       // for everything, so re-execute.
       return 1;
-      }
     }
+  }
   return 0;
 }
 
@@ -674,24 +675,24 @@ int vtkCompositeDataPipeline::ForwardUpstream(vtkInformation* request)
   // Do not forward upstream if the input is shared with another
   // executive.
   if(this->SharedInputInformation)
-    {
+  {
     return 1;
-    }
+  }
 
   if (!this->Algorithm->ModifyRequest(request, BeforeForward))
-    {
+  {
     return 0;
-    }
+  }
   int port = request->Get(FROM_OUTPUT_PORT());
 
   // Forward the request upstream through all input connections.
   int result = 1;
   for(int i=0; i < this->GetNumberOfInputPorts(); ++i)
-    {
+  {
     int nic = this->Algorithm->GetNumberOfInputConnections(i);
     vtkInformationVector* inVector = this->GetInputInformation()[i];
     for(int j=0; j < nic; ++j)
-      {
+    {
       vtkInformation* info = inVector->GetInformationObject(j);
       // Get the executive producing this input.  If there is none, then
       // it is a NULL input.
@@ -699,23 +700,23 @@ int vtkCompositeDataPipeline::ForwardUpstream(vtkInformation* request)
       int producerPort;
       vtkExecutive::PRODUCER()->Get(info, e, producerPort);
       if(e)
-        {
+      {
         request->Set(FROM_OUTPUT_PORT(), producerPort);
         if(!e->ProcessRequest(request,
                               e->GetInputInformation(),
                               e->GetOutputInformation()))
-          {
+        {
           result = 0;
-          }
-        request->Set(FROM_OUTPUT_PORT(), port);
         }
+        request->Set(FROM_OUTPUT_PORT(), port);
       }
     }
+  }
 
   if (!this->Algorithm->ModifyRequest(request, AfterForward))
-    {
+  {
     return 0;
-    }
+  }
 
   return result;
 }
@@ -726,34 +727,34 @@ int vtkCompositeDataPipeline::ForwardUpstream(
 {
   // Do not forward upstream if input information is shared.
   if(this->SharedInputInformation)
-    {
+  {
     return 1;
-    }
+  }
 
   if (!this->Algorithm->ModifyRequest(request, BeforeForward))
-    {
+  {
     return 0;
-    }
+  }
 
   int result = 1;
   if(vtkExecutive* e = this->GetInputExecutive(i, j))
-    {
+  {
     vtkAlgorithmOutput* input = this->Algorithm->GetInputConnection(i, j);
     int port = request->Get(FROM_OUTPUT_PORT());
     request->Set(FROM_OUTPUT_PORT(), input->GetIndex());
     if(!e->ProcessRequest(request,
                           e->GetInputInformation(),
                           e->GetOutputInformation()))
-      {
+    {
       result = 0;
-      }
-    request->Set(FROM_OUTPUT_PORT(), port);
     }
+    request->Set(FROM_OUTPUT_PORT(), port);
+  }
 
   if (!this->Algorithm->ModifyRequest(request, AfterForward))
-    {
+  {
     return 0;
-    }
+  }
 
   return result;
 }
@@ -767,31 +768,31 @@ void vtkCompositeDataPipeline::CopyDefaultInformation(
                                            inInfoVec, outInfoVec);
 
   if (request->Has(REQUEST_INFORMATION())||request->Has(REQUEST_TIME_DEPENDENT_INFORMATION()))
-    {
+  {
     if (this->GetNumberOfInputPorts() > 0)
-      {
+    {
       if (vtkInformation* inInfo = inInfoVec[0]->GetInformationObject(0))
-        {
+      {
         // Copy information from the first input to all outputs.
         for(int i=0; i < outInfoVec->GetNumberOfInformationObjects(); ++i)
-          {
+        {
           vtkInformation* outInfo = outInfoVec->GetInformationObject(i);
           outInfo->CopyEntry(inInfo, COMPOSITE_DATA_META_DATA());
-          }
         }
       }
     }
+  }
 
   if(request->Has(REQUEST_UPDATE_EXTENT()))
-    {
+  {
     int outputPort = -1;
     if(request->Has(FROM_OUTPUT_PORT()))
-      {
+    {
       outputPort = request->Get(FROM_OUTPUT_PORT());
-      }
+    }
 
     if(outInfoVec->GetNumberOfInformationObjects() > 0)
-      {
+    {
       // Copy information from the output port that made the request.
       // Since VerifyOutputInformation has already been called we know
       // there is output information with a data object.
@@ -800,18 +801,18 @@ void vtkCompositeDataPipeline::CopyDefaultInformation(
 
       // Loop over all input ports.
       for(int i=0; i < this->Algorithm->GetNumberOfInputPorts(); ++i)
-        {
+      {
         // Loop over all connections on this input port.
         int numInConnections = inInfoVec[i]->GetNumberOfInformationObjects();
         for (int j=0; j<numInConnections; j++)
-          {
+        {
           // Get the pipeline information for this input connection.
           vtkInformation* inInfo = inInfoVec[i]->GetInformationObject(j);
           inInfo->CopyEntry(outInfo, UPDATE_COMPOSITE_INDICES());
           inInfo->CopyEntry(outInfo, LOAD_REQUESTED_BLOCKS());
-          }
         }
       }
+    }
 
     // Find the port that has a data that we will iterator over.
     // If there is one, make sure that we use piece extent for
@@ -819,17 +820,17 @@ void vtkCompositeDataPipeline::CopyDefaultInformation(
     // only.
     int compositePort;
     if (this->ShouldIterateOverInput(inInfoVec, compositePort))
-      {
+    {
       // Get the output port from which to copy the extent.
       outputPort = -1;
       if(request->Has(FROM_OUTPUT_PORT()))
-        {
+      {
         outputPort = request->Get(FROM_OUTPUT_PORT());
-        }
+      }
 
       // Setup default information for the inputs.
       if(outInfoVec->GetNumberOfInformationObjects() > 0)
-        {
+      {
         // Copy information from the output port that made the request.
         // Since VerifyOutputInformation has already been called we know
         // there is output information with a data object.
@@ -840,7 +841,7 @@ void vtkCompositeDataPipeline::CopyDefaultInformation(
         int numInConnections =
           inInfoVec[compositePort]->GetNumberOfInformationObjects();
         for (int j=0; j<numInConnections; j++)
-          {
+        {
           // Get the pipeline information for this input connection.
           vtkInformation* inInfo =
             inInfoVec[compositePort]->GetInformationObject(j);
@@ -852,10 +853,10 @@ void vtkCompositeDataPipeline::CopyDefaultInformation(
           inInfo->CopyEntry(outInfo, UPDATE_NUMBER_OF_GHOST_LEVELS());
           inInfo->CopyEntry(outInfo, UPDATE_EXTENT_INITIALIZED());
           inInfo->CopyEntry(outInfo, LOAD_REQUESTED_BLOCKS());
-          }
         }
       }
     }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -863,9 +864,9 @@ void vtkCompositeDataPipeline::ResetPipelineInformation(int port,
                                                         vtkInformation* info)
 {
   if (info->Has(SUPPRESS_RESET_PI()))
-    {
+  {
     return;
-    }
+  }
 
   this->Superclass::ResetPipelineInformation(port, info);
   info->Remove(COMPOSITE_DATA_META_DATA());
@@ -902,13 +903,13 @@ int vtkCompositeDataPipeline::CheckCompositeData(
   int compositePort;
 
   if (this->ShouldIterateOverInput(inInfoVec, compositePort))
-    {
+  {
     // This assumes that the first output of the filter is the one
     // that will have the composite data.
     vtkDataObject* doOutput = outInfo->Get(vtkDataObject::DATA_OBJECT());
     vtkCompositeDataSet* output = vtkCompositeDataSet::SafeDownCast(doOutput);
     if (!output)
-      {
+    {
       output = this->CreateOutputCompositeDataSet(
         vtkCompositeDataSet::SafeDownCast(this->GetInputData(compositePort, 0, inInfoVec)),
         compositePort);
@@ -921,14 +922,14 @@ int vtkCompositeDataPipeline::CheckCompositeData(
       this->GetAlgorithm()->GetOutputPortInformation(port)->Set(
         vtkDataObject::DATA_EXTENT_TYPE(), output->GetExtentType());
       output->Delete();
-      }
-    return 1;
     }
+    return 1;
+  }
   // Otherwise, create a simple output
   else
-    {
+  {
     return this->Superclass::CheckDataObject(port, outInfoVec);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -936,14 +937,14 @@ vtkDataObject* vtkCompositeDataPipeline::GetCompositeInputData(
   int port, int index, vtkInformationVector **inInfoVec)
 {
   if (!inInfoVec[port])
-    {
+  {
     return 0;
-    }
+  }
   vtkInformation *info = inInfoVec[port]->GetInformationObject(index);
   if (!info)
-    {
+  {
     return 0;
-    }
+  }
   return info->Get(vtkDataObject::DATA_OBJECT());
 }
 
@@ -951,9 +952,9 @@ vtkDataObject* vtkCompositeDataPipeline::GetCompositeInputData(
 vtkDataObject* vtkCompositeDataPipeline::GetCompositeOutputData(int port)
 {
   if(!this->OutputPortIndexInRange(port, "get data for"))
-    {
+  {
     return 0;
-    }
+  }
 
   // Check that the given output port has a valid data object.
   vtkDebugMacro(<< "GetCompositeOutputData calling CheckCompositeData ");
@@ -962,9 +963,9 @@ vtkDataObject* vtkCompositeDataPipeline::GetCompositeOutputData(int port)
 
   // Return the data object.
   if(vtkInformation* info = this->GetOutputInformation(port))
-    {
+  {
     return info->Get(vtkDataObject::DATA_OBJECT());
-    }
+  }
   return 0;
 }
 
@@ -978,7 +979,7 @@ vtkCompositeDataSet* vtkCompositeDataPipeline::CreateOutputCompositeDataSet(
   if (input->IsA("vtkHierarchicalBoxDataSet") ||
       input->IsA("vtkOverlappingAMR") ||
       input->IsA("vtkNonOverlappingAMR") )
-    {
+  {
     vtkSmartPointer<vtkUniformGrid> tempInput = vtkSmartPointer<vtkUniformGrid>::New();
 
     // Check if the algorithm can accept UniformGrid on the input port.
@@ -987,9 +988,9 @@ vtkCompositeDataSet* vtkCompositeDataPipeline::CreateOutputCompositeDataSet(
     const char* inputType =
       inPortInfo->Get(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE());
     if (!tempInput->IsA(inputType))
-      {
+    {
       return vtkMultiBlockDataSet::New();
-      }
+    }
 
     vtkInformation* inInfo = this->GetInputInformation(compositePort, 0);
     vtkSmartPointer<vtkDataObject> curInput = inInfo->Get(vtkDataObject::DATA_OBJECT());
@@ -1021,10 +1022,10 @@ vtkCompositeDataSet* vtkCompositeDataPipeline::CreateOutputCompositeDataSet(
     // check the type of output data object created by the algorithm.
     vtkDataObject* curOutput = outInfo->Get(vtkDataObject::DATA_OBJECT());
     if (!curOutput->IsA("vtkUniformGrid"))
-      {
+    {
       return vtkMultiBlockDataSet::New();
-      }
     }
+  }
 
   return input->NewInstance();
 }
@@ -1037,23 +1038,14 @@ void vtkCompositeDataPipeline::MarkOutputsGenerated(
 {
   this->Superclass::MarkOutputsGenerated(request,inInfoVec,outInfoVec);
 
-  // Save the information about COMPOSITE_INDICES() as needed in the data
-  // object.
-  int outputPort = 0;
-  if(request->Has(FROM_OUTPUT_PORT()))
-    {
-    outputPort = request->Get(FROM_OUTPUT_PORT());
-    outputPort = (outputPort >= 0 ? outputPort : 0);
-    }
-
   for (int i=0; i < outInfoVec->GetNumberOfInformationObjects(); ++i)
-    {
+  {
     vtkInformation* outInfo = outInfoVec->GetInformationObject(i);
     vtkDataObject* data = outInfo->Get(vtkDataObject::DATA_OBJECT());
     if (data && !outInfo->Get(DATA_NOT_GENERATED()))
-      {
+    {
       if (outInfo->Has(UPDATE_COMPOSITE_INDICES()))
-        {
+      {
         size_t count = outInfo->Length(UPDATE_COMPOSITE_INDICES());
         int* indices = new int[count];
         // assume the source produced the blocks it was asked for:
@@ -1062,13 +1054,13 @@ void vtkCompositeDataPipeline::MarkOutputsGenerated(
         outInfo->Set(DATA_COMPOSITE_INDICES(), indices,
           static_cast<int>(count));
         delete []indices;
-        }
+      }
       else
-        {
+      {
         outInfo->Remove(DATA_COMPOSITE_INDICES());
-        }
       }
     }
+  }
 }
 
 //----------------------------------------------------------------------------
