@@ -70,10 +70,10 @@ vtkClipVolume::vtkClipVolume(vtkImplicitFunction *cf)
 vtkClipVolume::~vtkClipVolume()
 {
   if ( this->Locator )
-    {
+  {
     this->Locator->UnRegister(this);
     this->Locator = NULL;
-    }
+  }
 
   this->Triangulator->Delete();
   this->SetClipFunction(NULL);
@@ -87,23 +87,23 @@ vtkUnstructuredGrid *vtkClipVolume::GetClippedOutput()
 
 // Overload standard modified time function. If Clip functions is modified,
 // then this object is modified as well.
-unsigned long vtkClipVolume::GetMTime()
+vtkMTimeType vtkClipVolume::GetMTime()
 {
-  unsigned long mTime, time;
+  vtkMTimeType mTime, time;
 
   mTime=this->Superclass::GetMTime();
 
   if ( this->Locator != NULL )
-    {
+  {
     time = this->Locator->GetMTime();
     mTime = ( time > mTime ? time : mTime );
-    }
+  }
 
   if ( this->ClipFunction != NULL )
-    {
+  {
     time = this->ClipFunction->GetMTime();
     mTime = ( time > mTime ? time : mTime );
-    }
+  }
 
   return mTime;
 }
@@ -164,32 +164,32 @@ int vtkClipVolume::RequestData(
     input->GetExtent()[0] + input->GetExtent()[2] + input->GetExtent()[4];
 
   for (dimension=3, i=0; i<3; i++)
-    {
+  {
     if ( dims[i] <= 1 )
-      {
-      dimension--;
-      }
-    }
-  if ( dimension < 3 )
     {
+      dimension--;
+    }
+  }
+  if ( dimension < 3 )
+  {
     vtkErrorMacro("This filter only clips 3D volume data");
     return 1;
-    }
+  }
 
   if ( !this->ClipFunction && this->GenerateClipScalars )
-    {
+  {
     vtkErrorMacro(<<"Cannot generate clip scalars without clip function");
     return 1;
-    }
+  }
 
   // Create objects to hold output of clip operation
   //
   estimatedSize = numCells;
   estimatedSize = estimatedSize / 1024 * 1024; //multiple of 1024
   if (estimatedSize < 1024)
-    {
+  {
     estimatedSize = 1024;
-    }
+  }
 
   newPoints = vtkPoints::New();
   newPoints->Allocate(estimatedSize/2,estimatedSize/2);
@@ -203,55 +203,55 @@ int vtkClipVolume::RequestData(
 
   // locator used to merge potentially duplicate points
   if ( this->Locator == NULL )
-    {
+  {
     this->CreateDefaultLocator();
-    }
+  }
   this->Locator->InitPointInsertion (newPoints, input->GetBounds());
 
   // Determine whether we're clipping with input scalars or a clip function
   // and do necessary setup.
   if ( this->ClipFunction )
-    {
+  {
     vtkFloatArray *tmpScalars = vtkFloatArray::New();
     tmpScalars->Allocate(numPts);
     inPD = vtkPointData::New();
     inPD->ShallowCopy(input->GetPointData());
     if ( this->GenerateClipScalars )
-      {
+    {
       inPD->SetScalars(tmpScalars);
-      }
+    }
     for ( i=0; i < numPts; i++ )
-      {
+    {
       s = this->ClipFunction->FunctionValue(input->GetPoint(i));
       tmpScalars->InsertTuple(i,&s);
-      }
-    clipScalars = tmpScalars;
     }
+    clipScalars = tmpScalars;
+  }
   else //using input scalars
-    {
+  {
     clipScalars = this->GetInputArrayToProcess(0,inputVector);
     if ( !clipScalars )
-      {
+    {
       vtkErrorMacro(<<"Cannot clip without clip function or input scalars");
       return 1;
-      }
     }
+  }
 
   if ( !this->GenerateClipScalars && !input->GetPointData()->GetScalars())
-    {
+  {
     outPD->CopyScalarsOff();
-    }
+  }
   else
-    {
+  {
     outPD->CopyScalarsOn();
-    }
+  }
   outPD->InterpolateAllocate(inPD,estimatedSize,estimatedSize/2);
   outCD->CopyAllocate(inCD,estimatedSize,estimatedSize/2);
   clippedCD->CopyAllocate(inCD,estimatedSize,estimatedSize/2);
 
   // If generating second output, setup clipped output
   if ( this->GenerateClippedOutput )
-    {
+  {
     this->NumberOfClippedCells = 0;
     this->ClippedConnectivity = vtkCellArray::New();
     this->ClippedConnectivity->Allocate(estimatedSize); //storage for cells
@@ -259,7 +259,7 @@ int vtkClipVolume::RequestData(
     this->ClippedLocations->Allocate(estimatedSize);
     this->ClippedTypes = vtkUnsignedCharArray::New();
     this->ClippedTypes->Allocate(estimatedSize);
-    }
+  }
 
   // perform clipping on voxels - compute approriate numbers
   value = this->Value;
@@ -283,111 +283,111 @@ int vtkClipVolume::RequestData(
   // used in ClipVoxel().
   int abort=0;
   for ( k=0; k < numKCells && !abort; k++)
-    {
+  {
     // Check for progress and abort on every z-slice
     this->UpdateProgress(static_cast<double>(k) / numKCells);
     abort = this->GetAbortExecute();
     for ( j=0; j < numJCells; j++)
-      {
+    {
       for ( i=0; i < numICells; i++ )
-        {
+      {
         flip = (extOffset+i+j+k) & 0x1;
         cellId = i + j*numICells + k*sliceSize;
 
         input->GetCell(cellId,cell);
         if ( cell->GetCellType() == VTK_EMPTY_CELL )
-          {
+        {
           continue;
-          }
+        }
         cellPts = cell->GetPoints();
         cellIds = cell->GetPointIds();
 
         // gather scalar values for the cell and keep
         for ( above=below=0, ii=0; ii < 8; ii++ )
-          {
+        {
           s = clipScalars->GetComponent(cellIds->GetId(ii),0);
           cellScalars->SetComponent(ii, 0, s);
           if ( s >= value )
-            {
+          {
             above = 1;
-            }
-          else if ( s < value )
-            {
-            below = 1;
-            }
           }
+          else
+          {
+            below = 1;
+          }
+        }
 
         // take into account inside/out flag
         if ( this->InsideOut )
-          {
+        {
           above = !above;
           below = !below;
-          }
+        }
 
         // See whether voxel is fully inside or outside and triangulate
         // according to the flup variable.
         if ( (above && !below) ||
              (this->GenerateClippedOutput && (below && !above)) )
-          {
+        {
           cell->Triangulate(flip, tetraIds, tetraPts);
           ntetra = tetraPts->GetNumberOfPoints() / 4;
 
           if (above && !below)
-            {
+          {
             outputConn = this->Connectivity;
             outputLoc = this->Locations;
             outputTypes = this->Types;
             outputCount = &this->NumberOfCells;
             outputCD = outCD;
-            }
+          }
           else
-            {
+          {
             outputConn = this->ClippedConnectivity;
             outputLoc = this->ClippedLocations;
             outputTypes = this->ClippedTypes;
             outputCount = &this->NumberOfClippedCells;
             outputCD = clippedCD;
-            }
+          }
 
           for (ii=0; ii<ntetra; ii++)
-            {
+          {
             id = ii*4;
             for (jj=0; jj<4; jj++)
-              {
+            {
               tetraPts->GetPoint(id+jj, x);
               if ( this->Locator->InsertUniquePoint(x, pts[jj]) )
-                {
+              {
                 outPD->CopyData(inPD,tetraIds->GetId(id+jj),pts[jj]);
-                }
               }
+            }
             newCellId = outputConn->InsertNextCell(4,pts);
             (*outputCount)++;
             outputLoc->InsertNextValue(outputConn->GetTraversalLocation());
             outputConn->GetNextCell(npts,dpts); //updates traversal location
             outputTypes->InsertNextValue( VTK_TETRA );
             outputCD->CopyData(inCD,cellId,newCellId);
-            }//for each tetra produced by triangulation
-          }
+          }//for each tetra produced by triangulation
+        }
 
         else if (above == below ) // clipped voxel, have to triangulate
-          {
+        {
           if ( this->Mixed3DCellGeneration ) //use vtkTetra clipping templates
-            {
+          {
             cell->Triangulate(flip, tetraIds, tetraPts);
             this->ClipTets(value, clipTetra, clipScalars, cellScalars,
                            tetraIds, tetraPts, inPD, outPD,
                            inCD, cellId, outCD, clippedCD, this->InsideOut);
-            }
+          }
           else //use vtkOrderedTriangulator to produce tetrahedra
-            {
+          {
             this->ClipVoxel(value, cellScalars, flip, origin, spacing,
                             cellIds, cellPts, inPD, outPD,
                             inCD, cellId, outCD, clippedCD);
-            }
-          } // using ordered triangulator
-        }// for i
-      }// for j
-    }// for k
+          }
+        } // using ordered triangulator
+      }// for i
+    }// for j
+  }// for k
 
   // Create the output
   output->SetPoints(newPoints);
@@ -401,7 +401,7 @@ int vtkClipVolume::RequestData(
                 << output->GetNumberOfCells() << " tetra" );
 
   if ( this->GenerateClippedOutput )
-    {
+  {
     clippedOutput->SetPoints(newPoints);
     clippedOutput->SetCells(this->ClippedTypes,this->ClippedLocations,
                             this->ClippedConnectivity);
@@ -412,16 +412,16 @@ int vtkClipVolume::RequestData(
     clippedOutput->Squeeze();
     vtkDebugMacro(<<"Created (clipped output): "
                   << clippedOutput->GetNumberOfCells() << " tetra");
-    }
+  }
 
   // Update ourselves.  Because we don't know upfront how many cells
   // we've created, take care to reclaim memory.
   //
   if ( this->ClipFunction )
-    {
+  {
     clipScalars->Delete();
     inPD->Delete();
-    }
+  }
 
   // Clean up
   newPoints->Delete();
@@ -458,29 +458,29 @@ void vtkClipVolume::ClipTets(double value, vtkTetra *clipTetra,
 
   // Clip each tetrahedron
   for (i=0; i<ntetra; i++)
-    {
+  {
     id = i*4;
     for (j=0; j<4; j++)
-      {
+    {
       clipTetra->PointIds->SetId(j,tetraIds->GetId(id+j));
       clipTetra->Points->SetPoint(j,tetraPts->GetPoint(id+j));
       cellScalars->
         SetComponent(j,0,clipScalars->GetComponent(tetraIds->GetId(id+j),0));
-      }
+    }
     clipTetra->Clip(value, cellScalars, this->Locator, this->Connectivity,
                     inPD, outPD, inCD, cellId, outCD, insideOut);
     numNew = this->Connectivity->GetNumberOfCells() - this->NumberOfCells;
     this->NumberOfCells = this->Connectivity->GetNumberOfCells();
     for (k=0; k<numNew; k++)
-      {
+    {
       this->Locations->
         InsertNextValue(this->Connectivity->GetTraversalLocation());
       this->Connectivity->GetNextCell(npts,pts);
       this->Types->InsertNextValue((npts==4?VTK_TETRA:VTK_WEDGE));
-      }
+    }
 
     if ( this->GenerateClippedOutput )
-      {
+    {
       clipTetra->Clip(value, cellScalars, this->Locator,
                       this->ClippedConnectivity, inPD, outPD,
                       inCD, cellId, clippedCD, !insideOut);
@@ -489,14 +489,14 @@ void vtkClipVolume::ClipTets(double value, vtkTetra *clipTetra,
       this->NumberOfClippedCells =
         this->ClippedConnectivity->GetNumberOfCells();
       for (k=0; k<numNew; k++)
-        {
+      {
         this->ClippedLocations->InsertNextValue(
           this->ClippedConnectivity->GetTraversalLocation() );
         this->ClippedConnectivity->GetNextCell(npts,pts);
         this->ClippedTypes->InsertNextValue((npts==4?VTK_TETRA:VTK_WEDGE));
-        }
       }
     }
+  }
 }
 
 // Method to triangulate and clip voxel using ordered Delaunay
@@ -526,10 +526,10 @@ void vtkClipVolume::ClipVoxel(double value, vtkDataArray *cellScalars,
   // compute bounds for voxel and initialize
   cellPts->GetPoint(0,voxelOrigin);
   for (i=0; i<3; i++)
-    {
+  {
     bounds[2*i] = voxelOrigin[i];
     bounds[2*i+1] = voxelOrigin[i] + spacing[i];
-    }
+  }
 
   // Initialize Delaunay insertion process with voxel triangulation.
   // No more than 20 points (8 corners + 12 edges) may be inserted.
@@ -540,76 +540,76 @@ void vtkClipVolume::ClipVoxel(double value, vtkDataArray *cellScalars,
   int type;
   vtkIdType internalId[8]; //used to merge points if nearby edge intersection
   for (numPts=0; numPts<8; numPts++)
-    {
+  {
     ptId = order[flip][numPts];
 
     // Currently all points are injected because of the possibility
     // of intersection point merging.
     s1 = cellScalars->GetComponent(ptId,0);
     if ( (s1 >= value && !this->InsideOut) || (s1 < value && this->InsideOut) )
-      {
+    {
       type = 0; //inside
-      }
+    }
     else
-      {
+    {
       //type 1 is "outside"; type 4 is don't insert
       type = (this->GenerateClippedOutput ? 1 : 4);
-      }
+    }
 
     cellPts->GetPoint(ptId, x);
     if ( this->Locator->InsertUniquePoint(x, id) )
-      {
+    {
       outPD->CopyData(inPD, cellIds->GetId(ptId), id);
-      }
+    }
     internalId[ptId] = this->Triangulator->InsertPoint(id, x, x, type);
-    }//for eight voxel corner points
+  }//for eight voxel corner points
 
   // For each edge intersection point, insert into triangulation. Edge
   // intersections come from clipping value. Have to be careful of
   // intersections near exisiting points (causes bad Delaunay behavior).
   for (edgeNum=0; edgeNum < 12; edgeNum++)
-    {
+  {
     s1 = cellScalars->GetComponent(edges[edgeNum][0],0);
     s2 = cellScalars->GetComponent(edges[edgeNum][1],0);
 
     if ( (s1 < value && s2 >= value) || (s1 >= value && s2 < value) )
-      {
+    {
 
       t = (value - s1) / (s2 - s1);
 
       // Check to see whether near the intersection is near a voxel corner.
       // If so,have to merge requiring a change of type to type=boundary.
       if ( t < this->MergeTolerance )
-        {
+      {
         this->Triangulator->UpdatePointType(internalId[edges[edgeNum][0]], 2);
         continue;
-        }
+      }
       else if (t > (1.0 - this->MergeTolerance) )
-        {
+      {
         this->Triangulator->UpdatePointType(internalId[edges[edgeNum][1]], 2);
         continue;
-        }
+      }
 
       // generate edge intersection point
       cellPts->GetPoint(edges[edgeNum][0],p1);
       cellPts->GetPoint(edges[edgeNum][1],p2);
       for (i=0; i<3; i++)
-        {
+      {
         x[i] = p1[i] + t * (p2[i] - p1[i]);
-        }
+      }
 
       // Incorporate point into output and interpolate edge data as necessary
       if ( this->Locator->InsertUniquePoint(x, ptId) )
-        {
+      {
         outPD->InterpolateEdge(inPD, ptId, cellIds->GetId(edges[edgeNum][0]),
                                cellIds->GetId(edges[edgeNum][1]), t);
-        }
+      }
 
       //Insert into Delaunay triangulation
       this->Triangulator->InsertPoint(ptId,x,x,2);
 
-      }//if edge intersects value
-    }//for all edges
+    }//if edge intersects value
+  }//for all edges
 
   // triangulate the points
   this->Triangulator->Triangulate();
@@ -620,29 +620,29 @@ void vtkClipVolume::ClipVoxel(double value, vtkDataArray *cellScalars,
   numNew = this->Connectivity->GetNumberOfCells() - this->NumberOfCells;
   this->NumberOfCells = this->Connectivity->GetNumberOfCells();
   for (k=0; k<numNew; k++)
-    {
+  {
     newCellId = this->Locations->
       InsertNextValue(this->Connectivity->GetTraversalLocation());
     this->Connectivity->GetNextCell(npts,pts); //updates traversal location
     this->Types->InsertNextValue(VTK_TETRA);
     outCD->CopyData(inCD,cellId,newCellId);
-    }
+  }
 
   if ( this->GenerateClippedOutput )
-    {
+  {
     this->Triangulator->AddTetras(1,this->ClippedConnectivity);
     numNew = this->ClippedConnectivity->GetNumberOfCells() -
       this->NumberOfClippedCells;
     this->NumberOfClippedCells = this->ClippedConnectivity->GetNumberOfCells();
     for (k=0; k<numNew; k++)
-      {
+    {
       newCellId = this->ClippedLocations->
         InsertNextValue(this->ClippedConnectivity->GetTraversalLocation());
       this->ClippedConnectivity->GetNextCell(npts,pts);
       this->ClippedTypes->InsertNextValue(VTK_TETRA);
       clippedCD->CopyData(inCD,cellId,newCellId);
-      }
     }
+  }
 }
 
 
@@ -651,19 +651,19 @@ void vtkClipVolume::ClipVoxel(double value, vtkDataArray *cellScalars,
 void vtkClipVolume::SetLocator(vtkIncrementalPointLocator *locator)
 {
   if ( this->Locator == locator )
-    {
+  {
     return;
-    }
+  }
   if ( this->Locator )
-    {
+  {
     this->Locator->UnRegister(this);
     this->Locator = NULL;
-    }
+  }
 
   if (locator)
-    {
+  {
     locator->Register(this);
-    }
+  }
 
   this->Locator = locator;
   this->Modified();
@@ -672,9 +672,9 @@ void vtkClipVolume::SetLocator(vtkIncrementalPointLocator *locator)
 void vtkClipVolume::CreateDefaultLocator()
 {
   if ( this->Locator == NULL )
-    {
+  {
     this->Locator = vtkMergePoints::New();
-    }
+  }
 }
 
 int vtkClipVolume::FillInputPortInformation(int, vtkInformation *info)
@@ -688,24 +688,24 @@ void vtkClipVolume::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os,indent);
 
   if ( this->ClipFunction )
-    {
+  {
     os << indent << "Clip Function: " << this->ClipFunction << "\n";
-    }
+  }
   else
-    {
+  {
     os << indent << "Clip Function: (none)\n";
-    }
+  }
   os << indent << "InsideOut: " << (this->InsideOut ? "On\n" : "Off\n");
   os << indent << "Value: " << this->Value << "\n";
   os << indent << "Merge Tolerance: " << this->MergeTolerance << "\n";
   if ( this->Locator )
-    {
+  {
     os << indent << "Locator: " << this->Locator << "\n";
-    }
+  }
   else
-    {
+  {
     os << indent << "Locator: (none)\n";
-    }
+  }
 
   os << indent << "Generate Clip Scalars: "
      << (this->GenerateClipScalars ? "On\n" : "Off\n");
