@@ -52,7 +52,7 @@ public:
     this->DataSets.push_back(data);
     this->Levels.push_back(level);
   }
-  ~TemporalFractalOutputUtil()
+  ~TemporalFractalOutputUtil() VTK_OVERRIDE
   {
     this->DataSets.clear();
     this->Levels.clear();
@@ -61,20 +61,20 @@ public:
   void CreateOutput(vtkMultiBlockDataSet* mbs)
   {
     for(size_t i=0; i<this->DataSets.size();i++)
-      {
+    {
       vtkDataObject* dataSet = DataSets[i];
       unsigned int level = this->Levels[i];
       vtkMultiBlockDataSet* block = vtkMultiBlockDataSet::SafeDownCast(
         mbs->GetBlock(level));
       if (!block)
-        {
+      {
         block = vtkMultiBlockDataSet::New();
         mbs->SetBlock(level, block);
         block->Delete();
-        }
+      }
       unsigned int index = block->GetNumberOfBlocks();
       block->SetBlock(index, dataSet);
-      }
+    }
   }
   void CreateOutput(vtkHierarchicalBoxDataSet* hbds)
   {
@@ -82,38 +82,38 @@ public:
     int gridDescription(-1);
     double origin[3] = {DBL_MAX,DBL_MAX,DBL_MAX};
     for(size_t i=0; i<this->Levels.size();i++)
-      {
+    {
       unsigned int level = this->Levels[i];
       vtkUniformGrid* grid  = vtkUniformGrid::SafeDownCast(this->DataSets[i]);
       assert(grid);
       gridDescription = grid->GetGridDescription();
       double* gridOrigin = grid->GetOrigin();
       for(int d=0; d<3; d++)
-        {
+      {
         if(gridOrigin[d]<origin[d])
-          {
-          origin[d] = gridOrigin[d];
-          }
-        }
-      for (unsigned int j= static_cast<unsigned int>(blocksPerLevel.size()); j<=level; j++)
         {
-        blocksPerLevel.push_back(0);
+          origin[d] = gridOrigin[d];
         }
-      blocksPerLevel[level]++;
       }
+      for (unsigned int j= static_cast<unsigned int>(blocksPerLevel.size()); j<=level; j++)
+      {
+        blocksPerLevel.push_back(0);
+      }
+      blocksPerLevel[level]++;
+    }
 
     std::vector<unsigned int> blockIds(blocksPerLevel.size(),0); //keep track of the id at each level
     hbds->Initialize(static_cast<int>(blocksPerLevel.size()), &blocksPerLevel[0]);
     hbds->SetOrigin(origin);
     hbds->SetGridDescription(gridDescription);
     for(size_t i=0; i<this->Levels.size();i++)
-      {
+    {
       unsigned int level = this->Levels[i];
       unsigned int id  = blockIds[level];
       vtkUniformGrid* grid  = vtkUniformGrid::SafeDownCast(this->DataSets[i]);
       hbds->SetDataSet(level, id, grid);
       blockIds[level]++;
-      }
+    }
 
   }
 
@@ -186,36 +186,36 @@ void vtkTemporalFractal::SetBlockInfo(vtkUniformGrid *grid,
   // onFace[5]:zmax
 
   if (this->GhostLevels)
-    {
+  {
     if(!onFace[0])
-      {
-      ext[0] -= 1;
-      }
-    if(!onFace[2])
-      {
-      ext[2] -= 1;
-      }
-    if(!onFace[4])
-      {
-      ext[4] -= 1;
-      }
-    if(!onFace[1])
-      {
-      ext[1] += 1;
-      }
-    if(!onFace[3])
-      {
-      ext[3] += 1;
-      }
-    if(!onFace[5])
-      {
-      ext[5] += 1;
-      }
-    }
-  if (this->TwoDimensional)
     {
-    ext[4] = ext[5] = 0;
+      ext[0] -= 1;
     }
+    if(!onFace[2])
+    {
+      ext[2] -= 1;
+    }
+    if(!onFace[4])
+    {
+      ext[4] -= 1;
+    }
+    if(!onFace[1])
+    {
+      ext[1] += 1;
+    }
+    if(!onFace[3])
+    {
+      ext[3] += 1;
+    }
+    if(!onFace[5])
+    {
+      ext[5] += 1;
+    }
+  }
+  if (this->TwoDimensional)
+  {
+    ext[4] = ext[5] = 0;
+  }
 
   double bds[6];
   double origin[3];
@@ -235,26 +235,26 @@ void vtkTemporalFractal::SetBlockInfo(vtkUniformGrid *grid,
 
   dim[0] = dim[1] = dim[2] = 1;
   if (ext[1] > ext[0])
-    {
+  {
     dim[0] = ext[1]-ext[0]+2;
-    }
+  }
   if (ext[3] > ext[2])
-    {
+  {
     dim[1] = ext[3]-ext[2]+2;
-    }
+  }
   if (ext[5] > ext[4])
-    {
+  {
     dim[2] = ext[5]-ext[4]+2;
-    }
+  }
 
   grid->SetDimensions(dim);
   grid->SetSpacing(spacing);
   grid->SetOrigin(origin);
 
   if(this->GhostLevels>0)
-    {
+  {
     this->AddGhostLevelArray(grid,dim,onFace);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -265,36 +265,36 @@ void vtkTemporalFractal::SetRBlockInfo(vtkRectilinearGrid *grid,
                                            int onFace[6])
 {
   if (this->GhostLevels)
-    {
+  {
     if(!onFace[0])
-      {
-      ext[0] -= 1;
-      }
-    if(!onFace[2])
-      {
-      ext[2] -= 1;
-      }
-    if(!onFace[4])
-      {
-      ext[4] -= 1;
-      }
-    if(!onFace[1])
-      {
-      ext[1] += 1;
-      }
-    if(!onFace[3])
-      {
-      ext[3] += 1;
-      }
-    if(!onFace[5])
-      {
-      ext[5] += 1;
-      }
-    }
-  if (this->TwoDimensional)
     {
-    ext[4] = ext[5] = 0;
+      ext[0] -= 1;
     }
+    if(!onFace[2])
+    {
+      ext[2] -= 1;
+    }
+    if(!onFace[4])
+    {
+      ext[4] -= 1;
+    }
+    if(!onFace[1])
+    {
+      ext[1] += 1;
+    }
+    if(!onFace[3])
+    {
+      ext[3] += 1;
+    }
+    if(!onFace[5])
+    {
+      ext[5] += 1;
+    }
+  }
+  if (this->TwoDimensional)
+  {
+    ext[4] = ext[5] = 0;
+  }
 
   double bds[6];
   double origin[3];
@@ -314,17 +314,17 @@ void vtkTemporalFractal::SetRBlockInfo(vtkRectilinearGrid *grid,
 
   dim[0] = dim[1] = dim[2] = 1;
   if (ext[1] > ext[0])
-    {
+  {
     dim[0] = ext[1]-ext[0]+2;
-    }
+  }
   if (ext[3] > ext[2])
-    {
+  {
     dim[1] = ext[3]-ext[2]+2;
-    }
+  }
   if (ext[5] > ext[4])
-    {
+  {
     dim[2] = ext[5]-ext[4]+2;
-    }
+  }
 
   grid->SetDimensions(dim);
 
@@ -333,7 +333,7 @@ void vtkTemporalFractal::SetRBlockInfo(vtkRectilinearGrid *grid,
   vtkMath::RandomSeed(1234);
   int coord=0;
   while(coord<3)
-    {
+  {
     coords[coord]=vtkDoubleArray::New();
     //grid->SetOrigin(origin);
 
@@ -345,44 +345,44 @@ void vtkTemporalFractal::SetRBlockInfo(vtkRectilinearGrid *grid,
     int i=1;
     int c;
     if(this->GhostLevels && !onFace[coord*2+1])
-      {
+    {
       c=dim[coord]-2;
-      }
+    }
     else
-      {
+    {
       c=dim[coord]-1;
-      }
+    }
     uniformCoordinate=origin[coord];
 
     if(this->GhostLevels && !onFace[coord*2])
-      {
+    {
       uniformCoordinate+=spacing[coord];
       coords[coord]->InsertNextValue(uniformCoordinate);
       ++i;
-      }
+    }
 
     while(i<c)
-      {
+    {
       uniformCoordinate+=spacing[coord];
       // get a random number about 1/5 of the uniform spacing.
       double epsilon=(vtkMath::Random()-0.5)*spacing[coord]*0.4;
       coords[coord]->InsertNextValue(uniformCoordinate+epsilon);
       ++i;
-      }
+    }
 
     if(this->GhostLevels && !onFace[coord*2+1])
-      {
+    {
       uniformCoordinate+=spacing[coord];
       coords[coord]->InsertNextValue(uniformCoordinate);
       ++i;
-      }
+    }
 
     // last point
     uniformCoordinate+=spacing[coord];
     coords[coord]->InsertNextValue(uniformCoordinate);
 
     ++coord;
-    }
+  }
 
   //  grid->SetSpacing(spacing);
   grid->SetXCoordinates(coords[0]);
@@ -390,15 +390,15 @@ void vtkTemporalFractal::SetRBlockInfo(vtkRectilinearGrid *grid,
   grid->SetZCoordinates(coords[2]);
   coord=0;
   while(coord<3)
-    {
+  {
     coords[coord]->Delete();
     ++coord;
-    }
+  }
 
   if(this->GhostLevels>0)
-    {
+  {
     this->AddGhostLevelArray(grid,dim,onFace);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -408,27 +408,27 @@ int vtkTemporalFractal::TwoDTest(double bds[6], int level, int target)
   int v0, v1, v2, v3;
 
   if (level == target)
-    {
+  {
     return 0;
-    }
+  }
 
   if (level < 2 || !this->AdaptiveSubdivision)
-    {
+  {
     return 1;
-    }
+  }
 
   v0 = this->MandelbrotTest(bds[0], bds[2]);
   v1 = this->MandelbrotTest(bds[1], bds[2]);
   v2 = this->MandelbrotTest(bds[0], bds[3]);
   v3 = this->MandelbrotTest(bds[1], bds[3]);
   if (v0 && v1 && v2 && v3)
-    {
+  {
     return 0;
-    }
+  }
   if (!v0 && !v1 && !v2 && !v3)
-    {
+  {
     return 0;
-    }
+  }
   return 1;
 }
 
@@ -448,19 +448,19 @@ int vtkTemporalFractal::MandelbrotTest(double x, double y)
   zImag2 = zImag * zImag;
   v1 = (zReal2 + zImag2);
   while ( v1 < 4.0 && count < 100)
-    {
+  {
     zImag = 2.0 * zReal * zImag + cImag;
     zReal = zReal2 - zImag2 + cReal;
     zReal2 = zReal * zReal;
     zImag2 = zImag * zImag;
     ++count;
     v1 = (zReal2 + zImag2);
-    }
+  }
 
   if (count == 100)
-    {
+  {
     return 1;
-    }
+  }
 
   return 0;
 }
@@ -475,26 +475,26 @@ int vtkTemporalFractal::ProcessRequest(
 
   // create the output
   if(request->Has(vtkDemandDrivenPipeline::REQUEST_DATA_OBJECT()))
-    {
+  {
     return this->RequestDataObject(request, inputVector, outputVector);
-    }
+  }
 
   // generate the data
   if(request->Has(vtkCompositeDataPipeline::REQUEST_DATA()))
-    {
+  {
     int retVal = this->RequestData(request, inputVector, outputVector);
     return retVal;
-    }
+  }
 
   // execute information
   if(request->Has(vtkDemandDrivenPipeline::REQUEST_INFORMATION()))
-    {
+  {
     vtkInformation* info = outputVector->GetInformationObject(0);
     info->Set(
       CAN_HANDLE_PIECE_REQUEST(), 1);
 
     return this->RequestInformation(request, inputVector, outputVector);
-    }
+  }
 
 
   return this->Superclass::ProcessRequest(request, inputVector, outputVector);
@@ -528,15 +528,15 @@ int vtkTemporalFractal::RequestInformation(
   vtkInformation *info=outputVector->GetInformationObject(0);
 
   if (this->DiscreteTimeSteps)
-    {
+  {
     double tsteps[11];
     int i;
     for (i = 0; i < 11; ++i)
-      {
+    {
       tsteps[i] = i;
-      }
-    info->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(),tsteps,11);
     }
+    info->Set(vtkStreamingDemandDrivenPipeline::TIME_STEPS(),tsteps,11);
+  }
 
   double trange[2];
   trange[0] = 0.0;
@@ -563,11 +563,11 @@ int vtkTemporalFractal::RequestData(
 
   if (!info->Has(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER()) ||
       !info->Has(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES()))
-    {
+  {
     vtkErrorMacro("Expected information not found. "
                   "Cannot provide update extent.");
     return 0;
-    }
+  }
 
   // now create the HierarchicalDataSet for each time step
 
@@ -623,9 +623,9 @@ int vtkTemporalFractal
   ext[0] = ext[2] = ext[4] = 0;
   ext[1] = ext[3] = ext[5] = this->Dimensions - 1;
   if (this->Asymetric)
-    { // The changes to an extra 2 in the next level.
+  { // The changes to an extra 2 in the next level.
     ext[1] += 1;
-    }
+  }
 
   // Get a global (across all processes) count of the blocks.
   // Do not create the blocks.
@@ -654,13 +654,13 @@ int vtkTemporalFractal
                  ext[5],onFace);
 
   if(vtkHierarchicalBoxDataSet::SafeDownCast(output))
-    {
+  {
     this->OutputUtil->CreateOutput(vtkHierarchicalBoxDataSet::SafeDownCast(output));
-    }
+  }
   else if(vtkMultiBlockDataSet::SafeDownCast(output))
-    {
+  {
     this->OutputUtil->CreateOutput(vtkMultiBlockDataSet::SafeDownCast(output));
-    }
+  }
 
   double bounds[6];
 
@@ -670,25 +670,25 @@ int vtkTemporalFractal
   bounds[3]=oy+ySize;
   bounds[4]=oz;
   if(this->TwoDimensional)
-    {
+  {
     bounds[5]=oz;
-    }
+  }
   else
-    {
+  {
     bounds[5]=oz+zSize;
-    }
+  }
 
   info->Set(vtkStreamingDemandDrivenPipeline::BOUNDS(),bounds,6);
 
   if(!this->GenerateRectilinearGrids)
-    {
+  {
     vtkHierarchicalBoxDataSet* hbds =
       vtkHierarchicalBoxDataSet::SafeDownCast(output);
     this->AddVectorArray(hbds);
     this->AddTestArray(hbds);
     this->AddBlockIdArray(hbds);
     this->AddDepthArray(hbds);
-    }
+  }
   this->AddFractalArray(output);
 
 
@@ -709,76 +709,76 @@ int vtkTemporalFractal::LineTest2(float x0, float y0, float z0,
   // Special case ane point is inside box.
   if (x0>bds[0] && x0<bds[1] && y0>bds[2] && y0<bds[3] && z0>bds[4]
       && z0<bds[5])
-    {
+  {
     return 1;
-    }
+  }
   if (x1>bds[0] && x1<bds[1] && y1>bds[2] && y1<bds[3] && z1>bds[4]
       && z1<bds[5])
-    {
+  {
     return 1;
-    }
+  }
 
   // Do not worry about divide by zero.
   // min x
   x = bds[0];
   k = (x- x0) / (x1-x0);
   if (k >=0.0 && k <= 1.0)
-    {
+  {
     y = y0 + k*(y1-y0);
     z = z0 + k*(z1-z0);
     if (y >= bds[2] && y <= bds[3] && z >= bds[4] && z <= bds[5])
-      {
+    {
       return 1;
-      }
     }
+  }
   // max x
   x = bds[1];
   k = (x- x0) / (x1-x0);
   if (k >=0.0 && k <= 1.0)
-    {
+  {
     y = y0 + k*(y1-y0);
     z = z0 + k*(z1-z0);
     if (y >= bds[2] && y <= bds[3] && z >= bds[4] && z <= bds[5])
-      {
+    {
       return 1;
-      }
     }
+  }
   // min y
   y = bds[2];
   k = (y- y0) / (y1-y0);
   if (k >=0.0 && k <= 1.0)
-    {
+  {
     x = x0 + k*(x1-x0);
     z = z0 + k*(z1-z0);
     if (x >= bds[0] && x <= bds[1] && z >= bds[4] && z <= bds[5])
-      {
+    {
       return 1;
-      }
     }
+  }
   // max y
   y = bds[3];
   k = (y- y0) / (y1-y0);
   if (k >=0.0 && k <= 1.0)
-    {
+  {
     x = x0 + k*(x1-x0);
     z = z0 + k*(z1-z0);
     if (x >= bds[0] && x <= bds[1] && z >= bds[4] && z <= bds[5])
-      {
+    {
       return 1;
-      }
     }
+  }
   // min z
   z = bds[4];
   k = (z- z0) / (z1-z0);
   if (k >=0.0 && k <= 1.0)
-    {
+  {
     x = x0 + k*(x1-x0);
     y = y0 + k*(y1-y0);
     if (y >= bds[2] && y <= bds[3] && x >= bds[0] && x <= bds[1])
-      {
+    {
       return 1;
-      }
     }
+  }
 
   return 0;
 }
@@ -789,20 +789,20 @@ int vtkTemporalFractal::LineTest(float x0, float y0, float z0,
                             double bds[6], int level, int target)
 {
   if (level >= target)
-    {
+  {
     return 0;
-    }
+  }
 
   if (!this->AdaptiveSubdivision)
-    {
+  {
     return 1;
-    }
+  }
 
   // First check to see if the line intersects this block.
   if (this->LineTest2(x0, y0, z0, x1, y1, z1, bds))
-    {
+  {
     return 1;
-    }
+  }
 
   // If the line intersects our neighbor, then our levels cannot differ by
   // more than one.
@@ -816,9 +816,9 @@ int vtkTemporalFractal::LineTest(float x0, float y0, float z0,
   bds2[0] = bds[0] - size;
   bds2[1] = bds[1] + size;
   if (this->LineTest(x0, y0, z0, x1, y1, z1, bds2, level, target))
-    {
+  {
     return 1;
-    }
+  }
   bds2[0] = bds[0];
   bds2[1] = bds[1];
 
@@ -826,9 +826,9 @@ int vtkTemporalFractal::LineTest(float x0, float y0, float z0,
   bds2[2] = bds[2] - size;
   bds2[3] = bds[3] + size;
   if (this->LineTest(x0, y0, z0, x1, y1, z1, bds2, level, target))
-    {
+  {
     return 1;
-    }
+  }
   bds2[2] = bds[2];
   bds2[3] = bds[3];
 
@@ -836,9 +836,9 @@ int vtkTemporalFractal::LineTest(float x0, float y0, float z0,
   bds2[4] = bds[4] - size;
   bds2[5] = bds[5] + size;
   if (this->LineTest(x0, y0, z0, x1, y1, z1, bds2, level, target))
-    {
+  {
     return 1;
-    }
+  }
 
   return 0;
 }
@@ -859,13 +859,12 @@ void vtkTemporalFractal::Traverse(int &blockId,
   int x1, x2, y1, y2, z1, z2;
 
   if (this->TwoDimensional)
-    {
+  {
     z0 = z3 = 0;
-    }
+  }
 
   // Get the bounds of the proposed block.
-  int ext[6];
-  ext[0]=x0; ext[1]=x3; ext[2]=y0; ext[3]=y3, ext[4]=z0; ext[5]=z3;
+  int ext[6] = {x0, x3, y0, y3, z0, z3};
   this->CellExtentToBounds(level, ext, bds);
 
   x0 = x0*2;
@@ -883,17 +882,17 @@ void vtkTemporalFractal::Traverse(int &blockId,
   z1 = z2-1;
 
   if (x3-x2-x1+x0 > 2)
-    { // balance asymetric blocks.
+  { // balance asymetric blocks.
     x2 += 2;
     x1 += 2;
-    }
+  }
 
   int subOnFace[6];
 
   if (this->TwoDimensional)
-    {
+  {
     if (this->TwoDTest(bds, level, this->MaximumLevel))
-      {
+    {
       ++level;
       // Traverse the 4 new blocks.
       subOnFace[0]=onFace[0];
@@ -914,39 +913,39 @@ void vtkTemporalFractal::Traverse(int &blockId,
       subOnFace[0]=0;
       subOnFace[1]=onFace[1];
       this->Traverse(blockId, level, output, x2,x3,y2,y3,z0,z0,subOnFace);
-      }
+    }
     else
-      {
+    {
       if (this->BlockCount >= this->StartBlock
           && this->BlockCount <= this->EndBlock)
-        {
+      {
         vtkDataObject* newData(NULL);
         if(this->GenerateRectilinearGrids)
-          {
+        {
           vtkRectilinearGrid *grid=vtkRectilinearGrid::New();
           newData = grid;
           this->SetRBlockInfo(grid, level, ext,onFace);
-          }
+        }
         else
-          {
+        {
           vtkUniformGrid *grid=vtkUniformGrid::New();
           newData = grid;
           this->SetBlockInfo(grid, level, ext,onFace);
-          }
+        }
         this->OutputUtil->AddDataSet(newData,level);
         this->Levels->InsertValue(blockId, level);
         ++blockId;
-        }
-      ++this->BlockCount;
       }
+      ++this->BlockCount;
     }
+  }
   else
-    { // 3D
+  { // 3D
     if (this->LineTest(-1.64662,0.56383,1.16369, -1.05088,0.85595,0.87104, bds,
                        level, this->MaximumLevel) ||
         this->LineTest(-1.05088,0.85595,0.87104, -0.61430,1.00347,0.59553, bds,
                        level, this->MaximumLevel) )
-      { // break block into eight.
+    { // break block into eight.
       ++level;
       // Traverse the 8 new blocks.
       subOnFace[0]=onFace[0];
@@ -987,33 +986,33 @@ void vtkTemporalFractal::Traverse(int &blockId,
       subOnFace[0]=0;
       subOnFace[1]=onFace[1];
       this->Traverse(blockId, level, output, x2,x3,y2,y3,z2,z3,subOnFace);
-      }
+    }
     else
-      {
+    {
       if (this->BlockCount >= this->StartBlock
           && this->BlockCount <= this->EndBlock)
-        {
+      {
         vtkDataObject* newData(NULL);
         if(this->GenerateRectilinearGrids)
-          {
+        {
           vtkRectilinearGrid *grid=vtkRectilinearGrid::New();
           newData = grid;
           this->SetRBlockInfo(grid, level, ext,onFace);
-          }
+        }
         else
-          {
+        {
           vtkUniformGrid *grid=vtkUniformGrid::New();
           newData = grid;
           this->SetBlockInfo(grid, level, ext,onFace);
-          }
+        }
         this->OutputUtil->AddDataSet(newData,level);
         assert(newData->GetReferenceCount()==2);
         this->Levels->InsertValue(blockId, level);
         ++blockId;
-        }
-      ++this->BlockCount;
       }
+      ++this->BlockCount;
     }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -1024,11 +1023,11 @@ void vtkTemporalFractal::AddTestArray(vtkHierarchicalBoxDataSet *output)
   int levels=output->GetNumberOfLevels();
   int level=0;
   while(level<levels)
-    {
+  {
     int blocks=output->GetNumberOfDataSets(level);
     int block=0;
     while(block<blocks)
-      {
+    {
       vtkUniformGrid *grid;
       grid=vtkUniformGrid::SafeDownCast(output->GetDataSet(level,block));
       assert("check: grid_exists" && grid!=0);
@@ -1045,38 +1044,38 @@ void vtkTemporalFractal::AddTestArray(vtkHierarchicalBoxDataSet *output)
       grid->GetExtent(ext);
       // we need cell extents bu we just get point extents
       if(ext[5]>0)
-        {
+      {
         --ext[5];
-        }
+      }
       if(ext[3]>0)
-        {
+      {
         --ext[3];
-        }
+      }
       if(ext[1]>0)
-        {
+      {
         --ext[1];
-        }
+      }
       int debugcounter=0;
       for (z = ext[4]; z <= ext[5]; ++z)
-        {
+      {
         for (y = ext[2]; y <= ext[3]; ++y)
-          {
+        {
           for (x = ext[0]; x <= ext[1]; ++x)
-            {
+          {
             *arrayPtr++ = origin[0] + spacing[0]*(static_cast<double>(x) + 0.5)
               + origin[1] + spacing[1]*(static_cast<double>(y) + 0.5);
             ++debugcounter;
-            }
           }
         }
+      }
       assert("check: valid_debugcounter" && debugcounter==numCells);
       array->SetName("TestX");
       grid->GetCellData()->AddArray(array);
       array->Delete();
       ++block;
-      }
-    ++level;
     }
+    ++level;
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -1087,11 +1086,11 @@ void vtkTemporalFractal::AddVectorArray(vtkHierarchicalBoxDataSet *output)
   int levels=output->GetNumberOfLevels();
   int level=0;
   while(level<levels)
-    {
+  {
     int blocks=output->GetNumberOfDataSets(level);
     int block=0;
     while(block<blocks)
-      {
+    {
       vtkUniformGrid *grid;
       grid=vtkUniformGrid::SafeDownCast(output->GetDataSet(level,block));
       assert("check: grid_exists" && grid!=0);
@@ -1109,37 +1108,37 @@ void vtkTemporalFractal::AddVectorArray(vtkHierarchicalBoxDataSet *output)
       grid->GetExtent(ext);
       // we need cell extents bu we just get point extents
       if(ext[5]>0)
-        {
+      {
         --ext[5];
-        }
+      }
       if(ext[3]>0)
-        {
+      {
         --ext[3];
-        }
+      }
       if(ext[1]>0)
-        {
+      {
         --ext[1];
-        }
+      }
 
       for (z = ext[4]; z <= ext[5]; ++z)
-        {
+      {
         for (y = ext[2]; y <= ext[3]; ++y)
-          {
+        {
           for (x = ext[0]; x <= ext[1]; ++x)
-            {
+          {
             *arrayPtr++ = origin[0] + spacing[0]*(static_cast<double>(x)+ 0.5);
             *arrayPtr++ = origin[1] + spacing[1]*(static_cast<double>(y)+ 0.5);
             *arrayPtr++ = origin[2] + spacing[2]*(static_cast<double>(z)+ 0.5);
-            }
           }
         }
+      }
       array->SetName("VectorXYZ");
       grid->GetCellData()->AddArray(array);
       array->Delete();
       ++block;
-      }
-    ++level;
     }
+    ++level;
+  }
 }
 
 
@@ -1152,9 +1151,9 @@ void vtkTemporalFractal::AddFractalArray(vtkCompositeDataSet* output)
   int dims[3];
 
   for (iter->InitTraversal(); !iter->IsDoneWithTraversal(); iter->GoToNextItem())
-    {
+  {
     if(!this->GenerateRectilinearGrids)
-      {
+    {
       vtkUniformGrid *grid = vtkUniformGrid::SafeDownCast(
         iter->GetCurrentDataObject());
       assert("check: grid_exists" && grid!=0);
@@ -1173,17 +1172,17 @@ void vtkTemporalFractal::AddFractalArray(vtkCompositeDataSet* output)
       // we need the dimensions according to the cells
 
       if(dims[0]>1)
-        {
+      {
         --dims[0];
-        }
+      }
       if(dims[1]>1)
-        {
+      {
         --dims[1];
-        }
+      }
       if(dims[2]>1)
-        {
+      {
         --dims[2];
-        }
+      }
 
       // Shift point to center of voxel.
       fractalSource->SetWholeExtent(0,dims[0]-1, 0,dims[1]-1, 0,dims[2]-1);
@@ -1198,17 +1197,17 @@ void vtkTemporalFractal::AddFractalArray(vtkCompositeDataSet* output)
       float *fractalPtr = static_cast<float *>(fractal->GetVoidPointer(0));
 
       for (int i = 0; i < fractal->GetNumberOfTuples(); ++i)
-        {
+      {
         // Change fractal into volume fraction (iso surface at 0.5).
         *arrayPtr++ = *fractalPtr++ / (2.0 * this->FractalValue);
-        }
+      }
 
       array->SetName("Fractal Volume Fraction");
       grid->GetCellData()->SetScalars(array);
       array->Delete();
-      }
+    }
     else // rectilinear grid
-      {
+    {
       vtkRectilinearGrid *grid = vtkRectilinearGrid::SafeDownCast(
         iter->GetCurrentDataObject());
       assert("check: grid_exists" && grid!=0);
@@ -1223,8 +1222,8 @@ void vtkTemporalFractal::AddFractalArray(vtkCompositeDataSet* output)
       array->SetName("Fractal Volume Fraction");
       grid->GetCellData()->SetScalars(array);
       array->Delete();
-      }
     }
+  }
   fractalSource->Delete();
   iter->Delete();
 }
@@ -1237,11 +1236,11 @@ void vtkTemporalFractal::AddBlockIdArray(vtkHierarchicalBoxDataSet *output)
   int level=0;
   int blockId=0;
   while(level<levels)
-    {
+  {
     int blocks=output->GetNumberOfDataSets(level);
     int block=0;
     while(block<blocks)
-      {
+    {
       vtkUniformGrid *grid;
       grid=vtkUniformGrid::SafeDownCast(output->GetDataSet(level,block));
       assert("check: grid_exists" && grid!=0);
@@ -1252,18 +1251,18 @@ void vtkTemporalFractal::AddBlockIdArray(vtkHierarchicalBoxDataSet *output)
       array->Allocate(numCells);
       int cell=0;
       while(cell<numCells)
-        {
+      {
         array->InsertNextValue(blockId);
         ++cell;
-        }
+      }
       array->SetName("BlockId");
       grid->GetCellData()->AddArray(array);
       array->Delete();
       ++block;
       ++blockId;
-      }
-    ++level;
     }
+    ++level;
+  }
 }
 
 
@@ -1274,11 +1273,11 @@ void vtkTemporalFractal::AddDepthArray(vtkHierarchicalBoxDataSet *output)
   int level=0;
   int blockId=0;
   while(level<levels)
-    {
+  {
     int blocks=output->GetNumberOfDataSets(level);
     int block=0;
     while(block<blocks)
-      {
+    {
       vtkUniformGrid *grid;
       grid=vtkUniformGrid::SafeDownCast(output->GetDataSet(level,block));
       assert("check: grid_exists" && grid!=0);
@@ -1289,18 +1288,18 @@ void vtkTemporalFractal::AddDepthArray(vtkHierarchicalBoxDataSet *output)
       array->Allocate(numCells);
       int cell=0;
       while(cell<numCells)
-        {
+      {
         array->InsertNextValue(level);
         ++cell;
-        }
+      }
       array->SetName("Depth");
       grid->GetCellData()->AddArray(array);
       array->Delete();
       ++block;
       ++blockId;
-      }
-    ++level;
     }
+    ++level;
+  }
 }
 
 void vtkTemporalFractal::AddGhostLevelArray(vtkDataSet *grid,
@@ -1317,17 +1316,17 @@ void vtkTemporalFractal::AddGhostLevelArray(vtkDataSet *grid,
   dims[2]=dim[2];
 
   if(dims[0]>1)
-    {
+  {
     --dims[0];
-    }
+  }
   if(dims[1]>1)
-    {
+  {
     --dims[1];
-      }
+  }
   if(dims[2]>1)
-    {
+  {
     --dims[2];
-    }
+  }
 
   int numCells=grid->GetNumberOfCells();
   array->SetNumberOfTuples(numCells);
@@ -1340,86 +1339,86 @@ void vtkTemporalFractal::AddGhostLevelArray(vtkDataSet *grid,
 
 
   for (k = 0; k < dims[2]; ++k)
-    {
+  {
     // ghost level at the beginning
     if(onFace[4])
-      {
+    {
       kLevel=this->GhostLevels-1 - k; // or =-k
-      }
+    }
     else
-      {
+    {
       kLevel = this->GhostLevels - k;
-      }
+    }
     // ghost level at the end.
     if(onFace[5])
-      {
+    {
       tmp = k - dims[2] + 1 + this->GhostLevels-1;
-      }
+    }
     else
-      {
+    {
       tmp = k - dims[2] + 1 + this->GhostLevels;
-      }
+    }
     if (tmp > kLevel) { kLevel = tmp;}
     if (this->TwoDimensional)
-      {
+    {
       kLevel = 0;
-        }
+    }
     for (j = 0; j < dims[1]; ++j)
-      {
+    {
       jLevel = kLevel;
       if(onFace[2])
-        {
+      {
         tmp = this->GhostLevels-1 - j;
-        }
+      }
       else
-        {
+      {
         tmp = this->GhostLevels - j;
-        }
+      }
       if (tmp > jLevel) { jLevel = tmp;}
       if(onFace[3])
-          {
+      {
           tmp = j - dims[1] + 1 + this->GhostLevels-1;
-          }
+      }
       else
-        {
+      {
         tmp = j - dims[1] + 1 + this->GhostLevels;
-        }
+      }
       if (tmp > jLevel) { jLevel = tmp;}
       for (i = 0; i < dims[0]; ++i)
-        {
+      {
         iLevel = jLevel;
         if(onFace[0])
-          {
+        {
           tmp = this->GhostLevels-1 - i;
-          }
+        }
         else
-          {
+        {
           tmp = this->GhostLevels - i;
-          }
+        }
         if (tmp > iLevel) { iLevel = tmp;}
         if(onFace[1])
-          {
+        {
           tmp = i - dims[0] + 1 + this->GhostLevels-1;
-          }
+        }
         else
-          {
+        {
           tmp = i - dims[0] + 1 + this->GhostLevels;
-          }
+        }
         if (tmp > iLevel) { iLevel = tmp;}
 
         if (iLevel <= 0)
-          {
+        {
           *ptr = 0;
-          }
-        else
-          {
-          *ptr = iLevel;
-          }
-        ++ptr;
         }
+        else
+        {
+          *ptr |= vtkDataSetAttributes::DUPLICATECELL;
+        }
+        ++ptr;
       }
     }
-  array->SetName("vtkGhostLevels");
+  }
+  array->SetName(vtkDataSetAttributes::GhostArrayName());
   grid->GetCellData()->AddArray(array);
   array->Delete();
 }
@@ -1461,17 +1460,17 @@ void vtkTemporalFractal::ExecuteRectilinearMandelbrot(
   // we need the dimensions according to the cells
 
   if(dims[0]>1)
-    {
+  {
     --dims[0];
-    }
+  }
   if(dims[1]>1)
-    {
+  {
     --dims[1];
-    }
+  }
   if(dims[2]>1)
-    {
+  {
     --dims[2];
-    }
+  }
 
   int ext[6];
   double p[4];
@@ -1504,9 +1503,9 @@ void vtkTemporalFractal::ExecuteRectilinearMandelbrot(
 
   // Copy origin into pixel
   for (idx0 = 0; idx0 < 4; ++idx0)
-    {
+  {
     p[idx0] = origin[idx0];
-    }
+  }
 
   min0 = ext[0];
   max0 = ext[1];
@@ -1514,15 +1513,15 @@ void vtkTemporalFractal::ExecuteRectilinearMandelbrot(
   this->GetContinuousIncrements(ext, inc0, inc1, inc2);
 
   for (idx2 = ext[4]; idx2 <= ext[5]; ++idx2)
-    {
+  {
     p[a2] = coords[a2]->GetTuple1(idx2)+
       0.5*(coords[a2]->GetTuple1(idx2+1)-coords[a2]->GetTuple1(idx2));
     for (idx1 = ext[2]; idx1 <= ext[3]; ++idx1)
-      {
+    {
       p[a1] = coords[a1]->GetTuple1(idx1)+
         0.5*(coords[a1]->GetTuple1(idx1+1)-coords[a1]->GetTuple1(idx1));
       for (idx0 = min0; idx0 <= max0; ++idx0)
-        {
+      {
         p[a0] = coords[a0]->GetTuple1(idx0)+
           0.5*(coords[a0]->GetTuple1(idx0+1)-coords[a0]->GetTuple1(idx0));
 
@@ -1531,11 +1530,11 @@ void vtkTemporalFractal::ExecuteRectilinearMandelbrot(
 
         ++ptr;
         // inc0 is 0
-        }
-      ptr += inc1;
       }
-    ptr += inc2;
+      ptr += inc1;
     }
+    ptr += inc2;
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -1558,7 +1557,7 @@ double vtkTemporalFractal::EvaluateSet(double p[4])
   v0 = 0.0;
   v1 = (zReal2 + zImag2);
   while ( v1 < 4.0 && count < maximumNumberOfIterations)
-    {
+  {
     zImag = 2.0 * zReal * zImag + cImag;
     zReal = zReal2 - zImag2 + cReal;
     zReal2 = zReal * zReal;
@@ -1566,12 +1565,12 @@ double vtkTemporalFractal::EvaluateSet(double p[4])
     ++count;
     v0 = v1;
     v1 = (zReal2 + zImag2);
-    }
+  }
 
   if (count == maximumNumberOfIterations)
-    {
+  {
     return (double)count;
-    }
+  }
 
   return (double)count + (4.0 - v0)/(v1 - v0);
 }
@@ -1598,10 +1597,10 @@ void vtkTemporalFractal::GetContinuousIncrements(int extent[6],
   int increments[3];
 
   for (idx = 0; idx < 3; ++idx)
-    {
+  {
     increments[idx] = inc;
     inc *= (extent[idx*2+1] - extent[idx*2] + 1);
-    }
+  }
 
   incY = increments[1] - (e1 - e0 + 1)*increments[0];
   incZ = increments[2] - (e3 - e2 + 1)*increments[1];
@@ -1622,12 +1621,12 @@ void vtkTemporalFractal::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "Asymetric: " << this->Asymetric << endl;
   os << indent << "GenerateRectilinearGrids: ";
   if(this->GenerateRectilinearGrids)
-    {
+  {
     os << "True";
-    }
+  }
   else
-    {
+  {
     os << "False";
-    }
+  }
   os<< endl;
 }
