@@ -27,7 +27,7 @@
 #include "vtkInformationVector.h"
 #include "vtkSmartPointer.h"
 
-#include <math.h>
+#include <cmath>
 #include <string>
 
 vtkStandardNewMacro(vtkParametricFunctionSource);
@@ -58,10 +58,10 @@ namespace {
   void addTriCells(vtkIdType *&idPtr,
     int id1, int id2, int id3, int id4,
     bool clockwise)
-    {
+  {
       *(idPtr++) = 3;
       if ( clockwise )
-        {
+      {
         *(idPtr++) = id1;
         *(idPtr++) = id2;
         *(idPtr++) = id3;
@@ -69,19 +69,19 @@ namespace {
         *(idPtr++) = id1;
         *(idPtr++) = id3;
         *(idPtr++) = id4;
-        }
-      else
-        {
-        *(idPtr++) = id1;
-        *(idPtr++) = id3;
-        *(idPtr++) = id2;
-        *(idPtr++) = 3;
-        *(idPtr++) = id1;
-        *(idPtr++) = id4;
-        *(idPtr++) = id3;
-        }
       }
-    }
+      else
+      {
+        *(idPtr++) = id1;
+        *(idPtr++) = id3;
+        *(idPtr++) = id2;
+        *(idPtr++) = 3;
+        *(idPtr++) = id1;
+        *(idPtr++) = id4;
+        *(idPtr++) = id3;
+      }
+  }
+}
 
 //----------------------------------------------------------------------------
 void vtkParametricFunctionSource::MakeTriangles ( vtkCellArray * cells,
@@ -102,90 +102,90 @@ void vtkParametricFunctionSource::MakeTriangles ( vtkCellArray * cells,
   vtkIdType *idPtr = cells->WritePointer(numCells,numCells*4);
 
   for ( int i = 0; i < PtsU - 1; ++i )
-    {
+  {
     // Fill the allocated space with the indexes to the points.
     for ( int j = 0; j < PtsV - 1; ++j )
-      {
+    {
       id1 = j + i * PtsV;
       id2 = id1 + PtsV;
       id3 = id2 + 1;
       id4 = id1 + 1;
       addTriCells(idPtr,id1,id2,id3,id4,clockwise);
-      }
+    }
     // If necessary, connect the ends of the triangle strip.
     if ( this->ParametricFunction->GetJoinV() )
-      {
+    {
       id1 = id4;
       id2 = id3;
       if ( this->ParametricFunction->GetTwistV() )
-        {
+      {
         id3 = (i + 1) * PtsV;
         id4 = i * PtsV;
-        }
+      }
       else
-        {
+      {
         id3 = i * PtsV;
         id4 = (i + 1) * PtsV;
-        }
-      addTriCells(idPtr,id1,id2,id3,id4,clockwise);
       }
+      addTriCells(idPtr,id1,id2,id3,id4,clockwise);
     }
+  }
   // If required, connect the last triangle strip to the first by
   // adding a new triangle strip and filling it with the indexes
   // to the points.
   if ( this->ParametricFunction->GetJoinU() )
-    {
+  {
     for ( int j = 0; j < PtsV - 1; ++j )
-      {
+    {
       id1 = j + (PtsU - 1) * PtsV;
       id3 = id1 + 1;
       if ( this->ParametricFunction->GetTwistU() )
-        {
+      {
         id2 = PtsV - 1 - j;
         id4 = id2 - 1;
-        }
+      }
       else
-        {
+      {
         id2 = j;
         id4 = id2 + 1;
-        }
-      addTriCells(idPtr,id1,id2,id3,id4,clockwise);
       }
+      addTriCells(idPtr,id1,id2,id3,id4,clockwise);
+    }
 
     // If necessary, connect the ends of the triangle strip.
     if ( this->ParametricFunction->GetJoinV() )
-      {
+    {
       id1 = id3;
       id2 = id4;
       if ( this->ParametricFunction->GetTwistU() )
-        {
+      {
         if ( this->ParametricFunction->GetTwistV() )
-          {
+        {
           id3 = PtsV - 1;
           id4 = ( PtsU - 1 ) * PtsV;
-          }
+        }
         else
-          {
+        {
           id3 = ( PtsU - 1 ) * PtsV;
           id4 = PtsV - 1;
-          }
         }
+      }
       else
-        {
+      {
         if ( this->ParametricFunction->GetTwistV() )
-          {
+        {
           id3 = 0;
           id4 = ( PtsU - 1 ) * PtsV;
-          }
+        }
         else
-          {
+        {
           id3 = ( PtsU - 1 ) * PtsV;
           id4 = 0;
-          }
         }
-      addTriCells(idPtr,id1,id2,id3,id4,clockwise);
       }
+      addTriCells(idPtr,id1,id2,id3,id4,clockwise);
     }
+  }
   cells->Modified();
   vtkDebugMacro(<< "MakeTriangles() finished.");
 }
@@ -199,13 +199,13 @@ int vtkParametricFunctionSource::RequestData(vtkInformation *vtkNotUsed(info),
 
   // Check that a parametric function has been defined
   if ( !this->ParametricFunction )
-    {
+  {
     vtkErrorMacro(<<"Parametric function not defined");
     return 1;
-    }
+  }
 
   switch ( this->ParametricFunction->GetDimension() )
-    {
+  {
     case 1:
       this->Produce1DOutput(output);
       break;
@@ -216,7 +216,7 @@ int vtkParametricFunctionSource::RequestData(vtkInformation *vtkNotUsed(info),
       vtkErrorMacro("Functions of dimension "
                     << this->ParametricFunction->GetDimension()
                     << " are not supported.");
-    }
+  }
 
   return 1;
 }
@@ -230,13 +230,13 @@ void vtkParametricFunctionSource::Produce1DOutput(vtkInformationVector *output)
 
   // Set the desired precision for the points in the output.
   if(this->OutputPointsPrecision == vtkAlgorithm::DOUBLE_PRECISION)
-    {
+  {
     pts->SetDataType(VTK_DOUBLE);
-    }
+  }
   else
-    {
+  {
     pts->SetDataType(VTK_FLOAT);
-    }
+  }
 
   pts->SetNumberOfPoints(numPts);
   vtkIdType i;
@@ -247,12 +247,12 @@ void vtkParametricFunctionSource::Produce1DOutput(vtkInformationVector *output)
 
   // Insert points and cell points
   for (i=0; i<numPts; i++)
-    {
+  {
     t[0] = (double) i/this->UResolution;
     this->ParametricFunction->Evaluate(t,x,Du);
     pts->SetPoint(i,x);
     lines->InsertCellPoint(i);
-    }
+  }
 
   vtkInformation *outInfo = output->GetInformationObject(0);
   vtkPolyData *outData = static_cast<vtkPolyData*>
@@ -281,40 +281,40 @@ void vtkParametricFunctionSource::Produce2DOutput(vtkInformationVector *output)
   // Scalars associated with each point
   vtkSmartPointer<vtkFloatArray> sval = vtkSmartPointer<vtkFloatArray>::New();
   if ( this->ScalarMode != SCALAR_NONE )
-    {
+  {
     sval->SetNumberOfTuples(totPts);
     sval->SetName("Scalars");
-    }
+  }
 
   // The normals to the surface
   vtkSmartPointer<vtkFloatArray> nval = vtkSmartPointer<vtkFloatArray>::New();
   if (this->GenerateNormals)
-    {
+  {
     nval->SetNumberOfComponents(3);
     nval->SetNumberOfTuples(totPts);
     nval->SetName("Normals");
-    }
+  }
 
   // Texture coordinates
   vtkSmartPointer<vtkFloatArray> newTCoords = vtkSmartPointer<vtkFloatArray>::New();
   if ( this->GenerateTextureCoordinates != 0 )
-    {
+  {
     newTCoords->SetNumberOfComponents(2);
     newTCoords->Allocate(2*totPts);
     newTCoords->SetName("Textures");
-    }
+  }
 
   vtkSmartPointer<vtkPoints> points = vtkSmartPointer<vtkPoints>::New();
 
   // Set the desired precision for the points in the output.
   if(this->OutputPointsPrecision == vtkAlgorithm::DOUBLE_PRECISION)
-    {
+  {
     points->SetDataType(VTK_DOUBLE);
-    }
+  }
   else
-    {
+  {
     points->SetDataType(VTK_FLOAT);
-    }
+  }
 
   points->SetNumberOfPoints( totPts );
 
@@ -325,16 +325,16 @@ void vtkParametricFunctionSource::Produce2DOutput(vtkInformationVector *output)
   double u0 = this->ParametricFunction->GetMinimumU();
   double u_mp = (MaxU - u0)/2.0 + u0 - uStep;
   while ( u0 < u_mp )
-    {
+  {
     u0 += uStep;
-    }
+  }
 
   double v0 = this->ParametricFunction->GetMinimumV();
   double v_mp = (MaxV - v0)/2.0 + v0 - vStep;
   while ( v0 < v_mp )
-    {
+  {
     v0 += vStep;
-    }
+  }
   u_mp += uStep;
   v_mp += vStep;
 
@@ -352,25 +352,25 @@ void vtkParametricFunctionSource::Produce2DOutput(vtkInformationVector *output)
   float MaxJ = PtsV - 1;
 
   for ( int i = 0; i < PtsU; ++i )
-    {
+  {
     uv[0] += uStep;
     uv[1] = this->ParametricFunction->GetMinimumV() - vStep;
 
     double tc[2];
     if ( this->GenerateTextureCoordinates != 0 )
-      {
+    {
       tc[0] = i/MaxI;
-      }
+    }
 
     for ( int j = 0; j < PtsV; ++j )
-      {
+    {
       uv[1] += vStep;
 
       if ( this->GenerateTextureCoordinates != 0 )
-        {
+      {
         tc[1] = 1.0 - j/MaxJ;
         newTCoords->InsertNextTuple(tc);
-        }
+      }
 
       // The point
       double Pt[3];
@@ -387,9 +387,9 @@ void vtkParametricFunctionSource::Produce2DOutput(vtkInformationVector *output)
       double scalar;
 
       if ( this->ScalarMode != SCALAR_NONE )
-        {
+      {
         switch ( this->ScalarMode )
-          {
+        {
           case SCALAR_U:
             scalar = uv[0];
             break;
@@ -406,22 +406,22 @@ void vtkParametricFunctionSource::Produce2DOutput(vtkInformationVector *output)
             scalar = 0;
             // u0, v0
             if ( uv[0] == u0 && uv[1] == v0 )
-              {
+            {
               scalar = 3;
-              }
+            }
             else
-              {
+            {
               // u0 line
               if ( uv[0] == u0 )
-                {
+              {
                 scalar = 1;
-                }
+              }
               else
-                {
+              {
                 // v0 line
                 if ( uv[1] == v0 ) scalar = 2;
-                }
               }
+            }
             break;
           case SCALAR_MODULUS:
             rel_u = uv[0] - u_mp;
@@ -443,23 +443,23 @@ void vtkParametricFunctionSource::Produce2DOutput(vtkInformationVector *output)
             break;
           case SCALAR_QUADRANT:
             if ( uv[0] >= u0 && uv[1] >= v0 )
-              {
+            {
               scalar = 1;
               break;
-              }
+            }
             if ( uv[0] < u0 && uv[1] >= v0 )
-              {
+            {
               scalar = 2;
               break;
-              }
+            }
             if ( uv[0] < u0 && uv[1] < v0 )
-              {
+            {
               scalar = 3;
-              }
+            }
             else
-              {
+            {
               scalar = 4;
-              }
+            }
             break;
           case SCALAR_X:
             scalar = Pt[0];
@@ -479,23 +479,23 @@ void vtkParametricFunctionSource::Produce2DOutput(vtkInformationVector *output)
           case SCALAR_NONE:
           default:
             scalar = 0;
-          }
-        sval->SetValue(k, scalar);
         }
+        sval->SetValue(k, scalar);
+      }
 
       // Calculate the normal.
       if ( this->ParametricFunction->GetDerivativesAvailable() &&
            this->GenerateNormals)
-        {
+      {
         double n[3];
         vtkMath::Cross(Du,Dv,n);
         vtkMath::Normalize(n);
         nval->SetTuple3(k, n[0], n[1], n[2]);
-        }
+      }
 
       ++k;
-      }
     }
+  }
 
   vtkInformation *outInfo = output->GetInformationObject(0);
   vtkPolyData *outData = static_cast<vtkPolyData*>(outInfo->Get( vtkDataObject::DATA_OBJECT() ));
@@ -505,33 +505,36 @@ void vtkParametricFunctionSource::Produce2DOutput(vtkInformationVector *output)
   outData->SetPolys(tris);
 
   if (this->GenerateNormals)
-    {
+  {
     if (this->ParametricFunction->GetDerivativesAvailable())
-      {
+    {
       outData->GetPointData()->SetNormals( nval );
-      }
+    }
     else
-      {
+    {
       // Used to hold the surface
       vtkSmartPointer<vtkPolyData> pd = vtkSmartPointer<vtkPolyData>::New();
       pd->SetPoints( points );
       pd->SetPolys( tris );
       vtkSmartPointer<vtkPolyDataNormals> norm = vtkSmartPointer<vtkPolyDataNormals>::New();
+      // we prevent vtkPolyDataNormals from generating new points
+      // so that the number of newTCoords matches the number of points.
+      norm->SplittingOff();
       norm->SetInputData(pd);
       norm->Update();
       outData->DeepCopy(norm->GetOutput());
-      }
     }
+  }
 
   tris->Delete();
   if ( this->ScalarMode != SCALAR_NONE )
-    {
+  {
     outData->GetPointData()->SetScalars( sval );
-    }
+  }
   if ( this->GenerateTextureCoordinates != 0 )
-    {
+  {
     outData->GetPointData()->SetTCoords( newTCoords );
-    }
+  }
   outData->Modified();
 }
 
@@ -601,16 +604,16 @@ void vtkParametricFunctionSource::SetAllParametricTriangulatorParameters (
 */
 
 //----------------------------------------------------------------------------
-unsigned long vtkParametricFunctionSource::GetMTime()
+vtkMTimeType vtkParametricFunctionSource::GetMTime()
 {
-  unsigned long mTime=this->Superclass::GetMTime();
-  unsigned long funcMTime;
+  vtkMTimeType mTime=this->Superclass::GetMTime();
+  vtkMTimeType funcMTime;
 
   if ( this->ParametricFunction != NULL )
-    {
+  {
     funcMTime = this->ParametricFunction->GetMTime();
     mTime = ( funcMTime > mTime ? funcMTime : mTime );
-    }
+  }
 
   return mTime;
 }
@@ -625,13 +628,13 @@ void vtkParametricFunctionSource::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "W Resolution: " << this->WResolution << "\n";
 
   if ( this->ParametricFunction )
-    {
+  {
     os << indent << "Parametric Function: " << this->ParametricFunction << "\n";
-    }
+  }
   else
-    {
+  {
     os << indent << "No Parametric function defined\n";
-    }
+  }
 
   std::string s;
   switch ( this->ScalarMode )
@@ -680,7 +683,7 @@ void vtkParametricFunctionSource::PrintSelf(ostream& os, vtkIndent indent)
     break;
   default:
     s = "Unknown scalar mode.";
-   }
+  }
   os << indent << "Scalar Mode: " << s.c_str() << "\n";
   os << indent << "GenerateTextureCoordinates:" << (this->GenerateTextureCoordinates ? "On" : "Off" ) << "\n";
   os << indent << "Output Points Precision: " << this->OutputPointsPrecision
