@@ -23,7 +23,7 @@
 
 /*========================================================================
  For general information about using VTK and Qt, see:
- http://www.trolltech.com/products/3rdparty/vtksupport.html
+ http://www.vtk.org/Wiki/VTK/Examples/Cxx#Qt
 =========================================================================*/
 
 #ifdef _MSC_VER
@@ -44,8 +44,10 @@
 #include "qsignalmapper.h"
 #include "qtimer.h"
 #include "vtkRenderingOpenGLConfigure.h"
-#if defined(Q_WS_X11)
-#include "qx11info_x11.h"
+#if defined(Q_WS_X11) // aka Qt4
+# include "qx11info_x11.h"
+#elif defined(Q_OS_LINUX) // aka Qt5
+# include <QX11Info>
 #endif
 
 #if defined(Q_OS_WIN)
@@ -55,9 +57,6 @@
 
 #include "vtkInteractorStyleTrackballCamera.h"
 #include "vtkRenderWindow.h"
-#if defined(QVTK_USE_CARBON)
-#  include "vtkCarbonRenderWindow.h"
-#endif
 #include "vtkCommand.h"
 #include "vtkOStrStreamWrapper.h"
 #include "vtkObjectFactory.h"
@@ -69,7 +68,7 @@
 #include "vtkRenderer.h"
 #include "vtkRendererCollection.h"
 
-#if defined(VTK_USE_TDX) && defined(Q_WS_X11)
+#if defined(VTK_USE_TDX) && (defined(Q_WS_X11) || defined(Q_OS_LINUX))
 # include "vtkTDxUnixDevice.h"
 #endif
 
@@ -78,6 +77,7 @@ QVTKWidget::QVTKWidget(QWidget* p, Qt::WindowFlags f)
   : QWidget(p, f | Qt::MSWindowsOwnDC), mRenWin(NULL),
     cachedImageCleanFlag(false),
     automaticImageCache(false), maxImageCacheRenderRate(1.0),
+    mDeferRenderInPaintEvent(false),
     renderEventCallbackObserverId(0)
 {
   this->UseTDx=false;
@@ -104,13 +104,11 @@ QVTKWidget::QVTKWidget(QWidget* p, Qt::WindowFlags f)
   this->mCachedImage->SetOrigin(0,0,0);
   this->mCachedImage->SetSpacing(1,1,1);
 
-#if defined(QVTK_USE_CARBON)
-  this->DirtyRegionHandler = 0;
-  this->DirtyRegionHandlerUPP = 0;
-#endif
-
   mIrenAdapter = new QVTKInteractorAdapter(this);
 
+  this->mDeferedRenderTimer.setSingleShot(true);
+  this->mDeferedRenderTimer.setInterval(0);
+  this->connect(&this->mDeferedRenderTimer, SIGNAL(timeout()), SLOT(doDeferredRender()));
 }
 
 /*! destructor */
@@ -129,28 +127,28 @@ QVTKWidget::~QVTKWidget()
 void QVTKWidget::SetUseTDx(bool useTDx)
 {
   if(useTDx!=this->UseTDx)
-    {
+  {
     this->UseTDx=useTDx;
 
     if(this->UseTDx)
-      {
-#if defined(VTK_USE_TDX) && defined(Q_WS_X11)
+    {
+#if defined(VTK_USE_TDX) && (defined(Q_WS_X11) || defined(Q_OS_LINUX))
        QByteArray theSignal=
          QMetaObject::normalizedSignature("CreateDevice(vtkTDxDevice *)");
       if(QApplication::instance()->metaObject()->indexOfSignal(theSignal)!=-1)
-        {
+      {
         QObject::connect(QApplication::instance(),
                          SIGNAL(CreateDevice(vtkTDxDevice *)),
                          this,
                          SLOT(setDevice(vtkTDxDevice *)));
-        }
-      else
-        {
-        vtkGenericWarningMacro("Missing signal CreateDevice on QApplication. 3DConnexion device will not work. Define it or derive your QApplication from QVTKApplication.");
-        }
-#endif
       }
+      else
+      {
+        vtkGenericWarningMacro("Missing signal CreateDevice on QApplication. 3DConnexion device will not work. Define it or derive your QApplication from QVTKApplication.");
+      }
+#endif
     }
+  }
 }
 
 // ----------------------------------------------------------------------------
@@ -164,12 +162,12 @@ bool QVTKWidget::GetUseTDx() const
 vtkRenderWindow* QVTKWidget::GetRenderWindow()
 {
   if (!this->mRenWin)
-    {
+  {
     // create a default vtk window
     vtkRenderWindow* win = vtkRenderWindow::New();
     this->SetRenderWindow(win);
     win->Delete();
-    }
+  }
 
   return this->mRenWin;
 }
@@ -182,45 +180,45 @@ void QVTKWidget::SetRenderWindow(vtkRenderWindow* w)
 {
   // do nothing if we don't have to
   if(w == this->mRenWin)
-    {
+  {
     return;
-    }
+  }
 
   // unregister previous window
   if(this->mRenWin)
-    {
+  {
     if (this->renderEventCallbackObserverId)
-      {
+    {
       this->mRenWin->RemoveObserver(this->renderEventCallbackObserverId);
       this->renderEventCallbackObserverId = 0;
-      }
+    }
     //clean up window as one could remap it
     if(this->mRenWin->GetMapped())
-      {
+    {
       this->mRenWin->Finalize();
-      }
-#ifdef Q_WS_X11
+    }
+#if defined(Q_WS_X11) || defined(Q_OS_LINUX)
     this->mRenWin->SetDisplayId(NULL);
 #endif
     this->mRenWin->SetWindowId(NULL);
     this->mRenWin->UnRegister(NULL);
-    }
+  }
 
   // now set the window
   this->mRenWin = w;
 
   if(this->mRenWin)
-    {
+  {
     // register new window
     this->mRenWin->Register(NULL);
 
     // if it is mapped somewhere else, unmap it
     if(this->mRenWin->GetMapped())
-      {
+    {
       this->mRenWin->Finalize();
-      }
+    }
 
-#ifdef Q_WS_X11
+#if defined(Q_WS_X11) || defined(Q_OS_LINUX)
     // give the qt display id to the vtk window
     this->mRenWin->SetDisplayId(QX11Info::display());
 #endif
@@ -237,13 +235,13 @@ void QVTKWidget::SetRenderWindow(vtkRenderWindow* w)
 
     // have VTK start this window and create the necessary graphics resources
     if(isVisible())
-      {
+    {
       this->mRenWin->Start();
-      }
+    }
 
     // if an interactor wasn't provided, we'll make one by default
     if(!this->mRenWin->GetInteractor())
-      {
+    {
       // create a default interactor
       QVTKInteractor* iren = QVTKInteractor::New();
       iren->SetUseTDx(this->UseTDx);
@@ -256,7 +254,7 @@ void QVTKWidget::SetRenderWindow(vtkRenderWindow* w)
 
       iren->Delete();
       s->Delete();
-      }
+    }
 
     // tell the interactor the size of this window
     this->mRenWin->GetInteractor()->SetSize(this->width(), this->height());
@@ -267,28 +265,7 @@ void QVTKWidget::SetRenderWindow(vtkRenderWindow* w)
     this->renderEventCallbackObserverId =
       this->mRenWin->AddObserver(vtkCommand::RenderEvent,
         this, &QVTKWidget::renderEventCallback);
-    }
-
-#if defined(QVTK_USE_CARBON)
-  if(mRenWin && !this->DirtyRegionHandlerUPP)
-    {
-    this->DirtyRegionHandlerUPP = NewEventHandlerUPP(QVTKWidget::DirtyRegionProcessor);
-    static EventTypeSpec events[] = { {'cute', 20}, {'Cute', 20} };
-    // kEventClassQt, kEventQtRequestWindowChange from qt_mac_p.h
-    // Suggested by Sam Magnuson at Trolltech as best portabile hack
-    // around Apple's missing functionality in HI Toolbox.
-    InstallEventHandler(GetApplicationEventTarget(), this->DirtyRegionHandlerUPP,
-                        GetEventTypeCount(events), events,
-                        reinterpret_cast<void*>(this), &this->DirtyRegionHandler);
-    }
-  else if(!mRenWin && this->DirtyRegionHandlerUPP)
-    {
-    RemoveEventHandler(this->DirtyRegionHandler);
-    DisposeEventHandlerUPP(this->DirtyRegionHandlerUPP);
-    this->DirtyRegionHandler = 0;
-    this->DirtyRegionHandlerUPP = 0;
-    }
-#endif
+  }
 }
 
 
@@ -304,24 +281,24 @@ QVTKInteractor* QVTKWidget::GetInteractor()
 void QVTKWidget::markCachedImageAsDirty()
 {
   if (this->cachedImageCleanFlag)
-    {
+  {
     this->cachedImageCleanFlag = false;
     emit cachedImageDirty();
-    }
+  }
 }
 
 void QVTKWidget::saveImageToCache()
 {
   if (this->cachedImageCleanFlag)
-    {
+  {
     return;
-    }
+  }
 
   int w = this->width();
   int h = this->height();
   this->mCachedImage->SetExtent(0, w-1, 0, h-1, 0, 0);
   this->mCachedImage->AllocateScalars(VTK_UNSIGNED_CHAR, 3);
-  vtkUnsignedCharArray* array = vtkUnsignedCharArray::SafeDownCast(
+  vtkUnsignedCharArray* array = vtkArrayDownCast<vtkUnsignedCharArray>(
     this->mCachedImage->GetPointData()->GetScalars());
   // We use back-buffer if
   this->mRenWin->GetPixelData(0, 0, this->width()-1, this->height()-1,
@@ -334,11 +311,12 @@ void QVTKWidget::setAutomaticImageCacheEnabled(bool flag)
 {
   this->automaticImageCache = flag;
   if (!flag)
-    {
+  {
     this->mCachedImage->Initialize();
     this->mCachedImage->SetOrigin(0,0,0);
     this->mCachedImage->SetSpacing(1,1,1);
-    }
+    this->markCachedImageAsDirty();
+  }
 }
 bool QVTKWidget::isAutomaticImageCacheEnabled() const
 {
@@ -354,6 +332,16 @@ double QVTKWidget::maxRenderRateForImageCache() const
   return this->maxImageCacheRenderRate;
 }
 
+void QVTKWidget::setDeferRenderInPaintEvent(bool val)
+{
+  this->mDeferRenderInPaintEvent = val;
+}
+
+bool QVTKWidget::deferRenderInPaintEvent() const
+{
+  return this->mDeferRenderInPaintEvent;
+}
+
 vtkImageData* QVTKWidget::cachedImage()
 {
   // Make sure image is up to date.
@@ -369,45 +357,58 @@ vtkImageData* QVTKWidget::cachedImage()
 bool QVTKWidget::event(QEvent* e)
 {
   if(e->type() == QEvent::ParentAboutToChange)
-    {
+  {
     this->markCachedImageAsDirty();
     if (this->mRenWin)
-      {
+    {
       // Finalize the window to remove graphics resources associated with
       // this window
       if(this->mRenWin->GetMapped())
-        {
+      {
         this->mRenWin->Finalize();
-        }
       }
     }
+  }
   else if(e->type() == QEvent::ParentChange)
-    {
+  {
     if(this->mRenWin)
-      {
+    {
       x11_setup_window();
       // connect to new window
       this->mRenWin->SetWindowId( reinterpret_cast<void*>(this->winId()));
 
       // start up the window to create graphics resources for this window
       if(isVisible())
-        {
+      {
         this->mRenWin->Start();
-        }
       }
     }
+  }
+  else if(e->type() == QEvent::TouchBegin ||
+          e->type() == QEvent::TouchUpdate ||
+          e->type() == QEvent::TouchEnd)
+  {
+    if(this->mRenWin)
+    {
+      mIrenAdapter->ProcessEvent(e, this->mRenWin->GetInteractor());
+      if (e->isAccepted())
+      {
+        return true;
+      }
+    }
+  }
 
   if(QObject::event(e))
-    {
+  {
     return true;
-    }
+  }
 
   if(e->type() == QEvent::KeyPress)
-    {
+  {
     QKeyEvent* ke = static_cast<QKeyEvent*>(e);
     this->keyPressEvent(ke);
     return ke->isAccepted();
-    }
+  }
 
   return QWidget::event(e);
 }
@@ -420,9 +421,9 @@ void QVTKWidget::resizeEvent(QResizeEvent* e)
   QWidget::resizeEvent(e);
 
   if(!this->mRenWin)
-    {
+  {
     return;
-    }
+  }
 
   // Don't set size on subclass of vtkRenderWindow or it triggers recursion.
   // Getting this event in the first place means the window was already
@@ -431,9 +432,9 @@ void QVTKWidget::resizeEvent(QResizeEvent* e)
 
   // and update the interactor
   if(this->mRenWin->GetInteractor())
-    {
+  {
     mIrenAdapter->ProcessEvent(e, this->mRenWin->GetInteractor());
-    }
+  }
 
   this->markCachedImageAsDirty();
 }
@@ -443,9 +444,9 @@ void QVTKWidget::moveEvent(QMoveEvent* e)
   QWidget::moveEvent(e);
 
   if(!this->mRenWin)
-    {
+  {
     return;
-    }
+  }
 
   // Don't set size on subclass of vtkRenderWindow or it triggers recursion.
   // Getting this event in the first place means the window was already
@@ -457,30 +458,39 @@ void QVTKWidget::moveEvent(QMoveEvent* e)
  */
 void QVTKWidget::paintEvent(QPaintEvent* )
 {
-  vtkRenderWindowInteractor* iren = NULL;
-  if(this->mRenWin)
-    {
-    iren = this->mRenWin->GetInteractor();
-    }
-
-  if(!iren || !iren->GetEnabled())
-    {
+  vtkRenderWindowInteractor* iren = this->mRenWin ? this->mRenWin->GetInteractor() : NULL;
+  if (!iren || !iren->GetEnabled())
+  {
     return;
-    }
-
-  // if we have a saved image, use it
-  if (this->paintCachedImage())
-    {
-    return;
-    }
-
-  iren->Render();
+  }
 
   // In Qt 4.1+ let's support redirected painting
   // if redirected, let's grab the image from VTK, and paint it to the device
   QPaintDevice* device = QPainter::redirected(this);
-  if(device != NULL && device != this)
+  bool usingRedirectedDevice = (device != NULL && device != this);
+
+  // if we have a saved image, use it
+  if (this->paintCachedImage() == false)
+  {
+    // we don't defer render in redirected painting is active since the target
+    // being painted to may not be around when the deferred render call happens.
+    if (!usingRedirectedDevice && this->mDeferRenderInPaintEvent)
     {
+      this->deferRender();
+    }
+    else
+    {
+      iren->Render();
+    }
+  }
+
+  // Irrespective of whether cache was used on or, if using redirected painting
+  // is being employed, we need to "paint" the image from the render window to
+  // the redirected target.
+  if (usingRedirectedDevice)
+  {
+    Q_ASSERT(device);
+
     int w = this->width();
     int h = this->height();
     QImage img(w, h, QImage::Format_RGB32);
@@ -493,8 +503,7 @@ void QVTKWidget::paintEvent(QPaintEvent* )
 
     QPainter painter(this);
     painter.drawImage(QPointF(0.0,0.0), img);
-    return;
-    }
+  }
 }
 
 /*! handle mouse press event
@@ -506,9 +515,9 @@ void QVTKWidget::mousePressEvent(QMouseEvent* e)
   emit mouseEvent(e);
 
   if(this->mRenWin)
-    {
+  {
     mIrenAdapter->ProcessEvent(e, this->mRenWin->GetInteractor());
-    }
+  }
 
 }
 
@@ -517,12 +526,12 @@ void QVTKWidget::mousePressEvent(QMouseEvent* e)
 void QVTKWidget::mouseMoveEvent(QMouseEvent* e)
 {
   if(this->mRenWin)
-    {
+  {
     mIrenAdapter->ProcessEvent(e, this->mRenWin->GetInteractor());
 
     // Emit a mouse press event for anyone who might be interested
     emit mouseEvent(e);
-    }
+  }
 }
 
 
@@ -531,9 +540,9 @@ void QVTKWidget::mouseMoveEvent(QMouseEvent* e)
 void QVTKWidget::enterEvent(QEvent* e)
 {
   if(this->mRenWin)
-    {
+  {
     mIrenAdapter->ProcessEvent(e, this->mRenWin->GetInteractor());
-    }
+  }
 }
 
 /*! handle leave event
@@ -541,9 +550,9 @@ void QVTKWidget::enterEvent(QEvent* e)
 void QVTKWidget::leaveEvent(QEvent* e)
 {
   if(this->mRenWin)
-    {
+  {
     mIrenAdapter->ProcessEvent(e, this->mRenWin->GetInteractor());
-    }
+  }
 }
 
 /*! handle mouse release event
@@ -551,12 +560,12 @@ void QVTKWidget::leaveEvent(QEvent* e)
 void QVTKWidget::mouseReleaseEvent(QMouseEvent* e)
 {
   if(this->mRenWin)
-    {
+  {
     mIrenAdapter->ProcessEvent(e, this->mRenWin->GetInteractor());
 
     // Emit a mouse press event for anyone who might be interested
     emit mouseEvent(e);
-    }
+  }
 }
 
 /*! handle key press event
@@ -564,9 +573,9 @@ void QVTKWidget::mouseReleaseEvent(QMouseEvent* e)
 void QVTKWidget::keyPressEvent(QKeyEvent* e)
 {
   if(this->mRenWin)
-    {
+  {
     mIrenAdapter->ProcessEvent(e, this->mRenWin->GetInteractor());
-    }
+  }
 }
 
 /*! handle key release event
@@ -574,17 +583,17 @@ void QVTKWidget::keyPressEvent(QKeyEvent* e)
 void QVTKWidget::keyReleaseEvent(QKeyEvent* e)
 {
   if(this->mRenWin)
-    {
+  {
     mIrenAdapter->ProcessEvent(e, this->mRenWin->GetInteractor());
-    }
+  }
 }
 
 void QVTKWidget::wheelEvent(QWheelEvent* e)
 {
   if(this->mRenWin)
-    {
+  {
     mIrenAdapter->ProcessEvent(e, this->mRenWin->GetInteractor());
-    }
+  }
 }
 
 void QVTKWidget::focusInEvent(QFocusEvent* e)
@@ -615,41 +624,41 @@ void QVTKWidget::focusOutEvent(QFocusEvent* e)
 void QVTKWidget::contextMenuEvent(QContextMenuEvent* e)
 {
   if(this->mRenWin)
-    {
+  {
     mIrenAdapter->ProcessEvent(e, this->mRenWin->GetInteractor());
-    }
+  }
 }
 
 void QVTKWidget::dragEnterEvent(QDragEnterEvent* e)
 {
   if(this->mRenWin)
-    {
+  {
     mIrenAdapter->ProcessEvent(e, this->mRenWin->GetInteractor());
-    }
+  }
 }
 
 void QVTKWidget::dragMoveEvent(QDragMoveEvent* e)
 {
   if(this->mRenWin)
-    {
+  {
     mIrenAdapter->ProcessEvent(e, this->mRenWin->GetInteractor());
-    }
+  }
 }
 
 void QVTKWidget::dragLeaveEvent(QDragLeaveEvent* e)
 {
   if(this->mRenWin)
-    {
+  {
     mIrenAdapter->ProcessEvent(e, this->mRenWin->GetInteractor());
-    }
+  }
 }
 
 void QVTKWidget::dropEvent(QDropEvent* e)
 {
   if(this->mRenWin)
-    {
+  {
     mIrenAdapter->ProcessEvent(e, this->mRenWin->GetInteractor());
-    }
+  }
 }
 
 void QVTKWidget::showEvent(QShowEvent* e)
@@ -668,7 +677,7 @@ QPaintEngine* QVTKWidget::paintEngine() const
 // X11 stuff near the bottom of the file
 // to prevent namespace collisions with Qt headers
 
-#if defined Q_WS_X11
+#if defined(Q_WS_X11) || defined (Q_OS_LINUX)
 #if defined(VTK_USE_OPENGL_LIBRARY)
 #include "vtkXOpenGLRenderWindow.h"
 #endif
@@ -679,11 +688,11 @@ QPaintEngine* QVTKWidget::paintEngine() const
 // Receive notification of the creation of the TDxDevice
 void QVTKWidget::setDevice(vtkTDxDevice *device)
 {
-#ifdef Q_WS_X11
+#if defined(Q_WS_X11) || defined(Q_OS_LINUX)
   if(this->GetInteractor()->GetDevice()!=device)
-    {
+  {
     this->GetInteractor()->SetDevice(device);
-    }
+  }
 #else
   (void)device; // to avoid warnings.
 #endif
@@ -692,7 +701,10 @@ void QVTKWidget::setDevice(vtkTDxDevice *device)
 
 void QVTKWidget::x11_setup_window()
 {
-#if defined Q_WS_X11
+#if defined(Q_WS_X11)
+  // NOTE: deliberately not executing this code for Qt5. It caused issues with
+  // glewInit() when I did that. Just letting the Qt create the visual/colormap
+  // seems to work better.
 
   // this whole function is to allow this window to have a
   // different colormap and visual than the rest of the Qt application
@@ -705,9 +717,9 @@ void QVTKWidget::x11_setup_window()
   Qt::FocusPolicy focus_policy = focusPolicy();
   bool visible = isVisible();
   if(visible)
-    {
+  {
     hide();
-    }
+  }
 
 
   // get visual and colormap from VTK
@@ -719,22 +731,22 @@ void QVTKWidget::x11_setup_window()
 #if defined(VTK_USE_OPENGL_LIBRARY)
   vtkXOpenGLRenderWindow* ogl_win = vtkXOpenGLRenderWindow::SafeDownCast(mRenWin);
   if(ogl_win)
-    {
+  {
     vi = ogl_win->GetDesiredVisualInfo();
     cmap = ogl_win->GetDesiredColormap();
-    }
+  }
 #endif
 
   // can't get visual, oh well.
   // continue with Qt's default visual as it usually works
   if(!vi)
-    {
+  {
     if(visible)
-      {
+    {
       show();
-      }
-    return;
     }
+    return;
+  }
 
   // create the X window based on information VTK gave us
   XSetWindowAttributes attrib;
@@ -744,9 +756,9 @@ void QVTKWidget::x11_setup_window()
 
   Window p = RootWindow(display, DefaultScreen(display));
   if(parentWidget())
-    {
+  {
     p = parentWidget()->winId();
-    }
+  }
 
   XWindowAttributes a;
   XGetWindowAttributes(display, this->winId(), &a);
@@ -760,30 +772,30 @@ void QVTKWidget::x11_setup_window()
   Window *cmwret;
   int count;
   if ( XGetWMColormapWindows(display, topLevelWidget()->winId(), &cmwret, &count) )
-    {
+  {
     cmw = new Window[count+1];
     memcpy( (char *)cmw, (char *)cmwret, sizeof(Window)*count );
     XFree( (char *)cmwret );
     int i;
     for ( i=0; i<count; i++ )
-      {
+    {
       if ( cmw[i] == winId() )
-        {
+      {
         cmw[i] = win;
         break;
-        }
-      }
-    if ( i >= count )
-      {
-      cmw[count++] = win;
       }
     }
-  else
+    if ( i >= count )
     {
+      cmw[count++] = win;
+    }
+  }
+  else
+  {
     count = 1;
     cmw = new Window[count];
     cmw[0] = win;
-    }
+  }
 
 
   // tell Qt to initialize anything it needs to for this window
@@ -803,9 +815,9 @@ void QVTKWidget::x11_setup_window()
   this->setAttribute(Qt::WA_PaintOnScreen);
   this->setFocusPolicy(focus_policy);
   if(visible)
-    {
+  {
     show();
-    }
+  }
 
 #endif
 }
@@ -818,9 +830,9 @@ bool QVTKWidget::winEvent(MSG* msg, long*)
   // especially when AERO is off.
   if(msg->message == WM_PAINT &&
     QSysInfo::windowsVersion() >= QSysInfo::WV_VISTA)
-    {
+  {
     InvalidateRect((HWND)this->winId(), NULL, FALSE);
-    }
+  }
   return false;
 }
 
@@ -828,37 +840,21 @@ bool QVTKWidget::winEvent(MSG* msg, long*)
 bool QVTKWidget::nativeEvent(const QByteArray& eventType, void* message, long* result)
 {
   if (eventType == "windows_generic_MSG")
-    {
+  {
     winEvent((MSG*)message, result);
-    }
+  }
   return false;
 }
 #endif
 #endif
 
-#if defined (QVTK_USE_CARBON)
-OSStatus QVTKWidget::DirtyRegionProcessor(EventHandlerCallRef, EventRef event, void* wid)
-{
-  QVTKWidget* widget = reinterpret_cast<QVTKWidget*>(wid);
-  UInt32 event_kind = GetEventKind(event);
-  UInt32 event_class = GetEventClass(event);
-  if((event_class == 'cute' || event_class == 'Cute') && event_kind == 20)
-    {
-    static_cast<vtkCarbonRenderWindow*>(widget->GetRenderWindow())->UpdateGLRegion();
-    }
-  return eventNotHandledErr;
-}
-
-#endif
-
-
 //-----------------------------------------------------------------------------
 bool QVTKWidget::paintCachedImage()
 {
   // if we have a saved image, use it
   if (this->cachedImageCleanFlag)
-    {
-    vtkUnsignedCharArray* array = vtkUnsignedCharArray::SafeDownCast(
+  {
+    vtkUnsignedCharArray* array = vtkArrayDownCast<vtkUnsignedCharArray>(
       this->mCachedImage->GetPointData()->GetScalars());
     // put cached image into back buffer if we can
     this->mRenWin->SetPixelData(0, 0, this->width()-1, this->height()-1,
@@ -867,7 +863,7 @@ bool QVTKWidget::paintCachedImage()
     this->mRenWin->Frame();
     // or should we just put it on the front buffer?
     return true;
-    }
+  }
   return false;
 }
 
@@ -875,29 +871,49 @@ bool QVTKWidget::paintCachedImage()
 void QVTKWidget::renderEventCallback()
 {
   if (this->mRenWin)
-    {
+  {
     // prevent capturing the selection buffer as the cached image. to do this
     // we iterate through each renderer in the view and check if they have an
     // active selector object. if so we return without saving the image
     vtkRendererCollection *renderers = this->mRenWin->GetRenderers();
     if(renderers)
-      {
+    {
       renderers->InitTraversal();
 
       while(vtkRenderer *renderer = renderers->GetNextItem())
-        {
+      {
         if(renderer->GetSelector() != NULL)
-          {
+        {
           return;
-          }
         }
       }
+    }
+
+    // Render happened. If we have requested a render to happen, it has happened,
+    // so no need to request another render. Stop the timer.
+    this->mDeferedRenderTimer.stop();
 
     this->markCachedImageAsDirty();
     if (this->isAutomaticImageCacheEnabled() &&
       (this->mRenWin->GetDesiredUpdateRate() < this->maxRenderRateForImageCache()))
-      {
+    {
       this->saveImageToCache();
-      }
     }
+  }
+}
+
+//-----------------------------------------------------------------------------
+void QVTKWidget::deferRender()
+{
+  this->mDeferedRenderTimer.start();
+}
+
+//-----------------------------------------------------------------------------
+void QVTKWidget::doDeferredRender()
+{
+  vtkRenderWindowInteractor* iren = this->mRenWin ? this->mRenWin->GetInteractor() : NULL;
+  if (iren && iren->GetEnabled())
+  {
+    iren->Render();
+  }
 }
