@@ -31,7 +31,7 @@
 #include <string>
 #include <map>
 #include <cassert>
-#include <ctype.h> /* isspace */
+#include <cctype> /* isspace */
 
 vtkStandardNewMacro(vtkGenericEnSightReader);
 
@@ -120,10 +120,10 @@ vtkGenericEnSightReader::~vtkGenericEnSightReader()
   int i;
 
   if (this->Reader)
-    {
+  {
     this->Reader->Delete();
     this->Reader = NULL;
-    }
+  }
   delete this->IS;
   this->IS = NULL;
 
@@ -137,27 +137,27 @@ vtkGenericEnSightReader::~vtkGenericEnSightReader()
   this->FilePath = NULL;
 
   if (this->NumberOfVariables > 0)
-    {
+  {
     for (i = 0; i < this->NumberOfVariables; i++)
-      {
+    {
       delete [] this->VariableDescriptions[i];
-      }
+    }
     delete [] this->VariableDescriptions;
     delete [] this->VariableTypes;
     this->VariableDescriptions = NULL;
     this->VariableTypes = NULL;
-    }
+  }
   if (this->NumberOfComplexVariables > 0)
-    {
+  {
     for (i = 0; i < this->NumberOfComplexVariables; i++)
-      {
+    {
       delete [] this->ComplexVariableDescriptions[i];
-      }
+    }
     delete [] this->ComplexVariableDescriptions;
     delete [] this->ComplexVariableTypes;
     this->ComplexVariableDescriptions = NULL;
     this->ComplexVariableTypes = NULL;
-    }
+  }
 
   this->SetTimeSets(0);
   this->CellDataArraySelection->RemoveObserver(this->SelectionObserver);
@@ -187,9 +187,9 @@ int vtkGenericEnSightReader::RequestData(
   int i;
 
   if ( !this->Reader )
-    {
+  {
     return 0;
-    }
+  }
 
   vtkInformation *outInfo = outputVector->GetInformationObject(0);
 
@@ -201,10 +201,10 @@ int vtkGenericEnSightReader::RequestData(
   vtkInformation* tmpOutInfo =
     this->Reader->GetExecutive()->GetOutputInformation(0);
   if (outInfo->Has(vtkStreamingDemandDrivenPipeline::UPDATE_TIME_STEP()))
-    {
+  {
     tmpOutInfo->Set(vtkStreamingDemandDrivenPipeline::UPDATE_TIME_STEP(),
                     outInfo->Get(vtkStreamingDemandDrivenPipeline::UPDATE_TIME_STEP()));
-    }
+  }
 
   // GHOST LEVEL
   // uncomment these lines below if you want to active
@@ -249,43 +249,43 @@ int vtkGenericEnSightReader::RequestData(
   output->ShallowCopy(this->Reader->GetOutput());
 
   if (this->NumberOfVariables > 0)
-    {
+  {
     for (i = 0; i < this->NumberOfVariables; i++)
-      {
+    {
       delete [] this->VariableDescriptions[i];
-      }
+    }
     delete [] this->VariableDescriptions;
     delete [] this->VariableTypes;
     this->VariableDescriptions = NULL;
     this->VariableTypes = NULL;
     this->NumberOfVariables = 0;
-    }
+  }
   if (this->NumberOfComplexVariables > 0)
-    {
+  {
     for (i = 0; i < this->NumberOfComplexVariables; i++)
-      {
+    {
       delete [] this->ComplexVariableDescriptions[i];
-      }
+    }
     delete [] this->ComplexVariableDescriptions;
     delete [] this->ComplexVariableTypes;
     this->ComplexVariableDescriptions = NULL;
     this->ComplexVariableTypes = NULL;
     this->NumberOfComplexVariables = 0;
-    }
+  }
 
   for (i = 0; i < this->Reader->GetNumberOfVariables(); i++)
-    {
+  {
     this->AddVariableDescription(this->Reader->GetDescription(i));
     this->AddVariableType(this->Reader->GetVariableType(i));
     this->NumberOfVariables++;
-    }
+  }
   for (i = 0; i < this->Reader->GetNumberOfComplexVariables(); i++)
-    {
+  {
     this->AddComplexVariableDescription(
       this->Reader->GetComplexDescription(i));
     this->AddComplexVariableType(this->Reader->GetComplexVariableType(i));
     this->NumberOfComplexVariables++;
-    }
+  }
 
   return 1;
 }
@@ -295,10 +295,10 @@ void vtkGenericEnSightReader::SetTimeValue(float value)
 {
   vtkDebugMacro(<< this->GetClassName() << " (" << this << "): setting TimeValue to " << value);
   if (this->TimeValue != value)
-    {
+  {
     this->TimeValue = value;
     this->Modified();
-    }
+  }
   this->TimeValueInitialized = 1;
 }
 
@@ -313,146 +313,147 @@ int vtkGenericEnSightReader::DetermineEnSightVersion(int quiet)
   char *fileName = NULL;
   int lineRead;
   if (!this->CaseFileName)
-    {
+  {
     if (!quiet) vtkErrorMacro("A case file name must be specified.");
     return -1;
-    }
+  }
   std::string sfilename = "";
   if (this->FilePath)
-    {
+  {
     sfilename = this->FilePath;
     if (sfilename.at(sfilename.length()-1) != '/')
-      {
+    {
       sfilename += "/";
-      }
+    }
     sfilename += this->CaseFileName;
     vtkDebugMacro("full path to case file: "
                   << sfilename.c_str());
-    }
+  }
   else
-    {
+  {
     sfilename = this->CaseFileName;
-    }
+  }
 
   this->IS = new ifstream(sfilename.c_str(), ios::in);
   if (this->IS->fail())
-    {
+  {
     if (!quiet) vtkErrorMacro("Unable to open file: " << sfilename.c_str());
     delete this->IS;
     this->IS = NULL;
     return -1;
-    }
+  }
 
   this->ReadNextDataLine(line);
 
   if (strncmp(line, "FORMAT", 6) == 0)
-    {
+  {
     // found the FORMAT section
     vtkDebugMacro("*** FORMAT section");
     this->ReadNextDataLine(line);
 
     stringRead = sscanf(line, " %*s %*s %s", subLine);
     if (stringRead == 1)
-      {
+    {
       sscanf(line, " %*s %s %s", subLine1, subLine2);
       if (strncmp(subLine1,"ensight",7) == 0)
-        {
+      {
         if (strncmp(subLine2,"gold",4) == 0)
-          {
+        {
           lineRead = this->ReadNextDataLine(line);
           while (strncmp(line, "GEOMETRY", 8) != 0 && lineRead != 0)
-            {
+          {
             lineRead = this->ReadNextDataLine(line);
-            }
+          }
           if (lineRead == 0)
-            {
+          {
             return -1;
-            }
+          }
           if (strncmp(line, "GEOMETRY", 8) == 0)
-            {
+          {
             // found the GEOMETRY section
             vtkDebugMacro("*** GEOMETRY section");
 
             this->ReadNextDataLine(line);
             if (strncmp(line, "model:", 6) == 0)
-              {
+            {
               if (sscanf(line, " %*s %d %d %s", &xtimeSet, &fileSet, subLine) == 3)
-                {
+              {
                 timeSet = xtimeSet;
                 fileSet = xfileSet;
                 this->SetGeometryFileName(subLine);
-                }
+              }
               else if (sscanf(line, " %*s %d%*[ \t]%s", &xtimeSet, subLine) == 2)
-                {
+              {
                 timeSet = xtimeSet;
                 this->SetGeometryFileName(subLine);
-                }
+              }
               else if (sscanf(line, " %*s %s", subLine) == 1)
-                {
+              {
                 this->SetGeometryFileName(subLine);
-                }
-              } // geometry file name set
+              }
+            } // geometry file name set
             delete this->IS;
             this->IS = NULL;
 
+            if (!this->GeometryFileName || this->GeometryFileName[0] == '\0')
+            {
+              if (!quiet)
+              {
+                vtkErrorMacro(
+                      "A GeometryFileName must be specified in the case file.");
+              }
+              return 0;
+            }
+
             fileName = new char[strlen(this->GeometryFileName) + 1];
             strcpy(fileName, this->GeometryFileName);
 
-            if (!fileName)
-              {
-              if (!quiet)
-                {
-                vtkErrorMacro(
-                      "A GeometryFileName must be specified in the case file.");
-                }
-              return 0;
-              }
             if (strrchr(fileName, '*') != NULL)
-              {
+            {
               // RE-open case file; find right time set and fill in
               // wildcards from there if possible; if not, then find right
               // file set and fill in wildcards from there.
               if ( this->ReplaceWildcards(fileName, timeSet, fileSet) == 0 )
-                {
+              {
                 if (!quiet)
-                  {
+                {
                   vtkErrorMacro(
                     "upon DetermineEnSightVersion()'s call to ReplaceWildCards()");
-                  }
-                return -1;
                 }
+                return -1;
               }
+            }
             sfilename = "";
             if (this->FilePath)
-              {
+            {
               sfilename = this->FilePath;
               if (sfilename.at(sfilename.length()-1) != '/')
-                {
+              {
                 sfilename += "/";
-                }
+              }
               sfilename += fileName;
               vtkDebugMacro("full path to geometry file: "
                             << sfilename.c_str());
-              }
+            }
             else
-              {
+            {
               sfilename = fileName;
-              }
+            }
 
             // got full path to geometry file
 
             this->IFile = fopen(sfilename.c_str(), "rb");
             if (this->IFile == NULL)
-              {
+            {
               if (!quiet)
-                {
+              {
                 vtkErrorMacro("Unable to open file: " << sfilename.c_str());
                 vtkWarningMacro("Assuming binary file.");
-                }
+              }
               this->IFile = NULL;
               delete [] fileName;
               return vtkGenericEnSightReader::ENSIGHT_GOLD_BINARY;
-              } // end if IFile == NULL
+            } // end if IFile == NULL
 
             this->ReadBinaryLine(binaryLine);
             binaryLine[80] = '\0';
@@ -461,113 +462,115 @@ int vtkGenericEnSightReader::DetermineEnSightVersion(int quiet)
             // and jump to the start of the actual string
             binaryLinePtr = &binaryLine[0];
             if (strlen(binaryLine)<4)
-              {
+            {
               binaryLinePtr = &binaryLine[4];
-              }
+            }
             sscanf(binaryLinePtr, " %*s %s", subLine);
             // If the file is ascii, there might not be a null
             // terminator. This leads to a UMR in sscanf
             if (strncmp(subLine,"Binary",6) == 0 ||
                 strncmp(subLine,"binary",6) == 0)
-              {
+            {
               fclose(this->IFile);
               this->IFile = NULL;
               delete [] fileName;
               return vtkGenericEnSightReader::ENSIGHT_GOLD_BINARY;
-              } //end if binary
+            } //end if binary
 
             fclose(this->IFile);
             this->IFile = NULL;
             delete [] fileName;
             return vtkGenericEnSightReader::ENSIGHT_GOLD;
-            } // if we found the geometry section in the case file
-          } // if ensight gold file
-        } // if regular ensight file (not master_server)
+          } // if we found the geometry section in the case file
+        } // if ensight gold file
+      } // if regular ensight file (not master_server)
       else if (strncmp(subLine1,"master_server",13) == 0)
-        {
-        return vtkGenericEnSightReader::ENSIGHT_MASTER_SERVER;
-        }
-      } // if the type line is like "type: xxxx xxxx"
-    else
       {
+        return vtkGenericEnSightReader::ENSIGHT_MASTER_SERVER;
+      }
+    } // if the type line is like "type: xxxx xxxx"
+    else
+    {
       this->ReadNextDataLine(line);
       if (strncmp(line, "GEOMETRY", 8) == 0)
-        {
+      {
         // found the GEOMETRY section
         vtkDebugMacro("*** GEOMETRY section");
 
         this->ReadNextDataLine(line);
         if (strncmp(line, "model:", 6) == 0)
-          {
+        {
           if (sscanf(line, " %*s %d %d %s", &xtimeSet, &fileSet, subLine) == 3)
-            {
+          {
             timeSet = xtimeSet;
             fileSet = xfileSet;
             this->SetGeometryFileName(subLine);
-            }
+          }
           else if (sscanf(line, " %*s %d%*[ \t]%s", &xtimeSet, subLine) == 2)
-            {
+          {
             timeSet = xtimeSet;
             this->SetGeometryFileName(subLine);
-            }
+          }
           else if (sscanf(line, " %*s %s", subLine) == 1)
-            {
+          {
             this->SetGeometryFileName(subLine);
-            }
-          } // geometry file name set
+          }
+        } // geometry file name set
+
+        delete this->IS;
+        this->IS = NULL;
+
+        if (!this->GeometryFileName || this->GeometryFileName[0] == '\0')
+        {
+          if (!quiet)
+          {
+            vtkErrorMacro(
+                      "A GeometryFileName must be specified in the case file.");
+          }
+          return 0;
+        }
 
         fileName = new char[strlen(this->GeometryFileName) + 1];
         strcpy(fileName, this->GeometryFileName);
 
-        delete this->IS;
-        this->IS = NULL;
-        if (!fileName)
-          {
-          if (!quiet)
-            {
-            vtkErrorMacro(
-                      "A GeometryFileName must be specified in the case file.");
-            }
-          return 0;
-          }
         if (strrchr(fileName, '*') != NULL)
-          {
+        {
           // reopen case file; find right time set and fill in wildcards from
           // there if possible; if not, then find right file set and fill in
           // wildcards from there.
           this->ReplaceWildcards(fileName, timeSet, fileSet);
-          }
+        }
         sfilename = "";
         if (this->FilePath)
-          {
+        {
           sfilename = this->FilePath;
           if (sfilename.at(sfilename.length()-1) != '/')
-            {
+          {
             sfilename += "/";
-            }
+          }
           sfilename += fileName;
           vtkDebugMacro("full path to geometry file: "
                         << sfilename.c_str());
-          }
+        }
         else
-          {
+        {
           sfilename = fileName;
-          }
+        }
 
         // got full path to geometry file
 
         this->IFile = fopen(sfilename.c_str(), "rb");
         if (this->IFile == NULL)
-          {
+        {
           if (!quiet)
-            {
+          {
             vtkErrorMacro("Unable to open file: " << sfilename.c_str());
             vtkWarningMacro("Assuming binary file.");
-            }
+          }
           this->IFile = NULL;
           delete [] fileName;
           return vtkGenericEnSightReader::ENSIGHT_6_BINARY;
-          } // end if IFile == NULL
+        } // end if IFile == NULL
 
         this->ReadBinaryLine(binaryLine);
         // If the file is ascii, there might not be a null
@@ -575,29 +578,32 @@ int vtkGenericEnSightReader::DetermineEnSightVersion(int quiet)
         binaryLine[80] = '\0';
         sscanf(binaryLine, " %*s %s", subLine);
         if (strncmp(subLine,"Binary",6) == 0)
-          {
+        {
           fclose(this->IFile);
           this->IFile = NULL;
           delete [] fileName;
           return vtkGenericEnSightReader::ENSIGHT_6_BINARY;
-          } //end if binary
+        } //end if binary
 
         fclose(this->IFile);
         this->IFile = NULL;
         delete [] fileName;
         return vtkGenericEnSightReader::ENSIGHT_6;
-        } // if we found the geometry section in the case file
-      } // not ensight gold
-    } // if we found the format section in the case file
+      } // if we found the geometry section in the case file
+    } // not ensight gold
+  } // if we found the format section in the case file
 
-  if (fileName)
-    {
-    delete [] fileName;
-    }
+  delete [] fileName;
 
   return -1;
 }
 
+//----------------------------------------------------------------------------
+void vtkGenericEnSightReader::ClearForNewCaseFileName()
+{
+  this->TranslationTable->PartIdMap.clear();
+}
+
 //----------------------------------------------------------------------------
 void vtkGenericEnSightReader::SetCaseFileName(const char* fileName)
 {
@@ -607,40 +613,38 @@ void vtkGenericEnSightReader::SetCaseFileName(const char* fileName)
 
   if ( this->CaseFileName && fileName &&
        (!strcmp(this->CaseFileName, fileName)))
-    {
+  {
     return;
-    }
-  if (this->CaseFileName)
-    {
-    delete [] this->CaseFileName;
-    }
+  }
+  delete [] this->CaseFileName;
   if (fileName)
-    {
+  {
     this->CaseFileName = new char[strlen(fileName)+1];
     strcpy(this->CaseFileName, fileName);
-    }
+  }
   else
-    {
+  {
     this->CaseFileName = NULL;
-    }
+  }
 
+  this->ClearForNewCaseFileName();
   this->Modified();
   if (!this->CaseFileName)
-    {
+  {
     return;
-    }
+  }
 
   // strip off the path and save it as FilePath if it was included in the
   // filename
   endingSlash = strrchr(this->CaseFileName, '/');
   if(endingSlash == NULL)
-    {
+  {
     // check Windows directory separator
     endingSlash = strrchr(this->CaseFileName, '\\');
-    }
+  }
 
   if (endingSlash)
-    {
+  {
     position = endingSlash - this->CaseFileName + 1;
     path = new char[position + 1];
     numChars = static_cast<int>(strlen(this->CaseFileName));
@@ -652,7 +656,7 @@ void vtkGenericEnSightReader::SetCaseFileName(const char* fileName)
     strcpy(this->CaseFileName, newFileName);
     delete [] path;
     delete [] newFileName;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -663,12 +667,12 @@ int vtkGenericEnSightReader::ReadLine(char result[256])
   this->IS->getline(result,256);
 //  if (this->IS->eof())
   if (this->IS->fail())
-      {
+  {
       // Reset the error flag before returning. This way, we can keep working
       // if we handle the error downstream.
       this->IS->clear();
       return 0;
-      }
+  }
 
   return 1;
 }
@@ -681,9 +685,9 @@ int vtkGenericEnSightReader::ReadBinaryLine(char result[80])
   int n = static_cast<int>(fread(result, sizeof(char), 80, this->IFile));
 
   if ((n<80) || feof(this->IFile) || ferror(this->IFile))
-    {
+  {
     return 0;
-    }
+  }
 
   return 1;
 }
@@ -698,25 +702,25 @@ int vtkGenericEnSightReader::ReadNextDataLine(char result[256])
   int value = 1;
 
   while( isComment && value )
-    {
+  {
     value = this->ReadLine(result);
     if( *result && result[0] != '#' )
-      {
+    {
       size_t len = strlen( result );
       unsigned int i = 0;
       while( i < len && (static_cast<unsigned int>(result[i]) <= 255) && isspace(result[i]) )
-        {
+      {
         ++i;
-        }
+      }
       // If there was only space characters this is a comment, thus skip it
       if( i != len )
-        {
+      {
         // The line was not empty, not beginning by '#' and not composed
         // of only white space, this is not a comment
         isComment = 0;
-        }
       }
     }
+  }
 
   return value;
 }
@@ -726,92 +730,92 @@ int vtkGenericEnSightReader::RequestInformation(
   vtkInformation *request,
   vtkInformationVector **inputVector,
   vtkInformationVector *outputVector)
-  {
+{
   int version = this->DetermineEnSightVersion();
   int createReader = 1;
   if (version == vtkGenericEnSightReader::ENSIGHT_6)
-    {
+  {
     vtkDebugMacro("EnSight6");
     if (this->Reader)
-      {
+    {
       if (strcmp(this->Reader->GetClassName(), "vtkEnSight6Reader") == 0)
-        {
-        createReader = 0;
-        }
-      else
-        {
-        this->Reader->Delete();
-        }
-      }
-    if (createReader)
       {
-      this->Reader = vtkEnSight6Reader::New();
+        createReader = 0;
+      }
+      else
+      {
+        this->Reader->Delete();
       }
     }
-  else if (version == vtkGenericEnSightReader::ENSIGHT_6_BINARY)
+    if (createReader)
     {
+      this->Reader = vtkEnSight6Reader::New();
+    }
+  }
+  else if (version == vtkGenericEnSightReader::ENSIGHT_6_BINARY)
+  {
     vtkDebugMacro("EnSight6 binary");
     if (this->Reader)
-      {
+    {
       if (strcmp(this->Reader->GetClassName(), "vtkEnSight6BinaryReader") == 0)
-        {
-        createReader = 0;
-        }
-      else
-        {
-        this->Reader->Delete();
-        }
-      }
-    if (createReader)
       {
-      this->Reader = vtkEnSight6BinaryReader::New();
+        createReader = 0;
+      }
+      else
+      {
+        this->Reader->Delete();
       }
     }
-  else if (version == vtkGenericEnSightReader::ENSIGHT_GOLD)
+    if (createReader)
     {
+      this->Reader = vtkEnSight6BinaryReader::New();
+    }
+  }
+  else if (version == vtkGenericEnSightReader::ENSIGHT_GOLD)
+  {
     vtkDebugMacro("EnSightGold");
     if (this->Reader)
-      {
+    {
       if (strcmp(this->Reader->GetClassName(), "vtkEnSightGoldReader") == 0)
-        {
-        createReader = 0;
-        }
-      else
-        {
-        this->Reader->Delete();
-        }
-      }
-    if (createReader)
       {
-      this->Reader = vtkEnSightGoldReader::New();
+        createReader = 0;
+      }
+      else
+      {
+        this->Reader->Delete();
       }
     }
-  else if (version == vtkGenericEnSightReader::ENSIGHT_GOLD_BINARY)
+    if (createReader)
     {
+      this->Reader = vtkEnSightGoldReader::New();
+    }
+  }
+  else if (version == vtkGenericEnSightReader::ENSIGHT_GOLD_BINARY)
+  {
     vtkDebugMacro("EnSightGold binary");
     if (this->Reader)
-      {
+    {
       if (strcmp(this->Reader->GetClassName(),
         "vtkEnSightGoldBinaryReader") == 0)
-        {
-        createReader = 0;
-        }
-      else
-        {
-        this->Reader->Delete();
-        }
-      }
-    if (createReader)
       {
-      this->Reader = vtkEnSightGoldBinaryReader::New();
+        createReader = 0;
+      }
+      else
+      {
+        this->Reader->Delete();
       }
     }
-  else
+    if (createReader)
     {
+      this->Reader = vtkEnSightGoldBinaryReader::New();
+    }
+  }
+  else
+  {
     vtkErrorMacro("Error determining EnSightVersion");
     this->EnSightVersion = -1;
     return 0;
-    }
+  }
   this->EnSightVersion = version;
 
   // Copy current array selections to internal reader.
@@ -844,9 +848,9 @@ int vtkGenericEnSightReader::RequestInformation(
 
   this->SetTimeSets(this->Reader->GetTimeSets());
   if(!this->TimeValueInitialized)
-    {
+  {
     this->SetTimeValue(this->Reader->GetTimeValue());
-    }
+  }
   this->MinimumTimeValue = this->Reader->GetMinimumTimeValue();
   this->MaximumTimeValue = this->Reader->GetMaximumTimeValue();
 
@@ -866,28 +870,25 @@ void vtkGenericEnSightReader::AddVariableDescription(const char* description)
 
   // copy descriptions to temporary array
   for (i = 0; i < size; i++)
-    {
+  {
     newDescriptionList[i] =
       new char[strlen(this->VariableDescriptions[i]) + 1];
     strcpy(newDescriptionList[i], this->VariableDescriptions[i]);
     delete [] this->VariableDescriptions[i];
-    }
-  if (this->VariableDescriptions)
-    {
-    delete [] this->VariableDescriptions;
-    }
+  }
+  delete [] this->VariableDescriptions;
 
   // make room for new description
   this->VariableDescriptions = new char *[size+1];
 
   // copy existing descriptions back to first array
   for (i = 0; i < size; i++)
-    {
+  {
     this->VariableDescriptions[i] =
       new char[strlen(newDescriptionList[i]) + 1];
     strcpy(this->VariableDescriptions[i], newDescriptionList[i]);
     delete [] newDescriptionList[i];
-    }
+  }
   delete [] newDescriptionList;
 
   // add new description at end of first array
@@ -905,12 +906,12 @@ void vtkGenericEnSightReader::AddComplexVariableDescription(const char* descript
 
   // copy descriptions to temporary array
   for (i = 0; i < size; i++)
-    {
+  {
     newDescriptionList[i] =
       new char[strlen(this->ComplexVariableDescriptions[i]) + 1];
     strcpy(newDescriptionList[i], this->ComplexVariableDescriptions[i]);
     delete [] this->ComplexVariableDescriptions[i];
-    }
+  }
   delete [] this->ComplexVariableDescriptions;
 
   // make room for new description
@@ -918,12 +919,12 @@ void vtkGenericEnSightReader::AddComplexVariableDescription(const char* descript
 
   // copy existing descriptions back to first array
   for (i = 0; i < size; i++)
-    {
+  {
     this->ComplexVariableDescriptions[i] =
       new char[strlen(newDescriptionList[i]) + 1];
     strcpy(this->ComplexVariableDescriptions[i], newDescriptionList[i]);
     delete [] newDescriptionList[i];
-    }
+  }
   delete [] newDescriptionList;
 
   // add new description at end of first array
@@ -938,7 +939,7 @@ void vtkGenericEnSightReader::AddComplexVariableDescription(const char* descript
 int vtkGenericEnSightReader::GetNumberOfVariables(int type)
 {
   switch (type)
-    {
+  {
     case vtkEnSightReader::SCALAR_PER_NODE:
       return this->GetNumberOfScalarsPerNode();
     case vtkEnSightReader::VECTOR_PER_NODE:
@@ -966,16 +967,16 @@ int vtkGenericEnSightReader::GetNumberOfVariables(int type)
     default:
       vtkWarningMacro("unknow variable type");
       return -1;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 const char* vtkGenericEnSightReader::GetDescription(int n)
 {
   if (n < this->NumberOfVariables)
-    {
+  {
     return this->VariableDescriptions[n];
-    }
+  }
   return NULL;
 }
 
@@ -983,9 +984,9 @@ const char* vtkGenericEnSightReader::GetDescription(int n)
 const char* vtkGenericEnSightReader::GetComplexDescription(int n)
 {
   if (n < this->NumberOfComplexVariables)
-    {
+  {
     return this->ComplexVariableDescriptions[n];
-    }
+  }
   return NULL;
 }
 
@@ -995,39 +996,39 @@ const char* vtkGenericEnSightReader::GetDescription(int n, int type)
   int i, numMatches = 0;
 
   if (type < 8)
-    {
+  {
     for (i = 0; i < this->NumberOfVariables; i++)
-      {
+    {
       if (this->VariableTypes[i] == type)
-        {
-        if (numMatches == n)
-          {
-          return this->VariableDescriptions[i];
-          }
-        else
-          {
-          numMatches++;
-          }
-        }
-      }
-    }
-  else
-    {
-    for (i = 0; i < this->NumberOfVariables; i++)
       {
-      if (this->ComplexVariableTypes[i] == type)
-        {
         if (numMatches == n)
-          {
-          return this->ComplexVariableDescriptions[i];
-          }
+        {
+          return this->VariableDescriptions[i];
+        }
         else
-          {
+        {
           numMatches++;
-          }
         }
       }
     }
+  }
+  else
+  {
+    for (i = 0; i < this->NumberOfVariables; i++)
+    {
+      if (this->ComplexVariableTypes[i] == type)
+      {
+        if (numMatches == n)
+        {
+          return this->ComplexVariableDescriptions[i];
+        }
+        else
+        {
+          numMatches++;
+        }
+      }
+    }
+  }
 
   return NULL;
 }
@@ -1044,16 +1045,16 @@ void vtkGenericEnSightReader::AddVariableType(int variableType)
   types = new int[size];
 
   for (i = 0; i < size; i++)
-    {
+  {
     types[i] = this->VariableTypes[i];
-    }
+  }
   delete [] this->VariableTypes;
 
   this->VariableTypes = new int[size+1];
   for (i = 0; i < size; i++)
-    {
+  {
     this->VariableTypes[i] = types[i];
-    }
+  }
   delete [] types;
   this->VariableTypes[size] = variableType;
   vtkDebugMacro("variable type: " << this->VariableTypes[size]);
@@ -1067,25 +1068,25 @@ void vtkGenericEnSightReader::AddComplexVariableType(int variableType)
   int size = this->NumberOfComplexVariables;
 
   if (size > 0)
-    {
+  {
     types = new int[size];
     for (i = 0; i < size; i++)
-      {
+    {
       types[i] = this->ComplexVariableTypes[i];
-      }
-    delete [] this->ComplexVariableTypes;
     }
+    delete [] this->ComplexVariableTypes;
+  }
 
   this->ComplexVariableTypes = new int[size+1];
   for (i = 0; i < size; i++)
-    {
+  {
     this->ComplexVariableTypes[i] = types[i];
-    }
+  }
 
   if (size > 0)
-    {
+  {
     delete [] types;
-    }
+  }
   this->ComplexVariableTypes[size] = variableType;
   vtkDebugMacro("complex variable type: "
                 << this->ComplexVariableTypes[size]);
@@ -1095,9 +1096,9 @@ void vtkGenericEnSightReader::AddComplexVariableType(int variableType)
 int vtkGenericEnSightReader::GetVariableType(int n)
 {
   if (n < this->NumberOfVariables)
-    {
+  {
     return this->VariableTypes[n];
-    }
+  }
   return -1;
 }
 
@@ -1105,9 +1106,9 @@ int vtkGenericEnSightReader::GetVariableType(int n)
 int vtkGenericEnSightReader::GetComplexVariableType(int n)
 {
   if (n < this->NumberOfComplexVariables)
-    {
+  {
     return this->ComplexVariableTypes[n];
-    }
+  }
   return -1;
 }
 
@@ -1120,19 +1121,19 @@ int vtkGenericEnSightReader::ReplaceWildcards(char* fileName, int timeSet,
 
   std::string sfilename;
   if ( this->FilePath )
-    {
+  {
     sfilename = this->FilePath;
     if (  sfilename.at( sfilename.length() - 1 ) != '/'  )
-      {
+    {
       sfilename += "/";
-      }
+    }
     sfilename += this->CaseFileName;
     vtkDebugMacro( "full path to case file: " << sfilename.c_str() );
-    }
+  }
   else
-    {
+  {
     sfilename = this->CaseFileName;
-    }
+  }
 
   // We have got a valid CASE file name
   this->IS = new ifstream( sfilename.c_str(), ios::in );
@@ -1144,40 +1145,40 @@ int vtkGenericEnSightReader::ReplaceWildcards(char* fileName, int timeSet,
 
   // Locate the 'TIME' section
   do
-    {
+  {
     if ( this->ReadNextDataLine(line) == 0 )
-      {
+    {
       vtkErrorMacro(
         "ReplaceWildCards() failed to find the 'TIME' section!" );
       delete this->IS;
       this->IS = NULL;
       return 0;
-      }
-    } while ( strncmp(line, "TIME", 4) != 0 );
+    }
+  } while ( strncmp(line, "TIME", 4) != 0 );
 
 
   // Locate the very 'time set' entry by the index
   cmpTimeSet = -10000;
   do
-    {
+  {
     if ( this->ReadNextDataLine(line) == 0 )
-      {
+    {
       vtkErrorMacro(
         "ReplaceWildCards() failed to find the target 'time set' entry!" );
       delete this->IS;
       this->IS = NULL;
       return 0;
-      }
+    }
 
       // 'time set: <int>' --- where to obtain cmpTimeSet, a time set index
       lineScanResult = sscanf(line, "%*s %s %d", subLine, &cmpTimeSet);
-    } while ( lineScanResult != 2 || strncmp(line, "time", 4) != 0 ||
+  } while ( lineScanResult != 2 || strncmp(line, "time", 4) != 0 ||
               strncmp(subLine, "set", 3) != 0 || cmpTimeSet != timeSet );
 
   // Skip 'time set: <int>' and 'number of steps: <int>' to go to
   // 'filename xxx: ...' --- where to obtain the actual file name number(s)
   for ( int  i = 0;  i < 2;  i ++ )
-    {
+  {
     lineReadResult = this->ReadNextDataLine(line);
     if ( lineReadResult == 0 ||
          // check 'filename xxx: ...' upon the second line (i = 1)
@@ -1187,20 +1188,20 @@ int vtkGenericEnSightReader::ReplaceWildcards(char* fileName, int timeSet,
            )
          )
        )
-      {
+    {
       vtkErrorMacro(
         "ReplaceWildCards() failed to find the target 'filename ...: ...' entry!" );
       delete this->IS;
       this->IS = NULL;
       return 0;
-      }
     }
+  }
 
   fileNameNum = -10000;
 
   // 'filename numbers: ...'
   if ( strncmp(subLine, "numbers", 7) == 0 )
-    {
+  {
     // The filename number(s) may be provided on the line(s) following
     // 'filename numbers:', as is usually the case --- not "inline". Thus we
     // need to go to the FIRST line that indeed contains the filename number(s).
@@ -1211,24 +1212,24 @@ int vtkGenericEnSightReader::ReplaceWildcards(char* fileName, int timeSet,
 
     // not "inline"
     if ( sscanf(line, "%*s %*s %d", &fileNameNum) != 1 )
-      {
+    {
       // let's go to the next VALID line that might be several empty lines apart
       if ( this->ReadNextDataLine(line) == 0 )
-        {
+      {
         vtkErrorMacro(
           "ReplaceWildCards() failed to obtain any non-inline file name number!" );
         delete this->IS;
         this->IS = NULL;
         return 0;
-        }
+      }
 
       // obtain the first file name number from the next valid line
       sscanf(line, "%d", &fileNameNum);
-      }
     }
+  }
   // 'filename start number: ...' --- followed by 'filename increment: ...'
   else
-    {
+  {
     char  subSubLine[256];
     lineScanResult = sscanf( line, "%*s %s %s %d",
                              subLine, subSubLine, &fileNameNum );
@@ -1236,47 +1237,47 @@ int vtkGenericEnSightReader::ReplaceWildcards(char* fileName, int timeSet,
          strncmp(subLine,    "start",  5) != 0 ||
          strncmp(subSubLine, "number", 6) != 0
        )
-      {
+    {
       vtkErrorMacro(
         "ReplaceWildCards() failed to find 'filename start number: <int>'!" );
       delete this->IS;
       this->IS = NULL;
       return 0;
-      }
     }
+  }
 
   // Let's resort to the 'FILE' section, just in case of a failure so far
   if ( fileNameNum == -10000 )
-    {
+  {
     // Locate the 'FILE' section
     do
-      {
+    {
       if ( this->ReadNextDataLine(line) == 0 )
-        {
+      {
         vtkErrorMacro(
           "ReplaceWildCards() failed to find the optional 'FILE' section!" );
         delete this->IS;
         this->IS = NULL;
         return 0;
-        }
-      } while ( strncmp(line, "FILE", 4) != 0 );
+      }
+    } while ( strncmp(line, "FILE", 4) != 0 );
 
     // Locate the very 'file set' entry by the index
     cmpFileSet = -10000;
     do
-      {
+    {
       if ( this->ReadNextDataLine(line) == 0 )
-        {
+      {
         vtkErrorMacro(
           "ReplaceWildCards() failed to find the target 'file set' entry!" );
         delete this->IS;
         this->IS = NULL;
         return 0;
-        }
+      }
 
       // 'file set: <int>' --- to obtain cmpFileSet, a file set index
       lineScanResult = sscanf(line, "%*s %s %d", subLine, &cmpFileSet);
-      } while ( lineScanResult != 2 || strncmp(line, "file", 4) != 0 ||
+    } while ( lineScanResult != 2 || strncmp(line, "file", 4) != 0 ||
                 strncmp(subLine, "set", 3) != 0 || cmpFileSet != fileSet );
 
     // Skip 'file set: <int>' to go to
@@ -1291,14 +1292,14 @@ int vtkGenericEnSightReader::ReplaceWildcards(char* fileName, int timeSet,
     if ( lineReadResult == 0               || lineScanResult != 2 ||
          strncmp(line, "filename", 8) != 0 || strncmp(subLine, "index", 5) != 0
        )
-      {
+    {
       vtkErrorMacro(
         "ReplaceWildCards() failed to find 'filename index: <int>'!" );
       delete this->IS;
       this->IS = NULL;
       return 0;
-      }
     }
+  }
 
   // So far we have got a file name index
   this->ReplaceWildcardsHelper(fileName, fileNameNum);
@@ -1321,23 +1322,23 @@ void vtkGenericEnSightReader::ReplaceWildcardsHelper(char* fileName, int num)
 
   tmpNum /= 10;
   while (tmpNum >= 1)
-    {
+  {
     numDigits++;
     multTen *= 10;
     tmpNum /= 10;
-    }
+  }
 
   for (i = 0; i < numWildcards - numDigits; i++)
-    {
+  {
     fileName[i + wildcardPos] = '0';
-    }
+  }
 
   tmpNum = num;
   for (i = numWildcards - numDigits; i < numWildcards; i++)
-    {
+  {
     newNum = tmpNum / multTen;
     switch (newNum)
-      {
+    {
       case 0:
         newChar = '0';
         break;
@@ -1371,13 +1372,13 @@ void vtkGenericEnSightReader::ReplaceWildcardsHelper(char* fileName, int num)
       default:
         // This case should never be reached.
         return;
-      }
+    }
     assert( newChar == ('0' + newNum) );
 
     fileName[i + wildcardPos] = newChar;
     tmpNum -= multTen * newNum;
     multTen /= 10;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -1396,13 +1397,13 @@ void vtkGenericEnSightReader::SetByteOrderToLittleEndian()
 const char *vtkGenericEnSightReader::GetByteOrderAsString()
 {
   if ( this->ByteOrder ==  FILE_LITTLE_ENDIAN)
-    {
+  {
     return "LittleEndian";
-    }
+  }
   else
-    {
+  {
     return "BigEndian";
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -1465,9 +1466,9 @@ char** vtkGenericEnSightReader::CreateStringArray(int numStrings)
   char** strings = new char*[numStrings];
   int i;
   for(i=0; i < numStrings; ++i)
-    {
+  {
     strings[i] = 0;
-    }
+  }
   return strings;
 }
 
@@ -1475,14 +1476,10 @@ char** vtkGenericEnSightReader::CreateStringArray(int numStrings)
 void vtkGenericEnSightReader::DestroyStringArray(int numStrings,
                                                  char** strings)
 {
-  int i;
-  for(i=0; i < numStrings; ++i)
-    {
-    if(strings[i])
-      {
-      delete [] strings[i];
-      }
-    }
+  for(int i=0; i < numStrings; ++i)
+  {
+    delete [] strings[i];
+  }
   delete[] strings;
 }
 
@@ -1509,9 +1506,9 @@ void vtkGenericEnSightReader::SetDataArraySelectionSetsFromVariables()
 
   int i;
   for(i=0; i < this->NumberOfVariables; ++i)
-    {
+  {
     switch (this->VariableTypes[i])
-      {
+    {
       case vtkEnSightReader::SCALAR_PER_NODE:
       case vtkEnSightReader::VECTOR_PER_NODE:
       case vtkEnSightReader::TENSOR_SYMM_PER_NODE:
@@ -1530,12 +1527,12 @@ void vtkGenericEnSightReader::SetDataArraySelectionSetsFromVariables()
         strcpy(cellNames[cellArrayCount], this->VariableDescriptions[i]);
         ++cellArrayCount;
         break;
-      }
     }
+  }
   for(i=0; i < this->NumberOfComplexVariables; ++i)
-    {
+  {
     switch(this->ComplexVariableTypes[i])
-      {
+    {
       case vtkEnSightReader::COMPLEX_SCALAR_PER_NODE:
       case vtkEnSightReader::COMPLEX_VECTOR_PER_NODE:
         pointNames[pointArrayCount] =
@@ -1552,8 +1549,8 @@ void vtkGenericEnSightReader::SetDataArraySelectionSetsFromVariables()
                this->ComplexVariableDescriptions[i]);
         ++cellArrayCount;
         break;
-      }
     }
+  }
 
   this->PointDataArraySelection->SetArraysWithDefault(pointNames,
                                                       numPointArrays,
@@ -1599,9 +1596,9 @@ void vtkGenericEnSightReader::SelectionModifiedCallback(vtkObject*,
 void vtkGenericEnSightReader::SelectionModified()
 {
   if(!this->SelectionModifiedDoNotCallModified)
-    {
+  {
     this->Modified();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -1626,13 +1623,13 @@ int vtkGenericEnSightReader::GetPointArrayStatus(const char* name)
 void vtkGenericEnSightReader::SetPointArrayStatus(const char* name, int status)
 {
   if(status)
-    {
+  {
     this->PointDataArraySelection->EnableArray(name);
-    }
+  }
   else
-    {
+  {
     this->PointDataArraySelection->DisableArray(name);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -1657,13 +1654,13 @@ int vtkGenericEnSightReader::GetCellArrayStatus(const char* name)
 void vtkGenericEnSightReader::SetCellArrayStatus(const char* name, int status)
 {
   if(status)
-    {
+  {
     this->CellDataArraySelection->EnableArray(name);
-    }
+  }
   else
-    {
+  {
     this->CellDataArraySelection->DisableArray(name);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
