@@ -12,41 +12,37 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-// .NAME vtkOBJReader - read Wavefront .obj files
-// .SECTION Description
-// vtkOBJReader is a source object that reads Wavefront .obj
-// files. The output of this source object is polygonal data.
-// .SECTION See Also
-// vtkOBJImporter
+/**
+ * @class   vtkOBJReader
+ * @brief   read Wavefront .obj files
+ *
+ * vtkOBJReader is a source object that reads Wavefront .obj
+ * files. The output of this source object is polygonal data.
+ * @sa
+ * vtkOBJImporter
+*/
 
 #ifndef vtkOBJReader_h
 #define vtkOBJReader_h
 
 #include "vtkIOGeometryModule.h" // For export macro
-#include "vtkPolyDataAlgorithm.h"
+#include "vtkAbstractPolyDataReader.h"
 
-class VTKIOGEOMETRY_EXPORT vtkOBJReader : public vtkPolyDataAlgorithm
+class VTKIOGEOMETRY_EXPORT vtkOBJReader : public vtkAbstractPolyDataReader
 {
 public:
   static vtkOBJReader *New();
-  vtkTypeMacro(vtkOBJReader,vtkPolyDataAlgorithm);
+  vtkTypeMacro(vtkOBJReader,vtkAbstractPolyDataReader);
   void PrintSelf(ostream& os, vtkIndent indent);
 
-  // Description:
-  // Specify file name of Wavefront .obj file.
-  vtkSetStringMacro(FileName);
-  vtkGetStringMacro(FileName);
-
 protected:
   vtkOBJReader();
   ~vtkOBJReader();
 
   int RequestData(vtkInformation *, vtkInformationVector **, vtkInformationVector *);
-
-  char *FileName;
 private:
-  vtkOBJReader(const vtkOBJReader&);  // Not implemented.
-  void operator=(const vtkOBJReader&);  // Not implemented.
+  vtkOBJReader(const vtkOBJReader&) VTK_DELETE_FUNCTION;
+  void operator=(const vtkOBJReader&) VTK_DELETE_FUNCTION;
 };
 
 #endif
