@@ -39,15 +39,15 @@
 #include "vtkVariantArray.h"
 
 #include <cassert>
-#include <vtksys/ios/fstream>
-#include <vtksys/ios/sstream>
-#include <vtksys/stl/map>
-#include <vtksys/stl/set>
-#include <vtksys/stl/stack>
-#include <vtksys/stl/vector>
+#include <fstream>
+#include <sstream>
+#include <map>
+#include <set>
+#include <stack>
+#include <vector>
 
 #if defined (__BORLANDC__)
-#include <ctype.h> // for isspace, isdigit
+#include <cctype> // for isspace, isdigit
 #endif
 
 // I need a safe way to read a line of arbitrary length.  It exists on
@@ -55,7 +55,7 @@
 // myself.
 // This function is also defined in Infovis/vtkDelimitedTextReader.cxx,
 // so it would be nice to put this in a common file.
-static int my_getline(vtksys_ios::istream& stream, vtkStdString &output, char delim='\n');
+static int my_getline(std::istream& stream, vtkStdString &output, char delim='\n');
 
 vtkStandardNewMacro(vtkTulipReader);
 
@@ -72,7 +72,7 @@ vtkTulipReader::~vtkTulipReader()
   this->SetFileName(0);
 }
 
-void vtkTulipReader::PrintSelf(vtksys_ios::ostream& os, vtkIndent indent)
+void vtkTulipReader::PrintSelf(std::ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
 
@@ -83,17 +83,17 @@ void vtkTulipReader::PrintSelf(vtksys_ios::ostream& os, vtkIndent indent)
 int vtkTulipReader::FillOutputPortInformation(int port, vtkInformation* info)
 {
   if (port == 0)
-    {
+  {
     info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkUndirectedGraph");
-    }
+  }
   else if (port == 1)
-    {
+  {
     info->Set(vtkDataObject::DATA_TYPE_NAME(), "vtkAnnotationLayers");
-    }
+  }
   else
-    {
+  {
     return 0;
-    }
+  }
   return 1;
 }
 
@@ -123,78 +123,78 @@ struct vtkTulipReaderToken
   double DoubleValue;
 };
 
-static void vtkTulipReaderNextToken(vtksys_ios::istream& in, vtkTulipReaderToken& tok)
+static void vtkTulipReaderNextToken(std::istream& in, vtkTulipReaderToken& tok)
 {
   char ch = in.peek();
   while (!in.eof() && (ch == ';' || isspace(ch)))
-    {
+  {
     while (!in.eof() && ch == ';')
-      {
+    {
       vtkStdString comment;
       my_getline(in, comment);
       ch = in.peek();
-      }
+    }
     while (!in.eof() && isspace(ch))
-      {
+    {
       in.get();
       ch = in.peek();
-      }
     }
+  }
 
   if (in.eof())
-    {
+  {
     tok.Type = vtkTulipReaderToken::END_OF_FILE;
     return;
-    }
+  }
   if (ch == '(')
-    {
+  {
     in.get();
     tok.Type = vtkTulipReaderToken::OPEN_PAREN;
-    }
+  }
   else if (ch == ')')
-    {
+  {
     in.get();
     tok.Type = vtkTulipReaderToken::CLOSE_PAREN;
-    }
+  }
   else if (isdigit(ch) || ch == '.')
-    {
+  {
     bool isDouble = false;
-    vtksys_ios::stringstream ss;
+    std::stringstream ss;
     while (isdigit(ch) || ch == '.')
-      {
+    {
       in.get();
       isDouble = isDouble || ch == '.';
       ss << ch;
       ch = in.peek();
-      }
+    }
     if (isDouble)
-      {
+    {
       ss >> tok.DoubleValue;
       tok.Type = vtkTulipReaderToken::DOUBLE;
-      }
+    }
     else
-      {
+    {
       ss >> tok.IntValue;
       tok.Type = vtkTulipReaderToken::INT;
-      }
     }
+  }
   else if (ch == '"')
-    {
+  {
     in.get();
     tok.StringValue = "";
     ch = in.get();
     while (ch != '"')
-      {
+    {
       tok.StringValue += ch;
       ch = in.get();
-      }
-    tok.Type = vtkTulipReaderToken::TEXT;
     }
+    tok.Type = vtkTulipReaderToken::TEXT;
+  }
   else
-    {
+  {
     in >> tok.StringValue;
     tok.Type = vtkTulipReaderToken::KEYWORD;
-    }
+  }
 }
 
 int vtkTulipReader::RequestData(
@@ -203,17 +203,17 @@ int vtkTulipReader::RequestData(
   vtkInformationVector *outputVector)
 {
   if (this->FileName == NULL)
-    {
+  {
     vtkErrorMacro("File name undefined");
     return 0;
-    }
+  }
 
-  vtksys_ios::ifstream fin(this->FileName);
+  std::ifstream fin(this->FileName);
   if(!fin.is_open())
-    {
+  {
     vtkErrorMacro("Could not open file " << this->FileName << ".");
     return 0;
-    }
+  }
 
   // Get the output graph
   vtkSmartPointer<vtkMutableUndirectedGraph> builder =
@@ -230,38 +230,38 @@ int vtkTulipReader::RequestData(
   edgePedigrees->SetName("id");
 
   // Structures to record cluster hierarchy - all vertices belong to cluster 0.
-  vtksys_stl::vector<vtkTulipReaderCluster> clusters;
+  std::vector<vtkTulipReaderCluster> clusters;
   vtkTulipReaderCluster root;
   root.clusterId = 0;
   root.parentId = vtkTulipReaderCluster::NO_PARENT;
   root.name = "<default>";
   root.nodes = vtkSmartPointer<vtkIdTypeArray>::New();
 
-  vtksys_stl::stack<int> parentage;
+  std::stack<int> parentage;
   parentage.push(root.clusterId);
   clusters.push_back(root);
 
-  vtksys_stl::map<int, vtkIdType> nodeIdMap;
-  vtksys_stl::map<int, vtkIdType> edgeIdMap;
+  std::map<int, vtkIdType> nodeIdMap;
+  std::map<int, vtkIdType> edgeIdMap;
   vtkTulipReaderToken tok;
   vtkTulipReaderNextToken(fin, tok);
   while (tok.Type == vtkTulipReaderToken::OPEN_PAREN)
-    {
+  {
     vtkTulipReaderNextToken(fin, tok);
     assert(tok.Type == vtkTulipReaderToken::KEYWORD);
     if (tok.StringValue == "nodes")
-      {
+    {
       vtkTulipReaderNextToken(fin, tok);
       while (tok.Type != vtkTulipReaderToken::CLOSE_PAREN)
-        {
+      {
         assert(tok.Type == vtkTulipReaderToken::INT);
         vtkIdType id = builder->AddVertex(tok.IntValue);
         nodeIdMap[tok.IntValue] = id;
         vtkTulipReaderNextToken(fin, tok);
-        }
       }
+    }
     else if (tok.StringValue == "edge")
-      {
+    {
       vtkTulipReaderNextToken(fin, tok);
       assert(tok.Type == vtkTulipReaderToken::INT);
       int tulipId = tok.IntValue;
@@ -278,9 +278,9 @@ int vtkTulipReader::RequestData(
 
       vtkTulipReaderNextToken(fin, tok);
       assert(tok.Type == vtkTulipReaderToken::CLOSE_PAREN);
-      }
+    }
     else if (tok.StringValue == "cluster")
-      {
+    {
       // Cluster preamble
       vtkTulipReaderNextToken(fin, tok);
       assert(tok.Type == vtkTulipReaderToken::INT);
@@ -306,11 +306,11 @@ int vtkTulipReader::RequestData(
 
       vtkTulipReaderNextToken(fin, tok);
       while (tok.Type != vtkTulipReaderToken::CLOSE_PAREN)
-        {
+      {
         assert(tok.Type == vtkTulipReaderToken::INT);
         newCluster.nodes->InsertNextValue(nodeIdMap[tok.IntValue]);
         vtkTulipReaderNextToken(fin, tok);
-        }
+      }
 
       // Cluster edges - currently ignoring these...
       vtkTulipReaderNextToken(fin, tok);
@@ -322,23 +322,23 @@ int vtkTulipReader::RequestData(
 
       vtkTulipReaderNextToken(fin, tok);
       while (tok.Type != vtkTulipReaderToken::CLOSE_PAREN)
-        {
+      {
         assert(tok.Type == vtkTulipReaderToken::INT);
         vtkTulipReaderNextToken(fin, tok);
-        }
+      }
       clusters.push_back(newCluster);
 
       // End of cluster(s)
       vtkTulipReaderNextToken(fin, tok);
       while (tok.Type == vtkTulipReaderToken::CLOSE_PAREN)
-        {
+      {
         parentage.pop();
         vtkTulipReaderNextToken(fin, tok);
-        }
-      continue;
       }
+      continue;
+    }
     else if (tok.StringValue == "property")
-      {
+    {
       vtkTulipReaderNextToken(fin, tok);
       assert(tok.Type == vtkTulipReaderToken::INT);
       //int clusterId = tok.IntValue;
@@ -371,7 +371,7 @@ int vtkTulipReader::RequestData(
       // string : This is used to store text on elements.
 
       if (type == "string")
-        {
+      {
         vtkStringArray* vertArr = vtkStringArray::New();
         vertArr->SetName(name.c_str());
 
@@ -380,7 +380,7 @@ int vtkTulipReader::RequestData(
 
         vtkTulipReaderNextToken(fin, tok);
         while (tok.Type != vtkTulipReaderToken::CLOSE_PAREN)
-          {
+        {
           assert(tok.Type == vtkTulipReaderToken::OPEN_PAREN);
           vtkTulipReaderNextToken(fin, tok);
           assert(tok.Type == vtkTulipReaderToken::KEYWORD);
@@ -396,28 +396,28 @@ int vtkTulipReader::RequestData(
           vtkTulipReaderNextToken(fin, tok);
 
           if (key == "node")
-            {
+          {
             vertArr->InsertValue(nodeIdMap[id], value);
-            }
-          else if (key == "edge")
-            {
-            edgeArr->InsertValue(edgeIdMap[id], value);
-            }
           }
+          else if (key == "edge")
+          {
+            edgeArr->InsertValue(edgeIdMap[id], value);
+          }
+        }
 
         if (static_cast<size_t>(vertArr->GetNumberOfValues()) == nodeIdMap.size())
-          {
+        {
           builder->GetVertexData()->AddArray(vertArr);
-          }
+        }
         vertArr->Delete();
         if (static_cast<size_t>(edgeArr->GetNumberOfValues()) == edgeIdMap.size())
-          {
-          builder->GetEdgeData()->AddArray(edgeArr);
-          }
-        edgeArr->Delete();
-        }
-      else if (type == "int")
         {
+          builder->GetEdgeData()->AddArray(edgeArr);
+        }
+        edgeArr->Delete();
+      }
+      else if (type == "int")
+      {
         vtkIntArray* vertArr = vtkIntArray::New();
         vertArr->SetName(name.c_str());
 
@@ -426,7 +426,7 @@ int vtkTulipReader::RequestData(
 
         vtkTulipReaderNextToken(fin, tok);
         while (tok.Type != vtkTulipReaderToken::CLOSE_PAREN)
-          {
+        {
           assert(tok.Type == vtkTulipReaderToken::OPEN_PAREN);
           vtkTulipReaderNextToken(fin, tok);
           assert(tok.Type == vtkTulipReaderToken::KEYWORD);
@@ -437,7 +437,7 @@ int vtkTulipReader::RequestData(
           int id = tok.IntValue;
           vtkTulipReaderNextToken(fin, tok);
           assert(tok.Type == vtkTulipReaderToken::TEXT);
-          vtksys_ios::stringstream ss;
+          std::stringstream ss;
           int value;
           ss << tok.StringValue;
           ss >> value;
@@ -447,28 +447,28 @@ int vtkTulipReader::RequestData(
           vtkTulipReaderNextToken(fin, tok);
 
           if (key == "node")
-            {
+          {
             vertArr->InsertValue(nodeIdMap[id], value);
-            }
-          else if (key == "edge")
-            {
-            edgeArr->InsertValue(edgeIdMap[id], value);
-            }
           }
+          else if (key == "edge")
+          {
+            edgeArr->InsertValue(edgeIdMap[id], value);
+          }
+        }
 
         if (static_cast<size_t>(vertArr->GetNumberOfTuples()) == nodeIdMap.size())
-          {
+        {
           builder->GetVertexData()->AddArray(vertArr);
-          }
+        }
         vertArr->Delete();
         if (static_cast<size_t>(edgeArr->GetNumberOfTuples()) == edgeIdMap.size())
-          {
-          builder->GetEdgeData()->AddArray(edgeArr);
-          }
-        edgeArr->Delete();
-        }
-      else if (type == "double")
         {
+          builder->GetEdgeData()->AddArray(edgeArr);
+        }
+        edgeArr->Delete();
+      }
+      else if (type == "double")
+      {
         vtkDoubleArray* vertArr = vtkDoubleArray::New();
         vertArr->SetName(name.c_str());
 
@@ -477,7 +477,7 @@ int vtkTulipReader::RequestData(
 
         vtkTulipReaderNextToken(fin, tok);
         while (tok.Type != vtkTulipReaderToken::CLOSE_PAREN)
-          {
+        {
           assert(tok.Type == vtkTulipReaderToken::OPEN_PAREN);
           vtkTulipReaderNextToken(fin, tok);
           assert(tok.Type == vtkTulipReaderToken::KEYWORD);
@@ -488,7 +488,7 @@ int vtkTulipReader::RequestData(
           int id = tok.IntValue;
           vtkTulipReaderNextToken(fin, tok);
           assert(tok.Type == vtkTulipReaderToken::TEXT);
-          vtksys_ios::stringstream ss;
+          std::stringstream ss;
           double value;
           ss << tok.StringValue;
           ss >> value;
@@ -498,31 +498,31 @@ int vtkTulipReader::RequestData(
           vtkTulipReaderNextToken(fin, tok);
 
           if (key == "node")
-            {
+          {
             vertArr->InsertValue(nodeIdMap[id], value);
-            }
-          else if (key == "edge")
-            {
-            edgeArr->InsertValue(edgeIdMap[id], value);
-            }
           }
+          else if (key == "edge")
+          {
+            edgeArr->InsertValue(edgeIdMap[id], value);
+          }
+        }
 
         if (static_cast<size_t>(vertArr->GetNumberOfTuples()) == nodeIdMap.size())
-          {
+        {
           builder->GetVertexData()->AddArray(vertArr);
-          }
+        }
         vertArr->Delete();
         if (static_cast<size_t>(edgeArr->GetNumberOfTuples()) == edgeIdMap.size())
-          {
-          builder->GetEdgeData()->AddArray(edgeArr);
-          }
-        edgeArr->Delete();
-        }
-      else // Remaining properties are ignored.
         {
+          builder->GetEdgeData()->AddArray(edgeArr);
+        }
+        edgeArr->Delete();
+      }
+      else // Remaining properties are ignored.
+      {
         vtkTulipReaderNextToken(fin, tok);
         while (tok.Type != vtkTulipReaderToken::CLOSE_PAREN)
-          {
+        {
           assert(tok.Type == vtkTulipReaderToken::OPEN_PAREN);
           vtkTulipReaderNextToken(fin, tok);
           assert(tok.Type == vtkTulipReaderToken::KEYWORD);
@@ -533,25 +533,25 @@ int vtkTulipReader::RequestData(
           vtkTulipReaderNextToken(fin, tok);
           assert(tok.Type == vtkTulipReaderToken::CLOSE_PAREN);
           vtkTulipReaderNextToken(fin, tok);
-          }
         }
       }
+    }
     else if (tok.StringValue == "displaying")
-      {
+    {
       vtkTulipReaderNextToken(fin, tok);
       while (tok.Type != vtkTulipReaderToken::CLOSE_PAREN)
-        {
+      {
         assert(tok.Type == vtkTulipReaderToken::OPEN_PAREN);
         while (tok.Type != vtkTulipReaderToken::CLOSE_PAREN)
-          {
+        {
           vtkTulipReaderNextToken(fin, tok);
-          }
-        vtkTulipReaderNextToken(fin, tok);
         }
+        vtkTulipReaderNextToken(fin, tok);
       }
+    }
 
     vtkTulipReaderNextToken(fin, tok);
-    }
+  }
   assert(parentage.size() == 1);
 
   // Clean up
@@ -563,10 +563,10 @@ int vtkTulipReader::RequestData(
   // Move graph structure to output
   vtkGraph* output = vtkGraph::GetData(outputVector);
   if (!output->CheckedShallowCopy(builder))
-    {
+  {
     vtkErrorMacro(<<"Invalid graph structure.");
     return 0;
-    }
+  }
 
   // Create annotation layers output.
   vtkSmartPointer<vtkAnnotationLayers> annotationLayers =
@@ -575,14 +575,14 @@ int vtkTulipReader::RequestData(
   // Determine list of unique cluster names.
   std::set<vtkStdString> uniqueLabels;
   for (size_t i = 0; i < clusters.size(); ++i)
-    {
+  {
     uniqueLabels.insert(clusters.at(i).name);
-    }
+  }
 
   // Create annotations.
   std::set<vtkStdString>::iterator labels = uniqueLabels.begin();
   for (; labels != uniqueLabels.end(); labels++)
-    {
+  {
     vtkSmartPointer<vtkAnnotation> annotation = vtkSmartPointer<vtkAnnotation>::New();
     annotation->GetInformation()->Set(vtkAnnotation::COLOR(), 0.0, 0.0, 1.0);
     annotation->GetInformation()->Set(vtkAnnotation::OPACITY(), 0.5);
@@ -592,20 +592,20 @@ int vtkTulipReader::RequestData(
     vtkSmartPointer<vtkSelection> selection =
       vtkSmartPointer<vtkSelection>::New();
     for (size_t i = 0; i < clusters.size(); ++i)
-      {
+    {
       if (clusters.at(i).name.compare(labels->c_str()) == 0)
-        {
+      {
         vtkSelectionNode* selectionNode = vtkSelectionNode::New();
         selectionNode->SetFieldType(vtkSelectionNode::VERTEX);
         selectionNode->SetContentType(vtkSelectionNode::INDICES);
         selectionNode->SetSelectionList(clusters.at(i).nodes);
         selection->AddNode(selectionNode);
         selectionNode->Delete();
-        }
       }
+    }
     annotation->SetSelection(selection);
     annotationLayers->AddAnnotation(annotation);
-    }
+  }
 
   // Copy annotations to output port 1
   vtkInformation* info1 = outputVector->GetInformationObject(1);
@@ -616,7 +616,7 @@ int vtkTulipReader::RequestData(
 }
 
 static int
-my_getline(vtksys_ios::istream& in, vtkStdString &out, char delimiter)
+my_getline(std::istream& in, vtkStdString &out, char delimiter)
 {
   out = vtkStdString();
   unsigned int numCharactersRead = 0;
@@ -624,19 +624,19 @@ my_getline(vtksys_ios::istream& in, vtkStdString &out, char delimiter)
 
   while ((nextValue = in.get()) != EOF &&
          numCharactersRead < out.max_size())
-    {
+  {
     ++numCharactersRead;
 
     char downcast = static_cast<char>(nextValue);
     if (downcast != delimiter)
-      {
+    {
       out += downcast;
-      }
-    else
-      {
-      return numCharactersRead;
-      }
     }
+    else
+    {
+      return numCharactersRead;
+    }
+  }
 
   return numCharactersRead;
 }
