@@ -58,9 +58,9 @@ vtkPDataSetWriter::~vtkPDataSetWriter()
 void vtkPDataSetWriter::SetNumberOfPieces(int num)
 {
   if (num == this->NumberOfPieces)
-    {
+  {
     return;
-    }
+  }
 
   this->Modified();
   this->NumberOfPieces = num;
@@ -84,26 +84,26 @@ int vtkPDataSetWriter::Write()
   vtkAlgorithm *inputAlg = this->GetInputAlgorithm(0, 0, inputAlgPort);
 
   if (this->FileName == NULL)
-    {
+  {
     vtkErrorMacro("No file name.");
     return 0;
-    }
+  }
 
   if (this->StartPiece < 0)
-    {
+  {
     this->StartPiece = 0;
-    }
+  }
   if (this->NumberOfPieces < 0 || this->EndPiece < this->StartPiece)
-    {
+  {
     vtkWarningMacro("No pieces to write.");
     return 1;
-    }
+  }
 
   // Only one piece? The just write one vtk file.
   if (this->StartPiece == 0 && this->NumberOfPieces == 1)
-    {
+  {
     return this->vtkDataSetWriter::Write();
-    }
+  }
 
   // Lets compute the file root from the file name supplied by the user.
   length = static_cast<int>(strlen(this->FileName));
@@ -113,40 +113,40 @@ int vtkPDataSetWriter::Write()
   fileRoot[length] = '\0';
   // Trim off the pvtk extension.
   if (strncmp(fileRoot+length-5, ".pvtk", 5) == 0)
-    {
+  {
     fileRoot[length-5] = '\0';
-    }
+  }
   if (strncmp(fileRoot+length-4, ".vtk", 4) == 0)
-    {
+  {
     fileRoot[length-4] = '\0';
-    }
+  }
   // If we are using relative file names, trim off the directory path.
   if (this->UseRelativeFileNames)
-    {
+  {
     char *tmp, *slash;
     // Find the last / or \ in the file name.
     slash = NULL;
     tmp = fileRoot;
     while (*tmp != '\0')
-      {
+    {
       if (*tmp == '/' || *tmp == '\\')
-        {
+      {
         slash = tmp;
-        }
-      ++tmp;
       }
+      ++tmp;
+    }
     // Copy just the filename into root.
     if (slash)
-      {
+    {
       ++slash;
       tmp = fileRoot;
       while (*slash != '\0')
-        {
+      {
         *tmp++ = *slash++;
-        }
-      *tmp = '\0';
       }
+      *tmp = '\0';
     }
+  }
 
 
   // Restore the fileRoot to the full path.
@@ -154,13 +154,13 @@ int vtkPDataSetWriter::Write()
   fileRoot[length] = '\0';
   // Trim off the pvtk extension.
   if (strncmp(fileRoot+length-5, ".pvtk", 5) == 0)
-    {
+  {
     fileRoot[length-5] = '\0';
-    }
+  }
   if (strncmp(fileRoot+length-4, ".vtk", 4) == 0)
-    {
+  {
     fileRoot[length-4] = '\0';
-    }
+  }
 
   this->UpdateInformation();
 
@@ -169,25 +169,23 @@ int vtkPDataSetWriter::Write()
   writer->SetFileTypeToBinary();
   vtkDataObject *copy;
   for (i = this->StartPiece; i <= this->EndPiece; ++i)
-    {
+  {
     sprintf(fileName, this->FilePattern, fileRoot, i);
     writer->SetFileName(fileName);
-    inputAlg->SetUpdateExtent(inputAlgPort,
-                              i, this->NumberOfPieces, this->GhostLevel);
-    inputAlg->Update();
+    inputAlg->UpdatePiece(i, this->NumberOfPieces, this->GhostLevel);
 
     // Store the extent of this piece in Extents. This is later used
     // to write the extents in the pvtk file.
     vtkInformation* info = input->GetInformation();
     int* ext = 0;
     if (info->Has(vtkDataObject::DATA_EXTENT()))
-      {
+    {
       ext = input->GetInformation()->Get(vtkDataObject::DATA_EXTENT());
-      }
+    }
     if (ext)
-      {
+    {
       this->Extents[i] = std::vector<int>(ext, ext+6);
-      }
+    }
 
     copy = input->NewInstance();
     copy->ShallowCopy(input);
@@ -201,31 +199,31 @@ int vtkPDataSetWriter::Write()
     copy->Delete();
     copy = NULL;
     if (writer->GetErrorCode() == vtkErrorCode::OutOfDiskSpaceError)
-      {
+    {
       this->DeleteFiles();
       this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
       break;
-      }
     }
+  }
   writer->Delete();
   writer = NULL;
 
     // Lets write the toplevel file.
   if (this->StartPiece == 0 &&
       (!this->Controller || this->Controller->GetLocalProcessId() == 0))
-    {
+  {
     fptr = this->OpenFile();
     if (fptr == NULL)
-      {
+    {
       delete [] fileRoot;
       delete [] fileName;
       return 0;
-      }
+    }
     // Write a tag so that we know this file type.
     *fptr << "<File version=\"pvtk-1.0\"\n";
     fptr->flush();
     if (fptr->fail())
-      {
+    {
       vtkErrorMacro(<< "Unable to write to file: "<< this->FileName);
       this->CloseVTKFile(fptr);
       remove(this->FileName);
@@ -234,14 +232,14 @@ int vtkPDataSetWriter::Write()
       delete fptr;
       this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
       return 0;
-      }
+    }
 
     switch (input->GetDataObjectType())
-      {
+    {
       case VTK_POLY_DATA:
       case VTK_UNSTRUCTURED_GRID:
         if (!this->WriteUnstructuredMetaData(input, fileRoot, fileName, fptr))
-          {
+        {
           this->CloseVTKFile(fptr);
           remove(this->FileName);
           delete [] fileRoot;
@@ -249,13 +247,13 @@ int vtkPDataSetWriter::Write()
           delete fptr;
           this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
           return 0;
-          }
+        }
         break;
       case VTK_IMAGE_DATA:
       case VTK_STRUCTURED_POINTS:
         if (!this->WriteImageMetaData((vtkImageData*)input, fileRoot,
                                       fileName, fptr))
-          {
+        {
           this->CloseVTKFile(fptr);
           remove(this->FileName);
           delete [] fileRoot;
@@ -263,12 +261,12 @@ int vtkPDataSetWriter::Write()
           delete fptr;
           this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
           return 0;
-          }
+        }
         break;
       case VTK_RECTILINEAR_GRID:
         if (!this->WriteRectilinearGridMetaData((vtkRectilinearGrid*)input,
                                                 fileRoot, fileName, fptr))
-          {
+        {
           this->CloseVTKFile(fptr);
           remove(this->FileName);
           delete [] fileRoot;
@@ -276,12 +274,12 @@ int vtkPDataSetWriter::Write()
           delete fptr;
           this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
           return 0;
-          }
+        }
         break;
       case VTK_STRUCTURED_GRID:
         if (!this->WriteStructuredGridMetaData((vtkStructuredGrid*)input,
                                                fileRoot, fileName, fptr))
-          {
+        {
           this->CloseVTKFile(fptr);
           remove(this->FileName);
           delete [] fileRoot;
@@ -289,13 +287,13 @@ int vtkPDataSetWriter::Write()
           delete fptr;
           this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
           return 0;
-          }
+        }
         break;
-      }
+    }
 
     //fptr->close();
     delete fptr;
-    }
+  }
 
   delete [] fileName;
   delete [] fileRoot;
@@ -315,16 +313,16 @@ int vtkPDataSetWriter::WriteUnstructuredMetaData(vtkDataSet *input,
   // some processes.
   *fptr << "      numberOfPieces=\"" << this->NumberOfPieces << "\" >" << endl;
   for (i = 0; i < this->NumberOfPieces; ++i)
-    {
+  {
     sprintf(str, this->FilePattern, root, i);
     *fptr << "  <Piece fileName=\"" << str << "\" />" << endl;
-    }
+  }
   *fptr << "</File>" << endl;
   fptr->flush();
   if (fptr->fail())
-    {
+  {
     return 0;
-    }
+  }
   return 1;
 }
 
@@ -360,7 +358,7 @@ int vtkPDataSetWriter::WriteImageMetaData(vtkImageData * input,
   // meta-file. Note that the extent of each piece was already stored by
   // each writer. This is gathering it all to root node.
   if (this->Controller)
-    {
+  {
     // Even though the logic is pretty straightforward, we need to
     // do a fair amount of work to use GatherV. Each rank simply
     // serializes its extents to 7 int blocks - piece number and 6
@@ -375,77 +373,77 @@ int vtkPDataSetWriter::WriteImageMetaData(vtkImageData * input,
     vtkIdType* nPiecesAll = 0;
     vtkIdType* recvLengths = 0;
     if (rank == 0)
-      {
+    {
       nPiecesAll = new vtkIdType[nRanks];
       recvLengths = new vtkIdType[nRanks];
       offsets = new vtkIdType[nRanks];
-      }
+    }
     this->Controller->Gather(&nPieces, nPiecesAll, 1, 0);
     if (rank == 0)
-      {
+    {
       for (int i=0; i<nRanks; i++)
-        {
+      {
         offsets[i] = nPiecesTotal*7;
         nPiecesTotal += nPiecesAll[i];
         recvLengths[i] = nPiecesAll[i]*7;
-        }
       }
+    }
     int* sendBuffer = 0;
     int sendSize = nPieces*7;
     if (nPieces > 0)
-      {
+    {
       sendBuffer = new int[sendSize];
       ExtentsType::iterator iter = this->Extents.begin();
       for (int count = 0; iter != this->Extents.end(); iter++, count++)
-        {
+      {
         sendBuffer[count*7] = iter->first;
         memcpy(&sendBuffer[count*7+1], &iter->second[0], 6*sizeof(int));
-        }
       }
+    }
     int* recvBuffer = 0;
     if (rank == 0)
-      {
+    {
       recvBuffer = new int[nPiecesTotal*7];
-      }
+    }
     this->Controller->GatherV(sendBuffer, recvBuffer, sendSize,
       recvLengths, offsets, 0);
 
     if (rank == 0)
-      {
+    {
       // Add all received values to Extents.
       // These are later written in WritePPieceAttributes()
       for (int i=1; i<nRanks; i++)
-        {
+      {
         for (int j=0; j<nPiecesAll[i]; j++)
-          {
+        {
           int* buffer = recvBuffer + offsets[i] + j*7;
           this->Extents[*buffer] =
             std::vector<int>(buffer+1, buffer+7);
-          }
         }
       }
+    }
 
     delete[] nPiecesAll;
     delete[] recvBuffer;
     delete[] offsets;
     delete[] recvLengths;
     delete[] sendBuffer;
-    }
+  }
 
   for (int i = 0; i < this->NumberOfPieces; ++i)
-    {
+  {
     pi = &this->Extents[i][0];
     sprintf(str, this->FilePattern, root, i);
     *fptr << "  <Piece fileName=\"" << str << "\"" << endl
           << "      extent=\"" << pi[0] << " " << pi[1] << " " << pi[2] << " "
           << pi[3] << " " << pi[4] << " " << pi[5] << "\" />" << endl;
-    }
+  }
   *fptr << "</File>" << endl;
   fptr->flush();
   if (fptr->fail())
-    {
+  {
     return 0;
-    }
+  }
   return 1;
 }
 
@@ -469,20 +467,20 @@ int vtkPDataSetWriter::WriteRectilinearGridMetaData(vtkRectilinearGrid *input,
   // some processes.
   *fptr << "      numberOfPieces=\"" << this->NumberOfPieces << "\" >" << endl;
   for (i = 0; i < this->NumberOfPieces; ++i)
-    {
+  {
     pi = &this->Extents[i][0];
     sprintf(str, this->FilePattern, root, i);
     *fptr << "  <Piece fileName=\"" << str << "\"" << endl
           << "      extent=\"" << pi[0] << " " << pi[1] << " " << pi[2] << " "
           << pi[3] << " " << pi[4] << " " << pi[5] << "\" />" << endl;
-    }
+  }
   *fptr << "</File>" << endl;
 
   fptr->flush();
   if (fptr->fail())
-    {
+  {
     return 0;
-    }
+  }
   return 1;
 }
 
@@ -506,20 +504,20 @@ int vtkPDataSetWriter::WriteStructuredGridMetaData(vtkStructuredGrid *input,
   // some processes.
   *fptr << "      numberOfPieces=\"" << this->NumberOfPieces << "\" >" << endl;
   for (i = 0; i < this->NumberOfPieces; ++i)
-    {
+  {
     pi = &this->Extents[i][0];
     sprintf(str, this->FilePattern, root, i);
     *fptr << "  <Piece fileName=\"" << str << "\"" << endl
           << "      extent=\"" << pi[0] << " " << pi[1] << " " << pi[2] << " "
           << pi[3] << " " << pi[4] << " " << pi[5] << "\" />" << endl;
-    }
+  }
   *fptr << "</File>" << endl;
 
   fptr->flush();
   if (fptr->fail())
-    {
+  {
     return 0;
-    }
+  }
   return 1;
 }
 
@@ -533,11 +531,11 @@ ostream *vtkPDataSetWriter::OpenFile()
   fptr = new ofstream(this->FileName, ios::out);
 
   if (fptr->fail())
-    {
+  {
     vtkErrorMacro(<< "Unable to open file: "<< this->FileName);
     delete fptr;
     return NULL;
-    }
+  }
 
   return fptr;
 }
@@ -553,46 +551,46 @@ void vtkPDataSetWriter::DeleteFiles()
   fileRoot[length] = '\0';
   // Trim off the pvtk extension.
   if (strncmp(fileRoot+length-5, ".pvtk", 5) == 0)
-    {
+  {
     fileRoot[length-5] = '\0';
-    }
+  }
   if (strncmp(fileRoot+length-4, ".vtk", 4) == 0)
-    {
+  {
     fileRoot[length-4] = '\0';
-    }
+  }
   // If we are using relative file names, trim off the directory path.
   if (this->UseRelativeFileNames)
-    {
+  {
     char *tmp, *slash;
     // Find the last / or \ in the file name.
     slash = NULL;
     tmp = fileRoot;
     while (*tmp != '\0')
-      {
+    {
       if (*tmp == '/' || *tmp == '\\')
-        {
+      {
         slash = tmp;
-        }
-      ++tmp;
       }
+      ++tmp;
+    }
     // Copy just the filename into root.
     if (slash)
-      {
+    {
       ++slash;
       tmp = fileRoot;
       while (*slash != '\0')
-        {
+      {
         *tmp++ = *slash++;
-        }
-      *tmp = '\0';
       }
+      *tmp = '\0';
     }
+  }
 
   for (i = this->StartPiece; i <= this->EndPiece; i++)
-    {
+  {
     sprintf(fileName, this->FilePattern, fileRoot, i);
     remove(fileName);
-    }
+  }
 
   remove(this->FileName);
 
