@@ -95,135 +95,147 @@ int vtkXMLUnstructuredDataWriter::ProcessRequest(vtkInformation* request,
 {
 
   if(request->Has(vtkStreamingDemandDrivenPipeline::REQUEST_UPDATE_EXTENT()))
-    {
+  {
     if((this->WritePiece < 0) || (this->WritePiece >= this->NumberOfPieces))
-      {
+    {
       this->SetInputUpdateExtent(
         this->CurrentPiece, this->NumberOfPieces, this->GhostLevel);
-      }
+    }
     else
-      {
+    {
       this->SetInputUpdateExtent(
         this->WritePiece, this->NumberOfPieces, this->GhostLevel);
-      }
-    return 1;
     }
+    return 1;
+  }
 
   // generate the data
   else if(request->Has(vtkDemandDrivenPipeline::REQUEST_DATA()))
-    {
+  {
     this->SetErrorCode(vtkErrorCode::NoError);
 
-    if(!this->Stream && !this->FileName)
-      {
+    if(!this->Stream && !this->FileName && !this->WriteToOutputString)
+    {
       this->SetErrorCode(vtkErrorCode::NoFileNameError);
-      vtkErrorMacro("The FileName or Stream must be set first.");
+      vtkErrorMacro("The FileName or Stream must be set first or "
+        "the output must be written to a string.");
       return 0;
-      }
+    }
 
     int numPieces = this->NumberOfPieces;
 
     if (this->WritePiece >= 0)
-      {
+    {
       this->CurrentPiece = this->WritePiece;
-      }
+    }
     else
-      {
-      float progressRange[2] = {0,0};
-      this->GetProgressRange(progressRange);
-      this->SetProgressRange(progressRange, this->CurrentPiece, this->NumberOfPieces);
-      }
+    {
+      float wholeProgressRange[2] = {0,1};
+      this->SetProgressRange(wholeProgressRange, this->CurrentPiece, this->NumberOfPieces);
+    }
 
     int result = 1;
     if ((this->CurrentPiece == 0 && this->CurrentTimeIndex == 0) || this->WritePiece >= 0)
-      {
+    {
       // We are just starting to write.  Do not call
       // UpdateProgressDiscrete because we want a 0 progress callback the
       // first time.
       this->UpdateProgress(0);
 
       // Initialize progress range to entire 0..1 range.
-      float wholeProgressRange[2] = {0,1};
-      this->SetProgressRange(wholeProgressRange, 0, 1);
+      if (this->WritePiece >= 0)
+      {
+        float wholeProgressRange[2] = {0,1};
+        this->SetProgressRange(wholeProgressRange, 0, 1);
+      }
 
       if (!this->OpenStream())
-        {
+      {
         this->NumberOfPieces = numPieces;
         return 0;
-        }
+      }
+
+      if (this->GetInputAsDataSet() != NULL &&
+          (this->GetInputAsDataSet()->GetPointGhostArray() != NULL &&
+           this->GetInputAsDataSet()->GetCellGhostArray() != NULL))
+      {
+        // use the current version for the file.
+        this->UsePreviousVersion = false;
+      }
+
       // Write the file.
       if (!this->StartFile())
-        {
+      {
         this->NumberOfPieces = numPieces;
         return 0;
-        }
+      }
 
       if (!this->WriteHeader())
-        {
+      {
         this->NumberOfPieces = numPieces;
         return 0;
-        }
+      }
 
       this->CurrentTimeIndex = 0;
       if( this->DataMode == vtkXMLWriter::Appended && this->FieldDataOM->GetNumberOfElements())
-        {
+      {
         // Write the field data arrays.
         this->WriteFieldDataAppendedData(this->GetInput()->GetFieldData(),
           this->CurrentTimeIndex, this->FieldDataOM);
         if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-          {
+        {
           this->DeletePositionArrays();
           return 0;
-          }
         }
       }
+    }
 
     if( !(this->UserContinueExecuting == 0)) //if user ask to stop do not try to write a piece
-      {
+    {
       result = this->WriteAPiece();
-      }
+    }
 
     if((this->WritePiece < 0) || (this->WritePiece >= this->NumberOfPieces))
-      {
+    {
       // Tell the pipeline to start looping.
       if (this->CurrentPiece == 0)
-        {
+      {
         request->Set(vtkStreamingDemandDrivenPipeline::CONTINUE_EXECUTING(), 1);
-        }
-      this->CurrentPiece++;
       }
+      this->CurrentPiece++;
+    }
 
     if (this->CurrentPiece == this->NumberOfPieces || this->WritePiece >= 0)
-      {
+    {
       request->Remove(vtkStreamingDemandDrivenPipeline::CONTINUE_EXECUTING());
       this->CurrentPiece = 0;
       // We are done writing all the pieces, lets loop over time now:
       this->CurrentTimeIndex++;
 
       if( this->UserContinueExecuting != 1 )
-        {
+      {
         if (!this->WriteFooter())
-          {
+        {
           this->NumberOfPieces = numPieces;
           return 0;
-          }
+        }
 
         if (!this->EndFile())
-          {
+        {
           this->NumberOfPieces = numPieces;
           return 0;
-          }
+        }
 
         this->CloseStream();
         this->CurrentTimeIndex = 0; // Reset
-        }
       }
+    }
     this->NumberOfPieces = numPieces;
 
-    // We have finished writing.
-    this->UpdateProgressDiscrete(1);
+    // We have finished writing (at least this piece)
+    this->SetProgressPartial(1);
     return result;
-    }
+  }
   return this->Superclass::ProcessRequest(request, inputVector, outputVector);
 }
 
@@ -252,88 +264,88 @@ int vtkXMLUnstructuredDataWriter::WriteHeader()
   ostream& os = *(this->Stream);
 
   if(!this->WritePrimaryElement(os, indent))
-    {
+  {
     return 0;
-    }
+  }
 
   this->WriteFieldData(indent.GetNextIndent());
 
   if(this->DataMode == vtkXMLWriter::Appended)
-    {
+  {
     vtkIndent nextIndent = indent.GetNextIndent();
 
     this->AllocatePositionArrays();
 
     if((this->WritePiece < 0) || (this->WritePiece >= this->NumberOfPieces))
-      {
+    {
       // Loop over each piece and write its structure.
       int i;
       for(i=0; i < this->NumberOfPieces; ++i)
-        {
+      {
         // Open the piece's element.
         os << nextIndent << "<Piece";
         this->WriteAppendedPieceAttributes(i);
         if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-          {
+        {
           this->DeletePositionArrays();
           return 0;
-          }
+        }
         os << ">\n";
 
         this->WriteAppendedPiece(i, nextIndent.GetNextIndent());
         if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-          {
+        {
           this->DeletePositionArrays();
           return 0;
-          }
+        }
 
         // Close the piece's element.
         os << nextIndent << "</Piece>\n";
-        }
       }
+    }
     else
-      {
+    {
       // Write just the requested piece.
       // Open the piece's element.
       os << nextIndent << "<Piece";
       this->WriteAppendedPieceAttributes(this->WritePiece);
       if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-        {
+      {
         this->DeletePositionArrays();
         return 0;
-        }
+      }
       os << ">\n";
 
       this->WriteAppendedPiece(this->WritePiece, nextIndent.GetNextIndent());
       if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-        {
+      {
         this->DeletePositionArrays();
         return 0;
-        }
+      }
 
       // Close the piece's element.
       os << nextIndent << "</Piece>\n";
-      }
+    }
 
     // Close the primary element.
     os << indent << "</" << this->GetDataSetName() << ">\n";
     os.flush();
     if (os.fail())
-      {
+    {
       this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
       this->DeletePositionArrays();
       return 0;
-      }
+    }
 
     this->StartAppendedData();
     if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-      {
+    {
       this->DeletePositionArrays();
       return 0;
-      }
-
     }
 
+  }
+
   return 1;
 }
 
@@ -345,19 +357,19 @@ int vtkXMLUnstructuredDataWriter::WriteAPiece()
   int result=1;
 
   if(this->DataMode == vtkXMLWriter::Appended)
-    {
+  {
     this->WriteAppendedPieceData(this->CurrentPiece);
-    }
+  }
   else
-    {
+  {
     result = this->WriteInlineMode(indent);
-    }
+  }
 
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-    {
+  {
     this->DeletePositionArrays();
     result = 0;
-    }
+  }
   return result;
 }
 
@@ -369,20 +381,20 @@ int vtkXMLUnstructuredDataWriter::WriteFooter()
   ostream& os = *(this->Stream);
 
   if(this->DataMode == vtkXMLWriter::Appended)
-    {
+  {
     this->DeletePositionArrays();
     this->EndAppendedData();
-    }
+  }
   else
-    {
+  {
     // Close the primary element.
     os << indent << "</" << this->GetDataSetName() << ">\n";
     os.flush();
     if (os.fail())
-      {
+    {
       return 0;
-      }
     }
+  }
 
   return 1;
 }
@@ -397,16 +409,16 @@ int vtkXMLUnstructuredDataWriter::WriteInlineMode(vtkIndent indent)
   os << nextIndent << "<Piece";
   this->WriteInlinePieceAttributes();
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-    {
+  {
     return 0;
-    }
+  }
   os << ">\n";
 
   this->WriteInlinePiece(nextIndent.GetNextIndent());
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-    {
+  {
     return 0;
-    }
+  }
 
   // Close the piece's element.
   os << nextIndent << "</Piece>\n";
@@ -439,9 +451,9 @@ void vtkXMLUnstructuredDataWriter::WriteInlinePiece(vtkIndent indent)
   // Write the point data arrays.
   this->WritePointDataInline(input->GetPointData(), indent);
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-    {
+  {
     return;
-    }
+  }
 
   // Set the range of progress for the cell data arrays.
   this->SetProgressRange(progressRange, 1, fractions);
@@ -449,9 +461,9 @@ void vtkXMLUnstructuredDataWriter::WriteInlinePiece(vtkIndent indent)
   // Write the cell data arrays.
   this->WriteCellDataInline(input->GetCellData(), indent);
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-    {
+  {
     return;
-    }
+  }
 
   // Set the range of progress for the point specification array.
   this->SetProgressRange(progressRange, 2, fractions);
@@ -476,16 +488,16 @@ void vtkXMLUnstructuredDataWriter::WriteAppendedPiece(int index,
   this->WritePointDataAppended(input->GetPointData(), indent,
     &this->PointDataOM->GetPiece(index));
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-    {
+  {
     return;
-    }
+  }
 
   this->WriteCellDataAppended(input->GetCellData(), indent,
     &this->CellDataOM->GetPiece(index));
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-    {
+  {
     return;
-    }
+  }
 
   this->WritePointsAppended(input->GetPoints(), indent,
     &this->PointsOM->GetPiece(index));
@@ -503,9 +515,9 @@ void vtkXMLUnstructuredDataWriter::WriteAppendedPieceData(int index)
   this->WriteScalarAttribute("NumberOfPoints",
                              (points?points->GetNumberOfPoints():0));
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-    {
+  {
     return;
-    }
+  }
   os.seekp(returnPosition);
 
   // Split progress among point data, cell data, and point arrays.
@@ -521,9 +533,9 @@ void vtkXMLUnstructuredDataWriter::WriteAppendedPieceData(int index)
   this->WritePointDataAppendedData(input->GetPointData(), this->CurrentTimeIndex,
                                   &this->PointDataOM->GetPiece(index));
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-    {
+  {
     return;
-    }
+  }
 
   // Set the range of progress for the cell data arrays.
   this->SetProgressRange(progressRange, 1, fractions);
@@ -532,15 +544,15 @@ void vtkXMLUnstructuredDataWriter::WriteAppendedPieceData(int index)
   this->WriteCellDataAppendedData(input->GetCellData(), this->CurrentTimeIndex,
                                   &this->CellDataOM->GetPiece(index));
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-    {
+  {
     return;
-    }
+  }
 
   // Set the range of progress for the point specification array.
   this->SetProgressRange(progressRange, 2, fractions);
 
   // Write the point specification array.
-  // Since we are writting the point let save the Modified Time of vtkPoints:
+  // Since we are writing the point let save the Modified Time of vtkPoints:
   this->WritePointsAppendedData(input->GetPoints(), this->CurrentTimeIndex,
                                 &this->PointsOM->GetPiece(index));
 }
@@ -560,9 +572,9 @@ void vtkXMLUnstructuredDataWriter::WriteCellsInline(
   types->Allocate(numCells);
   for (cellIter->InitTraversal(); !cellIter->IsDoneWithTraversal();
        cellIter->GoToNextCell())
-    {
+  {
     types->InsertNextValue(static_cast<unsigned char>(cellIter->GetCellType()));
-    }
+  }
 
   this->WriteCellsInlineWorker(name, types.GetPointer(), indent);
 }
@@ -583,7 +595,10 @@ void vtkXMLUnstructuredDataWriter::WriteCellsInline(const char* name,
                         vtkIdTypeArray* faces, vtkIdTypeArray* faceOffsets,
                         vtkIndent indent)
 {
-  this->ConvertCells(cells);
+  if(cells)
+  {
+    this->ConvertCells(cells);
+  }
   this->ConvertFaces(faces, faceOffsets);
 
   this->WriteCellsInlineWorker(name, types, indent);
@@ -608,9 +623,9 @@ void vtkXMLUnstructuredDataWriter::WriteCellsInlineWorker(
   // Write the connectivity array.
   this->WriteArrayInline(this->CellPoints, indent.GetNextIndent());
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-    {
+  {
     return;
-    }
+  }
 
   // Set the range of progress for the offsets array.
   this->SetProgressRange(progressRange, 1, fractions);
@@ -618,55 +633,55 @@ void vtkXMLUnstructuredDataWriter::WriteCellsInlineWorker(
   // Write the offsets array.
   this->WriteArrayInline(this->CellOffsets, indent.GetNextIndent());
   if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-    {
+  {
     return;
-    }
+  }
 
   if(types)
-    {
+  {
     // Set the range of progress for the types array.
     this->SetProgressRange(progressRange, 2, fractions);
 
     // Write the types array.
     this->WriteArrayInline(types, indent.GetNextIndent(), "types");
     if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-      {
+    {
       return;
-      }
     }
+  }
 
   if (this->Faces->GetNumberOfTuples())
-    {
+  {
     // Set the range of progress for the faces array.
     this->SetProgressRange(progressRange, 3, fractions);
 
     // Write the connectivity array.
     this->WriteArrayInline(this->Faces, indent.GetNextIndent(), "faces");
     if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-      {
+    {
       return;
-      }
     }
+  }
 
   if (this->FaceOffsets->GetNumberOfTuples())
-    {
+  {
     // Set the range of progress for the face offset array.
     this->SetProgressRange(progressRange, 4, fractions);
 
     // Write the face offsets array.
     this->WriteArrayInline(this->FaceOffsets, indent.GetNextIndent(), "faceoffsets");
     if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-      {
+    {
       return;
-      }
     }
+  }
 
   os << indent << "</" << name << ">\n";
   os.flush();
   if (os.fail())
-    {
+  {
     this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -675,6 +690,18 @@ void vtkXMLUnstructuredDataWriter::WriteCellsAppended(const char* name,
                                                       vtkIndent indent,
                                                       OffsetsManagerGroup *cellsManager)
 {
+  this->WriteCellsAppended(name, types, 0, 0, indent, cellsManager);
+}
+
+//----------------------------------------------------------------------------
+void vtkXMLUnstructuredDataWriter::WriteCellsAppended(const char* name,
+                                                      vtkDataArray* types,
+                                                      vtkIdTypeArray* faces,
+                                                      vtkIdTypeArray* faceOffsets,
+                                                      vtkIndent indent,
+                                                      OffsetsManagerGroup *cellsManager)
+{
+  this->ConvertFaces(faces,faceOffsets);
   ostream& os = *(this->Stream);
   os << indent << "<" << name << ">\n";
 
@@ -688,27 +715,27 @@ void vtkXMLUnstructuredDataWriter::WriteCellsAppended(const char* name,
   const char *names[] = {NULL, NULL, "types", NULL, NULL};
 
   for(int t=0; t<this->NumberOfTimeSteps; t++)
-    {
+  {
     for(int i=0; i<5; i++)
-      {
+    {
       if(allcells[i])
-        {
+      {
         this->WriteArrayAppended(allcells[i], indent.GetNextIndent(),
           cellsManager->GetElement(i), names[i], 0, t);
         if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-          {
+        {
           return;
-          }
         }
       }
     }
+  }
   os << indent << "</" << name << ">\n";
   os.flush();
   if (os.fail())
-    {
+  {
     this->SetErrorCode(vtkErrorCode::OutOfDiskSpaceError);
     return;
-    }
+  }
 
 }
 
@@ -721,11 +748,11 @@ void vtkXMLUnstructuredDataWriter::WriteCellsAppended(
   types->Allocate(numCells);
   for (cellIter->InitTraversal(); !cellIter->IsDoneWithTraversal();
        cellIter->GoToNextCell())
-    {
+  {
     types->InsertNextValue(static_cast<unsigned char>(cellIter->GetCellType()));
-    }
+  }
 
-  this->WriteCellsAppended(name, types.GetPointer(), indent, cellsManager);
+  this->WriteCellsAppended(name, types.GetPointer(), 0, 0, indent, cellsManager);
 }
 
 //----------------------------------------------------------------------------
@@ -754,9 +781,9 @@ void vtkXMLUnstructuredDataWriter::WriteCellsAppendedData(
 
   for(cellIter->InitTraversal(); !cellIter->IsDoneWithTraversal();
       cellIter->GoToNextCell())
-    {
+  {
     types->InsertNextValue(static_cast<unsigned char>(cellIter->GetCellType()));
-    }
+  }
 
   this->WriteCellsAppendedDataWorker(types.GetPointer(), timestep,
                                      cellsManager);
@@ -772,9 +799,9 @@ vtkXMLUnstructuredDataWriter::WriteCellsAppendedData(vtkCellArray* cells,
                                                      OffsetsManagerGroup *cellsManager)
 {
   if (cells)
-    {
+  {
     this->ConvertCells(cells);
-    }
+  }
 
   this->ConvertFaces(faces, faceOffsets);
   this->WriteCellsAppendedDataWorker(types, timestep, cellsManager);
@@ -799,29 +826,29 @@ void vtkXMLUnstructuredDataWriter::WriteCellsAppendedDataWorker(
   allcells[4] = this->FaceOffsets->GetNumberOfTuples() ? this->FaceOffsets : 0;
 
   for(int i=0; i<5; i++)
-    {
+  {
     if(allcells[i])
-      {
+    {
       // Set the range of progress for the connectivity array.
       this->SetProgressRange(progressRange, i, fractions);
 
-      unsigned long mtime = allcells[i]->GetMTime();
-      unsigned long &cellsMTime = cellsManager->GetElement(i).GetLastMTime();
+      vtkMTimeType mtime = allcells[i]->GetMTime();
+      vtkMTimeType &cellsMTime = cellsManager->GetElement(i).GetLastMTime();
       // Only write cells if MTime has changed
       if( cellsMTime != mtime )
-        {
+      {
         cellsMTime = mtime;
         // Write the connectivity array.
         this->WriteArrayAppendedData(allcells[i],
           cellsManager->GetElement(i).GetPosition(timestep),
           cellsManager->GetElement(i).GetOffsetValue(timestep));
         if (this->ErrorCode == vtkErrorCode::OutOfDiskSpaceError)
-          {
-          return;
-          }
-        }
-      else
         {
+          return;
+        }
+      }
+      else
+      {
         // One timestep must have already been written or the
         // mtime would have changed and we would not be here.
         assert( timestep > 0 );
@@ -830,8 +857,8 @@ void vtkXMLUnstructuredDataWriter::WriteCellsAppendedDataWorker(
         this->ForwardAppendedDataOffset(cellsManager->GetElement(i).GetPosition(timestep),
                                         cellsManager->GetElement(i).GetOffsetValue(timestep),
                                         "offset" );
-        }
       }
+    }
   }
 }
 
@@ -844,16 +871,16 @@ void vtkXMLUnstructuredDataWriter::ConvertCells(
 
   for (cellIter->InitTraversal(); !cellIter->IsDoneWithTraversal();
        cellIter->GoToNextCell())
-    {
+  {
     vtkIdType *begin = cellIter->GetPointIds()->GetPointer(0);
     vtkIdType *end = begin + cellIter->GetNumberOfPoints();
     while (begin != end)
-      {
+    {
       this->CellPoints->InsertNextValue(*begin++);
-      }
+    }
 
     this->CellOffsets->InsertNextValue(this->CellPoints->GetNumberOfTuples());
-    }
+  }
 
   this->CellPoints->Squeeze();
   this->CellOffsets->Squeeze();
@@ -876,13 +903,13 @@ void vtkXMLUnstructuredDataWriter::ConvertCells(vtkCellArray* cells)
 
   vtkIdType i;
   for(i=0;i < numberOfCells; ++i)
-    {
+  {
     vtkIdType numberOfPoints = *inCell++;
     memcpy(outCellPoints, inCell, sizeof(vtkIdType)*numberOfPoints);
     outCellPoints += numberOfPoints;
     inCell += numberOfPoints;
     *outCellOffset++ = outCellPoints - outCellPointsBase;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -891,20 +918,20 @@ void vtkXMLUnstructuredDataWriter::ConvertFaces(vtkIdTypeArray* faces,
 {
   if (!faces || !faces->GetNumberOfTuples() ||
       !faceOffsets || !faceOffsets->GetNumberOfTuples())
-    {
+  {
     this->Faces->SetNumberOfTuples(0);
     this->FaceOffsets->SetNumberOfTuples(0);
     return;
-    }
+  }
 
   // copy faces stream.
   this->Faces->SetNumberOfTuples(faces->GetNumberOfTuples());
   vtkIdType * fromPtr = faces->GetPointer(0);
   vtkIdType * toPtr = this->Faces->GetPointer(0);
   for (vtkIdType i = 0; i < faces->GetNumberOfTuples(); i++)
-    {
+  {
     *toPtr++ = *fromPtr++;
-    }
+  }
 
   // this->FaceOffsets point to the face arrays of cells. Specifically
   // FaceOffsets[i] points to the end of the i-th cell's faces + 1. While
@@ -917,33 +944,33 @@ void vtkXMLUnstructuredDataWriter::ConvertFaces(vtkIdTypeArray* faces,
   vtkIdType* facesPtr = this->Faces->GetPointer(0);
   bool foundPolyhedronCell = false;
   for (vtkIdType i = 0; i < numberOfCells; i++)
-    {
+  {
     if (oldOffsetPtr[i] < 0) //non-polyhedron cell
-      {
+    {
       newOffsetPtr[i] = -1;
-      }
+    }
     else // polyhedron cell
-      {
+    {
       foundPolyhedronCell = true;
       // read numberOfFaces in a cell
       vtkIdType currLoc = oldOffsetPtr[i];
       vtkIdType numberOfCellFaces = facesPtr[currLoc];
       currLoc += 1;
       for (vtkIdType j = 0; j < numberOfCellFaces; j++)
-        {
+      {
         // read numberOfPoints in a face
         vtkIdType numberOfFacePoints = facesPtr[currLoc];
         currLoc += numberOfFacePoints + 1;
-        }
-      newOffsetPtr[i] = currLoc;
       }
+      newOffsetPtr[i] = currLoc;
     }
+  }
 
   if (!foundPolyhedronCell)
-    {
+  {
     this->Faces->SetNumberOfTuples(0);
     this->FaceOffsets->SetNumberOfTuples(0);
-    }
+  }
 
   return;
 }
@@ -968,9 +995,9 @@ void vtkXMLUnstructuredDataWriter::CalculateDataFractions(float* fractions)
   vtkIdType cdSize = cdArrays*this->GetNumberOfInputCells();
   int total = (pdSize+cdSize+this->GetNumberOfInputPoints());
   if(total == 0)
-    {
+  {
     total = 1;
-    }
+  }
   fractions[0] = 0;
   fractions[1] = float(pdSize)/total;
   fractions[2] = float(pdSize+cdSize)/total;
@@ -990,9 +1017,9 @@ void vtkXMLUnstructuredDataWriter::CalculateCellFractions(float* fractions,
                                this->FaceOffsets->GetNumberOfTuples() : 0;
   vtkIdType total = connectSize+offsetSize+faceSize+faceoffsetSize+typesSize;
   if(total == 0)
-    {
+  {
     total = 1;
-    }
+  }
   fractions[0] = 0;
   fractions[1] = float(connectSize)/total;
   fractions[2] = float(connectSize+offsetSize)/total;
