@@ -41,6 +41,7 @@
 #include "vtkStructuredGrid.h"
 #include "vtkTypeTraits.h"
 #include "vtkUnstructuredGrid.h"
+#include "vtksys/SystemTools.hxx"
 
 #include "XdmfArray.h"
 #include "XdmfAttribute.h"
@@ -55,15 +56,16 @@
 
 #include <algorithm>
 #include <map>
-#include <stdio.h>
+#include <cstdio>
+#include <sstream>
 #include <vector>
 
 #include <libxml/tree.h> // always after std::blah stuff
 
-#if defined(_WIN32) && !defined(__CYGWIN__)
-# define SNPRINTF _snprintf
+#ifdef VTK_USE_64BIT_IDS
+typedef XdmfInt64 vtkXdmfIdType;
 #else
-# define SNPRINTF snprintf
+typedef XdmfInt32 vtkXdmfIdType;
 #endif
 
 using namespace xdmf2;
@@ -81,26 +83,26 @@ class vtkXdmfWriterDomainMemoryHandler
 {
   public:
     vtkXdmfWriterDomainMemoryHandler()
-      {
+    {
         domain = new XdmfDomain();
-      }
+    }
     ~vtkXdmfWriterDomainMemoryHandler()
-      {
+    {
         for(std::vector<xdmf2::XdmfGrid*>::iterator iter = domainGrids.begin(); iter != domainGrids.end(); ++iter)
         {
           delete *iter;
         }
         delete domain;
-      }
+    }
   void InsertGrid(xdmf2::XdmfGrid* grid)
-      {
+  {
         domain->Insert(grid);
         domainGrids.push_back(grid);
-      }
+  }
     void InsertIntoRoot(XdmfRoot& root)
-      {
+    {
         root.Insert(domain);
-      }
+    }
   private:
     XdmfDomain* domain;
   std::vector<xdmf2::XdmfGrid*> domainGrids;
@@ -111,28 +113,28 @@ class vtkXdmfWriterDomainMemoryHandler
 struct vtkXdmfWriterInternal
 {
   class CellType
-    {
+  {
   public:
     CellType() : VTKType(0), NumPoints(0) {}
     CellType(const CellType& ct) : VTKType(ct.VTKType), NumPoints(ct.NumPoints) {}
     vtkIdType VTKType;
     vtkIdType NumPoints;
     bool operator<(const CellType& ct) const
-      {
+    {
       return this->VTKType < ct.VTKType || (this->VTKType == ct.VTKType && this->NumPoints < ct.NumPoints);
-      }
+    }
     bool operator==(const CellType& ct) const
-      {
+    {
       return this->VTKType == ct.VTKType && this->NumPoints == ct.NumPoints;
-      }
+    }
     CellType& operator=(const CellType& ct)
-      {
+    {
       this->VTKType = ct.VTKType;
       this->NumPoints = ct.NumPoints;
       return *this;
-      }
+    }
 
-    };
+  };
   typedef std::map<CellType, vtkSmartPointer<vtkIdList> > MapOfCellTypes;
   static void DetermineCellTypes(vtkPointSet *t, MapOfCellTypes& vec);
 };
@@ -141,28 +143,28 @@ struct vtkXdmfWriterInternal
 void vtkXdmfWriterInternal::DetermineCellTypes(vtkPointSet * t, vtkXdmfWriterInternal::MapOfCellTypes& vec)
 {
   if ( !t )
-    {
+  {
     return;
-    }
+  }
   vtkIdType cc;
   vtkGenericCell* cell = vtkGenericCell::New();
   for ( cc = 0; cc < t->GetNumberOfCells(); cc ++ )
-    {
+  {
     vtkXdmfWriterInternal::CellType ct;
     t->GetCell(cc, cell);
     ct.VTKType = cell->GetCellType();
     ct.NumPoints = cell->GetNumberOfPoints();
     vtkXdmfWriterInternal::MapOfCellTypes::iterator it = vec.find(ct);
     if ( it == vec.end() )
-      {
+    {
       vtkIdList *l = vtkIdList::New();
       it = vec.insert(vtkXdmfWriterInternal::MapOfCellTypes::value_type(ct,
           vtkSmartPointer<vtkIdList>(l))).first;
       l->Delete();
-      }
+    }
     // it->second->InsertUniqueId(cc);;
     it->second->InsertNextId(cc);;
-    }
+  }
   cell->Delete();
 }
 
@@ -186,6 +188,7 @@ vtkXdmfWriter::vtkXdmfWriter()
   this->TopTemporalGrid = NULL;
   this->DomainMemoryHandler = NULL;
   this->SetNumberOfOutputPorts(0);
+  this->MeshStaticOverTime = false;
 }
 
 //----------------------------------------------------------------------------
@@ -194,21 +197,12 @@ vtkXdmfWriter::~vtkXdmfWriter()
   this->SetFileName(NULL);
   this->SetHeavyDataFileName(NULL);
   this->SetHeavyDataGroupName(NULL);
-  if (this->DOM)
-    {
-    delete this->DOM;
-    this->DOM = NULL;
-    }
-  if (this->DomainMemoryHandler)
-    {
-    delete this->DomainMemoryHandler;
-    }
-  if (this->TopTemporalGrid)
-    {
-    delete this->TopTemporalGrid;
-    this->TopTemporalGrid = NULL;
-    }
+  delete this->DOM;
+  this->DOM = NULL;
   delete this->DomainMemoryHandler;
+  this->DomainMemoryHandler = NULL;
+  delete this->TopTemporalGrid;
+  this->TopTemporalGrid = NULL;
 
   //TODO: Verify memory isn't leaking
 }
@@ -249,19 +243,23 @@ int vtkXdmfWriter::Write()
 {
   // Make sure we have input.
   if (this->GetNumberOfInputConnections(0) < 1)
-    {
+  {
     vtkErrorMacro("No input provided!");
     return 0;
-    }
+  }
 
   // always write even if the data hasn't changed
   this->Modified();
 
+  this->TopologyAtT0.clear();
+  this->GeometryAtT0.clear();
+  this->UnlabelledDataArrayId = 0;
+
   //TODO: Specify name of heavy data companion file?
   if (!this->DOM)
-    {
+  {
     this->DOM = new xdmf2::XdmfDOM();
-    }
+  }
   this->DOM->SetOutputFileName(this->FileName);
 
   XdmfRoot root;
@@ -269,10 +267,7 @@ int vtkXdmfWriter::Write()
   root.SetVersion(2.2);
   root.Build();
 
-  if (this->DomainMemoryHandler)
-    {
-    delete this->DomainMemoryHandler;
-    }
+  delete this->DomainMemoryHandler;
   this->DomainMemoryHandler = new vtkXdmfWriterDomainMemoryHandler();
   this->DomainMemoryHandler->InsertIntoRoot(root);
 
@@ -296,14 +291,14 @@ int vtkXdmfWriter::RequestInformation(
   // Does the input have timesteps?
   vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
   if ( inInfo->Has(vtkStreamingDemandDrivenPipeline::TIME_STEPS()) )
-    {
+  {
     this->NumberOfTimeSteps =
       inInfo->Length( vtkStreamingDemandDrivenPipeline::TIME_STEPS() );
-    }
+  }
   else
-    {
+  {
     this->NumberOfTimeSteps = 1;
-    }
+  }
 
   return 1;
 }
@@ -317,7 +312,7 @@ int vtkXdmfWriter::RequestUpdateExtent(
   double *inTimes = inputVector[0]->GetInformationObject(0)->Get(
       vtkStreamingDemandDrivenPipeline::TIME_STEPS());
   if (inTimes && this->WriteAllTimeSteps)
-    {
+  {
     //TODO:? Add a user ivar to specify a particular time,
     //which is different from current time. Can do it by updating
     //to a particular time then writing without writealltimesteps,
@@ -326,7 +321,7 @@ int vtkXdmfWriter::RequestUpdateExtent(
     inputVector[0]->GetInformationObject(0)->Set(
         vtkStreamingDemandDrivenPipeline::UPDATE_TIME_STEP(),
         timeReq);
-    }
+  }
 
   return 1;
 }
@@ -338,65 +333,73 @@ int vtkXdmfWriter::RequestData(
   vtkInformationVector* vtkNotUsed(outputVector))
 {
   if (!this->DomainMemoryHandler)
-    {
+  {
     //call Write instead of this directly. That does setup first, then calls this.
     return 1;
-    }
+  }
+
+  this->WorkingDirectory = vtksys::SystemTools::GetFilenamePath(this->FileName);
+  this->BaseFileName     = vtksys::SystemTools::GetFilenameWithoutLastExtension(this->FileName);
+
+  // If mesh is static we force heavy data to be exported in HDF
+  int lightDataLimit = this->LightDataLimit;
+  this->LightDataLimit = this->MeshStaticOverTime ? 1 : this->LightDataLimit;
+
+  this->CurrentBlockIndex = 0;
 
   if (this->CurrentTimeIndex == 0 &&
       this->WriteAllTimeSteps &&
       this->NumberOfTimeSteps > 1)
-    {
+  {
     // Tell the pipeline to start looping.
     request->Set(vtkStreamingDemandDrivenPipeline::CONTINUE_EXECUTING(), 1);
 
     // make a top level temporal grid just under domain
-    if (this->TopTemporalGrid)
-      {
-      delete this->TopTemporalGrid;
-      this->TopTemporalGrid = NULL;
-      }
+    delete this->TopTemporalGrid;
+    this->TopTemporalGrid = NULL;
 
     xdmf2::XdmfGrid *tgrid = new xdmf2::XdmfGrid();
     tgrid->SetDeleteOnGridDelete(true);
     tgrid->SetGridType(XDMF_GRID_COLLECTION);
     tgrid->SetCollectionType(XDMF_GRID_COLLECTION_TEMPORAL);
+    tgrid->SetName(this->BaseFileName.c_str());
     XdmfTopology *t = tgrid->GetTopology();
     t->SetTopologyType(XDMF_NOTOPOLOGY);
     XdmfGeometry *geo = tgrid->GetGeometry();
     geo->SetGeometryType(XDMF_GEOMETRY_NONE);
 
     this->DomainMemoryHandler->InsertGrid(tgrid);
-
     this->TopTemporalGrid = tgrid;
-    }
+  }
 
   xdmf2::XdmfGrid *grid = new xdmf2::XdmfGrid();
   grid->SetDeleteOnGridDelete(true);
   if (this->TopTemporalGrid)
-    {
+  {
     this->TopTemporalGrid->Insert(grid);
-    }
+  }
   else
-    {
+  {
     this->DomainMemoryHandler->InsertGrid(grid);
-    }
+  }
+
+  this->CurrentTime = 0;
 
   vtkInformation* inInfo = inputVector[0]->GetInformationObject(0);
   vtkDataObject* input = inInfo->Get(vtkDataObject::DATA_OBJECT());
   vtkInformation *inDataInfo = input->GetInformation();
   if (inDataInfo->Has(vtkDataObject::DATA_TIME_STEP()))
-    {
+  {
     //I am assuming we are not given a temporal data object and getting just one time.
-    double dataT = input->GetInformation()->Get(vtkDataObject::DATA_TIME_STEP());
-    //cerr << "Writing " << this->CurrentTimeIndex << " " << *dataT << endl;
+    this->CurrentTime = input->GetInformation()->Get(vtkDataObject::DATA_TIME_STEP());
+    //cerr << "Writing timestep" << this->CurrentTimeIndex << " (" << this->CurrentTime << ")" << endl;
 
     XdmfTime *xT = grid->GetTime();
     xT->SetDeleteOnGridDelete(true);
     xT->SetTimeType(XDMF_TIME_SINGLE);
-    xT->SetValue(dataT);
+    xT->SetValue(this->CurrentTime);
     grid->Insert(xT);
-    }
+  }
 
   this->WriteDataSet(input, grid);
   //delete grid; //domain takes care of it?
@@ -404,14 +407,15 @@ int vtkXdmfWriter::RequestData(
   this->CurrentTimeIndex++;
   if (this->CurrentTimeIndex >= this->NumberOfTimeSteps &&
       this->WriteAllTimeSteps)
-    {
+  {
     // Tell the pipeline to stop looping.
     request->Remove(vtkStreamingDemandDrivenPipeline::CONTINUE_EXECUTING());
     this->CurrentTimeIndex = 0;
     //delete this->TopTemporalGrid; //domain takes care of it?
     this->TopTemporalGrid = NULL;
-    }
+  }
 
+  this->LightDataLimit = lightDataLimit;
   return 1;
 }
 
@@ -421,22 +425,22 @@ int vtkXdmfWriter::WriteDataSet(vtkDataObject *dobj, xdmf2::XdmfGrid *grid)
   //TODO:
   // respect parallelism
   if (!dobj)
-    {
+  {
     //vtkWarningMacro(<< "Null DS, someone else will take care of it");
     return 0;
-    }
+  }
   if (!grid)
-    {
+  {
     vtkWarningMacro(<< "Something is wrong, grid should have already been created for " << dobj);
     return 0;
-    }
+  }
 
   vtkCompositeDataSet *cdobj = vtkCompositeDataSet::SafeDownCast(dobj);
   if (cdobj)//!dobj->IsTypeOf("vtkCompositeDataSet")) //TODO: Why doesn't IsTypeOf work?
-    {
+  {
     this->WriteCompositeDataSet(cdobj, grid);
     return 1;
-    }
+  }
 
   return this->WriteAtomicDataSet(dobj, grid);
 }
@@ -446,17 +450,17 @@ int vtkXdmfWriter::WriteCompositeDataSet(vtkCompositeDataSet *dobj, xdmf2::XdmfG
 {
   //cerr << "internal node " << dobj << " is a " << dobj->GetClassName() << endl;
   if (dobj->IsA("vtkMultiPieceDataSet"))
-    {
+  {
     grid->SetGridType(XDMF_GRID_COLLECTION);
     grid->SetCollectionType(XDMF_GRID_COLLECTION_SPATIAL);
-    }
+  }
   else
-    {
+  {
     //fine for vtkMultiBlockDataSet
     //vtkHierarchicalBoxDataSet would be better served by a different xdmf tree type
     //vtkTemporalDataSet is internal to the VTK pipeline so I am ingnoring it
     grid->SetGridType(XDMF_GRID_TREE);
-    }
+  }
 
   XdmfTopology *t = grid->GetTopology();
   t->SetTopologyType(XDMF_NOTOPOLOGY);
@@ -467,36 +471,49 @@ int vtkXdmfWriter::WriteCompositeDataSet(vtkCompositeDataSet *dobj, xdmf2::XdmfG
   vtkDataObjectTreeIterator* treeIter =
     vtkDataObjectTreeIterator::SafeDownCast(iter);
   if(treeIter)
-    {
+  {
     treeIter->VisitOnlyLeavesOff();
     treeIter->TraverseSubTreeOff();
-    }
+  }
   vtkMultiBlockDataSet* mbds = vtkMultiBlockDataSet::SafeDownCast(dobj);
   iter->GoToFirstItem();
   while (!iter->IsDoneWithTraversal())
-    {
+  {
     xdmf2::XdmfGrid *childsGrid = new xdmf2::XdmfGrid();
     childsGrid->SetDeleteOnGridDelete(true);
     grid->Insert(childsGrid);
     vtkDataObject* ds = iter->GetCurrentDataObject();
 
     if (mbds)
-      {
+    {
       vtkInformation* info = mbds->GetMetaData(iter->GetCurrentFlatIndex() - 1);
       if (info)
-        {
+      {
         childsGrid->SetName(info->Get(vtkCompositeDataSet::NAME()));
-        }
       }
+    }
 
     this->WriteDataSet(ds, childsGrid);
     //delete childsGrid; //parent deletes children in Xdmf
     iter->GoToNextItem();
-    }
+  }
   iter->Delete();
 
   return 1;
 }
+
+//----------------------------------------------------------------------------
+void vtkXdmfWriter::SetupDataArrayXML(XdmfElement* e, XdmfArray* a) const
+{
+  std::stringstream ss;
+  ss << "<DataItem Dimensions = \"" << a->GetShapeAsString() <<
+    "\" NumberType = \"" << XdmfTypeToClassString(a->GetNumberType()) <<
+    "\" Precision = \"" << a->GetElementSize() <<
+    "\" Format = \"HDF\">" <<
+    a->GetHeavyDataSetName() << "</DataItem>";
+  e->SetDataXml(ss.str().c_str());
+}
+
 //------------------------------------------------------------------------------
 int vtkXdmfWriter::CreateTopology(vtkDataSet *ds, xdmf2::XdmfGrid *grid, vtkIdType PDims[3], vtkIdType CDims[3], vtkIdType &PRank, vtkIdType &CRank, void *staticdata)
 {
@@ -507,16 +524,37 @@ int vtkXdmfWriter::CreateTopology(vtkDataSet *ds, xdmf2::XdmfGrid *grid, vtkIdTy
   const char *heavyName = NULL;
   std::string heavyDataSetName;
   if (this->HeavyDataFileName)
-    {
+  {
     heavyDataSetName = std::string(this->HeavyDataFileName) + ":";
-    if (this->HeavyDataGroupName)
+    if (this->MeshStaticOverTime)
+    {
+      std::stringstream hdf5group;
+      hdf5group << "/Topology_";
+      if (this->CurrentBlockIndex >= 0)
       {
-      heavyDataSetName = heavyDataSetName + HeavyDataGroupName + "/Topology";
+        if (grid->GetName())
+        {
+          hdf5group << grid->GetName();
+        }
+        else
+        {
+          hdf5group << "Block_" << this->CurrentBlockIndex;
+        }
+        heavyDataSetName = heavyDataSetName + hdf5group.str();
       }
-    heavyName = heavyDataSetName.c_str();
     }
+    else
+    {
+      if (this->HeavyDataGroupName)
+      {
+        heavyDataSetName = heavyDataSetName + HeavyDataGroupName + "/Topology";
+      }
+    }
+    heavyName = heavyDataSetName.c_str();
+  }
 
   XdmfTopology *t = grid->GetTopology();
+  t->SetLightDataLimit(this->LightDataLimit);
 
   //
   // If the topology is unchanged from last grid written, we can reuse the XML
@@ -543,12 +581,34 @@ int vtkXdmfWriter::CreateTopology(vtkDataSet *ds, xdmf2::XdmfGrid *grid, vtkIdTy
     }
   }
 
+  if (this->MeshStaticOverTime)
+  {
+    if (this->CurrentTimeIndex == 0)
+    {
+      // Save current topology node at t0 for next time steps
+      this->TopologyAtT0.push_back(t);
+    }
+    else if (static_cast<int>(this->TopologyAtT0.size()) > this->CurrentBlockIndex)
+    {
+      // Get topology node at t0
+      XdmfTopology* topo = this->TopologyAtT0[this->CurrentBlockIndex];
+      // Setup current topology node with t0 properties
+      t->SetTopologyTypeFromString(topo->GetTopologyTypeAsString());
+      t->SetNumberOfElements(topo->GetNumberOfElements());
+
+      // Setup connectivity data XML according t0 one
+      this->SetupDataArrayXML(t, topo->GetConnectivity());
+      reusing_topology = true;
+      // process continue as need to setup PDims parameters
+    }
+  }
+
   //Topology
   switch (ds->GetDataObjectType()) {
   case VTK_STRUCTURED_POINTS:
   case VTK_IMAGE_DATA:
   case VTK_UNIFORM_GRID:
-    {
+  {
     t->SetTopologyType(XDMF_3DCORECTMESH);
     t->SetLightDataLimit(this->LightDataLimit);
     vtkImageData *id = vtkImageData::SafeDownCast(ds);
@@ -568,10 +628,10 @@ int vtkXdmfWriter::CreateTopology(vtkDataSet *ds, xdmf2::XdmfGrid *grid, vtkIdTy
     CDims[0] = Dims[0] - 1;
     CDims[1] = Dims[1] - 1;
     CDims[2] = Dims[2] - 1;
-    }
+  }
     break;
   case VTK_RECTILINEAR_GRID:
-    {
+  {
     t->SetTopologyType(XDMF_3DRECTMESH);
     vtkRectilinearGrid *rgrid = vtkRectilinearGrid::SafeDownCast(ds);
     int wExtent[6];
@@ -590,10 +650,10 @@ int vtkXdmfWriter::CreateTopology(vtkDataSet *ds, xdmf2::XdmfGrid *grid, vtkIdTy
     CDims[0] = Dims[0] - 1;
     CDims[1] = Dims[1] - 1;
     CDims[2] = Dims[2] - 1;
-    }
+  }
     break;
   case VTK_STRUCTURED_GRID:
-    {
+  {
     vtkStructuredGrid *sgrid = vtkStructuredGrid::SafeDownCast(ds);
     int rank = CRank = PRank = sgrid->GetDataDimension();
     if( rank == 3 ){
@@ -622,21 +682,21 @@ int vtkXdmfWriter::CreateTopology(vtkDataSet *ds, xdmf2::XdmfGrid *grid, vtkIdTy
     CDims[0] = Dims[0] - 1;
     CDims[1] = Dims[1] - 1;
     CDims[2] = Dims[2] - 1;
-    }
+  }
     break;
   case VTK_POLY_DATA:
   case VTK_UNSTRUCTURED_GRID:
-    {
+  {
     PRank = 1;
     PDims[0] = ds->GetNumberOfPoints();
     CRank = 1;
     CDims[0] = ds->GetNumberOfCells();
     if (reusing_topology)
-      {
+    {
       // don't need to do all this again
       // @TODO : t->SetNodesPerElement(ppCell);
       break;
-      }
+    }
     vtkXdmfWriterInternal::MapOfCellTypes cellTypes;
     vtkXdmfWriterInternal::DetermineCellTypes(vtkPointSet::SafeDownCast(ds), cellTypes);
 
@@ -647,13 +707,13 @@ int vtkXdmfWriter::CreateTopology(vtkDataSet *ds, xdmf2::XdmfGrid *grid, vtkIdTy
     //If don't have to do that, could use pointer sharing,
     //and the extra code path is bound to cause problems eventually.
     if ( cellTypes.size() == 1 )
-      {
+    {
       //cerr << "Homogeneous topology" << endl;
       t->SetNumberOfElements(ds->GetNumberOfCells());
       const vtkXdmfWriterInternal::CellType* ct = &cellTypes.begin()->first;
       vtkIdType ppCell = ct->NumPoints;
       switch(ct->VTKType)
-        {
+      {
         case VTK_VERTEX :
         case VTK_POLY_VERTEX :
           t->SetTopologyType(XDMF_POLYVERTEX);
@@ -692,17 +752,18 @@ int vtkXdmfWriter::CreateTopology(vtkDataSet *ds, xdmf2::XdmfGrid *grid, vtkIdTy
         default :
           t->SetTopologyType(XDMF_NOTOPOLOGY);
           break;
-        }
+      }
       XdmfArray *di = t->GetConnectivity();
       di->SetHeavyDataSetName(heavyName);
       if (VTK_SIZEOF_ID_TYPE==sizeof(XDMF_64_INT))
-        {
+      {
         di->SetNumberType(XDMF_INT64_TYPE);
-        }
+      }
       else
-        {
+      {
         di->SetNumberType(XDMF_INT32_TYPE);
-        }
+      }
+
       XdmfInt64 hDim[2];
       hDim[0] = ds->GetNumberOfCells();
       hDim[1] = ppCell;
@@ -711,40 +772,40 @@ int vtkXdmfWriter::CreateTopology(vtkDataSet *ds, xdmf2::XdmfGrid *grid, vtkIdTy
       vtkIdList* cellPoints = vtkIdList::New();
       vtkIdType cvnt=0;
       for(vtkIdType i = 0 ; i < ds->GetNumberOfCells(); i++ )
-        {
+      {
         ds->GetCellPoints(il->GetId(i), cellPoints);
         if ( ct->VTKType == VTK_VOXEL )
-          {
+        {
           // Hack for VTK_VOXEL
-          di->SetValue(cvnt++, cellPoints->GetId(0));
-          di->SetValue(cvnt++, cellPoints->GetId(1));
-          di->SetValue(cvnt++, cellPoints->GetId(3));
-          di->SetValue(cvnt++, cellPoints->GetId(2));
-          di->SetValue(cvnt++, cellPoints->GetId(4));
-          di->SetValue(cvnt++, cellPoints->GetId(5));
-          di->SetValue(cvnt++, cellPoints->GetId(7));
-          di->SetValue(cvnt++, cellPoints->GetId(6));
-          }
-        else if ( ct->VTKType == VTK_PIXEL )
-          {
-          // Hack for VTK_PIXEL
-          di->SetValue(cvnt++, cellPoints->GetId(0));
-          di->SetValue(cvnt++, cellPoints->GetId(1));
-          di->SetValue(cvnt++, cellPoints->GetId(3));
-          di->SetValue(cvnt++, cellPoints->GetId(2));
-          }
-        else
-          {
-          for( vtkIdType j = 0 ; j < ppCell ; j++ )
-            {
-            di->SetValue(cvnt++, cellPoints->GetId(j));
-            }
-          }//pd has 4 arrays, so it is rarely homogeoneous
+          di->SetValue(cvnt++, (vtkXdmfIdType)cellPoints->GetId(0));
+          di->SetValue(cvnt++, (vtkXdmfIdType)cellPoints->GetId(1));
+          di->SetValue(cvnt++, (vtkXdmfIdType)cellPoints->GetId(3));
+          di->SetValue(cvnt++, (vtkXdmfIdType)cellPoints->GetId(2));
+          di->SetValue(cvnt++, (vtkXdmfIdType)cellPoints->GetId(4));
+          di->SetValue(cvnt++, (vtkXdmfIdType)cellPoints->GetId(5));
+          di->SetValue(cvnt++, (vtkXdmfIdType)cellPoints->GetId(7));
+          di->SetValue(cvnt++, (vtkXdmfIdType)cellPoints->GetId(6));
         }
+        else if ( ct->VTKType == VTK_PIXEL )
+        {
+          // Hack for VTK_PIXEL
+          di->SetValue(cvnt++, (vtkXdmfIdType)cellPoints->GetId(0));
+          di->SetValue(cvnt++, (vtkXdmfIdType)cellPoints->GetId(1));
+          di->SetValue(cvnt++, (vtkXdmfIdType)cellPoints->GetId(3));
+          di->SetValue(cvnt++, (vtkXdmfIdType)cellPoints->GetId(2));
+        }
+        else
+        {
+          for( vtkIdType j = 0 ; j < ppCell ; j++ )
+          {
+            di->SetValue(cvnt++, (vtkXdmfIdType)cellPoints->GetId(j));
+          }
+        }//pd has 4 arrays, so it is rarely homogeoneous
+      }
       cellPoints->Delete();
-      } //homogenous
+    } //homogenous
     else
-      {
+    {
       //cerr << "Nonhomogeneous topology" << endl;
       //Non Homogeneous, used mixed topology type to dump them all
       t->SetTopologyType(XDMF_MIXED);
@@ -753,23 +814,23 @@ int vtkXdmfWriter::CreateTopology(vtkDataSet *ds, xdmf2::XdmfGrid *grid, vtkIdTy
       XdmfArray *di = t->GetConnectivity();
       di->SetHeavyDataSetName(heavyName);
       if (VTK_SIZEOF_ID_TYPE==sizeof(XDMF_64_INT))
-        {
+      {
         di->SetNumberType(XDMF_INT64_TYPE);
-        }
+      }
       else
-        {
+      {
         di->SetNumberType(XDMF_INT32_TYPE);
-        }
+      }
       vtkIdTypeArray *da = vtkIdTypeArray::New();
       da->SetNumberOfComponents(1);
       vtkUnstructuredGrid *ugrid = vtkUnstructuredGrid::SafeDownCast(ds);
       const int ESTIMATE=4; /*celltype+numids+id0+id1 or celtype+id0+id1+id2*/
       if (ugrid)
-        {
+      {
         da->Allocate(ugrid->GetCells()->GetSize()*ESTIMATE);
-        }
+      }
       else
-        {
+      {
         vtkPolyData *pd = vtkPolyData::SafeDownCast(ds);
         vtkIdType sizev = pd->GetVerts()->GetSize();
         vtkIdType sizel = pd->GetLines()->GetSize();
@@ -777,16 +838,16 @@ int vtkXdmfWriter::CreateTopology(vtkDataSet *ds, xdmf2::XdmfGrid *grid, vtkIdTy
         vtkIdType sizes = pd->GetStrips()->GetSize();
         vtkIdType rtotal = sizev+sizel+sizep+sizes;
         da->Allocate(rtotal*ESTIMATE);
-        }
+      }
 
       vtkIdType cntr = 0;
       for (vtkIdType cid=0 ; cid < numCells; cid++)
-        {
+      {
         vtkCell *cell = ds->GetCell(cid);
         vtkIdType cellType = ds->GetCellType(cid);
         vtkIdType numPts = cell->GetNumberOfPoints();
         switch(cellType)
-          {
+        {
           case VTK_VERTEX :
           case VTK_POLY_VERTEX :
             da->InsertValue(cntr++, XDMF_POLYVERTEX);
@@ -830,9 +891,9 @@ int vtkXdmfWriter::CreateTopology(vtkDataSet *ds, xdmf2::XdmfGrid *grid, vtkIdTy
           default :
             da->InsertValue(cntr++,XDMF_NOTOPOLOGY);
             break;
-          }
+        }
         if ( cellType == VTK_VOXEL )
-          {
+        {
           // Hack for VTK_VOXEL
           da->InsertValue(cntr++, cell->GetPointId(0));
           da->InsertValue(cntr++, cell->GetPointId(1));
@@ -842,24 +903,24 @@ int vtkXdmfWriter::CreateTopology(vtkDataSet *ds, xdmf2::XdmfGrid *grid, vtkIdTy
           da->InsertValue(cntr++, cell->GetPointId(5));
           da->InsertValue(cntr++, cell->GetPointId(7));
           da->InsertValue(cntr++, cell->GetPointId(6));
-          }
+        }
         else if ( cellType == VTK_PIXEL )
-          {
+        {
           // Hack for VTK_PIXEL
           da->InsertValue(cntr++, cell->GetPointId(0));
           da->InsertValue(cntr++, cell->GetPointId(1));
           da->InsertValue(cntr++, cell->GetPointId(3));
           da->InsertValue(cntr++, cell->GetPointId(2));
-          }
-        for (vtkIdType pid=0; pid < numPts; pid++)
-          {
-          da->InsertValue(cntr++, cell->GetPointId(pid));
-          }
         }
+        for (vtkIdType pid=0; pid < numPts; pid++)
+        {
+          da->InsertValue(cntr++, cell->GetPointId(pid));
+        }
+      }
       this->ConvertVToXArray(da, di, 1, &cntr, 2, heavyName);
       da->Delete();
-      }
     }
+  }
     break;
   default:
     t->SetTopologyType(XDMF_NOTOPOLOGY);
@@ -879,14 +940,34 @@ int vtkXdmfWriter::CreateGeometry(vtkDataSet *ds, xdmf2::XdmfGrid *grid, void *s
   const char *heavyName = NULL;
   std::string heavyDataSetName;
   if (this->HeavyDataFileName)
-    {
+  {
     heavyDataSetName = std::string(this->HeavyDataFileName) + ":";
-    if (this->HeavyDataGroupName)
+    if (this->MeshStaticOverTime)
+    {
+      std::stringstream hdf5group;
+      hdf5group << "/Geometry_";
+      if (this->CurrentBlockIndex >= 0)
       {
-      heavyDataSetName = heavyDataSetName + HeavyDataGroupName + "/Geometry";
+        if (grid->GetName())
+        {
+          hdf5group << grid->GetName();
+        }
+        else
+        {
+          hdf5group << "Block_" << this->CurrentBlockIndex;
+        }
+        heavyDataSetName = heavyDataSetName + hdf5group.str();
       }
-    heavyName = heavyDataSetName.c_str();
     }
+    else
+    {
+      if (this->HeavyDataGroupName)
+      {
+        heavyDataSetName = heavyDataSetName + HeavyDataGroupName + "/Geometry";
+      }
+    }
+    heavyName = heavyDataSetName.c_str();
+  }
 
   vtkXW2NodeHelp *staticnode = (vtkXW2NodeHelp*)staticdata;
   if (staticnode) {
@@ -901,11 +982,30 @@ int vtkXdmfWriter::CreateGeometry(vtkDataSet *ds, xdmf2::XdmfGrid *grid, void *s
     }
   }
 
+  if (this->MeshStaticOverTime)
+  {
+    if (this->CurrentTimeIndex == 0)
+    {
+      // Save current geometry node at t0 for next time steps
+      this->GeometryAtT0.push_back(geo);
+    }
+    else if (static_cast<int>(this->TopologyAtT0.size()) > this->CurrentBlockIndex)
+    {
+      // Get geometry node at t0
+      XdmfGeometry* geo0 = this->GeometryAtT0[this->CurrentBlockIndex];
+      // Setup current geometry node with t0 properties
+      geo->SetGeometryTypeFromString(geo0->GetGeometryTypeAsString());
+      // Setup points data XML according t0 one
+      this->SetupDataArrayXML(geo, geo0->GetPoints());
+      return 1;
+    }
+  }
+
   switch (ds->GetDataObjectType()) {
   case VTK_STRUCTURED_POINTS:
   case VTK_IMAGE_DATA:
   case VTK_UNIFORM_GRID:
-    {
+  {
     geo->SetGeometryType(XDMF_GEOMETRY_ORIGIN_DXDYDZ);
     vtkImageData *id = vtkImageData::SafeDownCast(ds);
     double orig[3], spacing[3];
@@ -919,10 +1019,10 @@ int vtkXdmfWriter::CreateGeometry(vtkDataSet *ds, xdmf2::XdmfGrid *grid, void *s
     spacing[0] = tmp;
     geo->SetOrigin(orig);
     geo->SetDxDyDz(spacing);
-    }
+  }
     break;
   case VTK_RECTILINEAR_GRID:
-    {
+  {
     vtkIdType len;
     geo->SetGeometryType(XDMF_GEOMETRY_VXVYVZ);
     vtkRectilinearGrid *rgrid = vtkRectilinearGrid::SafeDownCast(ds);
@@ -942,26 +1042,26 @@ int vtkXdmfWriter::CreateGeometry(vtkDataSet *ds, xdmf2::XdmfGrid *grid, void *s
     XdmfArray *xdaz = new XdmfArray;
     this->ConvertVToXArray(da, xdaz, 1, &len, 0, heavyName);
     geo->SetVectorZ(xdaz, 1);
-    }
+  }
     break;
   case VTK_STRUCTURED_GRID:
   case VTK_POLY_DATA:
   case VTK_UNSTRUCTURED_GRID:
-    {
+  {
     geo->SetGeometryType(XDMF_GEOMETRY_XYZ);
     vtkPointSet *pset = vtkPointSet::SafeDownCast(ds);
     vtkPoints *pts = pset->GetPoints();
     if (!pts)
-      {
+    {
       return 0;
-      }
+    }
     vtkDataArray *da = pts->GetData();
     XdmfArray *xda = geo->GetPoints();
     vtkIdType shape[2];
     shape[0] = da->GetNumberOfTuples();
     this->ConvertVToXArray(da, xda, 1, shape, 0, heavyName);
     geo->SetPoints(xda);
-    }
+  }
     break;
   default:
     geo->SetGeometryType(XDMF_GEOMETRY_NONE);
@@ -971,17 +1071,20 @@ int vtkXdmfWriter::CreateGeometry(vtkDataSet *ds, xdmf2::XdmfGrid *grid, void *s
 
   return 1;
 }
+
 //------------------------------------------------------------------------------
 int vtkXdmfWriter::WriteAtomicDataSet(vtkDataObject *dobj, xdmf2::XdmfGrid *grid)
 {
   //cerr << "Writing " << dobj << " a " << dobj->GetClassName() << endl;
   vtkDataSet *ds = vtkDataSet::SafeDownCast(dobj);
   if (!ds)
-    {
+  {
     //TODO: Fill in non Vis data types
     vtkWarningMacro(<< "Can not convert " << dobj->GetClassName() << " to XDMF yet.");
     return 0;
-    }
+  }
+
+  this->DOM->SetWorkingDirectory(this->WorkingDirectory.c_str());
 
   //Attributes
   vtkIdType FRank = 1;
@@ -991,17 +1094,42 @@ int vtkXdmfWriter::WriteAtomicDataSet(vtkDataObject *dobj, xdmf2::XdmfGrid *grid
   vtkIdType PRank = 3;
   vtkIdType PDims[3];
 
+  // We need to force a data and group name for supporting still mesh over time
+  // otherwise names are generated when the data is dumped in HDF5: too late
+  // because we need the name to reuse it when building the tree.
+  std::string hdf5name = this->BaseFileName + ".h5";
+  this->SetHeavyDataFileName(hdf5name.c_str());
+
+  std::stringstream hdf5group;
+  hdf5group << "/";
+  if (this->CurrentBlockIndex >= 0)
+  {
+    if (grid->GetName())
+    {
+      hdf5group << grid->GetName();
+    }
+    else
+    {
+      hdf5group << "Block_" << this->CurrentBlockIndex;
+    }
+  }
+  hdf5group << "_t" << setw(6) << setfill('0') << this->CurrentTime;
+  hdf5group << ends;
+  this->SetHeavyDataGroupName(hdf5group.str().c_str());
+
   this->CreateTopology(ds, grid, PDims, CDims, PRank, CRank, NULL);
   if (!this->CreateGeometry(ds, grid, NULL))
-    {
+  {
     return 0;
-    }
+  }
 
   FDims[0] = ds->GetFieldData()->GetNumberOfTuples();
   this->WriteArrays(ds->GetFieldData(),grid,XDMF_ATTRIBUTE_CENTER_GRID, FRank, FDims, "Field");
   this->WriteArrays(ds->GetCellData(), grid,XDMF_ATTRIBUTE_CENTER_CELL, CRank, CDims, "Cell");
   this->WriteArrays(ds->GetPointData(),grid,XDMF_ATTRIBUTE_CENTER_NODE, PRank, PDims, "Node");
 
+  this->CurrentBlockIndex++;
+
   return 1;
 }
 
@@ -1010,22 +1138,22 @@ int vtkXdmfWriter::WriteArrays(vtkFieldData* fd, xdmf2::XdmfGrid *grid, int asso
                                vtkIdType rank, vtkIdType *dims, const char *name)
 {
   if (!fd)
-    {
+  {
     return 0;
-    }
+  }
   vtkDataSetAttributes *dsa = vtkDataSetAttributes::SafeDownCast(fd);
 
   const char *heavyName = NULL;
   std::string heavyDataSetName;
   if (this->HeavyDataFileName)
-    {
+  {
     heavyDataSetName = std::string(this->HeavyDataFileName) + ":";
     if (this->HeavyDataGroupName)
-      {
+    {
       heavyDataSetName = heavyDataSetName + std::string(HeavyDataGroupName) + "/" + name;
-      }
-    heavyName = heavyDataSetName.c_str();
     }
+    heavyName = heavyDataSetName.c_str();
+  }
 
   //
   // Sort alphabetically to avoid potential bad ordering problems
@@ -1034,41 +1162,41 @@ int vtkXdmfWriter::WriteArrays(vtkFieldData* fd, xdmf2::XdmfGrid *grid, int asso
   std::vector<std::pair<int, std::string> > attributeNames;
   attributeNames.reserve(nbOfArrays);
   for (int i = 0; i < nbOfArrays; i++)
-    {
-    vtkDataArray *scalars = fd->GetArray(i);
+  {
+    vtkAbstractArray *scalars = fd->GetAbstractArray(i);
     attributeNames.push_back(std::pair<int, std::string>(i, scalars->GetName()));
-    }
+  }
   std::sort(attributeNames.begin(), attributeNames.end());
 
   for (int i = 0; i < nbOfArrays; i++)
-    {
+  {
     vtkDataArray *da = fd->GetArray(attributeNames[i].second.c_str());
     if (!da)
-      {
+    {
       //TODO: Dump non numeric arrays too
       vtkWarningMacro(<< "xdmfwriter can not convert non-numeric arrays yet.");
       continue;
-      }
+    }
 
     XdmfAttribute *attr = new XdmfAttribute;
     attr->SetLightDataLimit(this->LightDataLimit);
     attr->SetDeleteOnGridDelete(true);
     if (da->GetName())
-      {
+    {
       attr->SetName(da->GetName());
-      }
+    }
     else
-      {
+    {
       attr->SetName("ANONYMOUS");
-      }
+    }
     attr->SetAttributeCenter(association);
 
     int attributeType = 0;
     if (dsa)
-      {
+    {
       attributeType = dsa->IsArrayAnAttribute(attributeNames[i].first);
       switch (attributeType)
-        {
+      {
         case vtkDataSetAttributes::SCALARS:
           attributeType = XDMF_ATTRIBUTE_TYPE_SCALAR; //TODO: Is XDMF ok with 3 component(RGB) active scalars?
           break;
@@ -1084,37 +1212,37 @@ int vtkXdmfWriter::WriteArrays(vtkFieldData* fd, xdmf2::XdmfGrid *grid, int asso
         case vtkDataSetAttributes::PEDIGREEIDS: //TODO: ? type is variable
         default:
           break;
-        }
       }
+    }
 
     if (attributeType != 0)
-      {
+    {
       attr->SetActive(1);
       attr->SetAttributeType(attributeType);
-      }
+    }
     else
-      {
+    {
       //vtk doesn't mark it as a special array, use width to tell xdmf what to call it
       if (da->GetNumberOfComponents() == 1)
-        {
+      {
         attr->SetAttributeType(XDMF_ATTRIBUTE_TYPE_SCALAR);
-        }
+      }
       else if (da->GetNumberOfComponents() == 3)
-        {
+      {
         attr->SetAttributeType(XDMF_ATTRIBUTE_TYPE_VECTOR);
-        }
+      }
       else if (da->GetNumberOfComponents() == 6)
-        {
+      {
         // TODO: convert VTK 9 components symetric tensors to 6 components
         attr->SetAttributeType(XDMF_ATTRIBUTE_TYPE_TENSOR);
-        }
       }
+    }
 
     XdmfArray *xda = attr->GetValues();
     this->ConvertVToXArray(da, xda, rank, dims, 0, heavyName);
     attr->SetValues(xda);
     grid->Insert(attr);
-    }
+  }
 
   return 1;
 }
@@ -1128,20 +1256,20 @@ void vtkXdmfWriter::ConvertVToXArray(vtkDataArray *vda,
   XdmfInt32 lRank = rank;
   XdmfInt64 *lDims = new XdmfInt64[rank+1];
   for (vtkIdType i = 0; i < rank; i++)
-    {
+  {
     lDims[i] = dims[i];
-    }
+  }
   vtkIdType nc = vda->GetNumberOfComponents();
   //add additional dimension to the xdmf array to match the vtk arrays width,
   //ex coordinate arrays have xyz, so add [3]
   if (nc != 1)
-    {
+  {
     lDims[rank]=nc;
     lRank+=1;
-    }
+  }
 
   switch (vda->GetDataType())
-    {
+  {
     case VTK_DOUBLE:
       xda->SetNumberType(XDMF_FLOAT64_TYPE);
       break;
@@ -1179,28 +1307,40 @@ void vtkXdmfWriter::ConvertVToXArray(vtkDataArray *vda,
     case VTK_UNSIGNED___INT64:
     case VTK_UNSIGNED_LONG:
     case VTK_STRING:
-      {
+    {
       xda->SetNumberType(XDMF_UNKNOWN_TYPE);
       break;
-      }
     }
+  }
 
-  if (heavyprefix) {
-    std::string dsname = std::string(heavyprefix) + "/" + std::string(vda->GetName());
+  if (heavyprefix)
+  {
+    std::string name;
+    if (vda->GetName())
+    {
+      name = vda->GetName();
+    }
+    else
+    {
+      std::stringstream ss;
+      ss << "DataArray" << this->UnlabelledDataArrayId++;
+      name = ss.str();
+    }
+    std::string dsname = std::string(heavyprefix) + "/" + name;
     xda->SetHeavyDataSetName(dsname.c_str());
   }
 
   //TODO: if we can make xdmf write out immediately, then wouldn't have to keep around
   //arrays when working with temporal data
   if ((allocStrategy==0 && !this->TopTemporalGrid) || allocStrategy==1)
-    {
+  {
     //Do not let xdmf allocate its own buffer. xdmf just borrows vtk's and doesn't double mem size.
     xda->SetAllowAllocate(0);
     xda->SetShape(lRank, lDims);
     xda->SetDataPointer(vda->GetVoidPointer(0));
-    }
+  }
   else //(allocStrategy==0 && this->TopTemporalGrid) || allocStrategy==2)
-    {
+  {
     //Unfortunately data doesn't stick around with temporal updates, which is exactly when you want it most.
     xda->SetAllowAllocate(1);
     xda->SetShape(lRank, lDims);
@@ -1208,7 +1348,7 @@ void vtkXdmfWriter::ConvertVToXArray(vtkDataArray *vda,
            vda->GetNumberOfTuples()*
            vda->GetNumberOfComponents()*
            vda->GetElementComponentSize());
-    }
+  }
 
   delete[] lDims;
 }
