@@ -8,12 +8,12 @@
 #include "vtkPoints.h"
 #include "vtkTree.h"
 
-#include "vtksys/ios/sstream"
+#include <sstream>
 
 #include <vector>
 #include <algorithm>
 
-#include <math.h>
+#include <cmath>
 
 #ifdef VTK_USE_BOOST
 # include "vtkBoostBreadthFirstSearchTree.h"
@@ -29,22 +29,22 @@ class vtkCosmicTreeEntry
 {
 public:
   vtkCosmicTreeEntry( vtkIdType id, vtkIdType index, double radius )
-    {
+  {
     this->Radius = fabs( radius );
     this->Index = index;
     this->Id = id;
     this->Alpha = 0.;
     for ( int i = 0; i < 3; ++ i )
       this->Center[i] = 0.;
-    }
+  }
   void ComputeCenterFromAlpha( double Re )
-    {
+  {
     double R = Re - this->Radius;
     this->Center[0] = R * cos( this->Alpha );
     this->Center[1] = R * sin( this->Alpha );
-    }
+  }
   double PlaceCounterClockwise( const vtkCosmicTreeEntry& neighbor, double Re )
-    {
+  {
     double ri = neighbor.Radius;
     double rj = this->Radius;
     double Ri = Re - ri;
@@ -52,39 +52,39 @@ public:
     double rij = ri + rj;
     double dRe = Re - rij;
     if ( dRe < 0 )
-      {
+    {
       // Circles will not fit in another of radius Re.
       // Return how much to increment Re so that they will.
       this->Alpha = neighbor.Alpha + vtkMath::Pi();
       this->ComputeCenterFromAlpha( Re );
       return -dRe;
-      }
+    }
     // OK, expect a good answer from acos().
     this->Alpha = neighbor.Alpha + acos( ( rij * rij - ( Ri * Ri + Rj * Rj ) ) / ( -2. * Ri * Rj ) );
     this->ComputeCenterFromAlpha( Re );
     return 0.;
-    }
+  }
   double Defect( const vtkCosmicTreeEntry& other ) const
-    {
+  {
     // Assumes Center is valid
     double d = 0.;
     for ( int i = 0; i < 2; ++ i )
-      {
+    {
       double s = this->Center[i] - other.Center[i];
       d += s * s;
-      }
+    }
     // tangent circles should return 0.0. Overlapping circles return > 0. Values <= 0.0 OK.
     return this->Radius + other.Radius - sqrt( d );
-    }
+  }
   double Defect( const vtkCosmicTreeEntry& neighbor, double Re )
-    {
+  {
     double ri = neighbor.Radius;
     double rj = this->Radius;
     double rij = ri + rj;
     return rij - Re;
-    }
+  }
   bool operator < ( const vtkCosmicTreeEntry& other ) const
-    {
+  {
     // Note reversed checks for Radius. we want sorted in descending order...
     if ( this->Radius > other.Radius )
       return true;
@@ -99,7 +99,7 @@ public:
     if ( this->Id < other.Id )
       return true;
     return false;
-    }
+  }
   double Radius;
   double Alpha;
   vtkIdType Index;
@@ -130,31 +130,31 @@ static int vtkCosmicTreeLayoutStrategyComputeCentersQuick(
   int i;
   std::sort( circles.begin(), circles.end() );
   if ( N <= 0 )
-    {
+  {
     return 0;
-    }
+  }
   else if ( N == 1 )
-    {
+  {
     // When there's only a single child, create a concentric layout
     Re = circles[0].Radius * 1.25;
     for ( i = 0; i < 3; ++ i )
-      {
-      circles[0].Center[i] = 0.;
-      }
-    }
-  else if ( N == 2 )
     {
+      circles[0].Center[i] = 0.;
+    }
+  }
+  else if ( N == 2 )
+  {
     Re = circles[0].Radius + circles[1].Radius;
     circles[0].Center[0] =   circles[1].Radius;
     circles[1].Center[0] = - circles[0].Radius;
     for ( i = 1; i < 3; ++ i )
-      {
+    {
       circles[0].Center[i] = 0.;
       circles[1].Center[i] = 0.;
-      }
     }
+  }
   else
-    {
+  {
     // Choose an initial slice of the enclosing circle for each
     // input circle, based on radius if possible. If any slice
     // is close to or exceeds pi, then just start them out
@@ -166,24 +166,24 @@ static int vtkCosmicTreeLayoutStrategyComputeCentersQuick(
     ang.resize( N );
     angp.resize( N );
     for ( i = 0; i < N; ++ i )
-      {
+    {
       Rtot += circles[i].Radius;
-      }
+    }
     double factor = twopi / Rtot;
     const double limit = 0.75 * vtkMath::Pi();
     for ( i = 0; i < N; ++ i )
-      {
+    {
       ang[i] = factor * circles[i].Radius;
       if ( ang[i] > limit )
-        {
+      {
         factor = twopi / circles.size();
         for ( i = 0; i < N; ++ i )
-          {
+        {
           ang[i] = factor;
-          }
-        break;
         }
+        break;
       }
+    }
     // Iterate until we have things close to fully packed or we reach
     // the maximum number of iterations.
     double err = twopi;
@@ -191,19 +191,19 @@ static int vtkCosmicTreeLayoutStrategyComputeCentersQuick(
     int iter = 0;
     int bonk = 0; // number of successive times we are forced to set Re = 2.01*circles[0].Radius
     do
-      {
+    {
       // Compute a new enclosing radius. Do not allow it to shrink to
       // the point where the largest enclosed circle overlaps the origin.
       Re = circles[0].Radius * ( 1. + 1. / sin( ang[0] / 2. ) );
       if ( 1.99 * circles[0].Radius > Re )
-        {
+      {
         Re = 2.01 * circles[0].Radius;
         ++ bonk;
-        }
+      }
       else
-        {
+      {
         bonk = 0;
-        }
+      }
       double cumAngle = 0.;
       double sumAngp = 0.;
       // Compute new angles of the enclosing circle subtended by each circle
@@ -211,29 +211,29 @@ static int vtkCosmicTreeLayoutStrategyComputeCentersQuick(
       olderr = err;
       err = 0.;
       for ( i = 0; i < N; ++ i )
-        {
+      {
         vtkCosmicTreeEntry* circ = &circles[i];
         circ->Alpha = ang[i] / 2. + cumAngle;
         cumAngle += ang[i];
         sumAngp += ( angp[i] = 2. * asin( circ->Radius / ( Re - circ->Radius ) ) );
         double localErr = fabs( angp[i] - ang[i] );
         if ( localErr > err )
-          {
-          err = localErr;
-          }
-        }
-      for ( i = 0; i < N; ++ i )
         {
+          err = localErr;
+        }
+      }
+      for ( i = 0; i < N; ++ i )
+      {
         if ( angp[i] / sumAngp > 0.5 )
-          {
+        {
           sumAngp -= angp[i];
           angp[i] = sumAngp;
           sumAngp *= 2.;
-          }
-        ang[i] = angp[i] / sumAngp * twopi;
         }
-      ++ iter;
+        ang[i] = angp[i] / sumAngp * twopi;
       }
+      ++ iter;
+    }
     //while ( olderr > err && err > 1.e-8 && iter < 20 );
     //while ( ( olderr > err || err > 1.e-8 ) && ( iter < 31 && bonk < 3 ) );
     //while ( err > 1.e-8 && ( iter < 31 && bonk < 3 ) );
@@ -241,10 +241,10 @@ static int vtkCosmicTreeLayoutStrategyComputeCentersQuick(
     //while ( err > 1.e-8 && iter < 51 );
 
     for ( i = 0; i < N; ++ i )
-      {
+    {
       circles[i].ComputeCenterFromAlpha( Re );
-      }
     }
+  }
   return 0; // in the future, we might return other values when the number of iterations is exceeded, etc.
 }
 
@@ -273,14 +273,14 @@ void vtkCosmicTreeLayoutStrategy::PrintSelf( ostream& os, vtkIndent indent )
 void vtkCosmicTreeLayoutStrategy::Layout()
 {
   if ( ! this->Graph || this->Graph->GetNumberOfVertices() <= 0 || this->Graph->GetNumberOfEdges() <= 0 )
-    { // fail silently if the graph is empty in some way.
+  { // fail silently if the graph is empty in some way.
     return;
-    }
+  }
 
   vtkTree* tree = vtkTree::SafeDownCast( this->Graph );
   bool input_is_tree = ( tree != NULL );
   if ( ! input_is_tree )
-    { // Extract a tree from the graph.
+  { // Extract a tree from the graph.
 #ifdef VTK_USE_BOOST
     // Use the BFS search tree to perform the layout
     vtkBoostBreadthFirstSearchTree* bfs = vtkBoostBreadthFirstSearchTree::New();
@@ -293,15 +293,15 @@ void vtkCosmicTreeLayoutStrategy::Layout()
 #else
     vtkErrorMacro( "Layout only works on vtkTree unless VTK_USE_BOOST is on." );
 #endif
-    }
+  }
 
   // Create a new point set
   vtkIdType numVertices = tree->GetNumberOfVertices();
   if ( numVertices == 0 )
-    {
+  {
     vtkWarningMacro( "Tree has no vertices." );
     return;
-    }
+  }
 
   vtkPoints* newPoints = vtkPoints::New();
   newPoints->SetNumberOfPoints( numVertices );
@@ -310,41 +310,41 @@ void vtkCosmicTreeLayoutStrategy::Layout()
   vtkDoubleArray* scale; // scale factor associated with each non-leaf node when SizeLeafNodesOnly is false.
   vtkDataArray* inputRadii = 0;
   if ( this->NodeSizeArrayName && strlen( this->NodeSizeArrayName ) )
-    {
+  {
     inputRadii = this->Graph->GetVertexData()->GetArray( this->NodeSizeArrayName );
-    }
+  }
   if ( this->SizeLeafNodesOnly )
-    {
+  {
     mode = LEAVES;
     radii = this->CreateRadii( numVertices, -1., inputRadii );
     scale = 0; // No scale factor is necessary
     this->Graph->GetVertexData()->AddArray( radii );
     this->Graph->GetVertexData()->SetActiveScalars( radii->GetName() );
     radii->Delete();
-    }
+  }
   else
-    {
+  {
     // Since node size is specified at all nodes, the layout is overconstrained
     // and we must compute a scale factor for each non-leaf node to make the
     // children fit inside.
     scale = this->CreateScaleFactors( numVertices );
     this->Graph->GetVertexData()->AddArray( scale );
     scale->Delete();
-    radii = vtkDoubleArray::SafeDownCast( inputRadii );
+    radii = vtkArrayDownCast<vtkDoubleArray>( inputRadii );
     // Did we find a node size spec?
     if ( radii )
-      {
+    {
       mode = ALL; // read-only
-      }
+    }
     else
-      {
+    {
       mode = NONE; // write-only, all nodes fixed size.
       radii = this->CreateRadii( numVertices, 1., 0  );
       this->Graph->GetVertexData()->AddArray( radii );
       this->Graph->GetVertexData()->SetActiveScalars( radii->GetName() );
       radii->Delete();
-      }
     }
+  }
 
   // Setting the root to position 0,0 but this could
   // be whatever you want and should be controllable
@@ -360,52 +360,52 @@ void vtkCosmicTreeLayoutStrategy::Layout()
 #ifdef VTK_COSMIC_DBG
   cout << "octr = [ ";
   for ( vtkIdType k = 0; k < newPoints->GetNumberOfPoints(); ++ k )
-    {
+  {
     double* x = newPoints->GetPoint( k );
     //double r = radii->GetValue( k );
     //cout << "k: " << k << "   x: " << x[0] << " y: " << x[1] << "  r: " << r <<  "\n";
     cout << x[0] << " " << x[1] <<  "\n";
-    }
+  }
   cout << "]; orad = [ ";
 #endif // VTK_COSMIC_DBG
   for ( vtkIdType k = 0; k < newPoints->GetNumberOfPoints(); ++ k )
-    {
+  {
     double r = radii->GetValue( k );
 #ifdef VTK_COSMIC_DBG
     cout << r << "\n";
 #endif // VTK_COSMIC_DBG
     // FIXME: the GraphMapper expects a diameter. Make it accept radii instead.
     radii->SetValue( k, 2. * r );
-    }
+  }
 #ifdef VTK_COSMIC_DBG
   cout << "];\nplotbub( octr, orad );\n";
 #endif // VTK_COSMIC_DBG
 
   // Copy coordinates back into the original graph
   if ( input_is_tree )
-    {
+  {
     this->Graph->SetPoints( newPoints );
-    }
+  }
 #ifdef VTK_USE_BOOST
   else
-    {
+  {
     // Reorder the points based on the mapping back to graph vertex ids
     vtkPoints* reordered = vtkPoints::New();
     reordered->SetNumberOfPoints( newPoints->GetNumberOfPoints() );
     for ( vtkIdType i = 0; i < reordered->GetNumberOfPoints(); ++ i )
-      {
+    {
       reordered->SetPoint( i, 0, 0, 0 );
-      }
-    vtkIdTypeArray* graphVertexIdArr = vtkIdTypeArray::SafeDownCast(
+    }
+    vtkIdTypeArray* graphVertexIdArr = vtkArrayDownCast<vtkIdTypeArray>(
       tree->GetVertexData()->GetAbstractArray( "GraphVertexId" ) );
     for ( vtkIdType i = 0; i < graphVertexIdArr->GetNumberOfTuples(); ++ i )
-      {
+    {
       reordered->SetPoint(graphVertexIdArr->GetValue( i ), newPoints->GetPoint( i ) );
-      }
+    }
     this->Graph->SetPoints( reordered );
     tree->Delete();
     reordered->Delete();
-    }
+  }
 #endif
 
   // Clean up.
@@ -425,54 +425,54 @@ void vtkCosmicTreeLayoutStrategy::LayoutChildren(
   std::vector<vtkCosmicTreeEntry> circles;
   // I. Compute radii of children as required:
   switch ( mode )
-    {
+  {
   case ALL:
     // No computation required... All radii are as specified. We do need to fetch the radii, though.
     for ( childIdx = 0; childIdx < numberOfChildren; ++ childIdx )
-      {
+    {
       child = tree->GetChild( root, childIdx );
       circles.push_back( vtkCosmicTreeEntry( child, childIdx, radii->GetValue( child ) ) );
-      }
+    }
     break;
   case NONE:
     // Unit size means we can stop descending when depth == 0... all entries in radii are initialized to 1.0
     if ( depth < 0 && this->LayoutDepth >= 0 )
       return;
-    // fall through:
+    VTK_FALLTHROUGH;
   case LEAVES:
     // We must descend all the way down to the leaves, regardless of LayoutDepth.
     for ( childIdx = 0; childIdx < numberOfChildren; ++ childIdx )
-      {
+    {
       child = tree->GetChild( root, childIdx );
       this->LayoutChildren( tree, pts, radii, scale, child, depth - 1, mode );
       circles.push_back( vtkCosmicTreeEntry( child, childIdx, radii->GetValue( child ) ) );
-      }
-    break;
     }
+    break;
+  }
 
   // II. Now that we have radii of children, we can lay out this node
   if ( numberOfChildren <= 0 )
-    {
+  {
     Rext = radii->GetValue( root );
     Rext = ( mode == ALL || Rext <= 0. ) ? 1. : Rext;
-    }
+  }
   else
-    {
+  {
     vtkCosmicTreeLayoutStrategyComputeCentersQuick( numberOfChildren, circles, Rext );
     std::vector<vtkCosmicTreeEntry>::iterator cit;
     for ( cit = circles.begin(); cit != circles.end(); ++ cit )
-      {
+    {
       pts->SetPoint( cit->Id, cit->Center );
-      }
     }
+  }
   if ( mode == ALL )
-    {
+  {
     scale->SetValue( root, Rext );
-    }
+  }
   else
-    {
+  {
     radii->SetValue( root, Rext );
-    }
+  }
 }
 
 void vtkCosmicTreeLayoutStrategy::OffsetChildren(
@@ -487,23 +487,23 @@ void vtkCosmicTreeLayoutStrategy::OffsetChildren(
   double nextParent[4];
 
   switch ( mode )
-    {
+  {
   case ALL:
     // We must apply the scale factor.
     // III. Offset this node
     pts->GetPoint( root, nextParent );
     for ( int i = 0; i < 3; ++ i )
-      {
+    {
       nextParent[i] = ( nextParent[i] + parent[i] ) * parent[3];
-      }
+    }
     nextParent[3] = parent[3] / scale->GetValue( root );
     pts->SetPoint( root, nextParent );
 
     // IV. Offset children as required
     for ( childIdx = 0; childIdx < tree->GetNumberOfChildren( root ); ++ childIdx )
-      {
+    {
       this->OffsetChildren( tree, pts, radii, scale, nextParent, tree->GetChild( root, childIdx ), depth - 1, mode );
-      }
+    }
     break;
   case NONE:
   case LEAVES:
@@ -511,18 +511,18 @@ void vtkCosmicTreeLayoutStrategy::OffsetChildren(
     // III. Offset this node
     pts->GetPoint( root, nextParent );
     for ( int i = 0; i < 3; ++ i )
-      {
+    {
       nextParent[i] += parent[i];
-      }
+    }
     pts->SetPoint( root, nextParent );
 
     // IV. Offset children as required
     for ( childIdx = 0; childIdx < tree->GetNumberOfChildren( root ); ++ childIdx )
-      {
+    {
       this->OffsetChildren( tree, pts, radii, scale, nextParent, tree->GetChild( root, childIdx ), depth - 1, mode );
-      }
-    break;
     }
+    break;
+  }
 }
 
 vtkDoubleArray* vtkCosmicTreeLayoutStrategy::CreateRadii( vtkIdType numVertices, double initialValue, vtkDataArray* inputRadii )
@@ -531,14 +531,14 @@ vtkDoubleArray* vtkCosmicTreeLayoutStrategy::CreateRadii( vtkIdType numVertices,
   radii->SetNumberOfComponents( 1 );
   radii->SetNumberOfTuples( numVertices );
   if ( ! inputRadii )
-    {
+  {
     // Initialize all radii to some value...
     radii->FillComponent( 0, initialValue );
-    }
+  }
   else
-    {
+  {
     radii->DeepCopy( inputRadii );
-    }
+  }
   radii->SetName( "TreeRadius" );
   return radii;
 }
