@@ -52,20 +52,20 @@ public:
   static vtkResliceImageViewerScrollCallback *New()
     { return new vtkResliceImageViewerScrollCallback; }
 
-  virtual void Execute(vtkObject *, unsigned long ev, void*)
-    {
+  void Execute(vtkObject *, unsigned long ev, void*) VTK_OVERRIDE
+  {
     if (!this->Viewer->GetSliceScrollOnMouseWheel())
-      {
+    {
       return;
-      }
+    }
 
     // Do not process if any modifiers are ON
     if (this->Viewer->GetInteractor()->GetShiftKey() ||
         this->Viewer->GetInteractor()->GetControlKey() ||
         this->Viewer->GetInteractor()->GetAltKey())
-      {
+    {
       return;
-      }
+    }
 
     // forwards or backwards
     int sign = (ev == vtkCommand::MouseWheelForwardEvent) ? 1 : -1;
@@ -73,7 +73,7 @@ public:
 
     // Abort further event processing for the scroll.
     this->SetAbortFlag(1);
-    }
+  }
 
   vtkResliceImageViewerScrollCallback():Viewer(0) {}
   vtkResliceImageViewer *Viewer;
@@ -122,10 +122,10 @@ vtkResliceImageViewer::~vtkResliceImageViewer()
   this->Measurements->Delete();
 
   if (this->ResliceCursorWidget)
-    {
+  {
     this->ResliceCursorWidget->Delete();
     this->ResliceCursorWidget = NULL;
-    }
+  }
 
   this->PointPlacer->Delete();
   this->ScrollCallback->Delete();
@@ -137,9 +137,9 @@ void vtkResliceImageViewer::SetThickMode( int t )
   vtkSmartPointer< vtkResliceCursor > rc = this->GetResliceCursor();
 
   if (t == this->GetThickMode())
-    {
+  {
     return;
-    }
+  }
 
   vtkSmartPointer< vtkResliceCursorLineRepresentation >
     resliceCursorRepOld = vtkResliceCursorLineRepresentation::SafeDownCast(
@@ -149,15 +149,15 @@ void vtkResliceImageViewer::SetThickMode( int t )
   this->GetResliceCursor()->SetThickMode(t);
 
   if (t)
-    {
+  {
     resliceCursorRepNew = vtkSmartPointer<
         vtkResliceCursorThickLineRepresentation >::New();
-    }
+  }
   else
-    {
+  {
     resliceCursorRepNew = vtkSmartPointer<
         vtkResliceCursorLineRepresentation >::New();
-    }
+  }
 
   int e = this->ResliceCursorWidget->GetEnabled();
   this->ResliceCursorWidget->SetEnabled(0);
@@ -201,16 +201,16 @@ void vtkResliceImageViewer::SetLookupTable( vtkScalarsToColors * l )
   if (vtkResliceCursorRepresentation *rep =
         vtkResliceCursorRepresentation::SafeDownCast(
           this->ResliceCursorWidget->GetRepresentation()))
-    {
+  {
     rep->SetLookupTable(l);
-    }
+  }
 
   if (this->WindowLevel)
-    {
+  {
     this->WindowLevel->SetLookupTable(l);
     this->WindowLevel->SetOutputFormatToRGBA();
     this->WindowLevel->PassAlphaToOutputOn();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -219,9 +219,9 @@ vtkScalarsToColors * vtkResliceImageViewer::GetLookupTable()
   if (vtkResliceCursorRepresentation *rep =
         vtkResliceCursorRepresentation::SafeDownCast(
           this->ResliceCursorWidget->GetRepresentation()))
-    {
+  {
     return rep->GetLookupTable();
-    }
+  }
 
   return NULL;
 }
@@ -233,9 +233,9 @@ void vtkResliceImageViewer::UpdateOrientation()
 
     vtkCamera *cam = this->Renderer ? this->Renderer->GetActiveCamera() : NULL;
     if (cam)
-      {
+    {
       switch (this->SliceOrientation)
-        {
+      {
         case vtkImageViewer2::SLICE_ORIENTATION_XY:
           cam->SetFocalPoint(0,0,0);
           cam->SetPosition(0,0,1); // -1 if medical ?
@@ -253,8 +253,8 @@ void vtkResliceImageViewer::UpdateOrientation()
           cam->SetPosition(1,0,0); // -1 if medical ?
           cam->SetViewUp(0,0,1);
           break;
-        }
       }
+    }
 }
 
 //----------------------------------------------------------------------------
@@ -263,9 +263,9 @@ void vtkResliceImageViewer::UpdateDisplayExtent()
   // Only update the display extent in axis aligned mode
 
   if (this->ResliceMode == RESLICE_AXIS_ALIGNED)
-    {
+  {
     this->Superclass::UpdateDisplayExtent();
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -274,7 +274,7 @@ void vtkResliceImageViewer::InstallPipeline()
   this->Superclass::InstallPipeline();
 
   if (this->Interactor)
-    {
+  {
     this->ResliceCursorWidget->SetInteractor(this->Interactor);
 
     // Observe the scroll for slice manipulation at a higher priority
@@ -284,17 +284,17 @@ void vtkResliceImageViewer::InstallPipeline()
         this->ScrollCallback, 0.55 );
     this->Interactor->AddObserver(vtkCommand::MouseWheelBackwardEvent,
         this->ScrollCallback, 0.55 );
-    }
+  }
 
   if (this->Renderer)
-    {
+  {
     this->ResliceCursorWidget->SetDefaultRenderer(this->Renderer);
     vtkCamera *cam = this->Renderer->GetActiveCamera();
     cam->ParallelProjectionOn();
-    }
+  }
 
   if (this->ResliceMode == RESLICE_OBLIQUE)
-    {
+  {
     this->ResliceCursorWidget->SetEnabled(1);
     this->ImageActor->SetVisibility(0);
     this->UpdateOrientation();
@@ -305,27 +305,27 @@ void vtkResliceImageViewer::InstallPipeline()
     double onespacing[3] = {1, 1, 1};
     double *spacing = onespacing;
     if (this->GetResliceCursor()->GetImage())
-      {
+    {
       this->GetResliceCursor()->GetImage()->GetBounds(bounds);
       spacing = this->GetResliceCursor()->GetImage()->GetSpacing();
-      }
+    }
     double avg_spacing =
       (spacing[0] + spacing[1] + spacing[2]) / 3.0;
     cam->SetClippingRange(
       bounds[this->SliceOrientation * 2] - 100 * avg_spacing,
       bounds[this->SliceOrientation * 2 + 1] + 100 * avg_spacing);
-    }
+  }
   else
-    {
+  {
     this->ResliceCursorWidget->SetEnabled(0);
     this->ImageActor->SetVisibility(1);
     this->UpdateOrientation();
-    }
+  }
 
   if (this->WindowLevel)
-    {
+  {
     this->WindowLevel->SetLookupTable(this->GetLookupTable());
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -334,9 +334,9 @@ void vtkResliceImageViewer::UnInstallPipeline()
   this->ResliceCursorWidget->SetEnabled(0);
 
   if (this->Interactor)
-    {
+  {
     this->Interactor->RemoveObserver(this->ScrollCallback);
-    }
+  }
 
   this->Superclass::UnInstallPipeline();
 }
@@ -345,31 +345,31 @@ void vtkResliceImageViewer::UnInstallPipeline()
 void vtkResliceImageViewer::UpdatePointPlacer()
 {
   if (this->ResliceMode == RESLICE_OBLIQUE)
-    {
+  {
     this->PointPlacer->SetProjectionNormalToOblique();
     if (vtkResliceCursorRepresentation *rep =
         vtkResliceCursorRepresentation::SafeDownCast(
           this->ResliceCursorWidget->GetRepresentation()))
-      {
+    {
       const int planeOrientation =
         rep->GetCursorAlgorithm()->GetReslicePlaneNormal();
       vtkPlane *plane = this->GetResliceCursor()->GetPlane(planeOrientation);
       this->PointPlacer->SetObliquePlane(plane);
-      }
     }
+  }
   else
-    {
+  {
 
     if (!this->WindowLevel->GetInput())
-      {
+    {
       return;
-      }
+    }
 
     vtkImageData *input = this->ImageActor->GetInput();
     if ( !input )
-      {
+    {
       return;
-      }
+    }
 
     double spacing[3];
     input->GetSpacing(spacing);
@@ -386,24 +386,24 @@ void vtkResliceImageViewer::UpdatePointPlacer()
     int axis = vtkBoundedPlanePointPlacer::XAxis;
     double position = 0.0;
     if ( displayExtent[0] == displayExtent[1] )
-      {
+    {
       axis = vtkBoundedPlanePointPlacer::XAxis;
       position = origin[0] + displayExtent[0]*spacing[0];
-      }
+    }
     else if ( displayExtent[2] == displayExtent[3] )
-      {
+    {
       axis = vtkBoundedPlanePointPlacer::YAxis;
       position = origin[1] + displayExtent[2]*spacing[1];
-      }
+    }
     else if ( displayExtent[4] == displayExtent[5] )
-      {
+    {
       axis = vtkBoundedPlanePointPlacer::ZAxis;
       position = origin[2] + displayExtent[4]*spacing[2];
-      }
+    }
 
     this->PointPlacer->SetProjectionNormal(axis);
     this->PointPlacer->SetProjectionPosition(position);
-    }
+  }
 
 }
 
@@ -411,9 +411,9 @@ void vtkResliceImageViewer::UpdatePointPlacer()
 void vtkResliceImageViewer::Render()
 {
   if (!this->WindowLevel->GetInput())
-    {
+  {
     return;
-    }
+  }
 
   this->UpdatePointPlacer();
 
@@ -426,9 +426,9 @@ vtkResliceCursor * vtkResliceImageViewer::GetResliceCursor()
   if (vtkResliceCursorRepresentation *rep =
         vtkResliceCursorRepresentation::SafeDownCast(
           this->ResliceCursorWidget->GetRepresentation()))
-    {
+  {
     return rep->GetResliceCursor();
-    }
+  }
 
   return NULL;
 }
@@ -437,9 +437,9 @@ vtkResliceCursor * vtkResliceImageViewer::GetResliceCursor()
 void vtkResliceImageViewer::SetInputData(vtkImageData *in)
 {
   if(!in)
-    {
+  {
     return;
-    }
+  }
 
   this->WindowLevel->SetInputData(in);
   this->GetResliceCursor()->SetImage(in);
@@ -451,16 +451,16 @@ void vtkResliceImageViewer::SetInputData(vtkImageData *in)
   if (vtkResliceCursorRepresentation *rep =
         vtkResliceCursorRepresentation::SafeDownCast(
           this->ResliceCursorWidget->GetRepresentation()))
-    {
+  {
     if (vtkImageReslice *reslice =
         vtkImageReslice::SafeDownCast(rep->GetReslice()))
-      {
+    {
       // default background color is the min value of the image scalar range
       reslice->SetBackgroundColor(range[0],range[0],range[0],range[0]);
       this->SetColorWindow(range[1]-range[0]);
       this->SetColorLevel((range[0]+range[1])/2.0);
-      }
     }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -475,9 +475,9 @@ void vtkResliceImageViewer::SetInputConnection(vtkAlgorithmOutput* input)
 void vtkResliceImageViewer::SetResliceMode( int r )
 {
   if (r == this->ResliceMode)
-    {
+  {
     return;
-    }
+  }
 
   this->ResliceMode = r;
   this->Modified();
@@ -496,9 +496,9 @@ void vtkResliceImageViewer::SetColorWindow( double w )
   if (vtkResliceCursorRepresentation *rep =
         vtkResliceCursorRepresentation::SafeDownCast(
           this->ResliceCursorWidget->GetRepresentation()))
-    {
+  {
     rep->SetWindowLevel(w, rep->GetLevel(), 1);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -512,9 +512,9 @@ void vtkResliceImageViewer::SetColorLevel( double w )
   if (vtkResliceCursorRepresentation *rep =
         vtkResliceCursorRepresentation::SafeDownCast(
           this->ResliceCursorWidget->GetRepresentation()))
-    {
+  {
     rep->SetWindowLevel(rep->GetWindow(), w, 1);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -530,12 +530,12 @@ vtkPlane * vtkResliceImageViewer::GetReslicePlane()
   if (vtkResliceCursorRepresentation *rep =
       vtkResliceCursorRepresentation::SafeDownCast(
         this->ResliceCursorWidget->GetRepresentation()))
-    {
+  {
     const int planeOrientation =
       rep->GetCursorAlgorithm()->GetReslicePlaneNormal();
     vtkPlane *plane = this->GetResliceCursor()->GetPlane(planeOrientation);
     return plane;
-    }
+  }
 
   return NULL;
 }
@@ -546,11 +546,11 @@ double vtkResliceImageViewer::GetInterSliceSpacingInResliceMode()
   double n[3], imageSpacing[3], resliceSpacing = 0;
 
   if (vtkPlane *plane = this->GetReslicePlane())
-    {
+  {
     plane->GetNormal(n);
     this->GetResliceCursor()->GetImage()->GetSpacing(imageSpacing);
     resliceSpacing = fabs(vtkMath::Dot(n, imageSpacing));
-    }
+  }
 
   return resliceSpacing;
 }
@@ -560,19 +560,19 @@ void vtkResliceImageViewer::IncrementSlice( int inc )
 {
   if (this->GetResliceMode() ==
       vtkResliceImageViewer::RESLICE_AXIS_ALIGNED)
-    {
+  {
     int oldSlice = this->GetSlice();
     this->SetSlice(this->GetSlice() + inc);
     if (this->GetSlice() != oldSlice)
-      {
+    {
       this->InvokeEvent( vtkResliceImageViewer::SliceChangedEvent, NULL );
       this->InvokeEvent( vtkCommand::InteractionEvent, NULL );
-      }
     }
+  }
   else
-    {
+  {
     if (vtkPlane *p = this->GetReslicePlane())
-      {
+    {
       double n[3], c[3], bounds[6];
       p->GetNormal(n);
       const double spacing =
@@ -585,20 +585,20 @@ void vtkResliceImageViewer::IncrementSlice( int inc )
 
       // If the new center is inside, put it there...
       if (vtkImageData *image = this->GetResliceCursor()->GetImage())
-        {
+      {
         image->GetBounds(bounds);
         if (c[0] >= bounds[0] && c[0] <= bounds[1] &&
             c[1] >= bounds[2] && c[1] <= bounds[3] &&
             c[2] >= bounds[4] && c[2] <= bounds[5])
-          {
+        {
           this->GetResliceCursor()->SetCenter(c);
 
           this->InvokeEvent( vtkResliceImageViewer::SliceChangedEvent, NULL );
           this->InvokeEvent( vtkCommand::InteractionEvent, NULL );
-          }
         }
       }
     }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -616,7 +616,7 @@ void vtkResliceImageViewer::PrintSelf(ostream& os, vtkIndent indent)
   this->Measurements->PrintSelf(os,indent.GetNextIndent());
   os << indent << "Interactor: " << this->Interactor << "\n";
   if (this->Interactor)
-    {
+  {
     this->Interactor->PrintSelf(os,indent.GetNextIndent());
-    }
+  }
 }
