@@ -144,10 +144,10 @@ vtkImageTracerWidget::vtkImageTracerWidget()
 vtkImageTracerWidget::~vtkImageTracerWidget()
 {
   for ( int i = 0; i < this->NumberOfHandles; ++i )
-    {
+  {
     this->HandleGeometry[i]->Delete();
     this->Handle[i]->Delete();
-    }
+  }
   delete [] this->Handle;
   this->Handle = NULL;
 
@@ -155,25 +155,25 @@ vtkImageTracerWidget::~vtkImageTracerWidget()
   this->HandleGeometry = NULL;
 
   if ( this->HandleProperty )
-    {
+  {
     this->HandleProperty->Delete();
-    }
+  }
   if ( this->SelectedHandleProperty )
-    {
+  {
     this->SelectedHandleProperty->Delete();
-    }
+  }
   if ( this->LineProperty )
-    {
+  {
     this->LineProperty->Delete();
-    }
+  }
   if ( this->SelectedLineProperty )
-    {
+  {
     this->SelectedLineProperty->Delete();
-    }
+  }
   if ( this->ViewProp )
-    {
+  {
     this->ViewProp->UnRegister(this);
-    }
+  }
 
   this->LinePoints->Delete();
   this->LineCells->Delete();
@@ -196,21 +196,21 @@ vtkImageTracerWidget::~vtkImageTracerWidget()
 void vtkImageTracerWidget::SetViewProp(vtkProp* prop)
 {
   if ( this->ViewProp != prop )
-    {
+  {
     // Avoid destructor recursion
     vtkProp *temp = this->ViewProp;
     this->ViewProp = prop;
     if ( temp )
-      {
+    {
       temp->UnRegister(this);
-      }
+    }
     if ( this->ViewProp )
-      {
+    {
       this->ViewProp->Register(this);
       this->PropPicker->InitializePickList();
       this->PropPicker->AddPickList(this->ViewProp);
-      }
     }
+  }
 }
 
 //------------------------------------------------------------------------------
@@ -224,36 +224,36 @@ void vtkImageTracerWidget::RegisterPickers()
 void vtkImageTracerWidget::SetEnabled(int enabling)
 {
   if ( !this->Interactor )
-    {
+  {
     vtkErrorMacro(<<"The interactor must be set prior to enabling/disabling widget");
     return;
-    }
+  }
 
   if ( !this->ViewProp )
-    {
+  {
     vtkErrorMacro(<<"The external prop must be set prior to enabling/disabling widget");
     return;
-    }
+  }
 
   if ( enabling )
-    {
+  {
     vtkDebugMacro(<<"Enabling line widget");
 
     if ( this->Enabled ) //already enabled, just return
-      {
+    {
       return;
-      }
+    }
 
     if ( !this->CurrentRenderer )
-      {
+    {
       this->SetCurrentRenderer(this->Interactor->FindPokedRenderer(
                                this->Interactor->GetLastEventPosition()[0],
                                this->Interactor->GetLastEventPosition()[1]));
       if ( !this->CurrentRenderer )
-        {
+      {
         return;
-        }
       }
+    }
 
     this->Enabled = 1;
 
@@ -261,11 +261,11 @@ void vtkImageTracerWidget::SetEnabled(int enabling)
 
     // Turn on the handles
     for ( int i = 0; i < this->NumberOfHandles; ++i )
-      {
+    {
       this->CurrentRenderer->AddViewProp(this->Handle[i]);
       this->Handle[i]->SetProperty(this->HandleProperty);
       this->Handle[i]->PickableOff();
-      }
+    }
 
     this->SizeHandles();
 
@@ -274,27 +274,27 @@ void vtkImageTracerWidget::SetEnabled(int enabling)
     this->LineActor->PickableOff();
 
     this->InvokeEvent(vtkCommand::EnableEvent,NULL);
-    }
+  }
 
   else // disabling
-    {
+  {
     vtkDebugMacro(<<"Disabling tracer widget");
 
     if ( !this->Enabled ) //already disabled, just return
-      {
+    {
       return;
-      }
+    }
 
     // if disabling occurs without finishing an activity, cleanup states
     if ( this->State == vtkImageTracerWidget::Tracing )
-      {
+    {
       this->OnLeftButtonUp();
-      }
+    }
     else if ( this->State == vtkImageTracerWidget::Snapping )
-      {
+    {
       this->Interactor->SetControlKey( 1 );
       this->OnMiddleButtonUp();
-      }
+    }
 
     this->Enabled = 0;
 
@@ -303,16 +303,16 @@ void vtkImageTracerWidget::SetEnabled(int enabling)
 
     // Turn off the handles
     for ( int i = 0; i < this->NumberOfHandles; ++i )
-     {
+    {
      this->CurrentRenderer->RemoveViewProp(this->Handle[i]);
-     }
+    }
 
     this->CurrentRenderer->RemoveViewProp(this->LineActor);
 
     this->CurrentHandle = NULL;
     this->InvokeEvent(vtkCommand::DisableEvent,NULL);
     this->SetCurrentRenderer(NULL);
-    }
+  }
 
   this->Interactor->Render();
 }
@@ -325,7 +325,7 @@ void vtkImageTracerWidget::ProcessEvents(vtkObject* vtkNotUsed(object),
   vtkImageTracerWidget* self = reinterpret_cast<vtkImageTracerWidget *>( clientdata );
 
   switch ( event )
-    {
+  {
     case vtkCommand::LeftButtonPressEvent:
       self->OnLeftButtonDown();
       break;
@@ -347,7 +347,7 @@ void vtkImageTracerWidget::ProcessEvents(vtkObject* vtkNotUsed(object),
     case vtkCommand::MouseMoveEvent:
       self->OnMouseMove();
       break;
-    }
+  }
 }
 
 void vtkImageTracerWidget::AddObservers(void)
@@ -355,57 +355,57 @@ void vtkImageTracerWidget::AddObservers(void)
   // Listen for the following events
   vtkRenderWindowInteractor *i = this->Interactor;
   if(!i)
-    {
+  {
     return;
-    }
+  }
 
   i->AddObserver(vtkCommand::MouseMoveEvent, this->EventCallbackCommand,
                   this->Priority);
   if(this->HandleLeftMouseButton)
-    {
+  {
     i->AddObserver(vtkCommand::LeftButtonPressEvent,
                     this->EventCallbackCommand, this->Priority);
     i->AddObserver(vtkCommand::LeftButtonReleaseEvent,
                     this->EventCallbackCommand, this->Priority);
-    }
+  }
   if(this->HandleMiddleMouseButton)
-    {
+  {
     i->AddObserver(vtkCommand::MiddleButtonPressEvent,
                     this->EventCallbackCommand, this->Priority);
     i->AddObserver(vtkCommand::MiddleButtonReleaseEvent,
                     this->EventCallbackCommand, this->Priority);
-    }
+  }
   if(this->HandleRightMouseButton)
-    {
+  {
     i->AddObserver(vtkCommand::RightButtonPressEvent,
                     this->EventCallbackCommand, this->Priority);
     i->AddObserver(vtkCommand::RightButtonReleaseEvent,
                     this->EventCallbackCommand, this->Priority);
-    }
+  }
 }
 
 void vtkImageTracerWidget::SetInteraction(int interact)
 {
   if ( this->Interactor && this->Enabled )
-    {
+  {
     if ( this->Interaction == interact )
-      {
-      return;
-      }
-    if ( interact == 0 )
-      {
-      this->Interactor->RemoveObserver(this->EventCallbackCommand);
-      }
-    else
-      {
-      this->AddObservers();
-      }
-    this->Interaction = interact;
-    }
-  else
     {
-    vtkGenericWarningMacro(<<"Set interactor and Enabled before changing interaction...");
+      return;
     }
+    if ( interact == 0 )
+    {
+      this->Interactor->RemoveObserver(this->EventCallbackCommand);
+    }
+    else
+    {
+      this->AddObservers();
+    }
+    this->Interaction = interact;
+  }
+  else
+  {
+    vtkGenericWarningMacro(<<"Set interactor and Enabled before changing interaction...");
+  }
 }
 
 void vtkImageTracerWidget::PrintSelf(ostream& os, vtkIndent indent)
@@ -413,51 +413,51 @@ void vtkImageTracerWidget::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os,indent);
 
   if ( this->HandleProperty )
-    {
+  {
     os << indent << "Handle Property: " << this->HandleProperty << "\n";
-    }
+  }
   else
-    {
+  {
     os << indent << "Handle Property: (none)\n";
-    }
+  }
 
   if ( this->SelectedHandleProperty )
-    {
+  {
     os << indent << "Selected Handle Property: "
        << this->SelectedHandleProperty << "\n";
-    }
+  }
   else
-    {
+  {
     os << indent << "Selected Handle Property: (none)\n";
-    }
+  }
 
   if ( this->LineProperty )
-    {
+  {
     os << indent << "Line Property: " << this->LineProperty << "\n";
-    }
+  }
   else
-    {
+  {
     os << indent << "Line Property: (none)\n";
-    }
+  }
 
   if ( this->SelectedLineProperty )
-    {
+  {
     os << indent << "Selected Line Property: "
        << this->SelectedLineProperty << "\n";
-    }
+  }
   else
-    {
+  {
     os << indent << "Selected Line Property: (none)\n";
-    }
+  }
 
   if ( this->ViewProp )
-    {
+  {
     os << indent << "ViewProp: " << this->ViewProp << "\n";
-    }
+  }
   else
-    {
+  {
     os << indent << "ViewProp: (none)\n";
-    }
+  }
 
   os << indent << "Interaction: "
      << (this->Interaction ? "On\n" : "Off\n") ;
@@ -481,41 +481,41 @@ int vtkImageTracerWidget::HighlightHandle(vtkProp* prop)
 {
   // First unhighlight anything picked
   if ( this->CurrentHandle )
-    {
+  {
     this->CurrentHandle->SetProperty(this->HandleProperty);
     this->Interactor->Render();
-    }
+  }
 
   this->CurrentHandle = static_cast<vtkActor *>(prop);
 
   if ( this->CurrentHandle )
-    {
+  {
     this->ValidPick = 1;
     this->CurrentPicker->GetPickPosition(this->LastPickPosition);
     this->CurrentHandle->SetProperty(this->SelectedHandleProperty);
     for ( int i = 0; i < this->NumberOfHandles; ++i ) // find handle
-      {
+    {
       if ( this->CurrentHandle == this->Handle[i] )
-        {
+      {
         return i;
-        }
       }
     }
+  }
   return -1;
 }
 
 void vtkImageTracerWidget::HighlightLine(const int& highlight)
 {
   if ( highlight )
-    {
+  {
     this->ValidPick = 1;
     this->CurrentPicker->GetPickPosition(this->LastPickPosition);
     this->LineActor->SetProperty(this->SelectedLineProperty);
-    }
+  }
   else
-    {
+  {
     this->LineActor->SetProperty(this->LineProperty);
-    }
+  }
 }
 
 void vtkImageTracerWidget::AdjustHandlePosition(const int& handle, double pos[3])
@@ -523,22 +523,22 @@ void vtkImageTracerWidget::AdjustHandlePosition(const int& handle, double pos[3]
   if ( handle < 0 || handle >= this->NumberOfHandles ){ return; }
 
   if ( this->ProjectToPlane )
-    {
+  {
     pos[this->ProjectionNormal] = this->ProjectionPosition;
-    }
+  }
 
   this->HandleGenerator->SetCenter(0.0,0.0,0.0);
   this->Transform->Identity();
   this->Transform->PostMultiply();
 
   if ( this->ProjectionNormal == VTK_ITW_PROJECTION_YZ )
-    {
+  {
     this->Transform->RotateY(90.0);
-    }
+  }
   else if ( this->ProjectionNormal == VTK_ITW_PROJECTION_XZ )
-    {
+  {
     this->Transform->RotateX(90.0);
-    }
+  }
 
   this->Transform->Translate(pos);
   this->TransformFilter->Update();
@@ -553,17 +553,17 @@ void vtkImageTracerWidget::SetProjectionPosition(double position)
 
   int i;
   for ( i = 0; i < this->NumberOfHandles; ++i )
-    {
+  {
     this->AdjustHandlePosition(i,this->HandleGeometry[i]->GetCenter());
-    }
+  }
 
   double pt[3];
   for ( i = 0; i < this->NumberOfHandles; ++i )
-    {
+  {
     this->LinePoints->GetPoint(i,pt);
     pt[ this->ProjectionNormal ] = this->ProjectionPosition;
     this->LinePoints->SetPoint(i,pt);
-    }
+  }
 
   this->LinePoints->GetData()->Modified();
   this->LineData->Modified();
@@ -603,41 +603,41 @@ void vtkImageTracerWidget::OnLeftButtonDown()
 
   // Okay, make sure that the pick is in the current renderer
   if ( !this->CurrentRenderer || !this->CurrentRenderer->IsInViewport(X,Y) )
-    {
+  {
     this->State = vtkImageTracerWidget::Outside;
     return;
-    }
+  }
 
   int found = 0;
   if ( this->PropPicker->PickProp(X,Y,this->CurrentRenderer) )
-    {
+  {
     if ( this->ViewProp == this->PropPicker->GetViewProp() )
-      {
+    {
       found = 1;
       this->State = vtkImageTracerWidget::Tracing;
-      }
     }
+  }
 
    if ( !found )
-     {
+   {
      this->State = vtkImageTracerWidget::Outside;
      return;
-     }
+   }
 
   // first erase any handles if there any
   if ( this->NumberOfHandles > 1 )
-    {
+  {
     this->AllocateHandles(1);
-    }
+  }
 
   this->CurrentPicker = this->PropPicker;  //collect the pick position from the prop picker
   this->CurrentHandleIndex = this->HighlightHandle(this->Handle[0]);
 
   if ( this->CurrentHandleIndex == -1 )    //this should never happen
-    {
+  {
     this->State = vtkImageTracerWidget::Outside;
     return;
-    }
+  }
 
   // set the handle to the picked position
   this->AdjustHandlePosition(this->CurrentHandleIndex,this->LastPickPosition);
@@ -659,21 +659,21 @@ void vtkImageTracerWidget::OnLeftButtonUp()
   if ( this->State == vtkImageTracerWidget::Outside ||
        this->State == vtkImageTracerWidget::Start   ||
        this->State == vtkImageTracerWidget::Snapping )
-    {
+  {
     return;
-    }
+  }
 
   this->State = vtkImageTracerWidget::Start;
   this->CurrentHandleIndex = this->HighlightHandle(NULL);
 
   if ( this->AutoClose )  // attempt to close by tolerance
-    {
+  {
     this->ClosePath();
     if ( this->IsClosed() ) // if successful, remove the overlapping handle
-      {
+    {
       this->EraseHandle(this->NumberOfHandles - 1);
-      }
     }
+  }
 
   this->SizeHandles();
 
@@ -690,50 +690,50 @@ void vtkImageTracerWidget::OnMiddleButtonDown()
   int Y = this->Interactor->GetEventPosition()[1];
 
   if ( !this->CurrentRenderer || !this->CurrentRenderer->IsInViewport(X,Y) )
-    {
+  {
     this->State = vtkImageTracerWidget::Outside;
     return;
-    }
+  }
 
   int found = 0;
   if ( this->PropPicker->PickProp(X,Y,this->CurrentRenderer) )
-    {
+  {
     if ( this->ViewProp == this->PropPicker->GetViewProp() )
-      {
+    {
       found = 1;
       this->State = vtkImageTracerWidget::Snapping; // do snap tracing
-      }
     }
+  }
 
    if ( !found )
-     {
+   {
      this->State = vtkImageTracerWidget::Outside;
      return;
-     }
+   }
 
   if ( !this->IsSnapping )  // this is the first time so reset the handles
-    {
+  {
     if ( this->NumberOfHandles > 1 )
-      {
+    {
       this->AllocateHandles(1);
-      }
     }
+  }
 
   this->CurrentPicker = this->PropPicker;         // highlight the last handle
   this->CurrentHandleIndex = this->HighlightHandle(this->Handle[this->NumberOfHandles - 1]);
 
   if ( this->CurrentHandleIndex == -1 )  // sanity check: this should never happen
-    {
+  {
     this->State = vtkImageTracerWidget::Outside;
     return;
-    }
+  }
 
   this->AdjustHandlePosition(this->CurrentHandleIndex,this->LastPickPosition);
 
   if ( !this->IsSnapping )  // this is the first time so initialize the line
-    {
+  {
     this->ResetLine(this->GetHandlePosition(this->CurrentHandleIndex));
-    }
+  }
 
   this->IsSnapping = this->NumberOfHandles;
 
@@ -747,30 +747,30 @@ void vtkImageTracerWidget::OnMiddleButtonUp()
 {
   if ( this->State == vtkImageTracerWidget::Outside ||
        this->State == vtkImageTracerWidget::Start )
-    {
+  {
     return;
-    }
+  }
 
   if ( this->Interactor->GetControlKey() ) // finished the snapping
-    {
+  {
     this->IsSnapping = 0;
-    }
+  }
   else // continue snap drawing
-    {
+  {
     return;
-    }
+  }
 
   this->State = vtkImageTracerWidget::Start;
   this->CurrentHandleIndex = this->HighlightHandle(NULL);
 
   if ( this->AutoClose )
-    {
+  {
     this->ClosePath();
     if ( this->IsClosed() ) // if successful, remove the last overlapping handle
-      {
+    {
       this->EraseHandle(this->NumberOfHandles - 1);
-      }
     }
+  }
 
   this->SizeHandles();
 
@@ -789,93 +789,93 @@ void vtkImageTracerWidget::OnRightButtonDown()
   int Y = this->Interactor->GetEventPosition()[1];
 
   if ( !this->CurrentRenderer || !this->CurrentRenderer->IsInViewport(X,Y) )
-    {
+  {
     this->State = vtkImageTracerWidget::Outside;
     return;
-    }
+  }
 
   if ( this->Interactor->GetControlKey() && (this->NumberOfHandles > 1) )
-    {
+  {
     this->State = vtkImageTracerWidget::Erasing; // pick a handle to delete
     for ( int i = 0; i < this->NumberOfHandles; ++i )
-      {
-      this->Handle[i]->PickableOn();
-      }
-    this->CurrentPicker = this->HandlePicker;
-    }
-  else if ( this->Interactor->GetShiftKey()  && (this->NumberOfHandles > 1) )
     {
+      this->Handle[i]->PickableOn();
+    }
+    this->CurrentPicker = this->HandlePicker;
+  }
+  else if ( this->Interactor->GetShiftKey()  && (this->NumberOfHandles > 1) )
+  {
     this->State = vtkImageTracerWidget::Inserting; // pick a line to insert on
     this->LineActor->PickableOn();
     this->LinePicker->AddPickList(this->LineActor);
     this->CurrentPicker = this->LinePicker;
-    }
+  }
   else
-    {
+  {
     if ( this->NumberOfHandles < 3 && this->LinePoints->GetNumberOfPoints() > this->NumberOfHandles )
-      {
+    {
       this->State = vtkImageTracerWidget::Translating;
-      }
-    else
-      {
-      this->State = vtkImageTracerWidget::Moving;
-      }
-    for ( int i = 0; i < this->NumberOfHandles; ++i )
-      {
-      this->Handle[i]->PickableOn();
-      }
-    this->CurrentPicker = this->HandlePicker;
     }
+    else
+    {
+      this->State = vtkImageTracerWidget::Moving;
+    }
+    for ( int i = 0; i < this->NumberOfHandles; ++i )
+    {
+      this->Handle[i]->PickableOn();
+    }
+    this->CurrentPicker = this->HandlePicker;
+  }
 
   if ( this->ViewProp )  // don't pick the prop
-    {
+  {
     this->ViewProp->PickableOff();
-    }
+  }
 
   int found = 0;
   vtkAssemblyPath* path = this->GetAssemblyPath(X, Y, 0., this->CurrentPicker);
 
   if ( path )
-    {
+  {
     found = 1;
     if ( this->State == vtkImageTracerWidget::Erasing ||
          this->State == vtkImageTracerWidget::Moving  ||
          this->State == vtkImageTracerWidget::Translating )
-      {
+    {
       this->CurrentHandleIndex = this->HighlightHandle(path->GetFirstNode()->GetViewProp());
       if ( this->CurrentHandleIndex == -1 )
-        {
+      {
         found = 0;  // we didn't hit a handle
         for ( int i = 0; i < this->NumberOfHandles; ++i )
-          {
+        {
           this->Handle[i]->PickableOff();
-          }
         }
       }
+    }
     else if ( this->State == vtkImageTracerWidget::Inserting )
-      {
+    {
         if ( static_cast<vtkActor*>(path->GetFirstNode()->GetViewProp()) == this->LineActor )
         {
         this->HighlightLine(1);
         }
       else
-        {
+      {
         found = 0;
         this->LineActor->PickableOff();
-        }
       }
     }
+  }
 
   if ( !found )
-    {
+  {
     this->State = vtkImageTracerWidget::Outside;
     if ( this->ViewProp )
-      {
+    {
       this->ViewProp->PickableOn();
-      }
+    }
     this->CurrentPicker = NULL;
     return;
-    }
+  }
 
   this->EventCallbackCommand->SetAbortFlag(1);
   this->StartInteraction();
@@ -888,58 +888,58 @@ void vtkImageTracerWidget::OnRightButtonUp()
   if ( this->State == vtkImageTracerWidget::Outside ||
        this->State == vtkImageTracerWidget::Start   ||
        this->State == vtkImageTracerWidget::Snapping)
-    {
+  {
     return;
-    }
+  }
 
   if ( this->State == vtkImageTracerWidget::Erasing )
-    {
+  {
     int index = this->CurrentHandleIndex;
     this->CurrentHandleIndex = this->HighlightHandle(NULL);
     int closed = this->IsClosed();
     this->EraseHandle(index);
     this->BuildLinesFromHandles();
     if ( closed && this->NumberOfHandles > 2 )
-      {
-      this->AppendLine(this->HandleGeometry[0]->GetCenter());
-      }
-    }
-  else if ( this->State == vtkImageTracerWidget::Inserting )
     {
+      this->AppendLine(this->HandleGeometry[0]->GetCenter());
+    }
+  }
+  else if ( this->State == vtkImageTracerWidget::Inserting )
+  {
     this->HighlightLine(0);
     int closed = this->IsClosed();
     this->InsertHandleOnLine(this->LastPickPosition);
     this->BuildLinesFromHandles();
     if ( closed )
-      {
-      this->AppendLine(this->HandleGeometry[0]->GetCenter());
-      }
-    }
-  else if ( this->State == vtkImageTracerWidget::Moving )
     {
+      this->AppendLine(this->HandleGeometry[0]->GetCenter());
+    }
+  }
+  else if ( this->State == vtkImageTracerWidget::Moving )
+  {
     this->CurrentHandleIndex = this->HighlightHandle(NULL);
     if ( this->AutoClose && !this->IsClosed() )
-      {
+    {
       this->ClosePath();
       if ( this->IsClosed() ) // if successful, remove the last overlapping handle
-        {
+      {
         this->EraseHandle(this->NumberOfHandles - 1);
-        }
       }
     }
+  }
   else if ( this->State == vtkImageTracerWidget::Translating )
-    {
+  {
     this->CurrentHandleIndex = this->HighlightHandle(NULL);
-    }
+  }
 
   this->State = vtkImageTracerWidget::Start;
 
   this->SizeHandles();
 
   if ( this->ViewProp )
-    {
+  {
     this->ViewProp->PickableOn();
-    }
+  }
 
   this->EventCallbackCommand->SetAbortFlag(1);
   this->EndInteraction();
@@ -953,9 +953,9 @@ void vtkImageTracerWidget::OnMouseMove()
   // See whether we're active
   if ( this->State == vtkImageTracerWidget::Outside ||
        this->State == vtkImageTracerWidget::Start )
-    {
+  {
     return;
-    }
+  }
 
   int X = this->Interactor->GetEventPosition()[0];
   int Y = this->Interactor->GetEventPosition()[1];
@@ -963,15 +963,15 @@ void vtkImageTracerWidget::OnMouseMove()
 
   // Process the motion
   if ( this->CurrentHandle )
-    {
+  {
     if ( this->State == vtkImageTracerWidget::Tracing ||
          this->State == vtkImageTracerWidget::Snapping )
-      {
+    {
       this->Trace(X,Y);
-      }
+    }
     else if ( this->State == vtkImageTracerWidget::Moving ||
               this->State == vtkImageTracerWidget::Translating )
-      {
+    {
       double focalPoint[4], pickPoint[4], prevPickPoint[4];
 
       vtkCamera *camera = this->CurrentRenderer->GetActiveCamera();
@@ -989,15 +989,15 @@ void vtkImageTracerWidget::OnMouseMove()
       this->ComputeDisplayToWorld(double(X), double(Y), z, pickPoint);
 
       if ( this->State == vtkImageTracerWidget::Moving )
-        {
+      {
         this->MovePoint(prevPickPoint, pickPoint);
-        }
+      }
       else
-        {
+      {
         this->Translate(prevPickPoint, pickPoint);
-        }
       }
     }
+  }
 
   // Interact, if desired
   this->EventCallbackCommand->SetAbortFlag(1);
@@ -1014,46 +1014,46 @@ void vtkImageTracerWidget::Trace(int X, int Y)
   this->PropPicker->GetPickPosition(pos);
 
   if ( this->SnapToImage )
-    {
+  {
     this->Snap(pos);
-    }
+  }
 
   if ( this->ProjectToPlane )
-    {
+  {
     pos[this->ProjectionNormal] = this->ProjectionPosition;
-    }
+  }
 
   if (  this->LastX != X || this->LastY != Y )
-    {
+  {
     if ( this->State == vtkImageTracerWidget::Tracing )
-      {
+    {
       if ( this->NumberOfHandles == 1 )
-        {
-        this->AppendHandles(pos);
-        }
-      else
-        {
-        this->AdjustHandlePosition(this->CurrentHandleIndex,pos);
-        }
-      this->AppendLine(pos);
-      }
-    else if ( this->State == vtkImageTracerWidget::Snapping )
       {
+        this->AppendHandles(pos);
+      }
+      else
+      {
+        this->AdjustHandlePosition(this->CurrentHandleIndex,pos);
+      }
+      this->AppendLine(pos);
+    }
+    else if ( this->State == vtkImageTracerWidget::Snapping )
+    {
       if ( this->IsSnapping != this->CurrentHandleIndex  )
-        {
+      {
         this->AppendHandles(pos);
         this->AppendLine(pos);
         this->IsSnapping = this->CurrentHandleIndex;
-        }
+      }
       else
-        {
+      {
         this->AdjustHandlePosition(this->CurrentHandleIndex,pos);
         this->LinePoints->SetPoint(this->PickCount,pos);
         this->LinePoints->GetData()->Modified();
         this->LineData->Modified();
-        }
       }
-   }
+    }
+  }
 
   this->LastX = X;
   this->LastY = Y;
@@ -1085,10 +1085,10 @@ void vtkImageTracerWidget::MovePoint(const double *p1, const double *p2)
 
   // Special case when moving the first point
   if ( closed && (this->CurrentHandleIndex == 0) )
-    {
+  {
     this->LinePoints->SetPoint(this->LinePoints->GetNumberOfPoints()-1,
             this->HandleGeometry[0]->GetCenter());
-    }
+  }
 
   this->LinePoints->GetData()->Modified();
   this->LineData->Modified();
@@ -1105,26 +1105,26 @@ void vtkImageTracerWidget::Translate(const double *p1, const double *p2)
   double newCtr[3];
   int i;
   for ( i = 0; i < this->NumberOfHandles; ++i )
-    {
+  {
     double *ctr = this->HandleGeometry[i]->GetCenter();
     newCtr[0] = ctr[0] + v[0];
     newCtr[1] = ctr[1] + v[1];
     newCtr[2] = ctr[2] + v[2];
     this->AdjustHandlePosition(i,newCtr);
-    }
+  }
 
   for ( i = 0; i < this->LinePoints->GetNumberOfPoints(); ++i )
-    {
+  {
     double *ctr = this->LinePoints->GetPoint(i);
     newCtr[0] = ctr[0] + v[0];
     newCtr[1] = ctr[1] + v[1];
     newCtr[2] = ctr[2] + v[2];
     if ( this->ProjectToPlane )
-      {
+    {
       newCtr[this->ProjectionNormal] = this->ProjectionPosition;
-      }
-    this->LinePoints->SetPoint(i,newCtr);
     }
+    this->LinePoints->SetPoint(i,newCtr);
+  }
 
   this->LinePoints->GetData()->Modified();
   this->LineData->Modified();
@@ -1135,26 +1135,26 @@ void vtkImageTracerWidget::ResetHandles(void)
   if ( this->NumberOfHandles == 0 ){ return; }
 
   if ( this->CurrentHandle )
-    {
+  {
     this->CurrentHandle = NULL;
-    }
+  }
 
   this->HandlePicker->InitializePickList();
 
   int i;
   if ( this->CurrentRenderer )
-    {
+  {
     for (i = 0; i < this->NumberOfHandles; ++i )
-      {
+    {
       this->CurrentRenderer->RemoveViewProp(this->Handle[i]);
-      }
     }
+  }
 
   for ( i = 0; i < this->NumberOfHandles; ++i )
-    {
+  {
     this->HandleGeometry[i]->Delete();
     this->Handle[i]->Delete();
-    }
+  }
 
   this->NumberOfHandles = 0;
 
@@ -1179,7 +1179,7 @@ void vtkImageTracerWidget::AllocateHandles(const int& nhandles)
 
   int i;
   for ( i = 0; i < this->NumberOfHandles; ++i )
-    {
+  {
     this->HandleGeometry[i] = vtkPolyData::New();
     vtkPolyDataMapper* handleMapper = vtkPolyDataMapper::New();
     handleMapper->SetInputData(this->HandleGeometry[i]);
@@ -1189,15 +1189,15 @@ void vtkImageTracerWidget::AllocateHandles(const int& nhandles)
     this->Handle[i]->SetProperty(this->HandleProperty);
     this->Handle[i]->PickableOff();
     this->HandlePicker->AddPickList(this->Handle[i]);
-    }
+  }
 
   if ( this->CurrentRenderer && this->Enabled )
-    {
+  {
     for ( i = 0; i < this->NumberOfHandles; ++i )
-      {
+    {
       this->CurrentRenderer->AddViewProp(this->Handle[i]);
-      }
     }
+  }
 }
 
 void vtkImageTracerWidget::AppendHandles(double* pos)
@@ -1206,34 +1206,34 @@ void vtkImageTracerWidget::AppendHandles(double* pos)
   this->TemporaryHandlePoints->SetNumberOfTuples(this->NumberOfHandles+1);
   int i;
   for ( i = 0; i < this->NumberOfHandles; ++i )
-    {
+  {
     this->TemporaryHandlePoints->SetTuple(i,this->HandleGeometry[i]->GetCenter());
-    }
+  }
 
   this->TemporaryHandlePoints->SetTuple(this->NumberOfHandles,pos);
 
   this->AllocateHandles(this->TemporaryHandlePoints->GetNumberOfTuples());
 
   for ( i = 0; i < this->NumberOfHandles; ++i )
-    {
+  {
     this->AdjustHandlePosition(i,this->TemporaryHandlePoints->GetTuple(i));
-    }
+  }
 
   if ( this->CurrentHandleIndex != -1 )
-    {
+  {
     this->CurrentHandleIndex = this->NumberOfHandles - 1;
     this->CurrentHandle = this->Handle[this->CurrentHandleIndex];
     this->CurrentHandle->SetProperty(this->SelectedHandleProperty);
-    }
+  }
 }
 
 void vtkImageTracerWidget::InsertHandleOnLine(double* pos)
 {
   if ( this->NumberOfHandles < 3 &&
        this->LinePoints->GetNumberOfPoints() > 2 )
-    {
+  {
     return; // don't insert on a continuously traced line
-    }
+  }
 
   int id = this->LinePicker->GetCellId();
   if ( id == -1 ){ return; }
@@ -1242,23 +1242,23 @@ void vtkImageTracerWidget::InsertHandleOnLine(double* pos)
   this->TemporaryHandlePoints->SetNumberOfTuples(this->NumberOfHandles+1);
   int i;
   for ( i = 0; i <= id; i++ )
-    {
+  {
     this->TemporaryHandlePoints->SetTuple(i,this->HandleGeometry[i]->GetCenter());
-    }
+  }
 
   this->TemporaryHandlePoints->SetTuple(id+1,pos);
 
   for ( i = id + 1; i < this->NumberOfHandles; ++i )
-    {
+  {
     this->TemporaryHandlePoints->SetTuple(i+1,this->HandleGeometry[i]->GetCenter());
-    }
+  }
 
   this->AllocateHandles(this->TemporaryHandlePoints->GetNumberOfTuples());
 
   for ( i = 0; i < this->NumberOfHandles; ++i )
-    {
+  {
     this->AdjustHandlePosition(i,this->TemporaryHandlePoints->GetTuple(i));
-    }
+  }
 }
 
 void vtkImageTracerWidget::InitializeHandles(vtkPoints* points)
@@ -1271,22 +1271,22 @@ void vtkImageTracerWidget::InitializeHandles(vtkPoints* points)
   this->AllocateHandles( npts );
 
   for ( int i = 0; i < npts; ++i )
-    {
+  {
     this->AdjustHandlePosition(i,points->GetPoint(i));
-    }
+  }
 
   if ( npts > 1 )
-    {
+  {
     this->BuildLinesFromHandles();
     if ( this->AutoClose )
-      {
+    {
       this->ClosePath();
       if ( this->IsClosed() ) // if successful, remove the overlapping handle
-        {
+      {
         this->EraseHandle(this->NumberOfHandles - 1);
-        }
       }
     }
+  }
 }
 
 void vtkImageTracerWidget::EraseHandle(const int& index)
@@ -1298,19 +1298,19 @@ void vtkImageTracerWidget::EraseHandle(const int& index)
   int i;
   int count = 0;
   for ( i = 0; i < this->NumberOfHandles; ++i )
-    {
+  {
     if ( i != index )
-      {
+    {
       this->TemporaryHandlePoints->SetTuple(count++,this->HandleGeometry[i]->GetCenter());
-      }
     }
+  }
 
   this->AllocateHandles(this->TemporaryHandlePoints->GetNumberOfTuples());
 
   for ( i = 0; i < this->NumberOfHandles; ++i )
-    {
+  {
     this->AdjustHandlePosition(i,this->TemporaryHandlePoints->GetTuple(i));
-    }
+  }
 }
 
 void vtkImageTracerWidget::ResetLine(double* pos)
@@ -1357,9 +1357,9 @@ void vtkImageTracerWidget::BuildLinesFromHandles()
   this->ResetLine(this->HandleGeometry[0]->GetCenter());
 
   for ( int i = 1; i < this->NumberOfHandles; ++i )
-    {
+  {
     this->AppendLine(this->HandleGeometry[i]->GetCenter());
-    }
+  }
 }
 
 void vtkImageTracerWidget::ClosePath()
@@ -1373,11 +1373,11 @@ void vtkImageTracerWidget::ClosePath()
   this->LinePoints->GetPoint(npts-1,p1);
 
   if ( sqrt(vtkMath::Distance2BetweenPoints(p0,p1)) <= this->CaptureRadius )
-    {
+  {
     this->LinePoints->SetPoint(npts-1,p0);
     this->LinePoints->GetData()->Modified();
     this->LineData->Modified();
-    }
+  }
 }
 
 int vtkImageTracerWidget::IsClosed() // can only be based on line data
@@ -1401,22 +1401,22 @@ void vtkImageTracerWidget::GetPath(vtkPolyData *pd)
 void vtkImageTracerWidget::SetSnapToImage(int snap)
 {
   if ( this->GetInput() )
-    {
+  {
     if ( this->GetInput()->GetDataObjectType() != VTK_IMAGE_DATA )
-      {
+    {
       vtkErrorMacro(<<"Input data must be of type vtkImageData");
       return;
-      }
-    else
-      {
-      this->SnapToImage = snap;
-      }
     }
-  else
+    else
     {
+      this->SnapToImage = snap;
+    }
+  }
+  else
+  {
     vtkGenericWarningMacro(<<"SetInput with type vtkImageData first");
     return;
-    }
+  }
 }
 
 void vtkImageTracerWidget::Snap(double* pos) // overwrites pos
@@ -1425,35 +1425,35 @@ void vtkImageTracerWidget::Snap(double* pos) // overwrites pos
   if ( !ptr ){ return; }
 
   if ( this->ImageSnapType == VTK_ITW_SNAP_CELLS )  // snap to cell center
-    {
+  {
     double bounds[6];
     double weights[8];
     double pcoords[3];
     int subId;
     vtkIdType cellId = ptr->FindCell(pos,NULL,-1,0.0,subId,pcoords,weights);
     if ( cellId != -1 )
-      {
+    {
       ptr->GetCellBounds(cellId,bounds);
       for ( int i = 0; i < 3; ++i )
-        {
+      {
         pos[i] = bounds[i*2]+ 0.5*(bounds[i*2+1]-bounds[i*2]);
-        }
       }
     }
+  }
   else // snap to nearest point
-    {
+  {
     vtkIdType ptId = ptr->FindPoint(pos);
     if ( ptId != -1 )
-      {
+    {
       ptr->GetPoint(ptId,pos);
-      }
     }
+  }
 }
 
 void vtkImageTracerWidget::CreateDefaultProperties()
 {
   if ( !this->HandleProperty )
-    {
+  {
     this->HandleProperty = vtkProperty::New();
     this->HandleProperty->SetAmbient(1.0);
     this->HandleProperty->SetDiffuse(0.0);
@@ -1461,9 +1461,9 @@ void vtkImageTracerWidget::CreateDefaultProperties()
     this->HandleProperty->SetLineWidth(2);
     this->HandleProperty->SetRepresentationToWireframe();
     this->HandleProperty->SetInterpolationToFlat();
-    }
+  }
   if ( !this->SelectedHandleProperty )
-    {
+  {
     this->SelectedHandleProperty = vtkProperty::New();
     this->SelectedHandleProperty->SetAmbient(1.0);
     this->SelectedHandleProperty->SetDiffuse(0.0);
@@ -1471,9 +1471,9 @@ void vtkImageTracerWidget::CreateDefaultProperties()
     this->SelectedHandleProperty->SetLineWidth(2);
     this->SelectedHandleProperty->SetRepresentationToWireframe();
     this->SelectedHandleProperty->SetInterpolationToFlat();
-    }
+  }
   if ( !this->LineProperty )
-    {
+  {
     this->LineProperty = vtkProperty::New();
     this->LineProperty->SetAmbient(1.0);
     this->LineProperty->SetDiffuse(0.0);
@@ -1481,9 +1481,9 @@ void vtkImageTracerWidget::CreateDefaultProperties()
     this->LineProperty->SetLineWidth(2);
     this->LineProperty->SetRepresentationToWireframe();
     this->LineProperty->SetInterpolationToFlat();
-    }
+  }
   if ( !this->SelectedLineProperty )
-    {
+  {
     this->SelectedLineProperty = vtkProperty::New();
     this->SelectedLineProperty->SetAmbient(1.0);
     this->SelectedLineProperty->SetDiffuse(0.0);
@@ -1491,7 +1491,7 @@ void vtkImageTracerWidget::CreateDefaultProperties()
     this->SelectedLineProperty->SetLineWidth(2);
     this->SelectedLineProperty->SetRepresentationToWireframe();
     this->SelectedLineProperty->SetInterpolationToFlat();
-    }
+  }
 }
 
 void vtkImageTracerWidget::PlaceWidget(double bds[6])
@@ -1515,9 +1515,9 @@ void vtkImageTracerWidget::PlaceWidget(double bds[6])
   this->AdjustHandlePosition(0,xyz);
 
   for ( int i = 0; i < 6; ++i )
-    {
+  {
     this->InitialBounds[i] = bounds[i];
-    }
+  }
   this->InitialLength = sqrt((bounds[1]-bounds[0])*(bounds[1]-bounds[0]) +
                              (bounds[3]-bounds[2])*(bounds[3]-bounds[2]) +
                              (bounds[5]-bounds[4])*(bounds[5]-bounds[4]));
@@ -1529,28 +1529,3 @@ void vtkImageTracerWidget::SizeHandles()
   // TODO...
   return;
 }
-
-//----------------------------------------------------------------------------
-#ifndef VTK_LEGACY_REMOVE
-# ifdef VTK_WORKAROUND_WINDOWS_MANGLE
-#  undef SetProp
-void vtkImageTracerWidget::SetPropA(vtkProp* prop)
-{
-  VTK_LEGACY_REPLACED_BODY(vtkImageTracerWidget::SetProp, "VTK 5.0",
-                           vtkImageTracerWidget::SetViewProp);
-  this->SetViewProp(prop);
-}
-void vtkImageTracerWidget::SetPropW(vtkProp* prop)
-{
-  VTK_LEGACY_REPLACED_BODY(vtkImageTracerWidget::SetProp, "VTK 5.0",
-                           vtkImageTracerWidget::SetViewProp);
-  this->SetViewProp(prop);
-}
-# endif
-void vtkImageTracerWidget::SetProp(vtkProp* prop)
-{
-  VTK_LEGACY_REPLACED_BODY(vtkImageTracerWidget::SetProp, "VTK 5.0",
-                           vtkImageTracerWidget::SetViewProp);
-  this->SetViewProp(prop);
-}
-#endif
