@@ -44,12 +44,12 @@ public:
   vtksys::hash_map<int, void *> MultipleData;
 
   class vtkRMICallback
-    {
+  {
   public:
     unsigned long Id;
     vtkRMIFunctionType Function;
     void* LocalArgument;
-    };
+  };
 
   typedef std::vector<vtkRMICallback> RMICallbackVector;
 
@@ -111,14 +111,14 @@ vtkMultiProcessController::~vtkMultiProcessController()
 {
   if ( this->OutputWindow &&
        (this->OutputWindow == vtkOutputWindow::GetInstance()) )
-    {
+  {
     vtkOutputWindow::SetInstance(0);
-    }
+  }
 
   if (this->OutputWindow)
-    {
+  {
     this->OutputWindow->Delete();
-    }
+  }
 
   delete this->Internal;
 }
@@ -138,75 +138,75 @@ void vtkMultiProcessController::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "BroadcastTriggerRMI: " <<
       (this->BroadcastTriggerRMI ? "(yes)" : "(no)");
   if (this->OutputWindow)
-    {
+  {
     os << endl;
     this->OutputWindow->PrintSelf(os, nextIndent);
-    }
+  }
   else
-    {
+  {
     os << "(none)" << endl;
-    }
+  }
   os << indent << "Communicator: ";
   if (this->Communicator)
-    {
+  {
     os << endl;
     this->Communicator->PrintSelf(os, nextIndent);
-    }
+  }
   else
-    {
+  {
     os << "(none)" << endl;
-    }
+  }
   os << indent << "RMI communicator: ";
   if (this->RMICommunicator)
-    {
+  {
     os << endl;
     this->RMICommunicator->PrintSelf(os, nextIndent);
-    }
+  }
   else
-    {
+  {
     os << "(none)" << endl;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 void vtkMultiProcessController::SetNumberOfProcesses(int num)
 {
   if(this->Communicator)
-    {
+  {
     this->Communicator->SetNumberOfProcesses(num);
-    }
+  }
   else
-    {
+  {
     vtkErrorMacro("Communicator not set.");
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 int vtkMultiProcessController::GetNumberOfProcesses()
 {
   if(this->Communicator)
-    {
+  {
     return this->Communicator->GetNumberOfProcesses();
-    }
+  }
   else
-    {
+  {
     vtkErrorMacro("Communicator not set.");
     return 0;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
 int vtkMultiProcessController::GetLocalProcessId()
 {
   if(this->Communicator)
-    {
+  {
     return this->Communicator->GetLocalProcessId();
-    }
+  }
   else
-    {
+  {
     vtkErrorMacro("Communicator not set.");
     return -1;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -233,15 +233,15 @@ void vtkMultiProcessController::SetMultipleMethod( int index,
 {
   // You can only set the method for 0 through NumberOfProcesses-1
   if ( index >= this->GetNumberOfProcesses() )
-    {
+  {
     vtkErrorMacro( << "Can't set method " << index <<
       " with a processes count of " << this->GetNumberOfProcesses() );
-    }
+  }
   else
-    {
+  {
     this->Internal->MultipleMethod[index] = f;
     this->Internal->MultipleData[index]   = data;
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -251,15 +251,15 @@ void vtkMultiProcessController::GetMultipleMethod(int index,
 {
   if (   this->Internal->MultipleMethod.find(index)
       != this->Internal->MultipleMethod.end() )
-    {
+  {
     func = this->Internal->MultipleMethod[index];
     data = this->Internal->MultipleData[index];
-    }
+  }
   else
-    {
+  {
     func = NULL;
     data = NULL;
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -267,16 +267,16 @@ vtkMultiProcessController *vtkMultiProcessController::CreateSubController(
                                                          vtkProcessGroup *group)
 {
   if (group->GetCommunicator() != this->Communicator)
-    {
+  {
     vtkErrorMacro(<< "Invalid group for creating a sub controller.");
     return NULL;
-    }
+  }
 
   if (group->FindProcessId(this->GetLocalProcessId()) < 0)
-    {
+  {
     // The group does not contain this process.  Just return NULL.
     return NULL;
-    }
+  }
 
   vtkSubCommunicator *subcomm = vtkSubCommunicator::New();
   subcomm->SetGroup(group);
@@ -313,37 +313,37 @@ vtkMultiProcessController *vtkMultiProcessController::PartitionController(
   inPartition.assign(numProc, false);
 
   for (int i = 0; i < numProc; i++)
-    {
+  {
     if (inPartition[i]) continue;
     int targetColor = allColors[i];
     std::list<int> partitionIds;     // Make sorted list, then put in group.
     for (int j = i; j < numProc; j++)
-      {
+    {
       if (allColors[j] != targetColor) continue;
       inPartition[j] = true;
       std::list<int>::iterator iter = partitionIds.begin();
       while ((iter != partitionIds.end()) && (allKeys[*iter] <= allKeys[j]))
-        {
+      {
         iter++;
-        }
-      partitionIds.insert(iter, j);
       }
+      partitionIds.insert(iter, j);
+    }
     // Copy list into process group.
     VTK_CREATE(vtkProcessGroup, group);
     group->Initialize(this);
     group->RemoveAllProcessIds();
     for (std::list<int>::iterator iter = partitionIds.begin();
          iter != partitionIds.end(); iter++)
-      {
+    {
       group->AddProcessId(*iter);
-      }
+    }
     // Use group to create controller.
     vtkMultiProcessController *sc = this->CreateSubController(group);
     if (sc)
-      {
+    {
       subController = sc;
-      }
     }
+  }
 
   return subController;
 }
@@ -366,9 +366,9 @@ void vtkMultiProcessController::RemoveAllRMICallbacks(int tag)
   vtkInternal::RMICallbackMap::iterator iter =
     this->Internal->RMICallbacks.find(tag);
   if (iter != this->Internal->RMICallbacks.end())
-    {
+  {
     this->Internal->RMICallbacks.erase(iter);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -377,18 +377,18 @@ bool vtkMultiProcessController::RemoveRMICallback(unsigned long id)
   vtkInternal::RMICallbackMap::iterator iterMap;
   for (iterMap = this->Internal->RMICallbacks.begin();
     iterMap != this->Internal->RMICallbacks.end(); ++iterMap)
-    {
+  {
     vtkInternal::RMICallbackVector::iterator iterVec;
     for (iterVec = iterMap->second.begin();
       iterVec != iterMap->second.end(); ++iterVec)
-      {
+    {
       if (iterVec->Id == id)
-        {
+      {
         iterMap->second.erase(iterVec);
         return true;
-        }
       }
     }
+  }
   return false;
 }
 
@@ -398,13 +398,13 @@ int vtkMultiProcessController::RemoveFirstRMI(int tag)
   vtkInternal::RMICallbackMap::iterator iter =
     this->Internal->RMICallbacks.find(tag);
   if (iter != this->Internal->RMICallbacks.end())
-    {
+  {
     if (iter->second.begin() != iter->second.end())
-      {
+    {
       iter->second.erase(iter->second.begin());
       return 1;
-      }
     }
+  }
   return 0;
 }
 
@@ -429,24 +429,24 @@ void vtkMultiProcessController::TriggerRMIOnAllChildren(
 {
 
   if( this->BroadcastTriggerRMI )
-    {
+  {
     this->BroadcastTriggerRMIOnAllChildren(arg,argLength,rmiTag);
-    } // END if use broadcast method
+  } // END if use broadcast method
   else
-    {
+  {
     int myid = this->GetLocalProcessId();
     int childid = 2 * myid + 1;
     int numProcs = this->GetNumberOfProcesses();
     if (numProcs > childid)
-      {
+    {
       this->TriggerRMIInternal(childid, arg, argLength, rmiTag, true);
-      }
+    }
     childid++;
     if (numProcs > childid)
-      {
+    {
       this->TriggerRMIInternal(childid, arg, argLength, rmiTag, true);
-      }
-    } // END else
+    }
+  } // END else
 }
 
 //----------------------------------------------------------------------------
@@ -455,17 +455,17 @@ void vtkMultiProcessController::TriggerRMI(int remoteProcessId,
                                            int rmiTag)
 {
   if( this->BroadcastTriggerRMI  )
-    {
+  {
     vtkErrorMacro(
         "TriggerRMI should not be called when BroadcastTriggerRMI is ON");
-    }
+  }
 
   // Deal with sending RMI to ourself here for now.
   if (remoteProcessId == this->GetLocalProcessId())
-    {
+  {
     this->ProcessRMI(remoteProcessId, arg, argLength, rmiTag);
     return;
-    }
+  }
 
   this->TriggerRMIInternal(remoteProcessId, arg, argLength, rmiTag, false);
 }
@@ -489,19 +489,19 @@ void vtkMultiProcessController::BroadcastTriggerRMIOnAllChildren(
   // If possible, send the data over a single broadcast
   int buffer_size = sizeof(int)*(126 /*128-2*/);
   if( (argLength >= 0) && (argLength < buffer_size) )
-    {
+  {
     if( argLength > 0 )
-      {
-      memcpy(&triggerMessage[2],arg,argLength);
-      }
-    this->RMICommunicator->Broadcast(triggerMessage,128,0);
-    }
-  else
     {
+      memcpy(&triggerMessage[2],arg,argLength);
+    }
+    this->RMICommunicator->Broadcast(triggerMessage,128,0);
+  }
+  else
+  {
     this->RMICommunicator->Broadcast(triggerMessage,128,0);
     this->RMICommunicator->Broadcast(
         reinterpret_cast<unsigned char*>(arg),argLength,0);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -517,7 +517,7 @@ int vtkMultiProcessController::BroadcastProcessRMIs(
   this->InvokeEvent(vtkCommand::StartEvent);
 
   do
-    {
+  {
     this->RMICommunicator->Broadcast(triggerMessage,128,0);
 
 #ifdef VTK_WORDS_BIGENDIAN
@@ -530,38 +530,35 @@ int vtkMultiProcessController::BroadcastProcessRMIs(
     argLength = triggerMessage[1];
 
     if( argLength > 0 )
-      {
+    {
       arg = new unsigned char[ argLength ];
       int buffer_size = sizeof(int)*(126 /*128-2*/);
 
       if( argLength < buffer_size )
-        {
+      {
         memcpy(arg,&triggerMessage[2],argLength);
-        } // END if message is inline
+      } // END if message is inline
       else
-        {
+      {
         this->RMICommunicator->Broadcast(arg,argLength,0);
-        } // END else message was not inline
+      } // END else message was not inline
 
-      } // END if non-null arguments
+    } // END if non-null arguments
 
     this->ProcessRMI(0 /*we broadcast from rank 0*/, arg, argLength,rmiTag);
 
-    if( arg != NULL )
-      {
-      delete [] arg;
-      arg = NULL;
-      }
+    delete [] arg;
+    arg = NULL;
 
     // check for break
     if (this->BreakFlag)
-      {
+    {
       this->BreakFlag = 0;
       this->InvokeEvent(vtkCommand::EndEvent);
       return error;
-      }
+    }
 
-    } while( !dont_loop );
+  } while( !dont_loop );
 
   this->InvokeEvent(vtkCommand::EndEvent);
   return error;
@@ -591,26 +588,26 @@ void vtkMultiProcessController::TriggerRMIInternal(int remoteProcessId,
   // significantly, since sending multiple small messages is generally slower
   // than sending a single large message.
   if (argLength >= 0 && static_cast<unsigned int>(argLength) < sizeof(int)*(128-4))
-    {
+  {
     if (argLength > 0)
-      {
+    {
       memcpy(&triggerMessage[4], arg, argLength);
-      }
+    }
     int num_bytes = static_cast<int>(4*sizeof(int)) + argLength;
     this->RMICommunicator->Send(reinterpret_cast<unsigned char*>(triggerMessage),
       num_bytes, remoteProcessId, RMI_TAG);
-    }
+  }
   else
-    {
+  {
     this->RMICommunicator->Send(
       reinterpret_cast<unsigned char*>(triggerMessage),
       static_cast<int>(4*sizeof(int)), remoteProcessId, RMI_TAG);
     if (argLength > 0)
-      {
+    {
       this->RMICommunicator->Send((char*)arg, argLength, remoteProcessId,
         RMI_ARG_TAG);
-      }
     }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -619,22 +616,22 @@ void vtkMultiProcessController::TriggerBreakRMIs()
   int idx, num;
 
   if( this->BroadcastTriggerRMI == 1 )
-    {
+  {
     this->BroadcastTriggerRMIOnAllChildren(NULL,0,BREAK_RMI_TAG);
     return;
-    }
+  }
 
   if (this->GetLocalProcessId() != 0)
-    {
+  {
     vtkErrorMacro("Break should be triggered from process 0.");
     return;
-    }
+  }
 
   num = this->GetNumberOfProcesses();
   for (idx = 1; idx < num; ++idx)
-    {
+  {
     this->TriggerRMI(idx, NULL, 0, BREAK_RMI_TAG);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -647,9 +644,9 @@ int vtkMultiProcessController::ProcessRMIs()
 int vtkMultiProcessController::ProcessRMIs(int reportErrors, int dont_loop)
 {
   if( this->BroadcastTriggerRMI )
-    {
+  {
     return this->BroadcastProcessRMIs(reportErrors,dont_loop);
-    }
+  }
 
 
   this->InvokeEvent(vtkCommand::StartEvent);
@@ -658,19 +655,19 @@ int vtkMultiProcessController::ProcessRMIs(int reportErrors, int dont_loop)
   int error = RMI_NO_ERROR;
 
   do
-    {
+  {
     if (!this->RMICommunicator->Receive(
         reinterpret_cast<unsigned char*>(triggerMessage),
         static_cast<vtkIdType>(128*sizeof(int)), ANY_SOURCE, RMI_TAG) ||
       this->RMICommunicator->GetCount() < static_cast<int>(4*sizeof(int)))
-      {
+    {
       if (reportErrors)
-        {
+      {
         vtkErrorMacro("Could not receive RMI trigger message.");
-        }
+      }
       error = RMI_TAG_ERROR;
       break;
-      }
+    }
 #ifdef VTK_WORDS_BIGENDIAN
     // Header is sent in little-endian form. We need to convert it to  big
     // endian.
@@ -678,60 +675,57 @@ int vtkMultiProcessController::ProcessRMIs(int reportErrors, int dont_loop)
 #endif
 
     if (triggerMessage[1] > 0)
-      {
+    {
       arg = new unsigned char[triggerMessage[1]];
       // If the message length is small enough, the TriggerRMIInternal() call
       // packs the message data inline. So depending on the message length we
       // use the inline data or make a second receive to fetch the data.
       if (static_cast<unsigned int>(triggerMessage[1]) < sizeof(int)*(128-4))
-        {
+      {
         int num_bytes = static_cast<int>(4 *sizeof(int)) + triggerMessage[1];
         if (this->RMICommunicator->GetCount() != num_bytes)
-          {
+        {
           if (reportErrors)
-            {
+          {
             vtkErrorMacro("Could not receive the RMI argument in its entirety.");
-            }
+          }
           error= RMI_ARG_ERROR;
           break;
-          }
-        memcpy(arg, &triggerMessage[4], triggerMessage[1]);
         }
+        memcpy(arg, &triggerMessage[4], triggerMessage[1]);
+      }
       else
-        {
+      {
         if (!this->RMICommunicator->Receive((char*)(arg), triggerMessage[1],
             triggerMessage[2], RMI_ARG_TAG) ||
           this->RMICommunicator->GetCount() != triggerMessage[1])
-          {
+        {
           if (reportErrors)
-            {
+          {
             vtkErrorMacro("Could not receive RMI argument.");
-            }
+          }
           error = RMI_ARG_ERROR;
           break;
-          }
         }
       }
+    }
     if (triggerMessage[3] == 1 && this->GetNumberOfProcesses() > 3)//propagate==true
-      {
+    {
       this->TriggerRMIOnAllChildren(arg, triggerMessage[1], triggerMessage[0]);
-      }
+    }
     this->ProcessRMI(triggerMessage[2], arg, triggerMessage[1],
       triggerMessage[0]);
-    if (arg)
-      {
-      delete [] arg;
-      arg = NULL;
-      }
+    delete [] arg;
+    arg = NULL;
 
     // check for break
     if (this->BreakFlag)
-      {
+    {
       this->BreakFlag = 0;
       this->InvokeEvent(vtkCommand::EndEvent);
       return error;
-      }
-    } while (!dont_loop);
+    }
+  } while (!dont_loop);
 
   this->InvokeEvent(vtkCommand::EndEvent);
   return error;
@@ -750,29 +744,29 @@ void vtkMultiProcessController::ProcessRMI(int remoteProcessId,
   vtkInternal::RMICallbackMap::iterator iter =
     this->Internal->RMICallbacks.find(rmiTag);
   if (iter != this->Internal->RMICallbacks.end())
-    {
+  {
     vtkInternal::RMICallbackVector::iterator iterVec;
     for (iterVec = iter->second.begin();
       iterVec != iter->second.end(); iterVec++)
-      {
+    {
       if (iterVec->Function)
-        {
+      {
         callbacks.push_back(*iterVec);
-        }
       }
     }
+  }
 
   if (callbacks.size()==0)
-    {
+  {
     vtkErrorMacro("Process " << this->GetLocalProcessId() <<
                   " Could not find RMI with tag " << rmiTag);
-    }
+  }
 
   std::vector<vtkInternal::vtkRMICallback>::iterator citer;
   for (citer = callbacks.begin(); citer != callbacks.end(); citer++)
-    {
+  {
     (*citer->Function)(citer->LocalArgument, arg, argLength, remoteProcessId);
-    }
+  }
 }
 
 //============================================================================
@@ -782,9 +776,9 @@ static vtkWeakPointer<vtkMultiProcessController> VTK_GLOBAL_MULTI_PROCESS_CONTRO
 vtkMultiProcessController *vtkMultiProcessController::GetGlobalController()
 {
   if (VTK_GLOBAL_MULTI_PROCESS_CONTROLLER == NULL)
-    {
+  {
     return NULL;
-    }
+  }
 
   return VTK_GLOBAL_MULTI_PROCESS_CONTROLLER->GetLocalController();
 }
