@@ -39,14 +39,14 @@ vtkStandardNewMacro(vtkContext2D);
 bool vtkContext2D::Begin(vtkContextDevice2D *device)
 {
   if (this->Device == device)
-    {
+  {
     //Handle the case where the same device is set multiple times
     return true;
-    }
+  }
   else if (this->Device)
-    {
+  {
     this->Device->Delete();
-    }
+  }
   this->Device = device;
   this->Device->Register(this);
   this->Modified();
@@ -57,13 +57,13 @@ bool vtkContext2D::Begin(vtkContextDevice2D *device)
 bool vtkContext2D::End()
 {
   if (this->Device)
-    {
+  {
     this->Device->End();
     this->Device->Delete();
     this->Device = NULL;
     this->Modified();
     return true;
-    }
+  }
   return true;
 }
 
@@ -100,10 +100,10 @@ void vtkContext2D::BufferIdModeEnd()
 void vtkContext2D::DrawLine(float x1, float y1, float x2, float y2)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   float x[] = { x1, y1, x2, y2 };
   this->Device->DrawPoly(&x[0], 2);
 }
@@ -112,10 +112,10 @@ void vtkContext2D::DrawLine(float x1, float y1, float x2, float y2)
 void vtkContext2D::DrawLine(float p[4])
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   this->Device->DrawPoly(&p[0], 2);
 }
 
@@ -123,16 +123,16 @@ void vtkContext2D::DrawLine(float p[4])
 void vtkContext2D::DrawLine(vtkPoints2D *points)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   if (points->GetNumberOfPoints() < 2)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint a line with <2 points.");
     return;
-    }
-  float *f = vtkFloatArray::SafeDownCast(points->GetData())->GetPointer(0);
+  }
+  float *f = vtkArrayDownCast<vtkFloatArray>(points->GetData())->GetPointer(0);
   this->Device->DrawPoly(f, 2);
 }
 
@@ -140,16 +140,16 @@ void vtkContext2D::DrawLine(vtkPoints2D *points)
 void vtkContext2D::DrawPoly(float *x, float *y, int n)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   float *p = new float[2*n];
   for (int i = 0; i < n; ++i)
-    {
+  {
     p[2*i]   = x[i];
     p[2*i+1] = y[i];
-    }
+  }
   this->Device->DrawPoly(p, n);
   delete[] p;
 }
@@ -160,7 +160,7 @@ void vtkContext2D::DrawPoly(vtkPoints2D *points)
   // Construct an array with the correct coordinate packing for OpenGL.
   int n = static_cast<int>(points->GetNumberOfPoints());
   // If the points are of type float then call OpenGL directly
-  float *f = vtkFloatArray::SafeDownCast(points->GetData())->GetPointer(0);
+  float *f = vtkArrayDownCast<vtkFloatArray>(points->GetData())->GetPointer(0);
   this->DrawPoly(f, n);
 }
 
@@ -168,15 +168,15 @@ void vtkContext2D::DrawPoly(vtkPoints2D *points)
 void vtkContext2D::DrawPoly(float *points, int n)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   if (n < 2)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint a line with <2 points.");
     return;
-    }
+  }
   this->Device->DrawPoly(points, n);
 }
 
@@ -185,18 +185,44 @@ void vtkContext2D::DrawPoly(float *points, int n,
                             unsigned char *colors, int nc_comps)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   if (n < 2)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint a line with <2 points.");
     return;
-    }
+  }
   this->Device->DrawPoly(points, n, colors, nc_comps);
 }
 
+//-----------------------------------------------------------------------------
+void vtkContext2D::DrawLines(vtkPoints2D *points)
+{
+  // Construct an array with the correct coordinate packing for OpenGL.
+  int n = static_cast<int>(points->GetNumberOfPoints());
+  // If the points are of type float then call OpenGL directly
+  float *f = vtkArrayDownCast<vtkFloatArray>(points->GetData())->GetPointer(0);
+  this->DrawLines(f, n);
+}
+
+//-----------------------------------------------------------------------------
+void vtkContext2D::DrawLines(float *points, int n)
+{
+  if (!this->Device)
+  {
+    vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
+    return;
+  }
+  if (n < 2)
+  {
+    vtkErrorMacro(<< "Attempted to paint a line with <2 points.");
+    return;
+  }
+  this->Device->DrawLines(points, n);
+}
+
 //-----------------------------------------------------------------------------
 void vtkContext2D::DrawPoint(float x, float y)
 {
@@ -210,10 +236,10 @@ void vtkContext2D::DrawPoints(float *x, float *y, int n)
   // Copy the points into an array and draw it.
   float *p = new float[2*n];
   for (int i = 0; i < n; ++i)
-    {
+  {
     p[2*i]   = x[i];
     p[2*i+1] = y[i];
-    }
+  }
   this->DrawPoints(&p[0], n);
   delete[] p;
 }
@@ -224,7 +250,7 @@ void vtkContext2D::DrawPoints(vtkPoints2D *points)
   // Construct an array with the correct coordinate packing for OpenGL.
   int n = static_cast<int>(points->GetNumberOfPoints());
   // If the points are of type float then call OpenGL directly
-  float *f = vtkFloatArray::SafeDownCast(points->GetData())->GetPointer(0);
+  float *f = vtkArrayDownCast<vtkFloatArray>(points->GetData())->GetPointer(0);
   this->DrawPoints(f, n);
 }
 
@@ -232,10 +258,10 @@ void vtkContext2D::DrawPoints(vtkPoints2D *points)
 void vtkContext2D::DrawPoints(float *points, int n)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   this->Device->DrawPoints(points, n);
 }
 
@@ -245,7 +271,7 @@ void vtkContext2D::DrawPointSprites(vtkImageData *sprite, vtkPoints2D *points)
   // Construct an array with the correct coordinate packing for OpenGL.
   int n = static_cast<int>(points->GetNumberOfPoints());
   // If the points are of type float then call OpenGL directly
-  float *f = vtkFloatArray::SafeDownCast(points->GetData())->GetPointer(0);
+  float *f = vtkArrayDownCast<vtkFloatArray>(points->GetData())->GetPointer(0);
   this->DrawPointSprites(sprite, f, n);
 }
 
@@ -257,13 +283,13 @@ void vtkContext2D::DrawPointSprites(vtkImageData *sprite, vtkPoints2D *points,
   int n = static_cast<int>(points->GetNumberOfPoints());
   int nc = static_cast<int>(colors->GetNumberOfTuples());
   if (n != nc)
-    {
+  {
     vtkErrorMacro(<< "Attempted to color points with array of wrong length");
     return;
-    }
+  }
   int nc_comps = static_cast<int>(colors->GetNumberOfComponents());
   // If the points are of type float then call OpenGL directly
-  float *f = vtkFloatArray::SafeDownCast(points->GetData())->GetPointer(0);
+  float *f = vtkArrayDownCast<vtkFloatArray>(points->GetData())->GetPointer(0);
   unsigned char *c = colors->GetPointer(0);
   this->DrawPointSprites(sprite, f, n, c, nc_comps);
 }
@@ -273,10 +299,10 @@ void vtkContext2D::DrawPointSprites(vtkImageData *sprite, float *points, int n,
          unsigned char *colors, int nc_comps)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   this->Device->DrawPointSprites(sprite, points, n, colors, nc_comps);
 }
 
@@ -284,10 +310,10 @@ void vtkContext2D::DrawPointSprites(vtkImageData *sprite, float *points, int n,
 void vtkContext2D::DrawPointSprites(vtkImageData *sprite, float *points, int n)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   this->Device->DrawPointSprites(sprite, points, n);
 }
 
@@ -296,10 +322,10 @@ void vtkContext2D::DrawMarkers(int shape, bool highlight, float *points, int n,
                                unsigned char *colors, int nc_comps)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   this->Device->DrawMarkers(shape, highlight, points, n, colors, nc_comps);
 }
 
@@ -314,7 +340,7 @@ void vtkContext2D::DrawMarkers(int shape, bool highlight, vtkPoints2D *points)
 {
   // Construct an array with the correct coordinate packing for OpenGL.
   int n = static_cast<int>(points->GetNumberOfPoints());
-  float *f = vtkFloatArray::SafeDownCast(points->GetData())->GetPointer(0);
+  float *f = vtkArrayDownCast<vtkFloatArray>(points->GetData())->GetPointer(0);
   this->DrawMarkers(shape, highlight, f, n);
 }
 
@@ -325,12 +351,12 @@ void vtkContext2D::DrawMarkers(int shape, bool highlight, vtkPoints2D *points, v
   int n = static_cast<int>(points->GetNumberOfPoints());
   int nc = static_cast<int>(colors->GetNumberOfTuples());
   if (n != nc)
-    {
+  {
     vtkErrorMacro(<< "Attempted to color points with array of wrong length");
     return;
-    }
+  }
   int nc_comps = static_cast<int>(colors->GetNumberOfComponents());
-  float *f = vtkFloatArray::SafeDownCast(points->GetData())->GetPointer(0);
+  float *f = vtkArrayDownCast<vtkFloatArray>(points->GetData())->GetPointer(0);
   unsigned char *c = colors->GetPointer(0);
   this->DrawMarkers(shape, highlight, f, n, c, nc_comps);
 }
@@ -339,10 +365,10 @@ void vtkContext2D::DrawMarkers(int shape, bool highlight, vtkPoints2D *points, v
 void vtkContext2D::DrawRect(float x, float y, float width, float height)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   float p[] = { x,       y,
                 x+width, y,
                 x+width, y+height,
@@ -368,10 +394,10 @@ void vtkContext2D::DrawQuad(float x1, float y1, float x2, float y2,
 void vtkContext2D::DrawQuad(float *p)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
 
   // Draw the filled area of the quad.
   this->Device->DrawQuad(p, 4);
@@ -388,7 +414,7 @@ void vtkContext2D::DrawQuadStrip(vtkPoints2D *points)
   // Construct an array with the correct coordinate packing for OpenGL.
   int n = static_cast<int>(points->GetNumberOfPoints());
   // If the points are of type float then call OpenGL directly
-  float *f = vtkFloatArray::SafeDownCast(points->GetData())->GetPointer(0);
+  float *f = vtkArrayDownCast<vtkFloatArray>(points->GetData())->GetPointer(0);
   this->DrawQuadStrip(f, n);
 }
 
@@ -396,10 +422,10 @@ void vtkContext2D::DrawQuadStrip(vtkPoints2D *points)
 void vtkContext2D::DrawQuadStrip(float *points, int n)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   // Draw the filled area of the polygon.
   this->Device->DrawQuadStrip(points, n);
 }
@@ -410,10 +436,10 @@ void vtkContext2D::DrawPolygon(float *x, float *y, int n)
   // Copy the points into an array and draw it.
   float *p = new float[2*n];
   for (int i = 0; i < n; ++i)
-    {
+  {
     p[2*i]   = x[i];
     p[2*i+1] = y[i];
-    }
+  }
   this->DrawPolygon(&p[0], n);
   delete[] p;}
 
@@ -423,7 +449,7 @@ void vtkContext2D::DrawPolygon(vtkPoints2D *points)
   // Construct an array with the correct coordinate packing for OpenGL.
   int n = static_cast<int>(points->GetNumberOfPoints());
   // If the points are of type float then call OpenGL directly
-  float *f = vtkFloatArray::SafeDownCast(points->GetData())->GetPointer(0);
+  float *f = vtkArrayDownCast<vtkFloatArray>(points->GetData())->GetPointer(0);
   this->DrawPolygon(f, n);
 }
 
@@ -431,10 +457,10 @@ void vtkContext2D::DrawPolygon(vtkPoints2D *points)
 void vtkContext2D::DrawPolygon(float *points, int n)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   // Draw the filled area of the polygon.
   this->Device->DrawPolygon(points, n);
 
@@ -481,10 +507,10 @@ void vtkContext2D::DrawEllipseWedge(float x, float y, float outRx, float outRy,
   assert("pre: ordered_ry" && inRy<=outRy);
 
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   // don't tessellate here. The device context knows what to do with an
   // arc. An OpenGL device context will tessellate but and SVG context with
   // just generate an arc.
@@ -508,10 +534,10 @@ void vtkContext2D::DrawEllipticArc(float x, float y, float rX, float rY,
   assert("pre: positive_rY" && rY>=0);
 
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   // don't tessellate here. The device context knows what to do with an
   // arc. An OpenGL device context will tessellate but and SVG context with
   // just generate an arc.
@@ -542,7 +568,7 @@ void vtkContext2D::DrawStringRect(vtkPoints2D *rect, const char* string)
 //-----------------------------------------------------------------------------
 void vtkContext2D::DrawString(vtkPoints2D *point, const vtkStdString &string)
 {
-  float *f = vtkFloatArray::SafeDownCast(point->GetData())->GetPointer(0);
+  float *f = vtkArrayDownCast<vtkFloatArray>(point->GetData())->GetPointer(0);
   this->DrawString(f[0], f[1], string);
 }
 
@@ -550,14 +576,14 @@ void vtkContext2D::DrawString(vtkPoints2D *point, const vtkStdString &string)
 void vtkContext2D::DrawString(float x, float y, const vtkStdString &string)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   if (string.empty())
-    {
+  {
     return;
-    }
+  }
   float f[] = { x, y };
   this->Device->DrawString(f, string);
 }
@@ -565,7 +591,7 @@ void vtkContext2D::DrawString(float x, float y, const vtkStdString &string)
 //-----------------------------------------------------------------------------
 void vtkContext2D::DrawString(vtkPoints2D *point, const vtkUnicodeString &string)
 {
-  float *f = vtkFloatArray::SafeDownCast(point->GetData())->GetPointer(0);
+  float *f = vtkArrayDownCast<vtkFloatArray>(point->GetData())->GetPointer(0);
   this->DrawString(f[0], f[1], string);
 }
 
@@ -573,14 +599,14 @@ void vtkContext2D::DrawString(vtkPoints2D *point, const vtkUnicodeString &string
 void vtkContext2D::DrawString(float x, float y, const vtkUnicodeString &string)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   if (string.empty())
-    {
+  {
     return;
-    }
+  }
   float f[] = { x, y };
   this->Device->DrawString(&f[0], string);
 }
@@ -588,7 +614,7 @@ void vtkContext2D::DrawString(float x, float y, const vtkUnicodeString &string)
 //-----------------------------------------------------------------------------
 void vtkContext2D::DrawString(vtkPoints2D *point, const char* string)
 {
-  float *f = vtkFloatArray::SafeDownCast(point->GetData())->GetPointer(0);
+  float *f = vtkArrayDownCast<vtkFloatArray>(point->GetData())->GetPointer(0);
   this->DrawString(f[0], f[1], vtkStdString(string));
 }
 
@@ -603,7 +629,7 @@ void vtkContext2D::ComputeStringBounds(const vtkStdString &string,
                                        vtkPoints2D *bounds)
 {
   bounds->SetNumberOfPoints(2);
-  float *f = vtkFloatArray::SafeDownCast(bounds->GetData())->GetPointer(0);
+  float *f = vtkArrayDownCast<vtkFloatArray>(bounds->GetData())->GetPointer(0);
   this->ComputeStringBounds(string, f);
 }
 
@@ -612,10 +638,10 @@ void vtkContext2D::ComputeStringBounds(const vtkStdString &string,
                                        float bounds[4])
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   this->Device->ComputeStringBounds(string, bounds);
 }
 
@@ -624,7 +650,7 @@ void vtkContext2D::ComputeStringBounds(const vtkUnicodeString &string,
                                        vtkPoints2D *bounds)
 {
   bounds->SetNumberOfPoints(2);
-  float *f = vtkFloatArray::SafeDownCast(bounds->GetData())->GetPointer(0);
+  float *f = vtkArrayDownCast<vtkFloatArray>(bounds->GetData())->GetPointer(0);
   this->ComputeStringBounds(string, f);
 }
 
@@ -633,10 +659,10 @@ void vtkContext2D::ComputeStringBounds(const vtkUnicodeString &string,
                                        float bounds[4])
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   this->Device->ComputeStringBounds(string, bounds);
 }
 
@@ -654,6 +680,12 @@ void vtkContext2D::ComputeStringBounds(const char* string,
   this->ComputeStringBounds(vtkStdString(string), bounds);
 }
 
+//-----------------------------------------------------------------------------
+void vtkContext2D::ComputeJustifiedStringBounds(const char* string, float bounds[4])
+{
+  this->Device->ComputeJustifiedStringBounds(string, bounds);
+}
+
 //-----------------------------------------------------------------------------
 int vtkContext2D::ComputeFontSizeForBoundedString(const vtkStdString &string,
                                                   float width, float height)
@@ -667,23 +699,23 @@ int vtkContext2D::ComputeFontSizeForBoundedString(const vtkStdString &string,
 
   // font size is too big
   if (stringBounds[2] > width || stringBounds[3] > height)
-    {
+  {
     while (stringBounds[2] > width || stringBounds[3] > height)
-      {
+    {
       --currentFontSize;
       this->GetTextProp()->SetFontSize(currentFontSize);
       this->ComputeStringBounds(string, stringBounds);
       if (currentFontSize < 0)
-        {
+      {
         this->GetTextProp()->SetFontSize(0);
         return 0;
-        }
       }
     }
+  }
 
   // font size is too small
   else
-    {
+  {
       while (stringBounds[2] < width && stringBounds[3] < height)
       {
       ++currentFontSize;
@@ -692,7 +724,7 @@ int vtkContext2D::ComputeFontSizeForBoundedString(const vtkStdString &string,
       }
     --currentFontSize;
     this->GetTextProp()->SetFontSize(currentFontSize);
-    }
+  }
 
   this->GetTextProp()->SetOrientation(orientation);
   return currentFontSize;
@@ -702,7 +734,7 @@ int vtkContext2D::ComputeFontSizeForBoundedString(const vtkStdString &string,
 void vtkContext2D::DrawMathTextString(vtkPoints2D *point,
                                       const vtkStdString &string)
 {
-  float *f = vtkFloatArray::SafeDownCast(point->GetData())->GetPointer(0);
+  float *f = vtkArrayDownCast<vtkFloatArray>(point->GetData())->GetPointer(0);
   this->DrawMathTextString(f[0], f[1], string);
 }
 
@@ -711,14 +743,14 @@ void vtkContext2D::DrawMathTextString(float x, float y,
                                       const vtkStdString &string)
 {
   if (!this->Device)
-    {
+  {
     vtkErrorMacro(<< "Attempted to paint with no active vtkContextDevice2D.");
     return;
-    }
+  }
   if (string.empty())
-    {
+  {
     return;
-    }
+  }
   float f[] = { x, y };
   this->Device->DrawMathTextString(f, string);
 }
@@ -726,7 +758,7 @@ void vtkContext2D::DrawMathTextString(float x, float y,
 //-----------------------------------------------------------------------------
 void vtkContext2D::DrawMathTextString(vtkPoints2D *point, const char* string)
 {
-  float *f = vtkFloatArray::SafeDownCast(point->GetData())->GetPointer(0);
+  float *f = vtkArrayDownCast<vtkFloatArray>(point->GetData())->GetPointer(0);
   this->DrawMathTextString(f[0], f[1], vtkStdString(string));
 }
 
@@ -742,13 +774,13 @@ void vtkContext2D::DrawMathTextString(vtkPoints2D *point,
                                       const vtkStdString &fallback)
 {
   if (this->Device->MathTextIsSupported())
-    {
+  {
     this->DrawMathTextString(point, string);
-    }
+  }
   else
-    {
+  {
     this->DrawString(point, fallback);
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -757,13 +789,13 @@ void vtkContext2D::DrawMathTextString(float x, float y,
                                       const vtkStdString &fallback)
 {
   if (this->Device->MathTextIsSupported())
-    {
+  {
     this->DrawMathTextString(x, y, string);
-    }
+  }
   else
-    {
+  {
     this->DrawString(x, y, fallback);
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -771,13 +803,13 @@ void vtkContext2D::DrawMathTextString(vtkPoints2D *point, const char *string,
                                       const char *fallback)
 {
   if (this->Device->MathTextIsSupported())
-    {
+  {
     this->DrawMathTextString(point, string);
-    }
+  }
   else
-    {
+  {
     this->DrawString(point, fallback);
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -785,13 +817,13 @@ void vtkContext2D::DrawMathTextString(float x, float y, const char *string,
                                       const char *fallback)
 {
   if (this->Device->MathTextIsSupported())
-    {
+  {
     this->DrawMathTextString(x, y, string);
-    }
+  }
   else
-    {
+  {
     this->DrawString(x, y, fallback);
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -830,9 +862,9 @@ void vtkContext2D::ApplyPen(vtkPen *pen)
 vtkPen* vtkContext2D::GetPen()
 {
   if (this->Device)
-    {
+  {
     return this->Device->GetPen();
-    }
+  }
   return NULL;
 }
 
@@ -846,9 +878,9 @@ void vtkContext2D::ApplyBrush(vtkBrush *brush)
 vtkBrush* vtkContext2D::GetBrush()
 {
   if (this->Device)
-    {
+  {
     return this->Device->GetBrush();
-    }
+  }
   return NULL;
 }
 
@@ -862,9 +894,9 @@ void vtkContext2D::ApplyTextProp(vtkTextProperty *prop)
 vtkTextProperty* vtkContext2D::GetTextProp()
 {
   if (this->Device)
-    {
+  {
     return this->Device->GetTextProp();
-    }
+  }
   return NULL;
 }
 
@@ -872,19 +904,19 @@ vtkTextProperty* vtkContext2D::GetTextProp()
 void vtkContext2D::SetTransform(vtkTransform2D *transform)
 {
   if (transform)
-    {
+  {
     this->Device->SetMatrix(transform->GetMatrix());
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
 vtkTransform2D* vtkContext2D::GetTransform()
 {
   if (this->Device && this->Transform)
-    {
+  {
     this->Device->GetMatrix(this->Transform->GetMatrix());
     return this->Transform;
-    }
+  }
   return NULL;
 }
 
@@ -892,9 +924,9 @@ vtkTransform2D* vtkContext2D::GetTransform()
 void vtkContext2D::AppendTransform(vtkTransform2D *transform)
 {
   if(!transform)
-    {
+  {
     return;
-    }
+  }
 
   this->Device->MultiplyMatrix(transform->GetMatrix());
 }
@@ -943,43 +975,49 @@ void vtkContext2D::SetContext3D(vtkContext3D *context)
 
 //-----------------------------------------------------------------------------
 vtkVector2f vtkContext2D::CalculateTextPosition(vtkPoints2D* rect)
+{
+  if (rect->GetNumberOfPoints() < 2)
+  {
+    return vtkVector2f();
+  }
+
+  float *f = vtkArrayDownCast<vtkFloatArray>(rect->GetData())->GetPointer(0);
+  return this->CalculateTextPosition(f);
+}
+
+//-----------------------------------------------------------------------------
+vtkVector2f vtkContext2D::CalculateTextPosition(float rect[4])
 {
   // Draw the text at the appropriate point inside the rect for the alignment
   // specified. This is a convenience when an area of the screen should have
   // text drawn that is aligned to the entire area.
-  if (rect->GetNumberOfPoints() < 2)
-    {
-    return vtkVector2f();
-    }
-
   vtkVector2f p(0, 0);
-  float *f = vtkFloatArray::SafeDownCast(rect->GetData())->GetPointer(0);
 
   if (this->Device->GetTextProp()->GetJustification() == VTK_TEXT_LEFT)
-    {
-    p.SetX(f[0]);
-    }
+  {
+    p.SetX(rect[0]);
+  }
   else if (this->Device->GetTextProp()->GetJustification() == VTK_TEXT_CENTERED)
-    {
-    p.SetX(f[0] + 0.5f*f[2]);
-    }
+  {
+    p.SetX(rect[0] + 0.5f*rect[2]);
+  }
   else
-    {
-    p.SetX(f[0] + f[2]);
-    }
+  {
+    p.SetX(rect[0] + rect[2]);
+  }
 
   if (this->Device->GetTextProp()->GetVerticalJustification() == VTK_TEXT_BOTTOM)
-    {
-    p.SetY(f[1]);
-    }
+  {
+    p.SetY(rect[1]);
+  }
   else if (this->Device->GetTextProp()->GetVerticalJustification() == VTK_TEXT_CENTERED)
-    {
-    p.SetY(f[1] + 0.5f*f[3]);
-    }
+  {
+    p.SetY(rect[1] + 0.5f*rect[3]);
+  }
   else
-    {
-    p.SetY(f[1] + f[3]);
-    }
+  {
+    p.SetY(rect[1] + rect[3]);
+  }
   return p;
 }
 
@@ -995,13 +1033,13 @@ vtkContext2D::vtkContext2D() : Context3D(NULL)
 vtkContext2D::~vtkContext2D()
 {
   if (this->Device)
-    {
+  {
     this->Device->Delete();
-    }
+  }
   if (this->Transform)
-    {
+  {
     this->Transform->Delete();
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -1010,12 +1048,12 @@ void vtkContext2D::PrintSelf(ostream &os, vtkIndent indent)
   this->Superclass::PrintSelf(os, indent);
   os << indent << "Context Device: ";
   if (this->Device)
-    {
+  {
     os << endl;
     this->Device->PrintSelf(os, indent.GetNextIndent());
-    }
+  }
   else
-    {
+  {
     os << "(none)" << endl;
-    }
+  }
 }
