@@ -43,13 +43,13 @@ class vtkContextScene::Private
 {
 public:
   Private()
-    {
+  {
     this->Event.SetButton(vtkContextMouseEvent::NO_BUTTON);
     this->IsDirty = true;
-    }
+  }
   ~Private()
-    {
-    }
+  {
+  }
 
   // The item with a current mouse down
   vtkWeakPointer<vtkAbstractContextItem> itemMousePressCurrent;
@@ -89,13 +89,13 @@ vtkContextScene::~vtkContextScene()
   this->Storage = NULL;
   this->SetAnnotationLink(NULL);
   if(this->BufferId!=0)
-    {
+  {
     this->BufferId->Delete();
-    }
+  }
   if (this->Transform)
-    {
+  {
     this->Transform->Delete();
-    }
+  }
   delete this->Children;
 }
 
@@ -106,25 +106,31 @@ void vtkContextScene::SetRenderer(vtkRenderer *r)
   this->BufferIdSupportTested=false;
 }
 
+//-----------------------------------------------------------------------------
+vtkRenderer *vtkContextScene::GetRenderer()
+{
+  return this->Renderer;
+}
+
 //-----------------------------------------------------------------------------
 bool vtkContextScene::Paint(vtkContext2D *painter)
 {
   vtkDebugMacro("Paint event called.");
   size_t size = this->Children->size();
   if (size && this->Transform)
-    {
+  {
     painter->PushMatrix();
     painter->SetTransform(this->Transform);
-    }
+  }
   this->Children->PaintItems(painter);
   if (size && this->Transform)
-    {
+  {
     painter->PopMatrix();
-    }
+  }
   if(this->Storage->IsDirty)
-    {
+  {
     this->BufferIdDirty=true;
-    }
+  }
   this->Storage->IsDirty = false;
   this->LastPainter=painter;
   return true;
@@ -137,15 +143,15 @@ void vtkContextScene::PaintIds()
   size_t size = this->Children->size();
 
   if(size>16777214) // 24-bit limit, 0 reserved for background encoding.
-    {
+  {
     vtkWarningMacro(<<"picking will not work properly as there are two many items. Items over 16777214 will be ignored.");
     size=16777214;
-    }
+  }
   for (size_t i = 0; i < size; ++i)
-    {
+  {
     this->LastPainter->ApplyId(i+1);
     (*this->Children)[i]->Paint(this->LastPainter);
-    }
+  }
   this->Storage->IsDirty = false;
 }
 
@@ -171,13 +177,13 @@ bool vtkContextScene::RemoveItem(unsigned int index)
 vtkAbstractContextItem * vtkContextScene::GetItem(unsigned int index)
 {
   if (index < this->Children->size())
-    {
+  {
     return this->Children->at(index);
-    }
+  }
   else
-    {
+  {
     return 0;
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -197,26 +203,26 @@ void vtkContextScene::ClearItems()
 int vtkContextScene::GetViewWidth()
 {
   if (this->Renderer)
-    {
+  {
     return this->Renderer->GetRenderWindow()->GetSize()[0];
-    }
+  }
   else
-    {
+  {
     return 0;
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
 int vtkContextScene::GetViewHeight()
 {
   if (this->Renderer)
-    {
+  {
     return this->Renderer->GetRenderWindow()->GetSize()[1];
-    }
+  }
   else
-    {
+  {
     return 0;
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -231,18 +237,29 @@ int vtkContextScene::GetSceneHeight()
   return this->Geometry[1];
 }
 
+//-----------------------------------------------------------------------------
+vtkVector2i vtkContextScene::GetLogicalTileScale()
+{
+  vtkVector2i result(1);
+  if (this->ScaleTiles && this->Renderer && this->Renderer->GetRenderWindow())
+  {
+    this->Renderer->GetRenderWindow()->GetTileScale(result.GetData());
+  }
+  return result;
+}
+
 //-----------------------------------------------------------------------------
 void vtkContextScene::SetDirty(bool isDirty)
 {
   if (this->Storage->IsDirty == isDirty)
-    {
+  {
     return;
-    }
+  }
   this->Storage->IsDirty = isDirty;
   if(this->Storage->IsDirty)
-    {
+  {
     this->BufferIdDirty=true;
-    }
+  }
   this->Modified();
 }
 
@@ -257,14 +274,14 @@ bool vtkContextScene::GetDirty() const
 void vtkContextScene::ReleaseGraphicsResources()
 {
   if(this->BufferId!=0)
-    {
+  {
     this->BufferId->ReleaseGraphicsResources();
-    }
+  }
   for(vtkContextScenePrivate::const_iterator it = this->Children->begin();
     it != this->Children->end(); ++it)
-    {
+  {
     (*it)->ReleaseGraphicsResources();
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -283,9 +300,9 @@ vtkAbstractContextBufferId *vtkContextScene::GetBufferId()
 void vtkContextScene::SetTransform(vtkTransform2D* transform)
 {
   if (this->Transform == transform)
-    {
+  {
     return;
-    }
+  }
   this->Transform->Delete();
   this->Transform = transform;
   this->Transform->Register(this);
@@ -295,14 +312,14 @@ void vtkContextScene::SetTransform(vtkTransform2D* transform)
 vtkTransform2D* vtkContextScene::GetTransform()
 {
   if (this->Transform)
-    {
+  {
     return this->Transform;
-    }
+  }
   else
-    {
+  {
     this->Transform = vtkTransform2D::New();
     return this->Transform;
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -311,9 +328,9 @@ bool vtkContextScene::ProcessSelectionEvent(unsigned int rect[5])
   cout << "ProcessSelectionEvent called! " << endl;
   cout << "Rect:";
   for (int i = 0; i < 5; ++i)
-    {
+  {
     cout << "\t" << rect[i];
-    }
+  }
   cout << endl;
   return false;
 }
@@ -322,13 +339,13 @@ bool vtkContextScene::ProcessSelectionEvent(unsigned int rect[5])
 void vtkContextScene::TestBufferIdSupport()
 {
   if (!this->BufferIdSupportTested)
-    {
+  {
     vtkNew<vtkAbstractContextBufferId> b;
     b->SetContext(this->Renderer->GetRenderWindow());
     this->BufferIdSupported = b->IsSupported();
     b->ReleaseGraphicsResources();
     this->BufferIdSupportTested = true;
-    }
+  }
 }
 
 // ----------------------------------------------------------------------------
@@ -343,12 +360,12 @@ void vtkContextScene::UpdateBufferId()
   if (this->BufferId==0 || this->BufferIdDirty ||
       width!=this->BufferId->GetWidth() ||
       height!=this->BufferId->GetHeight())
-    {
+  {
     if (this->BufferId == 0)
-      {
+    {
       this->BufferId = vtkAbstractContextBufferId::New();
       this->BufferId->SetContext(this->Renderer->GetRenderWindow());
-      }
+    }
     this->BufferId->SetWidth(width);
     this->BufferId->SetHeight(height);
     this->BufferId->Allocate();
@@ -358,7 +375,7 @@ void vtkContextScene::UpdateBufferId()
     this->LastPainter->BufferIdModeEnd();
 
     this->BufferIdDirty = false;
-    }
+  }
 }
 
 // ----------------------------------------------------------------------------
@@ -367,13 +384,13 @@ vtkAbstractContextItem* vtkContextScene::GetPickedItem()
   vtkContextMouseEvent &event = this->Storage->Event;
   for(vtkContextScenePrivate::const_reverse_iterator it =
       this->Children->rbegin(); it != this->Children->rend(); ++it)
-    {
+  {
     vtkAbstractContextItem* item = (*it)->GetPickedItem(event);
     if (item)
-      {
+    {
       return item;
-      }
     }
+  }
   return NULL;
 }
 
@@ -383,24 +400,24 @@ vtkIdType vtkContextScene::GetPickedItem(int x, int y)
   vtkIdType result = -1;
   this->TestBufferIdSupport();
   if (this->UseBufferId && this->BufferIdSupported)
-    {
+  {
     this->UpdateBufferId();
     result=this->BufferId->GetPickedItem(x,y);
-    }
+  }
   else
-    {
+  {
     size_t i = this->Children->size()-1;
     vtkContextMouseEvent &event = this->Storage->Event;
     for(vtkContextScenePrivate::const_reverse_iterator it =
         this->Children->rbegin(); it != this->Children->rend(); ++it, --i)
-      {
+    {
       if ((*it)->Hit(event))
-        {
+      {
         result = static_cast<vtkIdType>(i);
         break;
-        }
       }
     }
+  }
 
   // Work-around for Qt bug under Linux (and maybe other platforms), 4.5.2
   // or 4.6.2 :
@@ -412,9 +429,9 @@ vtkIdType vtkContextScene::GetPickedItem(int x, int y)
   // [-1,this->GetNumberOfItems()-1] is set to -1 (<=> no hit)
 
   if(result<-1 || result>=static_cast<vtkIdType>(this->GetNumberOfItems()))
-    {
+  {
     result=-1;
-    }
+  }
 
   assert("post: valid_result" && result>=-1 &&
          result<static_cast<vtkIdType>(this->GetNumberOfItems()));
@@ -431,31 +448,31 @@ bool vtkContextScene::MouseMoveEvent(const vtkContextMouseEvent &e)
   vtkAbstractContextItem* newItemPicked = this->GetPickedItem();
 #if 0
   if (newItemPicked)
-    {
+  {
     cerr << "picked a " << newItemPicked->GetClassName() << endl;
-    }
+  }
   else
-    {
+  {
     cerr << "picked nothing" << endl;
-    }
+  }
 #endif
   if (this->Storage->itemPicked.GetPointer() != newItemPicked)
-    {
+  {
     if (this->Storage->itemPicked.GetPointer())
-      {
+    {
       // Make sure last picked object is still part of this scene.
       if (this->Storage->itemPicked->GetScene() == this)
-        {
+      {
         vtkAbstractContextItem* cur = this->Storage->itemPicked;
         res = this->ProcessItem(cur, event, &vtkAbstractContextItem::MouseLeaveEvent) || res;
-        }
-      }
-    if (newItemPicked)
-      {
-      vtkAbstractContextItem* cur = newItemPicked;
-      res = this->ProcessItem(cur, event, &vtkAbstractContextItem::MouseEnterEvent) || res;
       }
     }
+    if (newItemPicked)
+    {
+      vtkAbstractContextItem* cur = newItemPicked;
+      res = this->ProcessItem(cur, event, &vtkAbstractContextItem::MouseEnterEvent) || res;
+    }
+  }
 
   this->Storage->itemPicked = newItemPicked;
 
@@ -464,15 +481,15 @@ bool vtkContextScene::MouseMoveEvent(const vtkContextMouseEvent &e)
   // Check if there is a selected item that needs to receive a move event
   if (this->Storage->itemMousePressCurrent.GetPointer() &&
       this->Storage->itemMousePressCurrent->GetScene() == this)
-    {
+  {
     vtkAbstractContextItem* cur = this->Storage->itemMousePressCurrent;
     res = this->ProcessItem(cur, event, &vtkAbstractContextItem::MouseMoveEvent) || res;
-    }
+  }
   else if (this->Storage->itemPicked.GetPointer())
-    {
+  {
     vtkAbstractContextItem* cur = this->Storage->itemPicked;
     res = this->ProcessItem(cur, event, &vtkAbstractContextItem::MouseMoveEvent) || res;
-    }
+  }
 
   // Update the last positions now
   event.SetLastScreenPos(event.GetScreenPos());
@@ -485,7 +502,7 @@ bool vtkContextScene::MouseMoveEvent(const vtkContextMouseEvent &e)
 bool vtkContextScene::ButtonPressEvent(const vtkContextMouseEvent &e)
 {
   switch (e.GetButton())
-    {
+  {
     case vtkContextMouseEvent::LEFT_BUTTON:
       this->InvokeEvent(vtkCommand::LeftButtonPressEvent);
       break;
@@ -497,7 +514,7 @@ bool vtkContextScene::ButtonPressEvent(const vtkContextMouseEvent &e)
       break;
     default:
       break;
-    }
+  }
 
   bool res = false;
   vtkContextMouseEvent &event = this->Storage->Event;
@@ -509,11 +526,11 @@ bool vtkContextScene::ButtonPressEvent(const vtkContextMouseEvent &e)
 
   vtkAbstractContextItem* newItemPicked = this->GetPickedItem();
   if (newItemPicked)
-    {
+  {
     vtkAbstractContextItem* cur = newItemPicked;
     res = this->ProcessItem(cur, event,
                             &vtkAbstractContextItem::MouseButtonPressEvent);
-    }
+  }
   this->Storage->itemMousePressCurrent = newItemPicked;
   return res;
 }
@@ -522,7 +539,7 @@ bool vtkContextScene::ButtonPressEvent(const vtkContextMouseEvent &e)
 bool vtkContextScene::ButtonReleaseEvent(const vtkContextMouseEvent &e)
 {
   switch (e.GetButton())
-    {
+  {
     case vtkContextMouseEvent::LEFT_BUTTON:
       this->InvokeEvent(vtkCommand::LeftButtonReleaseEvent);
       break;
@@ -534,11 +551,11 @@ bool vtkContextScene::ButtonReleaseEvent(const vtkContextMouseEvent &e)
       break;
     default:
       break;
-    }
+  }
 
   bool res = false;
   if (this->Storage->itemMousePressCurrent.GetPointer())
-    {
+  {
     vtkContextMouseEvent &event = this->Storage->Event;
     this->EventCopy(e);
     event.SetButton(e.GetButton());
@@ -546,7 +563,7 @@ bool vtkContextScene::ButtonReleaseEvent(const vtkContextMouseEvent &e)
     res = this->ProcessItem(cur, event,
                             &vtkAbstractContextItem::MouseButtonReleaseEvent);
     this->Storage->itemMousePressCurrent = NULL;
-    }
+  }
   this->Storage->Event.SetButton(vtkContextMouseEvent::NO_BUTTON);
   return res;
 }
@@ -564,11 +581,11 @@ bool vtkContextScene::DoubleClickEvent(const vtkContextMouseEvent &e)
 
   vtkAbstractContextItem* newItemPicked = this->GetPickedItem();
   if (newItemPicked)
-    {
+  {
     vtkAbstractContextItem* cur = newItemPicked;
     res = this->ProcessItem(cur, event,
                             &vtkAbstractContextItem::MouseDoubleClickEvent);
-    }
+  }
   return res;
 }
 
@@ -585,22 +602,22 @@ bool vtkContextScene::MouseWheelEvent(int delta,const vtkContextMouseEvent &e)
 
   vtkAbstractContextItem* newItemPicked = this->GetPickedItem();
   if (newItemPicked)
-    {
+  {
     vtkContextMouseEvent itemEvent = event;
     vtkAbstractContextItem* cur = newItemPicked;
     itemEvent.SetPos(cur->MapFromScene(event.GetPos()));
     itemEvent.SetLastPos(cur->MapFromScene(event.GetLastPos()));
     while (cur && !cur->MouseWheelEvent(itemEvent, delta))
-      {
+    {
       cur = cur->GetParent();
       if (cur)
-        {
+      {
         itemEvent.SetPos(cur->MapToParent(itemEvent.GetPos()));
         itemEvent.SetLastPos(cur->MapToParent(itemEvent.GetLastPos()));
-        }
       }
-    res = (cur != 0);
     }
+    res = (cur != 0);
+  }
   return res;
 }
 
@@ -611,9 +628,9 @@ bool vtkContextScene::KeyPressEvent(const vtkContextKeyEvent &keyEvent)
   event.SetScreenPos(keyEvent.GetPosition());
   vtkAbstractContextItem* newItemPicked = this->GetPickedItem();
   if (newItemPicked)
-    {
+  {
     return newItemPicked->KeyPressEvent(keyEvent);
-    }
+  }
   return false;
 }
 
@@ -624,9 +641,9 @@ bool vtkContextScene::KeyReleaseEvent(const vtkContextKeyEvent &keyEvent)
   event.SetScreenPos(keyEvent.GetPosition());
   vtkAbstractContextItem* newItemPicked = this->GetPickedItem();
   if (newItemPicked)
-    {
+  {
     return newItemPicked->KeyReleaseEvent(keyEvent);
-    }
+  }
   return false;
 }
 
@@ -640,14 +657,14 @@ inline bool vtkContextScene::ProcessItem(vtkAbstractContextItem* cur,
   itemEvent.SetPos(cur->MapFromScene(event.GetPos()));
   itemEvent.SetLastPos(cur->MapFromScene(event.GetLastPos()));
   while (cur && !(cur->*eventPtr)(itemEvent))
-    {
+  {
     cur = cur->GetParent();
     if (cur)
-      {
+    {
       itemEvent.SetPos(cur->MapToParent(itemEvent.GetPos()));
       itemEvent.SetLastPos(cur->MapToParent(itemEvent.GetLastPos()));
-      }
     }
+  }
   res = (cur != 0);
   return res;
 }
