@@ -43,44 +43,51 @@ float vtkGL2PSUtilities::LineWidthFactor = 5.f / 7.f;
 
 void vtkGL2PSUtilities::DrawString(const char *str,
                                    vtkTextProperty *tprop, double pos[3],
-                                   double backgroundDepth)
+                                   double)
 {
   if (!str)
-    {
+  {
     return;
-    }
+  }
 
   vtkTextRenderer *tren(vtkTextRenderer::GetInstance());
   if (tren == NULL)
-    {
+  {
     vtkNew<vtkGL2PSUtilities> dummy;
     vtkErrorWithObjectMacro(dummy.GetPointer(),
                             <<"vtkTextRenderer unavailable.");
     return;
-    }
+  }
+
+  int dpi = vtkGL2PSUtilities::RenderWindow->GetDPI();
 
   // Draw the background if needed:
   if (tprop->GetBackgroundOpacity() > 0.)
-    {
+  {
     vtkTextRenderer::Metrics metrics;
-    if (tren->GetMetrics(tprop, str, metrics))
-      {
-      double bgPos[3] = { pos[0], pos[1], backgroundDepth };
+    if (tren->GetMetrics(tprop, str, metrics, dpi))
+    {
+      double bgPos[4] = { pos[0], pos[1], pos[2], 1. };
       vtkGL2PSUtilities::ProjectPoint(bgPos);
+      bgPos[2] += 1e-6;
 
-      double bgVerts[12];
-      bgVerts[0] = bgPos[0] + static_cast<double>(metrics.TopLeft[0]);
-      bgVerts[1] = bgPos[1] + static_cast<double>(metrics.TopLeft[1]);
-      bgVerts[2] = bgPos[2];
-      bgVerts[3] = bgPos[0] + static_cast<double>(metrics.BottomLeft[0]);
-      bgVerts[4] = bgPos[1] + static_cast<double>(metrics.BottomLeft[1]);
-      bgVerts[5] = bgPos[2];
-      bgVerts[6] = bgPos[0] + static_cast<double>(metrics.BottomRight[0]);
-      bgVerts[7] = bgPos[1] + static_cast<double>(metrics.BottomRight[1]);
-      bgVerts[8] = bgPos[2];
-      bgVerts[9]  = bgPos[0] + static_cast<double>(metrics.TopRight[0]);
-      bgVerts[10] = bgPos[1] + static_cast<double>(metrics.TopRight[1]);
-      bgVerts[11] = bgPos[2];
+      double bgVerts[16];
+      bgVerts[0]  = bgPos[0] + static_cast<double>(metrics.TopLeft[0]);
+      bgVerts[1]  = bgPos[1] + static_cast<double>(metrics.TopLeft[1]);
+      bgVerts[2]  = bgPos[2];
+      bgVerts[3]  = bgPos[3];
+      bgVerts[4]  = bgPos[0] + static_cast<double>(metrics.BottomLeft[0]);
+      bgVerts[5]  = bgPos[1] + static_cast<double>(metrics.BottomLeft[1]);
+      bgVerts[6]  = bgPos[2];
+      bgVerts[7]  = bgPos[3];
+      bgVerts[8]  = bgPos[0] + static_cast<double>(metrics.BottomRight[0]);
+      bgVerts[9]  = bgPos[1] + static_cast<double>(metrics.BottomRight[1]);
+      bgVerts[10] = bgPos[2];
+      bgVerts[11] = bgPos[3];
+      bgVerts[12] = bgPos[0] + static_cast<double>(metrics.TopRight[0]);
+      bgVerts[13] = bgPos[1] + static_cast<double>(metrics.TopRight[1]);
+      bgVerts[14] = bgPos[2];
+      bgVerts[15] = bgPos[3];
 
       vtkGL2PSUtilities::UnprojectPoints(bgVerts, 4);
 
@@ -91,14 +98,14 @@ void vtkGL2PSUtilities::DrawString(const char *str,
                 tprop->GetBackgroundColor()[1],
                 tprop->GetBackgroundColor()[2],
                 tprop->GetBackgroundOpacity());
-      glVertexPointer(3, GL_DOUBLE, 0, bgVerts);
+      glVertexPointer(3, GL_DOUBLE, 4 * sizeof(double), bgVerts);
       glDrawArrays(GL_TRIANGLE_FAN, 0, 4);
-      }
     }
+  }
 
   bool isMath = tren->DetectBackend(str) == vtkTextRenderer::MathText;
   if (!isMath && !vtkGL2PSUtilities::TextAsPath)
-    {
+  {
     const char *fontname = vtkGL2PSUtilities::TextPropertyToPSFontName(tprop);
 
     GLint align = static_cast<GLint>(
@@ -106,7 +113,8 @@ void vtkGL2PSUtilities::DrawString(const char *str,
 
     GLfloat angle = static_cast<GLfloat>(tprop->GetOrientation());
 
-    GLint fontSize = static_cast<GLint>(tprop->GetFontSize());
+    // GL2PS assumes 72 DPI, so we'll have to adjust the font size:
+    GLint fontSize = static_cast<GLint>(tprop->GetFontSize() * (dpi / 72.));
 
     GL2PSrgba rgba;
     double rgbad[3];
@@ -118,12 +126,12 @@ void vtkGL2PSUtilities::DrawString(const char *str,
 
     glRasterPos3dv(pos);
     gl2psTextOptColor(str, fontname, fontSize, align, angle, rgba);
-    }
+  }
   else
-    {
+  {
     // Render the string to a path and then draw it to GL2PS:
     vtkNew<vtkPath> path;
-    tren->StringToPath(tprop, str, path.GetPointer());
+    tren->StringToPath(tprop, str, path.GetPointer(), dpi);
     // Get color
     double rgbd[3];
     tprop->GetColor(rgbd[0], rgbd[1], rgbd[2]);
@@ -133,13 +141,13 @@ void vtkGL2PSUtilities::DrawString(const char *str,
       static_cast<unsigned char>(rgbd[2]*255),
       static_cast<unsigned char>(tprop->GetOpacity()*255)};
 
-    double devicePos[3] = {pos[0], pos[1], pos[2]};
+    double devicePos[4] = { pos[0], pos[1], pos[2], 1. };
     vtkGL2PSUtilities::ProjectPoint(devicePos);
 
     vtkGL2PSUtilities::DrawPath(path.GetPointer(), pos, devicePos, rgba, NULL,
                                 0.0, -1.f, (std::string("Pathified string: ")
                                             + str).c_str());
-    }
+  }
 }
 
 const char *vtkGL2PSUtilities::TextPropertyToPSFontName(vtkTextProperty *tprop)
@@ -148,71 +156,71 @@ const char *vtkGL2PSUtilities::TextPropertyToPSFontName(vtkTextProperty *tprop)
   bool italic = tprop->GetItalic() != 0;
 
   switch (tprop->GetFontFamily())
-    {
+  {
     case VTK_ARIAL:
-      {
+    {
       if (!bold && !italic)
-        {
+      {
         return "Helvetica";
-        }
-      else if (bold && italic)
-        {
-        return "Helvetica-BoldItalic";
-        }
-      else if (bold)
-        {
-        return "Helvetica-Bold";
-        }
-      else if (italic)
-        {
-        return "Helvetica-Italic";
-        }
       }
+      else if (bold && italic)
+      {
+        return "Helvetica-BoldItalic";
+      }
+      else if (bold)
+      {
+        return "Helvetica-Bold";
+      }
+      else if (italic)
+      {
+        return "Helvetica-Italic";
+      }
+    }
       break;
     case VTK_TIMES:
-      {
+    {
       if (!bold && !italic)
-        {
+      {
         return "Times-Roman";
-        }
-      else if (bold && italic)
-        {
-        return "Times-BoldOblique";
-        }
-      else if (bold)
-        {
-        return "Times-Bold";
-        }
-      else if (italic)
-        {
-        return "Times-Oblique";
-        }
       }
+      else if (bold && italic)
+      {
+        return "Times-BoldOblique";
+      }
+      else if (bold)
+      {
+        return "Times-Bold";
+      }
+      else if (italic)
+      {
+        return "Times-Oblique";
+      }
+    }
       break;
     case VTK_COURIER:
-      {
+    {
       if (!bold && !italic)
-        {
+      {
         return "Courier";
-        }
-      else if (bold && italic)
-        {
-        return "Courier-BoldOblique";
-        }
-      else if (bold)
-        {
-        return "Courier-Bold";
-        }
-      else if (italic)
-        {
-        return "Courier-Oblique";
-        }
       }
+      else if (bold && italic)
+      {
+        return "Courier-BoldOblique";
+      }
+      else if (bold)
+      {
+        return "Courier-Bold";
+      }
+      else if (italic)
+      {
+        return "Courier-Oblique";
+      }
+    }
       break;
     case VTK_UNKNOWN_FONT:
     default:
       break;
-    }
+  }
 
   return "Helvetica";
 }
@@ -220,60 +228,60 @@ const char *vtkGL2PSUtilities::TextPropertyToPSFontName(vtkTextProperty *tprop)
 int vtkGL2PSUtilities::TextPropertyToGL2PSAlignment(vtkTextProperty *tprop)
 {
   switch (tprop->GetJustification())
-    {
+  {
     case VTK_TEXT_LEFT:
       switch (tprop->GetVerticalJustification())
-        {
+      {
         case VTK_TEXT_TOP:
-          {
+        {
           return GL2PS_TEXT_TL;
-          }
-        case VTK_TEXT_CENTERED:
-          {
-          return GL2PS_TEXT_CL;
-          }
-        case VTK_TEXT_BOTTOM:
-          {
-          return GL2PS_TEXT_BL;
-          }
         }
+        case VTK_TEXT_CENTERED:
+        {
+          return GL2PS_TEXT_CL;
+        }
+        case VTK_TEXT_BOTTOM:
+        {
+          return GL2PS_TEXT_BL;
+        }
+      }
       break;
     case VTK_TEXT_CENTERED:
       switch (tprop->GetVerticalJustification())
-        {
+      {
         case VTK_TEXT_TOP:
-          {
+        {
           return GL2PS_TEXT_T;
-          }
-        case VTK_TEXT_CENTERED:
-          {
-          return GL2PS_TEXT_C;
-          }
-        case VTK_TEXT_BOTTOM:
-          {
-          return GL2PS_TEXT_B;
-          }
         }
+        case VTK_TEXT_CENTERED:
+        {
+          return GL2PS_TEXT_C;
+        }
+        case VTK_TEXT_BOTTOM:
+        {
+          return GL2PS_TEXT_B;
+        }
+      }
       break;
     case VTK_TEXT_RIGHT:
       switch (tprop->GetVerticalJustification())
-        {
+      {
         case VTK_TEXT_TOP:
-          {
+        {
           return GL2PS_TEXT_TR;
-          }
-        case VTK_TEXT_CENTERED:
-          {
-          return GL2PS_TEXT_CR;
-          }
-        case VTK_TEXT_BOTTOM:
-          {
-          return GL2PS_TEXT_BR;
-          }
         }
+        case VTK_TEXT_CENTERED:
+        {
+          return GL2PS_TEXT_CR;
+        }
+        case VTK_TEXT_BOTTOM:
+        {
+          return GL2PS_TEXT_BR;
+        }
+      }
     default:
       break;
-    }
+  }
 
   return GL2PS_TEXT_BL;
 }
@@ -301,12 +309,12 @@ void vtkGL2PSUtilities::DrawPath(vtkPath *path, double rasterPos[3],
   std::string l(label ? label : "");
   size_t idx = 0;
   while ((idx = l.find('\n', idx)) != std::string::npos)
-    {
+  {
     l.replace(idx, 1, "\\n");
-    }
+  }
 
   switch (gl2psGetFileFormat())
-    {
+  {
     case GL2PS_PS:
     case GL2PS_EPS:
       vtkGL2PSUtilities::DrawPathPS(path, rasterPos, windowPos, rgba, scale,
@@ -322,7 +330,7 @@ void vtkGL2PSUtilities::DrawPath(vtkPath *path, double rasterPos[3],
       break;
     default:
       break;
-    }
+  }
 }
 
 void vtkGL2PSUtilities::StartExport()
@@ -359,13 +367,13 @@ void vtkGL2PSUtilities::DrawPathPS(vtkPath *path, double rasterPos[3],
                                    float strokeWidth, const char *label)
 {
   vtkFloatArray *points =
-      vtkFloatArray::SafeDownCast(path->GetPoints()->GetData());
+      vtkArrayDownCast<vtkFloatArray>(path->GetPoints()->GetData());
   vtkIntArray *codes = path->GetCodes();
 
   if (points->GetNumberOfTuples() != codes->GetNumberOfTuples())
-    {
+  {
     return;
-    }
+  }
 
   std::stringstream out;
   out.setf(std::ios_base::left | std::ios_base::fixed);
@@ -389,24 +397,24 @@ void vtkGL2PSUtilities::DrawPathPS(vtkPath *path, double rasterPos[3],
 #endif
   int *codeEnd = code + codes->GetNumberOfTuples();
   if (label != NULL && label[0] != '\0')
-    {
+  {
     out << "% " << label << endl;
-    }
+  }
   out << "gsave" << endl;
   out << "initmatrix" << endl;
   out << windowPos[0] << " " << windowPos[1] << " translate" << endl;
   if (scale)
-    {
+  {
     out << scale[0] << " " << scale[1] << " scale" << endl;
-    }
+  }
   out << rotateAngle << " rotate" << endl;
   out << "newpath" << endl;
   while (code < codeEnd)
-    {
+  {
     assert(pt - ptBegin == (code - codeBegin) * 3);
 
     switch (static_cast<vtkPath::ControlPointType>(*code))
-      {
+    {
       case vtkPath::MOVE_TO:
         curX = *pt;
         curY = *(++pt);
@@ -421,7 +429,7 @@ void vtkGL2PSUtilities::DrawPathPS(vtkPath *path, double rasterPos[3],
         break;
       case vtkPath::CONIC_CURVE:
         // Postscript doesn't support conic curves -- elevate order to cubic:
-        {
+      {
         // Next point should be a CONIC_CURVE as well
         code += 1;
         const float &conicX = *pt;
@@ -441,10 +449,10 @@ void vtkGL2PSUtilities::DrawPathPS(vtkPath *path, double rasterPos[3],
         out << curveto[0][0] << " " << curveto[0][1] << endl
             << curveto[1][0] << " " << curveto[1][1] << endl
             << curveto[2][0] << " " << curveto[2][1] << " curveto" << endl;
-        }
+      }
         break;
       case vtkPath::CUBIC_CURVE:
-        {
+      {
         // Next two points should be CUBIC_CURVEs as well
         code += 2;
 
@@ -460,30 +468,30 @@ void vtkGL2PSUtilities::DrawPathPS(vtkPath *path, double rasterPos[3],
         out << curveto[0][0] << " " << curveto[0][1] << endl
             << curveto[1][0] << " " << curveto[1][1] << endl
             << curveto[2][0] << " " << curveto[2][1] << " curveto" << endl;
-        }
+      }
         break;
       default:
         out << "% Unrecognized control code: " << *code << endl;
         pt +=2;
         break;
-      }
+    }
 
     ++code;
     ++pt;
-    }
+  }
 
   out << static_cast<float>(rgba[0])/255.f << " " <<
          static_cast<float>(rgba[1])/255.f << " " <<
          static_cast<float>(rgba[2])/255.f << " setrgbcolor" << endl;
 
   if (strokeWidth > 1e-5)
-    {
+  {
     out << strokeWidth << " setlinewidth\nstroke" << endl;
-    }
+  }
   else
-    {
+  {
     out << "fill" << endl;
-    }
+  }
   out << "grestore" << endl;
 
   glRasterPos3dv(rasterPos);
@@ -497,13 +505,13 @@ void vtkGL2PSUtilities::DrawPathPDF(vtkPath *path, double rasterPos[3],
                                     const char *)
 {
   vtkFloatArray *points =
-      vtkFloatArray::SafeDownCast(path->GetPoints()->GetData());
+      vtkArrayDownCast<vtkFloatArray>(path->GetPoints()->GetData());
   vtkIntArray *codes = path->GetCodes();
 
   if (points->GetNumberOfTuples() != codes->GetNumberOfTuples())
-    {
+  {
     return;
-    }
+  }
 
   std::stringstream out;
   out.setf(std::ios_base::left | std::ios_base::fixed);
@@ -548,17 +556,17 @@ void vtkGL2PSUtilities::DrawPathPDF(vtkPath *path, double rasterPos[3],
       << " cm" << endl;
   // scale
   if (scale)
-    {
+  {
     out << scale[0] << " " << 0.f << " " << 0.f << " " << scale[1] << " " << 0.f
         << " " << 0.f << " cm" << endl;
-    }
+  }
 
   while (code < codeEnd)
-    {
+  {
     assert(pt - ptBegin == (code - codeBegin) * 3);
 
     switch (static_cast<vtkPath::ControlPointType>(*code))
-      {
+    {
       case vtkPath::MOVE_TO:
         curX = *pt;
         curY = *(++pt);
@@ -573,7 +581,7 @@ void vtkGL2PSUtilities::DrawPathPDF(vtkPath *path, double rasterPos[3],
         break;
       case vtkPath::CONIC_CURVE:
         // Postscript doesn't support conic curves -- elevate order to cubic:
-        {
+      {
         // Next point should be a CONIC_CURVE as well
         code += 1;
         const float &conicX = *pt;
@@ -593,10 +601,10 @@ void vtkGL2PSUtilities::DrawPathPDF(vtkPath *path, double rasterPos[3],
         out << curveto[0][0] << " " << curveto[0][1] << endl
             << curveto[1][0] << " " << curveto[1][1] << endl
             << curveto[2][0] << " " << curveto[2][1] << " c" << endl;
-        }
+      }
         break;
       case vtkPath::CUBIC_CURVE:
-        {
+      {
         // Next two points should be CUBIC_CURVEs as well
         code += 2;
 
@@ -612,27 +620,27 @@ void vtkGL2PSUtilities::DrawPathPDF(vtkPath *path, double rasterPos[3],
         out << curveto[0][0] << " " << curveto[0][1] << endl
             << curveto[1][0] << " " << curveto[1][1] << endl
             << curveto[2][0] << " " << curveto[2][1] << " c" << endl;
-        }
+      }
         break;
       default:
         out << "% Unrecognized control code: " << *code << endl;
         pt +=2;
         break;
-      }
+    }
 
     ++code;
     ++pt;
-    }
+  }
 
   out << "h ";
   if (strokeWidth > 1e-5)
-    {
+  {
     out << strokeWidth << " w S" << endl;
-    }
+  }
   else
-    {
+  {
     out<< "f" << endl;
-    }
+  }
   out << "Q" << endl; // Pop state
 
   glRasterPos3dv(rasterPos);
@@ -645,13 +653,13 @@ void vtkGL2PSUtilities::DrawPathSVG(vtkPath *path, double rasterPos[3],
                                     float strokeWidth, const char *label)
 {
   vtkFloatArray *points =
-      vtkFloatArray::SafeDownCast(path->GetPoints()->GetData());
+      vtkArrayDownCast<vtkFloatArray>(path->GetPoints()->GetData());
   vtkIntArray *codes = path->GetCodes();
 
   if (points->GetNumberOfTuples() != codes->GetNumberOfTuples())
-    {
+  {
     return;
-    }
+  }
 
   std::stringstream out;
   out.setf(std::ios_base::left | std::ios_base::fixed);
@@ -670,11 +678,11 @@ void vtkGL2PSUtilities::DrawPathSVG(vtkPath *path, double rasterPos[3],
 
   // Get the size of the render window -- needed to calculate the SVG position.
   if (!vtkGL2PSUtilities::RenderWindow)
-    {
+  {
     vtkNew<vtkGL2PSUtilities> dummy;
     vtkErrorWithObjectMacro(dummy.GetPointer(), << "No render window set!");
     return;
-    }
+  }
   double windowHeight =
       static_cast<double>(vtkGL2PSUtilities::RenderWindow->GetSize()[1]);
 
@@ -686,25 +694,25 @@ void vtkGL2PSUtilities::DrawPathSVG(vtkPath *path, double rasterPos[3],
 #endif
 
   if (label != NULL && label[0] != '\0')
-    {
+  {
     out << "<!-- " << label << " -->" << endl;
-    }
+  }
 
   int *codeEnd = code + codes->GetNumberOfTuples();
   out << "<g transform=\"" << endl
       << "     translate(" << windowPos[0] << " "
       << windowHeight - windowPos[1] << ")" << endl;
   if (scale)
-    {
+  {
     out << "     scale(" << scale[0] << " " << -scale[1] << ")" << endl;
-    }
+  }
   else
-    {
+  {
     out << "     scale(1.0 -1.0)" << endl;
-    }
+  }
   out << "     rotate(" << rotateAngle << ")\"" << endl;
   if (strokeWidth > 1e-5)
-    {
+  {
     out << "   fill=\"none\"" << endl
         << "   stroke-width=\"" << strokeWidth << "\"" << endl
         << "   stroke=\"rgb(" << std::setprecision(0)
@@ -712,26 +720,26 @@ void vtkGL2PSUtilities::DrawPathSVG(vtkPath *path, double rasterPos[3],
         << static_cast<int>(rgba[1]) << ","
         << static_cast<int>(rgba[2])
         << std::setprecision(floatPrec) << ")\"" << endl;
-    }
+  }
   else
-    {
+  {
     out << "   stroke=\"none\"" << endl
         << "   fill=\"rgb(" << std::setprecision(0)
              << static_cast<int>(rgba[0]) << ","
              << static_cast<int>(rgba[1]) << ","
              << static_cast<int>(rgba[2])
              << std::setprecision(floatPrec) << ")\"" << endl;
-    }
+  }
     out << "   opacity=\"" << static_cast<float>(rgba[3])/255.f << "\"\n"
       << ">" << endl
       << "  <path d=\"" << std::right << endl;
 
   while (code < codeEnd)
-    {
+  {
     assert(pt - ptBegin == (code - codeBegin) * 3);
 
     switch (static_cast<vtkPath::ControlPointType>(*code))
-      {
+    {
       case vtkPath::MOVE_TO:
         curX = *pt;
         curY = *(++pt);
@@ -745,7 +753,7 @@ void vtkGL2PSUtilities::DrawPathSVG(vtkPath *path, double rasterPos[3],
         out << "    L " << curX << " " << curY << endl;
         break;
       case vtkPath::CONIC_CURVE:
-        {
+      {
         // Next point should be a CONIC_CURVE as well
         code += 1;
         const float &conicX = *pt;
@@ -762,10 +770,10 @@ void vtkGL2PSUtilities::DrawPathSVG(vtkPath *path, double rasterPos[3],
         curveto[1][1] = curY = nextY;
         out << "    Q " << curveto[0][0] << " " << curveto[0][1] << endl
             << "      " << curveto[1][0] << " " << curveto[1][1] << endl;
-        }
+      }
         break;
       case vtkPath::CUBIC_CURVE:
-        {
+      {
         // Next two points should be CUBIC_CURVEs as well
         code += 2;
 
@@ -781,17 +789,17 @@ void vtkGL2PSUtilities::DrawPathSVG(vtkPath *path, double rasterPos[3],
         out << "    C " << curveto[0][0] << " " << curveto[0][1] << endl
             << "      " << curveto[1][0] << " " << curveto[1][1] << endl
             << "      " << curveto[2][0] << " " << curveto[2][1] << endl;
-        }
+      }
         break;
       default:
         out << "<!-- Unrecognized control code: " << *code << " -->" << endl;
         pt +=2;
         break;
-      }
+    }
 
     ++code;
     ++pt;
-    }
+  }
 
   out << "    \" />" << endl
       << "</g>" << endl;
@@ -801,7 +809,7 @@ void vtkGL2PSUtilities::DrawPathSVG(vtkPath *path, double rasterPos[3],
 }
 
 
-inline void vtkGL2PSUtilities::ProjectPoint(double point[3],
+inline void vtkGL2PSUtilities::ProjectPoint(double point[4],
                                             vtkMatrix4x4 *actorMatrix)
 {
   // Build transformation matrix
@@ -821,11 +829,11 @@ inline void vtkGL2PSUtilities::ProjectPoint(double point[3],
                             modelviewMatrix.GetPointer(),
                             transformMatrix.GetPointer());
   if (actorMatrix)
-    {
+  {
     vtkMatrix4x4::Multiply4x4(transformMatrix.GetPointer(),
                               actorMatrix,
                               transformMatrix.GetPointer());
-    }
+  }
 
   double viewport[4];
   glGetDoublev(GL_VIEWPORT, viewport);
@@ -837,12 +845,8 @@ inline void vtkGL2PSUtilities::ProjectPoint(double point[3],
   const double zFactor1 = (depthRange[1] - depthRange[0]) * 0.5;
   const double zFactor2 = (depthRange[1] + depthRange[0]) * 0.5;
 
-  double tmp[4] = {point[0], point[1], point[2], 1.0};
-  vtkGL2PSUtilities::ProjectPoint(tmp, transformMatrix.GetPointer(), viewport,
+  vtkGL2PSUtilities::ProjectPoint(point, transformMatrix.GetPointer(), viewport,
                                   halfWidth, halfHeight, zFactor1, zFactor2);
-  point[0] = tmp[0];
-  point[1] = tmp[1];
-  point[2] = tmp[2];
 }
 
 inline void vtkGL2PSUtilities::ProjectPoint(double point[4],
@@ -885,11 +889,11 @@ inline void vtkGL2PSUtilities::ProjectPoints(vtkPoints *points,
                             modelviewMatrix.GetPointer(),
                             transformMatrix.GetPointer());
   if (actorMatrix)
-    {
+  {
     vtkMatrix4x4::Multiply4x4(transformMatrix.GetPointer(),
                               actorMatrix,
                               transformMatrix.GetPointer());
-    }
+  }
 
   double viewport[4];
   glGetDoublev(GL_VIEWPORT, viewport);
@@ -903,14 +907,14 @@ inline void vtkGL2PSUtilities::ProjectPoints(vtkPoints *points,
 
   double point[4];
   for (vtkIdType i = 0; i < points->GetNumberOfPoints(); ++i)
-    {
+  {
     points->GetPoint(i, point);
     point[3] = 1.0;
     vtkGL2PSUtilities::ProjectPoint(point, transformMatrix.GetPointer(),
                                     viewport, halfWidth, halfHeight, zFactor1,
                                     zFactor2);
     points->SetPoint(i, point);
-    }
+  }
 }
 
 void vtkGL2PSUtilities::UnprojectPoint(double point[4],
@@ -950,11 +954,11 @@ void vtkGL2PSUtilities::UnprojectPoints(double *points3D, vtkIdType numPoints,
                             modelviewMatrix.GetPointer(),
                             transformMatrix.GetPointer());
   if (actorMatrix)
-    {
+  {
     vtkMatrix4x4::Multiply4x4(transformMatrix.GetPointer(),
                               actorMatrix,
                               transformMatrix.GetPointer());
-    }
+  }
 
   transformMatrix->Invert();
 
@@ -968,14 +972,11 @@ void vtkGL2PSUtilities::UnprojectPoints(double *points3D, vtkIdType numPoints,
   const double zFactor1 = (depthRange[1] - depthRange[0]) * 0.5;
   const double zFactor2 = (depthRange[1] + depthRange[0]) * 0.5;
 
-  double point[4];
   for (vtkIdType i = 0; i < numPoints; ++i)
-    {
-    std::copy(points3D + (i * 3), points3D + ((i + 1) * 3), point);
-    point[3] = 1.0;
+  {
+    double *point = points3D + (i * 4);
     vtkGL2PSUtilities::UnprojectPoint(point, transformMatrix.GetPointer(),
                                       viewport, halfWidth, halfHeight, zFactor1,
                                       zFactor2);
-    std::copy(point, point + 3, points3D + (i * 3));
-    }
+  }
 }
