@@ -81,10 +81,10 @@ vtkLabeledTreeMapDataMapper::vtkLabeledTreeMapDataMapper()
   // This class will manage the maintenance and deletion of
   // this array.
   for (int i = 0; i < this->NumberOfLabelsAllocated; i++)
-    {
+  {
     this->TextMappers[i]->Delete();
     this->TextMappers[i] = NULL;
-    }
+  }
 }
 
 vtkLabeledTreeMapDataMapper::~vtkLabeledTreeMapDataMapper()
@@ -95,27 +95,27 @@ vtkLabeledTreeMapDataMapper::~vtkLabeledTreeMapDataMapper()
   this->VerticalLabelProperty->Delete();
   int i;
   for (i = 0; i <= this->MaxFontLevel; i++)
-    {
+  {
     delete [] this->FontWidths[i];
     this->HLabelProperties[i]->Delete();
-    }
+  }
   delete [] this->FontWidths;
   delete [] this->FontHeights;
   delete [] this->HLabelProperties;
   delete [] this->ChildrenCount;
   delete [] this->LabelMasks;
   if (this->TextMappers)
-    {
+  {
     for (i=0; i < this->NumberOfLabelsAllocated; i++)
-      {
+    {
       if (this->TextMappers[i])
-        {
+      {
         this->TextMappers[i]->Delete();
-        }
       }
+    }
     delete [] this->TextMappers;
     this->TextMappers = NULL;
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -129,15 +129,15 @@ void vtkLabeledTreeMapDataMapper::SetRectanglesArrayName(const char* name)
 void vtkLabeledTreeMapDataMapper::ReleaseGraphicsResources(vtkWindow *win)
 {
   if (this->TextMappers != NULL )
-    {
+  {
     for (int i=0; i < this->NumberOfLabelsAllocated; i++)
-      {
+    {
       if (this->TextMappers[i])
-        {
+      {
         this->TextMappers[i]->ReleaseGraphicsResources(win);
-        }
       }
     }
+  }
 }
 
 vtkTree *vtkLabeledTreeMapDataMapper::GetInputTree()
@@ -152,26 +152,26 @@ void vtkLabeledTreeMapDataMapper::UpdateFontSizes()
   int tSize[2], i;
   // Make sure that there is a text mapper at index 0
   if (!this->TextMappers[0])
-    {
+  {
     this->TextMappers[0] = vtkTextMapper::New();
     this->NumberOfLabels = 1;
-    }
+  }
 
   for (i = 0; i <= this->MaxFontLevel; i++)
-    {
+  {
     this->TextMappers[0]->SetTextProperty(this->HLabelProperties[i]);
     this->FontHeights[i] = 0;
     for (test[0] = 32; test[0] < 127; test[0]++)
-      {
+    {
       this->TextMappers[0]->SetInput(test);
       this->TextMappers[0]->GetSize(this->CurrentViewPort, tSize);
       this->FontWidths[i][test[0]-32] = tSize[0];
       if (this->FontHeights[i] < tSize[1])
-        {
+      {
         this->FontHeights[i] = tSize[1];
-        }
       }
     }
+  }
 }
 
 void vtkLabeledTreeMapDataMapper::PrintSelf(ostream& os, vtkIndent indent)
@@ -183,9 +183,9 @@ void vtkLabeledTreeMapDataMapper::PrintSelf(ostream& os, vtkIndent indent)
   int i;
   os << "Font Sizes: ";
   for (i = 0; i <= this->MaxFontLevel; i++)
-    {
+  {
     os << this->HLabelProperties[i]->GetFontSize() << " ";
-    }
+  }
   os << endl;
 
   os << indent << "Level Range: [" << this->StartLevel
@@ -244,55 +244,55 @@ void vtkLabeledTreeMapDataMapper::GetVertexLabel(vtkIdType vertex,
   double val;
   int j;
   if ( numericData )
-    {
+  {
     if ( numComp == 1 )
-      {
+    {
       if (numericData->GetDataType() == VTK_CHAR)
-        {
+      {
         if (strcmp(this->LabelFormat,"%c") != 0)
-          {
+        {
           vtkErrorMacro(<<"Label format must be %c to use with char");
           string[0] = '\0';
           return;
-          }
+        }
         sprintf(string, this->LabelFormat,
                 static_cast<char>(numericData->GetComponent(vertex, activeComp)));
-        }
+      }
       else
-        {
+      {
         sprintf(string, this->LabelFormat,
                 numericData->GetComponent(vertex, activeComp));
-        }
       }
+    }
     else
-      {
+    {
       strcpy(format, "("); strcat(format, this->LabelFormat);
       for (j=0; j<(numComp-1); j++)
-        {
+      {
         sprintf(string, format, numericData->GetComponent(vertex, j));
         strcpy(format,string); strcat(format,", ");
         strcat(format, this->LabelFormat);
-        }
+      }
       sprintf(string, format, numericData->GetComponent(vertex, numComp-1));
       strcat(string, ")");
-      }
     }
+  }
   else if (stringData)// rendering string data
-    {
+  {
     if (strcmp(this->LabelFormat,"%s") != 0)
-      {
+    {
       vtkErrorMacro(<<"Label format must be %s to use with strings");
       string[0] = '\0';
       return;
-      }
+    }
     sprintf(string, this->LabelFormat,
             stringData->GetValue(vertex).c_str());
-    }
+  }
   else // Use the vertex id
-    {
+  {
     val = static_cast<double>(vertex);
     sprintf(string, this->LabelFormat, val);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -302,12 +302,12 @@ void vtkLabeledTreeMapDataMapper::RenderOverlay(vtkViewport *viewport,
   int i;
   double x[3];
   for (i=0; i<this->NumberOfLabels; i++)
-    {
+  {
     this->TextPoints->GetPoint(i,x);
     actor->GetPositionCoordinate()->SetCoordinateSystemToWorld();
     actor->GetPositionCoordinate()->SetValue(x);
     this->TextMappers[i]->RenderOverlay(viewport, actor);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -322,17 +322,17 @@ void vtkLabeledTreeMapDataMapper::RenderOpaqueGeometry(vtkViewport *viewport,
   vtkStringArray *stringData;
   vtkTree *input=this->GetInputTree();
   if ( ! input )
-    {
+  {
     vtkErrorMacro(<<"Need input tree to render labels (2)");
     return;
-    }
+  }
 
   vtkTextProperty *tprop = this->GetLabelTextProperty();
   if (!tprop)
-    {
+  {
     vtkErrorMacro(<<"Need text property to render labels");
     return;
-    }
+  }
 
   this->GetInputAlgorithm()->Update();
 
@@ -342,11 +342,11 @@ void vtkLabeledTreeMapDataMapper::RenderOpaqueGeometry(vtkViewport *viewport,
   // Get the treeMap info
   tempData = this->GetInputArrayToProcess(0, input);
   if (!tempData)
-    {
+  {
     vtkErrorMacro(<< "Input Tree does not have box information.");
     return;
-    }
-  vtkFloatArray *boxInfo = vtkFloatArray::SafeDownCast(tempData);
+  }
+  vtkFloatArray *boxInfo = vtkArrayDownCast<vtkFloatArray>(tempData);
 
   // Check to see whether we have to rebuild everything
   if ( this->UpdateWindowInfo(viewport) ||
@@ -354,15 +354,15 @@ void vtkLabeledTreeMapDataMapper::RenderOpaqueGeometry(vtkViewport *viewport,
        this->GetMTime() > this->BuildTime ||
        input->GetMTime() > this->BuildTime ||
        tprop->GetMTime() > this->BuildTime)
-    {
+  {
     vtkDebugMacro(<<"Rebuilding labels");
 
     // See if we have to recalculate fonts sizes
     if (this->CurrentViewPort != viewport)
-      {
+    {
       this->CurrentViewPort = viewport;
       this->UpdateFontSizes();
-      }
+    }
 
     // figure out what to label, and if we can label it
     pointIdLabels = 0;
@@ -370,79 +370,79 @@ void vtkLabeledTreeMapDataMapper::RenderOpaqueGeometry(vtkViewport *viewport,
     numericData = NULL;
     stringData = NULL;
     switch (this->LabelMode)
-      {
+    {
       case VTK_LABEL_IDS:
         pointIdLabels = 1;
         break;
       case VTK_LABEL_SCALARS:
         if ( pd->GetScalars() )
-          {
+        {
           numericData = pd->GetScalars();
-          }
+        }
         break;
       case VTK_LABEL_VECTORS:
         if ( pd->GetVectors() )
-          {
+        {
           numericData = pd->GetVectors();
-          }
+        }
         break;
       case VTK_LABEL_NORMALS:
         if ( pd->GetNormals() )
-          {
+        {
           numericData = pd->GetNormals();
-          }
+        }
         break;
       case VTK_LABEL_TCOORDS:
         if ( pd->GetTCoords() )
-          {
+        {
           numericData = pd->GetTCoords();
-          }
+        }
         break;
       case VTK_LABEL_TENSORS:
         if ( pd->GetTensors() )
-          {
+        {
           numericData = pd->GetTensors();
-          }
+        }
         break;
       case VTK_LABEL_FIELD_DATA:
       {
       int arrayNum;
       if (this->FieldDataName != NULL)
-        {
+      {
         abstractData = pd->GetAbstractArray(this->FieldDataName, arrayNum);
-        }
+      }
       else
-        {
+      {
         arrayNum = (this->FieldDataArray < pd->GetNumberOfArrays() ?
                     this->FieldDataArray : pd->GetNumberOfArrays() - 1);
         abstractData = pd->GetAbstractArray(arrayNum);
-        }
-      numericData = vtkDataArray::SafeDownCast(abstractData);
-      stringData = vtkStringArray::SafeDownCast(abstractData);
-      }; break;
       }
+      numericData = vtkArrayDownCast<vtkDataArray>(abstractData);
+      stringData = vtkArrayDownCast<vtkStringArray>(abstractData);
+      }; break;
+    }
 
     // determine number of components and check input
     if ( pointIdLabels )
-      {
+    {
       ;
-      }
+    }
     else if ( numericData )
-      {
+    {
       numComp = numericData->GetNumberOfComponents();
       activeComp = 0;
       if ( this->LabeledComponent >= 0 )
-        {
+      {
         activeComp = (this->LabeledComponent < numComp ?
                       this->LabeledComponent : numComp - 1);
         numComp = 1;
-        }
       }
+    }
     else if ( !stringData )
-      {
+    {
       vtkErrorMacro(<<"Need input data to render labels (3)");
       return;
-      }
+    }
 
     // Make sure that the array of TextMappers can accommodate
     // the number of vertices in the tree - Note that we may
@@ -450,15 +450,15 @@ void vtkLabeledTreeMapDataMapper::RenderOpaqueGeometry(vtkViewport *viewport,
 
     numVertices = input->GetNumberOfVertices();
     if ( numVertices > this->NumberOfLabelsAllocated )
-      {
+    {
       // delete old stuff
       for (i=0; i < this->NumberOfLabelsAllocated; i++)
-        {
+      {
           if (this->TextMappers[i])
           {
           this->TextMappers[i]->Delete();
           }
-        }
+      }
       delete [] this->TextMappers;
 
       this->NumberOfLabelsAllocated = numVertices;
@@ -466,23 +466,23 @@ void vtkLabeledTreeMapDataMapper::RenderOpaqueGeometry(vtkViewport *viewport,
       this->VertexList->SetNumberOfIds(numVertices);
       this->TextPoints->Allocate(numVertices);
       for (i = 0; i < numVertices; i++)
-        {
+      {
         this->TextMappers[i] = 0;
-        }
       }
+    }
 
     this->LabelTree(input, boxInfo, numericData, stringData,
                     activeComp, numComp);
-    }
+  }
 
 
   for (i=0; i<this->NumberOfLabels; i++)
-    {
+  {
     this->TextPoints->GetPoint(i,x);
     actor->GetPositionCoordinate()->SetCoordinateSystemToWorld();
     actor->GetPositionCoordinate()->SetValue(x);
     this->TextMappers[i]->RenderOpaqueGeometry(viewport, actor);
-    }
+  }
 }
 
 void vtkLabeledTreeMapDataMapper::LabelTree(vtkTree *tree,
@@ -499,66 +499,66 @@ void vtkLabeledTreeMapDataMapper::LabelTree(vtkTree *tree,
   vtkTextProperty *tprop = NULL;
   vtkIdType vertex, level, root = tree->GetRoot();
   if (root < 0)
-    {
+  {
     vtkErrorMacro(<< "Input Tree does not have a root.");
     return;
-    }
+  }
 
   this->NumberOfLabels = 0;
   vtkTreeDFSIterator* dfs = vtkTreeDFSIterator::New();
   dfs->SetTree(tree);
   while (dfs->HasNext())
-    {
+  {
     // Are we suppose to display this vertex?
     vertex = dfs->Next();
     level = tree->GetLevel(vertex);
 
     if (level >= this->StartLevel && (this->EndLevel == -1 || level <= this->EndLevel))
-      {
-      boxInfo->GetTupleValue(vertex, blimits); // Get the extents of the vertex
+    {
+      boxInfo->GetTypedTuple(vertex, blimits); // Get the extents of the vertex
       if (this->ConvertToDC(blimits, blimitsDC))
-        {
+      {
         continue;
-        }
+      }
 
       this->GetVertexLabel(vertex, numericData, stringData, activeComp, numComps,
                          string);
       results = this->AnalyseLabel(string, level, blimitsDC, textPosWC, &tprop);
       if (results == 1)
-        {
+      {
         // Label doesn't fit in its box - don't both processing children
         continue;
-        }
       }
+    }
     else
-      {
+    {
       // results == 2 from AnalyseLabel means that the label can't be
       // displayed due to reasons other than size - well in this
       // case we can't display due to the level limit we
       // also have to deactive the maks for this level
       this->LabelMasks[level][0] = -1.0;
       results = 2;
-      }
+    }
 
     if (!results)
-      {
+    {
       if (!this->TextMappers[this->NumberOfLabels])
-        {
+      {
         this->TextMappers[this->NumberOfLabels] = vtkTextMapper::New();
-        }
+      }
       this->TextMappers[this->NumberOfLabels]->SetInput(string);
       this->TextMappers[this->NumberOfLabels]->
         SetTextProperty(tprop);
       this->TextPoints->SetPoint(this->NumberOfLabels, textPosWC);
       ++(this->NumberOfLabels);
-      }
+    }
 
     // Is this level the deepest we can display?
     if (this->EndLevel == level)
-      {
+    {
       continue;
-      }
     }
+  }
   dfs->Delete();
   this->BuildTime.Modified();
 }
@@ -567,24 +567,24 @@ int vtkLabeledTreeMapDataMapper::GetStringSize(char *string, int level)
 {
 
   if (level > this->MaxFontLevel)
-    {
+  {
     level = this->MaxFontLevel;
-    }
+  }
   int size = 0, i;
   for(i = 0; string[i] != '\0'; i++)
-    {
+  {
     if (string[i] < 32)
-      {
+    {
       continue;
-      }
+    }
 
     if (string[i] > 126)
-      {
+    {
       continue;
-      }
+    }
 
     size += this->FontWidths[level][string[i]-32];
-    }
+  }
   return size;
 }
 
@@ -602,49 +602,49 @@ int vtkLabeledTreeMapDataMapper::ConvertToDC(float *binfo, float *newBinfo)
   double windowHeight = this->WindowLimits[1][1] - this->WindowLimits[1][0];
 
   if (newBinfo[0] >= windowWidth)
-    {
+  {
     return 1;
-    }
+  }
 
   if (newBinfo[1] <= 0)
-    {
+  {
     return 1;
-    }
+  }
 
   if (newBinfo[2] >= windowHeight)
-    {
+  {
     return 1;
-    }
+  }
 
   if (newBinfo[3] <= 0)
-    {
+  {
     return 1;
-    }
+  }
 
   if (!this->ClipTextMode)
-    {
+  {
     return 0;
-    }
+  }
 
   if (newBinfo[0] < 0)
-    {
+  {
     newBinfo[0] = 0;
-    }
+  }
 
   if (newBinfo[1] > windowWidth)
-    {
+  {
     newBinfo[1] = windowWidth;
-    }
+  }
 
   if (newBinfo[2] < 0)
-    {
+  {
     newBinfo[2] = 0;
-    }
+  }
 
   if (newBinfo[3] > windowHeight)
-    {
+  {
     newBinfo[3] = windowHeight;
-    }
+  }
 
   return 0;
 }
@@ -655,35 +655,35 @@ void vtkLabeledTreeMapDataMapper::SetFontSizeRange(int maxSize, int minSize,
   int nLevels = (maxSize - minSize) / delta;
   int i, s;
   if (nLevels < 0)
-    {
+  {
     vtkErrorMacro(<<"maxSize is smaller than minSize");
     return;
-    }
+  }
 
   if ((maxSize - (nLevels * delta)) > minSize)
-    {
+  {
     ++nLevels;
-    }
+  }
 
   if (this->MaxFontLevel != nLevels)
-    {
+  {
     if (this->MaxFontLevel)
-      {
+    {
       delete [] this->FontHeights;
       for (i = 0; i <= this->MaxFontLevel; i++)
-        {
+      {
         delete [] this->FontWidths[i];
         this->HLabelProperties[i]->Delete();
-        }
+      }
       delete [] this->FontWidths;
       delete [] this->HLabelProperties;
-      }
+    }
     this->MaxFontLevel = nLevels;
     this->FontHeights = new int[this->MaxFontLevel+1];
     this->FontWidths = new int *[this->MaxFontLevel+1];
     this->HLabelProperties = new vtkTextProperty *[this->MaxFontLevel+1];
     for(i = 0; i <= this->MaxFontLevel; i++)
-      {
+    {
       this->FontWidths[i] = new int[95];
       this->HLabelProperties[i] = vtkTextProperty::New();
       this->HLabelProperties[i]->SetFontSize(12);
@@ -694,12 +694,12 @@ void vtkLabeledTreeMapDataMapper::SetFontSizeRange(int maxSize, int minSize,
       this->HLabelProperties[i]->SetJustificationToCentered();
       this->HLabelProperties[i]->SetVerticalJustificationToCentered();
       this->HLabelProperties[i]->SetColor(1, 1, 1);
-      }
     }
+  }
   for(i = 0, s = maxSize; i < this->MaxFontLevel; i++, s -= delta)
-    {
+  {
     this->HLabelProperties[i]->SetFontSize(s);
-    }
+  }
   this->HLabelProperties[i]->SetFontSize(minSize);
 
   this->CurrentViewPort = 0;
@@ -724,46 +724,36 @@ int vtkLabeledTreeMapDataMapper::AnalyseLabel(char * string, int level,
   sizes[1] = blimitsDC[3] - blimitsDC[2];
   trueLevel = level -  this->StartLevel;
   if (trueLevel < 0)
-    {
+  {
     vtkErrorMacro(<< "Invalid level.");
     trueLevel = 0;
-    }
+  }
   trueLevel =
     (trueLevel > this->MaxFontLevel) ? this->MaxFontLevel : trueLevel;
    fsize = this->GetStringSize(string, trueLevel);
-  // Determine the orientation of the label
-  // Vertical Label - THIS DOESN'T WORK DUE TO ISSUES WITH vtkTextActor
-  // so always do the following - hence the 1 in the condition
-  if (1 || (sizes[0] >= sizes[1]))
-    {
-    // Horizontal label
-    oDir = 0;
-    *tprop = this->HLabelProperties[trueLevel];
-    }
-  else
-    {
-    // Vertical Label - THIS DOESN'T WORK DUE TO ISSUES WITH vtkTextActor
-    oDir = 1;
-    *tprop = this->VerticalLabelProperty;
-    }
+
+  // Horizontal label.
+  // (Vertical labels don't work due to issues with vtkTextActor.)
+  oDir = 0;
+  *tprop = this->HLabelProperties[trueLevel];
 
   // Is this level dynamic or static?
   if (level >= this->DynamicLevel)
-    {
+  {
 
     // See if the text will not even fit in the box
     if (sizes[!oDir] < this->FontHeights[trueLevel])
-      {
+    {
     // Text will not fit
       return 1;
-      }
+    }
 
     if (sizes[oDir] < fsize)
-      {
+    {
       // Text will not fit
       return 1;
-      }
     }
+  }
   // Calculate the bounding box of the text
   // Determine where to place the text
   tPosDC[0] = 0.5 *(blimitsDC[0] + blimitsDC[1]);
@@ -779,7 +769,7 @@ int vtkLabeledTreeMapDataMapper::AnalyseLabel(char * string, int level,
   // If the label is not to be centered based on the clipped form of the
   // vertex's box see if it has been clipped away
   if (!this->ClipTextMode)
-    {
+  {
     // The 'flimits' variable contains the bounding box of the label
     // in coordinates relative to (0, 0) in the window -- that is, the
     // lower left corner of the window.  These next few lines test to
@@ -793,25 +783,25 @@ int vtkLabeledTreeMapDataMapper::AnalyseLabel(char * string, int level,
         (flimits[1] <= 0) ||
         (flimits[2] >= windowHeight) ||
         (flimits[3] <= 0))
-      {
+    {
       this->LabelMasks[level][0] = -1.0;
       return 2;
-      }
     }
+  }
 
   // Apply Masks
   if (level && (level > this->DynamicLevel))
-    {
+  {
     if (this->ApplyMasks(level, flimits, blimitsDC))
-      {
+    {
       // This label does not fit based on the masks
       // Since device coordinate can not be < 0 set
       // the first component of the mask to be -1
       // to indicate the mask is not to be used
       this->LabelMasks[level][0] = -1.0;
       return 2;
-      }
     }
+  }
 
   this->LabelMasks[level][0] = flimits[0];
   this->LabelMasks[level][1] = flimits[1];
@@ -837,44 +827,44 @@ int vtkLabeledTreeMapDataMapper::ApplyMasks(int level, float flimits[4],
   int changed = 1, dir = 0, l;
   int status = 1;
   if (!this->ChildMotion)
-    {
+  {
     // If any of the masks intersect the label don't display it
     for (l = 0; l < level; l++)
-      {
+    {
       // Skip all masks that refer to labels that are not displayed
       // (i.e. that the first component < 0)
       if (this->LabelMasks[l][0] < 0.0)
-        {
+      {
         continue;
-        }
+      }
       if (this->LabelMasks[l][0] > flimits[1])
-        {
+      {
         continue;
-        }
+      }
       if (this->LabelMasks[l][1] < flimits[0])
-        {
+      {
         continue;
-        }
+      }
       if (this->LabelMasks[l][2] > flimits[3])
-        {
+      {
         continue;
-        }
+      }
       if (this->LabelMasks[l][3] < flimits[2])
-        {
+      {
         continue;
-        }
+      }
       // If we are here the label intersects the mask
       return 1;
-      }
-    return 0;
     }
+    return 0;
+  }
 
   // dir == 0 indicates we are dropping the label and 1 means we are raising it
   while (changed)
-    {
+  {
     changed = 0;
     for (l = 0; l < level; l++)
-      {
+    {
       // Skip all masks that refer to labels that are not displayed
       // (i.e. that the first component < 0)
       // or do not interfere in the y-direction
@@ -884,110 +874,110 @@ int vtkLabeledTreeMapDataMapper::ApplyMasks(int level, float flimits[4],
       if ((this->LabelMasks[l][0] < 0.0) ||
           (this->LabelMasks[l][1] < 0.0) ||
           (this->LabelMasks[l][2] < 0.0))
-        {
+      {
         continue;
-        }
+      }
 
       // If the label passes either x-check it will never
       // interfere with a horizontal label
       if (this->LabelMasks[l][0] > flimits[1])
-        {
+      {
         // Set the second component to be -(value + 1) - the reason
         // for the offset is to take of the case the original value is 0
         this->LabelMasks[l][1] = -1.0 * (this->LabelMasks[l][1] + 1.0);
         continue;
-        }
+      }
       if (this->LabelMasks[l][1] < flimits[0])
-        {
+      {
         this->LabelMasks[l][1] = -1.0 * (this->LabelMasks[l][1] + 1.0);
         continue;
-        }
+      }
       if (this->LabelMasks[l][2] > (flimits[3]+dy))
-        {
+      {
         // If dy < 0 then this condition will always be true and
         // this check can be turned off
         if (dy < 0.0)
-          {
-          this->LabelMasks[l][2] = -1.0 * (this->LabelMasks[l][2] + 1.0);
-          }
-        continue;
-        }
-      if (this->LabelMasks[l][3] < (flimits[2]+dy))
         {
+          this->LabelMasks[l][2] = -1.0 * (this->LabelMasks[l][2] + 1.0);
+        }
+        continue;
+      }
+      if (this->LabelMasks[l][3] < (flimits[2]+dy))
+      {
         // If dy > 0 then this condition will always be true and
         // this check can be turned off
         if (dy > 0.0)
-          {
+        {
           this->LabelMasks[l][2] = -1.0 * (this->LabelMasks[l][2] + 1.0);
-          }
-        continue;
         }
+        continue;
+      }
       // If we are here then the mask does clip the label
       // see which direction we are going it - added a cushion of 5 pixels
       if (dir)
-        {
+      {
         dy = 5 + this->LabelMasks[l][3] - flimits[2];
-        }
+      }
       else
-        {
+      {
         dy = this->LabelMasks[l][2] - (5 + flimits[3]);
-        }
+      }
 
       // Indicate that we changed something
       changed = 1;
-      }
+    }
 
     // See if anything changed - if it did then repeat the mask loop
     if (changed)
-      {
+    {
       continue;
-      }
+    }
 
     // See if the current label position will not fit on the screen
     if ((blimits[2] > (flimits[2] + dy)) || (blimits[3] < (flimits[3] + dy)))
-      {
+    {
       // Have we been dropping the label?
       if (!dir)
-        {
+      {
         // Try raising it - we will need to reset all the masks with
         // negative third components
         dir = 1;
         changed = 1;
         for (l = 0; l < level; l++)
-          {
+        {
           if (this->LabelMasks[l][2] < 0.0)
-            {
+          {
             this->LabelMasks[l][2] = - 1.0 * (this->LabelMasks[l][2]+ 1.0);
-            }
           }
         }
+      }
       // in this case there was no way to display the label
       status = 1;
-      }
+    }
     else
-      {
+    {
       // Success
       status = 0;
       flimits[2] += dy;
       flimits[3] += dy;
-      }
     }
+  }
 
     // Reset masks that were deactivated
     for (l = 0; l < level; l++)
-      {
+    {
       if (this->LabelMasks[l][1] < 0.0)
-        {
+      {
         this->LabelMasks[l][1] = - 1.0 * (this->LabelMasks[l][1]+ 1.0);
         continue;
-        }
+      }
 
       if (this->LabelMasks[l][2] < 0.0)
-        {
+      {
         this->LabelMasks[l][2] = - 1.0 * (this->LabelMasks[l][2]+ 1.0);
         continue;
-        }
       }
+    }
 
   return status;
 }
@@ -995,10 +985,10 @@ int vtkLabeledTreeMapDataMapper::ApplyMasks(int level, float flimits[4],
 void vtkLabeledTreeMapDataMapper::SetLevelRange(int start, int end)
 {
   if (((end != -1) && (start > end)) || (start < 0))
-    {
+  {
     vtkErrorMacro(<<"Invalid level range specified.");
     return;
-    }
+  }
 
   this->StartLevel = start;
   this->EndLevel = end;
