@@ -12,10 +12,10 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#include <stdio.h>
+#include <cstdio>
 #include <cstdlib>
-#include <string.h>
-#include <math.h>
+#include <cstring>
+#include <cmath>
 
 
 #ifndef _WIN32_WINNT
@@ -78,26 +78,26 @@ vtkWin32RenderWindowInteractor::~vtkWin32RenderWindowInteractor()
 
   // we need to release any hold we have on a windows event loop
   if (this->WindowId && this->Enabled && this->InstallMessageProc)
-    {
+  {
     vtkWin32OpenGLRenderWindow *ren;
     ren = static_cast<vtkWin32OpenGLRenderWindow *>(this->RenderWindow);
     tmp = (vtkWin32OpenGLRenderWindow *)(vtkGetWindowLong(this->WindowId,sizeof(vtkLONG)));
     // watch for odd conditions
     if ((tmp != ren) && (ren != NULL))
-      {
+    {
       // OK someone else has a hold on our event handler
       // so lets have them handle this stuff
       // well send a USER message to the other
       // event handler so that it can properly
       // call this event handler if required
       CallWindowProc(this->OldProc,this->WindowId,WM_USER+14,28,(intptr_t)this->OldProc);
-      }
-    else
-      {
-      vtkSetWindowLong(this->WindowId,vtkGWL_WNDPROC,(intptr_t)this->OldProc);
-      }
-    this->Enabled = 0;
     }
+    else
+    {
+      vtkSetWindowLong(this->WindowId,vtkGWL_WNDPROC,(intptr_t)this->OldProc);
+    }
+    this->Enabled = 0;
+  }
 #ifdef VTK_USE_TDX
   this->Device->Delete();
 #endif
@@ -108,18 +108,18 @@ void  vtkWin32RenderWindowInteractor::StartEventLoop()
 {
   // No need to do anything if this is a 'mapped' interactor
   if (!this->Enabled || !this->InstallMessageProc)
-    {
+  {
     return;
-    }
+  }
 
   this->StartedMessageLoop = 1;
 
   MSG msg;
   while (GetMessage(&msg, NULL, 0, 0))
-    {
+  {
     TranslateMessage(&msg);
     DispatchMessage(&msg);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -131,14 +131,14 @@ void vtkWin32RenderWindowInteractor::Initialize()
 
   // make sure we have a RenderWindow and camera
   if ( ! this->RenderWindow)
-    {
+  {
     vtkErrorMacro(<<"No renderer defined!");
     return;
-    }
+  }
   if (this->Initialized)
-    {
+  {
     return;
-    }
+  }
   this->Initialized = 1;
   // get the info we need from the RenderingWindow
   ren = (vtkWin32OpenGLRenderWindow *)(this->RenderWindow);
@@ -157,37 +157,37 @@ void vtkWin32RenderWindowInteractor::Enable()
   vtkWin32OpenGLRenderWindow *ren;
   vtkWin32OpenGLRenderWindow *tmp;
   if (this->Enabled)
-    {
+  {
     return;
-    }
+  }
   if (this->InstallMessageProc)
-    {
+  {
     // add our callback
     ren = (vtkWin32OpenGLRenderWindow *)(this->RenderWindow);
     this->OldProc = (WNDPROC)vtkGetWindowLong(this->WindowId,vtkGWL_WNDPROC);
     tmp=(vtkWin32OpenGLRenderWindow *)vtkGetWindowLong(this->WindowId,sizeof(vtkLONG));
     // watch for odd conditions
     if (tmp != ren)
-      {
+    {
       // OK someone else has a hold on our event handler
       // so lets have them handle this stuff
       // well send a USER message to the other
       // event handler so that it can properly
       // call this event handler if required
       CallWindowProc(this->OldProc,this->WindowId,WM_USER+12,24,(intptr_t)vtkHandleMessage);
-      }
+    }
     else
-      {
+    {
       vtkSetWindowLong(this->WindowId,vtkGWL_WNDPROC,(intptr_t)vtkHandleMessage);
-      }
+    }
 
 #ifdef VTK_USE_TDX
     if(this->UseTDx)
-      {
+    {
       this->Device->SetInteractor(this);
       this->Device->Initialize();
       this->Device->StartListening();
-      }
+    }
 #endif
 
     // in case the size of the window has changed while we were away
@@ -195,7 +195,7 @@ void vtkWin32RenderWindowInteractor::Enable()
     size = ren->GetSize();
     this->Size[0] = size[0];
     this->Size[1] = size[1];
-    }
+  }
   this->Enabled = 1;
   this->Modified();
 }
@@ -206,37 +206,37 @@ void vtkWin32RenderWindowInteractor::Disable()
 {
   vtkWin32OpenGLRenderWindow *tmp;
   if (!this->Enabled)
-    {
+  {
     return;
-    }
+  }
 
   if (this->InstallMessageProc && this->Enabled && this->WindowId)
-    {
+  {
     // we need to release any hold we have on a windows event loop
     vtkWin32OpenGLRenderWindow *ren;
     ren = (vtkWin32OpenGLRenderWindow *)(this->RenderWindow);
     tmp = (vtkWin32OpenGLRenderWindow *)vtkGetWindowLong(this->WindowId,sizeof(vtkLONG));
     // watch for odd conditions
     if ((tmp != ren) && (ren != NULL))
-      {
+    {
       // OK someone else has a hold on our event handler
       // so lets have them handle this stuff
       // well send a USER message to the other
       // event handler so that it can properly
       // call this event handler if required
       CallWindowProc(this->OldProc,this->WindowId,WM_USER+14,28,(intptr_t)this->OldProc);
-      }
+    }
     else
-      {
+    {
       vtkSetWindowLong(this->WindowId,vtkGWL_WNDPROC,(intptr_t)this->OldProc);
-      }
+    }
 #ifdef VTK_USE_TDX
     if(this->Device->GetInitialized())
-      {
+    {
       this->Device->Close();
-      }
-#endif
     }
+#endif
+  }
   this->Enabled = 0;
   this->Modified();
 }
@@ -247,9 +247,9 @@ void vtkWin32RenderWindowInteractor::TerminateApp(void)
   // Only post a quit message if Start was called...
   //
   if (this->StartedMessageLoop)
-    {
+  {
     PostQuitMessage(0);
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -333,13 +333,13 @@ static const char *VKeyCodeToKeySymTable[] = {
 //-------------------------------------------------------------
 // Event loop handlers
 //-------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnMouseMove(HWND hWnd, UINT nFlags,
-                                                 int X, int Y)
+int vtkWin32RenderWindowInteractor::OnMouseMove(HWND hWnd, UINT nFlags,
+                                                int X, int Y)
 {
   if (!this->Enabled)
-    {
-    return;
-    }
+  {
+    return 0;
+  }
 
   this->SetEventInformationFlipY(X,
                                  Y,
@@ -348,7 +348,7 @@ void vtkWin32RenderWindowInteractor::OnMouseMove(HWND hWnd, UINT nFlags,
   this->SetAltKey(GetKeyState(VK_MENU) & (~1));
   if (!this->MouseInWindow &&
       (X >= 0 && X < this->Size[0] && Y >= 0 && Y < this->Size[1]))
-    {
+  {
     this->InvokeEvent(vtkCommand::EnterEvent, NULL);
     this->MouseInWindow = 1;
     // request WM_MOUSELEAVE generation
@@ -357,73 +357,71 @@ void vtkWin32RenderWindowInteractor::OnMouseMove(HWND hWnd, UINT nFlags,
     tme.dwFlags = TME_LEAVE;
     tme.hwndTrack = hWnd;
     TrackMouseEvent(&tme);
-    }
+  }
 
-  this->InvokeEvent(vtkCommand::MouseMoveEvent, NULL);
+  return this->InvokeEvent(vtkCommand::MouseMoveEvent, NULL);
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnNCMouseMove(HWND, UINT nFlags,
-                                                   int X, int Y)
+int vtkWin32RenderWindowInteractor::OnNCMouseMove(HWND, UINT nFlags,
+                                                  int X, int Y)
 {
-  if (!this->Enabled)
-    {
-    return;
-    }
+  if (!this->Enabled || !this->MouseInWindow)
+  {
+    return 0;
+  }
 
   int *pos = this->RenderWindow->GetPosition();
-  if (this->MouseInWindow)
-    {
-    this->SetEventInformationFlipY(X - pos[0],
-                                   Y - pos[1],
-                                   nFlags & MK_CONTROL,
-                                   nFlags & MK_SHIFT);
-    this->SetAltKey(GetKeyState(VK_MENU) & (~1));
-    this->InvokeEvent(vtkCommand::LeaveEvent, NULL);
-    this->MouseInWindow = 0;
-    }
+  this->SetEventInformationFlipY(X - pos[0],
+                                 Y - pos[1],
+                                 nFlags & MK_CONTROL,
+                                 nFlags & MK_SHIFT);
+  this->SetAltKey(GetKeyState(VK_MENU) & (~1));
+  const int ret = this->InvokeEvent(vtkCommand::LeaveEvent, NULL);
+  this->MouseInWindow = 0;
+  return ret;
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnMouseWheelForward(HWND,UINT nFlags,
-                                                   int X, int Y)
+int vtkWin32RenderWindowInteractor::OnMouseWheelForward(HWND, UINT nFlags,
+                                                        int X, int Y)
 {
   if (!this->Enabled)
-    {
-    return;
-    }
+  {
+    return 0;
+  }
   this->SetEventInformationFlipY(X,
                                  Y,
                                  nFlags & MK_CONTROL,
                                  nFlags & MK_SHIFT);
   this->SetAltKey(GetKeyState(VK_MENU) & (~1));
-  this->InvokeEvent(vtkCommand::MouseWheelForwardEvent,NULL);
+  return this->InvokeEvent(vtkCommand::MouseWheelForwardEvent, NULL);
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnMouseWheelBackward(HWND,UINT nFlags,
-                                                   int X, int Y)
+int vtkWin32RenderWindowInteractor::OnMouseWheelBackward(HWND, UINT nFlags,
+                                                         int X, int Y)
 {
   if (!this->Enabled)
-    {
-    return;
-    }
+  {
+    return 0;
+  }
   this->SetEventInformationFlipY(X,
                                  Y,
                                  nFlags & MK_CONTROL,
                                  nFlags & MK_SHIFT);
   this->SetAltKey(GetKeyState(VK_MENU) & (~1));
-  this->InvokeEvent(vtkCommand::MouseWheelBackwardEvent,NULL);
+  return this->InvokeEvent(vtkCommand::MouseWheelBackwardEvent, NULL);
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnLButtonDown(HWND wnd,UINT nFlags,
-                                                   int X, int Y, int repeat)
+int vtkWin32RenderWindowInteractor::OnLButtonDown(HWND wnd, UINT nFlags,
+                                                  int X, int Y, int repeat)
 {
   if (!this->Enabled)
-    {
-    return;
-    }
+  {
+    return 0;
+  }
   SetFocus(wnd);
   SetCapture(wnd);
   this->SetEventInformationFlipY(X,
@@ -432,34 +430,35 @@ void vtkWin32RenderWindowInteractor::OnLButtonDown(HWND wnd,UINT nFlags,
                                  nFlags & MK_SHIFT,
                                  0, repeat);
   this->SetAltKey(GetKeyState(VK_MENU) & (~1));
-  this->InvokeEvent(vtkCommand::LeftButtonPressEvent,NULL);
+  return this->InvokeEvent(vtkCommand::LeftButtonPressEvent, NULL);
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnLButtonUp(HWND,UINT nFlags,
-                                                 int X, int Y)
+int vtkWin32RenderWindowInteractor::OnLButtonUp(HWND, UINT nFlags,
+                                                int X, int Y)
 {
   if (!this->Enabled)
-    {
-    return;
-    }
+  {
+    return 0;
+  }
   this->SetEventInformationFlipY(X,
                                  Y,
                                  nFlags & MK_CONTROL,
                                  nFlags & MK_SHIFT);
   this->SetAltKey(GetKeyState(VK_MENU) & (~1));
-  this->InvokeEvent(vtkCommand::LeftButtonReleaseEvent,NULL);
+  const int ret = this->InvokeEvent(vtkCommand::LeftButtonReleaseEvent,NULL);
   ReleaseCapture( );
+  return ret;
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnMButtonDown(HWND wnd,UINT nFlags,
-                                                   int X, int Y, int repeat)
+int vtkWin32RenderWindowInteractor::OnMButtonDown(HWND wnd, UINT nFlags,
+                                                  int X, int Y, int repeat)
 {
   if (!this->Enabled)
-    {
-    return;
-    }
+  {
+    return 0;
+  }
   SetFocus(wnd);
   SetCapture(wnd);
   this->SetEventInformationFlipY(X,
@@ -468,34 +467,35 @@ void vtkWin32RenderWindowInteractor::OnMButtonDown(HWND wnd,UINT nFlags,
                                  nFlags & MK_SHIFT,
                                  0, repeat);
   this->SetAltKey(GetKeyState(VK_MENU) & (~1));
-  this->InvokeEvent(vtkCommand::MiddleButtonPressEvent,NULL);
+  return this->InvokeEvent(vtkCommand::MiddleButtonPressEvent, NULL);
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnMButtonUp(HWND,UINT nFlags,
-                                                 int X, int Y)
+int vtkWin32RenderWindowInteractor::OnMButtonUp(HWND, UINT nFlags,
+                                                int X, int Y)
 {
   if (!this->Enabled)
-    {
-    return;
-    }
+  {
+    return 0;
+  }
   this->SetEventInformationFlipY(X,
                                  Y,
                                  nFlags & MK_CONTROL,
                                  nFlags & MK_SHIFT);
   this->SetAltKey(GetKeyState(VK_MENU) & (~1));
-  this->InvokeEvent(vtkCommand::MiddleButtonReleaseEvent,NULL);
+  const int ret = this->InvokeEvent(vtkCommand::MiddleButtonReleaseEvent,NULL);
   ReleaseCapture( );
+  return ret;
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnRButtonDown(HWND wnd,UINT nFlags,
-                                                   int X, int Y, int repeat)
+int vtkWin32RenderWindowInteractor::OnRButtonDown(HWND wnd, UINT nFlags,
+                                                  int X, int Y, int repeat)
 {
   if (!this->Enabled)
-    {
-    return;
-    }
+  {
+    return 0;
+  }
   SetFocus(wnd);
   SetCapture(wnd);
   this->SetEventInformationFlipY(X,
@@ -504,59 +504,64 @@ void vtkWin32RenderWindowInteractor::OnRButtonDown(HWND wnd,UINT nFlags,
                                  nFlags & MK_SHIFT,
                                  0, repeat);
   this->SetAltKey(GetKeyState(VK_MENU) & (~1));
-  this->InvokeEvent(vtkCommand::RightButtonPressEvent,NULL);
+  return this->InvokeEvent(vtkCommand::RightButtonPressEvent, NULL);
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnRButtonUp(HWND,UINT nFlags,
-                                                 int X, int Y)
+int vtkWin32RenderWindowInteractor::OnRButtonUp(HWND, UINT nFlags,
+                                                int X, int Y)
 {
   if (!this->Enabled)
-    {
-    return;
-    }
+  {
+    return 0;
+  }
   this->SetEventInformationFlipY(X,
                                  Y,
                                  nFlags & MK_CONTROL,
                                  nFlags & MK_SHIFT);
   this->SetAltKey(GetKeyState(VK_MENU) & (~1));
-  this->InvokeEvent(vtkCommand::RightButtonReleaseEvent,NULL);
+  const int ret = this->InvokeEvent(vtkCommand::RightButtonReleaseEvent,NULL);
   ReleaseCapture( );
+  return ret;
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnSize(HWND,UINT, int X, int Y) {
+int vtkWin32RenderWindowInteractor::OnSize(HWND, UINT, int X, int Y)
+{
   this->UpdateSize(X,Y);
   if (this->Enabled)
-    {
-    this->InvokeEvent(vtkCommand::ConfigureEvent,NULL);
-    }
+  {
+     return this->InvokeEvent(vtkCommand::ConfigureEvent, NULL);
+  }
+  return 0;
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnTimer(HWND,UINT timerId)
+int vtkWin32RenderWindowInteractor::OnTimer(HWND, UINT timerId)
 {
   if (!this->Enabled)
-    {
-    return;
-    }
+  {
+    return 0;
+  }
   int tid = static_cast<int>(timerId);
-  this->InvokeEvent(vtkCommand::TimerEvent,(void*)&tid);
+  const int ret = this->InvokeEvent(vtkCommand::TimerEvent,(void*)&tid);
 
   // Here we deal with one-shot versus repeating timers
   if ( this->IsOneShotTimer(tid) )
-    {
+  {
     KillTimer(this->WindowId,tid); //'cause windows timers are always repeating
-    }
+  }
+
+  return ret;
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnKeyDown(HWND, UINT vCode, UINT nRepCnt, UINT nFlags)
+int vtkWin32RenderWindowInteractor::OnKeyDown(HWND, UINT vCode, UINT nRepCnt, UINT nFlags)
 {
   if (!this->Enabled)
-    {
-    return;
-    }
+  {
+    return 0;
+  }
   int ctrl  = GetKeyState(VK_CONTROL) & (~1);
   int shift = GetKeyState(VK_SHIFT) & (~1);
   int alt = GetKeyState(VK_MENU) & (~1);
@@ -566,36 +571,36 @@ void vtkWin32RenderWindowInteractor::OnKeyDown(HWND, UINT vCode, UINT nRepCnt, U
     BYTE keyState[256];
     GetKeyboardState(keyState);
     if (ToAscii(vCode,nFlags & 0xff,keyState,&nChar,0) == 0)
-      {
+    {
       nChar = 0;
-      }
+    }
 #endif
   }
   const char *keysym = AsciiToKeySymTable[(unsigned char)nChar];
   if (keysym == 0)
-    {
+  {
     keysym = VKeyCodeToKeySymTable[(unsigned char)vCode];
-    }
+  }
   if (keysym == 0)
-    {
+  {
     keysym = "None";
-    }
+  }
   this->SetKeyEventInformation(ctrl,
                                shift,
                                nChar,
                                nRepCnt,
                                keysym);
   this->SetAltKey(alt);
-  this->InvokeEvent(vtkCommand::KeyPressEvent, NULL);
+  return this->InvokeEvent(vtkCommand::KeyPressEvent, NULL);
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnKeyUp(HWND, UINT vCode, UINT nRepCnt, UINT nFlags)
+int vtkWin32RenderWindowInteractor::OnKeyUp(HWND, UINT vCode, UINT nRepCnt, UINT nFlags)
 {
   if (!this->Enabled)
-    {
-    return;
-    }
+  {
+    return 0;
+  }
   int ctrl  = GetKeyState(VK_CONTROL) & (~1);
   int shift = GetKeyState(VK_SHIFT) & (~1);
   int alt = GetKeyState(VK_MENU) & (~1);
@@ -605,37 +610,37 @@ void vtkWin32RenderWindowInteractor::OnKeyUp(HWND, UINT vCode, UINT nRepCnt, UIN
 #ifndef _WIN32_WCE
     GetKeyboardState(keyState);
     if (ToAscii(vCode,nFlags & 0xff,keyState,&nChar,0) == 0)
-      {
+    {
       nChar = 0;
-      }
+    }
 #endif
   }
   const char *keysym = AsciiToKeySymTable[(unsigned char)nChar];
   if (keysym == 0)
-    {
+  {
     keysym = VKeyCodeToKeySymTable[(unsigned char)vCode];
-    }
+  }
   if (keysym == 0)
-    {
+  {
     keysym = "None";
-    }
+  }
   this->SetKeyEventInformation(ctrl,
                                shift,
                                nChar,
                                nRepCnt,
                                keysym);
   this->SetAltKey(alt);
-  this->InvokeEvent(vtkCommand::KeyReleaseEvent, NULL);
+  return this->InvokeEvent(vtkCommand::KeyReleaseEvent, NULL);
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnChar(HWND,UINT nChar,
-                                            UINT nRepCnt, UINT)
+int vtkWin32RenderWindowInteractor::OnChar(HWND, UINT nChar,
+                                           UINT nRepCnt, UINT)
 {
   if (!this->Enabled)
-    {
-    return;
-    }
+  {
+    return 0;
+  }
   int ctrl  = GetKeyState(VK_CONTROL) & (~1);
   int shift = GetKeyState(VK_SHIFT) & (~1);
   int alt = GetKeyState(VK_MENU) & (~1);
@@ -644,38 +649,44 @@ void vtkWin32RenderWindowInteractor::OnChar(HWND,UINT nChar,
                                nChar,
                                nRepCnt);
   this->SetAltKey(alt);
-  this->InvokeEvent(vtkCommand::CharEvent, NULL);
+  return this->InvokeEvent(vtkCommand::CharEvent, NULL);
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnFocus(HWND,UINT)
+int vtkWin32RenderWindowInteractor::OnFocus(HWND, UINT)
 {
   if (!this->Enabled)
-    {
-    return;
-    }
+  {
+    return 0;
+  }
 
 #ifdef VTK_USE_TDX
   if(this->Device->GetInitialized() && !this->Device->GetIsListening())
-    {
+  {
     this->Device->StartListening();
-    }
+    return 1;
+  }
 #endif
+
+  return 0;
 }
 
 //----------------------------------------------------------------------------
-void vtkWin32RenderWindowInteractor::OnKillFocus(HWND,UINT)
+int vtkWin32RenderWindowInteractor::OnKillFocus(HWND, UINT)
 {
   if (!this->Enabled)
-    {
-    return;
-    }
+  {
+    return 0;
+  }
 #ifdef VTK_USE_TDX
   if(this->Device->GetInitialized() && this->Device->GetIsListening())
-    {
+  {
     this->Device->StopListening();
-    }
+    return 1;
+  }
 #endif
+
+  return 0;
 }
 
 //----------------------------------------------------------------------------
@@ -690,16 +701,16 @@ LRESULT CALLBACK vtkHandleMessage(HWND hWnd,UINT uMsg, WPARAM wParam,
   ren = (vtkWin32OpenGLRenderWindow *)vtkGetWindowLong(hWnd,sizeof(vtkLONG));
 
   if (ren)
-    {
+  {
     me = (vtkWin32RenderWindowInteractor *)ren->GetInteractor();
-    }
+  }
 
   if (me && me->GetReferenceCount()>0)
-    {
+  {
     me->Register(me);
     res = vtkHandleMessage2(hWnd,uMsg,wParam,lParam,me);
     me->UnRegister(me);
-    }
+  }
 
   return res;
 }
@@ -714,56 +725,61 @@ LRESULT CALLBACK vtkHandleMessage2(HWND hWnd,UINT uMsg, WPARAM wParam,
                                    vtkWin32RenderWindowInteractor *me)
 {
   if ((uMsg == WM_USER+13)&&(wParam == 26))
-    {
+  {
     // someone is telling us to set our OldProc
     me->OldProc = (WNDPROC)lParam;
     return 1;
-    }
+  }
+
+  int handled(0);
 
   switch (uMsg)
-    {
+  {
     case WM_PAINT:
-      me->Render();
-      return CallWindowProc(me->OldProc,hWnd,uMsg,wParam,lParam);
+    {
+      const LRESULT ret(CallWindowProc(me->OldProc, hWnd, uMsg, wParam, lParam));
+      me->InvokeEvent(vtkCommand::RenderEvent, NULL);
+      return ret;
+    }
 
     case WM_SIZE:
-      me->OnSize(hWnd,wParam,LOWORD(lParam),HIWORD(lParam));
-      return CallWindowProc(me->OldProc,hWnd,uMsg,wParam,lParam);
+      handled = me->OnSize(hWnd,wParam,LOWORD(lParam),HIWORD(lParam));
+      break;
 
     case WM_LBUTTONDBLCLK:
-      me->OnLButtonDown(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y, 1);
+      handled = me->OnLButtonDown(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y, 1);
       break;
 
     case WM_LBUTTONDOWN:
-      me->OnLButtonDown(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y, 0);
+      handled = me->OnLButtonDown(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y, 0);
       break;
 
     case WM_LBUTTONUP:
-      me->OnLButtonUp(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y);
+      handled = me->OnLButtonUp(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y);
       break;
 
     case WM_MBUTTONDBLCLK:
-      me->OnMButtonDown(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y, 1);
+      handled = me->OnMButtonDown(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y, 1);
       break;
 
     case WM_MBUTTONDOWN:
-      me->OnMButtonDown(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y, 0);
+      handled = me->OnMButtonDown(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y, 0);
       break;
 
     case WM_MBUTTONUP:
-      me->OnMButtonUp(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y);
+      handled = me->OnMButtonUp(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y);
       break;
 
     case WM_RBUTTONDBLCLK:
-      me->OnRButtonDown(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y, 1);
+      handled = me->OnRButtonDown(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y, 1);
       break;
 
     case WM_RBUTTONDOWN:
-      me->OnRButtonDown(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y, 0);
+      handled = me->OnRButtonDown(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y, 0);
       break;
 
     case WM_RBUTTONUP:
-      me->OnRButtonUp(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y);
+      handled = me->OnRButtonUp(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y);
       break;
 
     case WM_MOUSELEAVE:
@@ -772,25 +788,25 @@ LRESULT CALLBACK vtkHandleMessage2(HWND hWnd,UINT uMsg, WPARAM wParam,
       break;
 
     case WM_MOUSEMOVE:
-      me->OnMouseMove(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y);
+      handled = me->OnMouseMove(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y);
       break;
 
     case WM_MOUSEWHEEL:
-      {
+    {
       POINT pt;
       pt.x = MAKEPOINTS(lParam).x;
       pt.y = MAKEPOINTS(lParam).y;
       ::ScreenToClient(hWnd, &pt);
       if( GET_WHEEL_DELTA_WPARAM(wParam) > 0)
-        me->OnMouseWheelForward(hWnd,wParam,pt.x,pt.y);
+        handled = me->OnMouseWheelForward(hWnd,wParam,pt.x,pt.y);
       else
-        me->OnMouseWheelBackward(hWnd,wParam,pt.x,pt.y);
-      }
+        handled = me->OnMouseWheelBackward(hWnd,wParam,pt.x,pt.y);
+    }
       break;
 
 #ifdef WM_MCVMOUSEMOVE
     case WM_NCMOUSEMOVE:
-      me->OnNCMouseMove(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y);
+      handled = me->OnNCMouseMove(hWnd,wParam,MAKEPOINTS(lParam).x,MAKEPOINTS(lParam).y);
       break;
 #endif
 
@@ -799,51 +815,53 @@ LRESULT CALLBACK vtkHandleMessage2(HWND hWnd,UINT uMsg, WPARAM wParam,
       break;
 
     case WM_CHAR:
-      me->OnChar(hWnd,wParam,LOWORD(lParam),HIWORD(lParam));
+      handled = me->OnChar(hWnd,wParam,LOWORD(lParam),HIWORD(lParam));
       break;
 
     case WM_KEYDOWN:
     case WM_SYSKEYDOWN:
-      me->OnKeyDown(hWnd,wParam,LOWORD(lParam),HIWORD(lParam));
+      handled = me->OnKeyDown(hWnd,wParam,LOWORD(lParam),HIWORD(lParam));
       break;
 
     case WM_KEYUP:
     case WM_SYSKEYUP:
-      me->OnKeyUp(hWnd,wParam,LOWORD(lParam),HIWORD(lParam));
+      handled = me->OnKeyUp(hWnd,wParam,LOWORD(lParam),HIWORD(lParam));
       break;
 
     case WM_TIMER:
-      me->OnTimer(hWnd,wParam);
+      handled = me->OnTimer(hWnd,wParam);
       break;
 
     case WM_ACTIVATE:
       if(wParam==WA_INACTIVE)
-        {
-        me->OnKillFocus(hWnd,wParam);
-        }
+      {
+        handled = me->OnKillFocus(hWnd,wParam);
+      }
       else
-        {
-        me->OnFocus(hWnd,wParam);
-        }
+      {
+        handled = me->OnFocus(hWnd,wParam);
+      }
       break;
 
     case WM_SETFOCUS:
       // occurs when SetFocus() is called on the current window
-      me->OnFocus(hWnd,wParam);
+      handled = me->OnFocus(hWnd,wParam);
       break;
 
     case WM_KILLFOCUS:
       // occurs when the focus was on the current window and SetFocus() is
       // called on another window.
-      me->OnKillFocus(hWnd,wParam);
+      handled = me->OnKillFocus(hWnd,wParam);
       break;
 
     default:
-      if (me)
-        {
-        return CallWindowProc(me->OldProc,hWnd,uMsg,wParam,lParam);
-        }
-    };
+      break;
+  };
+
+  if (0 == handled)
+  {
+    return CallWindowProc(me->OldProc, hWnd, uMsg, wParam, lParam);
+  }
 
   return 0;
 }
@@ -856,19 +874,19 @@ vtkWin32RenderWindowInteractor::SetClassExitMethod(void (*f)(void *),void *arg)
 {
   if ( f != vtkWin32RenderWindowInteractor::ClassExitMethod
        || arg != vtkWin32RenderWindowInteractor::ClassExitMethodArg)
-    {
+  {
     // delete the current arg if there is a delete method
     if ((vtkWin32RenderWindowInteractor::ClassExitMethodArg)
         && (vtkWin32RenderWindowInteractor::ClassExitMethodArgDelete))
-      {
+    {
       (*vtkWin32RenderWindowInteractor::ClassExitMethodArgDelete)
         (vtkWin32RenderWindowInteractor::ClassExitMethodArg);
-      }
+    }
     vtkWin32RenderWindowInteractor::ClassExitMethod = f;
     vtkWin32RenderWindowInteractor::ClassExitMethodArg = arg;
 
     // no call to this->Modified() since this is a class member function
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -877,11 +895,11 @@ void
 vtkWin32RenderWindowInteractor::SetClassExitMethodArgDelete(void (*f)(void *))
 {
   if (f != vtkWin32RenderWindowInteractor::ClassExitMethodArgDelete)
-    {
+  {
     vtkWin32RenderWindowInteractor::ClassExitMethodArgDelete = f;
 
     // no call to this->Modified() since this is a class member function
-    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -896,13 +914,13 @@ void vtkWin32RenderWindowInteractor::PrintSelf(ostream& os, vtkIndent indent)
 void vtkWin32RenderWindowInteractor::ExitCallback()
 {
   if (this->HasObserver(vtkCommand::ExitEvent))
-    {
+  {
     this->InvokeEvent(vtkCommand::ExitEvent,NULL);
-    }
+  }
   else if (this->ClassExitMethod)
-    {
+  {
     (*this->ClassExitMethod)(this->ClassExitMethodArg);
-    }
+  }
 
   this->TerminateApp();
 }
