@@ -32,7 +32,7 @@
 #include "vtkPixelBufferObject.h"
 #include "vtkImageExtractComponents.h"
 #include "vtkMultiProcessController.h"
-#include <vtksys/ios/sstream>
+#include <sstream>
 #include "vtkTimerLog.h"
 #include "vtkStdString.h"
 #include "vtkImageData.h"
@@ -48,7 +48,9 @@
 # include "vtkOpenGLState.h"
 #endif
 
-#ifndef VTKGL2
+#ifdef VTK_OPENGL2
+# include "vtk_glew.h"
+#else
 # include "vtkgl.h"
 # include "vtkOpenGLExtensionManager.h"
 #endif
@@ -73,29 +75,26 @@ vtkCompositeRGBAPass::vtkCompositeRGBAPass()
 vtkCompositeRGBAPass::~vtkCompositeRGBAPass()
 {
   if(this->Controller!=0)
-    {
+  {
       this->Controller->Delete();
-    }
+  }
   if(this->Kdtree!=0)
-    {
+  {
       this->Kdtree->Delete();
-    }
+  }
   if(this->PBO!=0)
-    {
+  {
     vtkErrorMacro(<<"PixelBufferObject should have been deleted in ReleaseGraphicsResources().");
-    }
+  }
    if(this->RGBATexture!=0)
-    {
+   {
     vtkErrorMacro(<<"RGBATexture should have been deleted in ReleaseGraphicsResources().");
-    }
+   }
    if(this->RootTexture!=0)
-     {
+   {
      vtkErrorMacro(<<"RootTexture should have been deleted in ReleaseGraphicsResources().");
-    }
-   if(this->RawRGBABuffer!=0)
-     {
-     delete[] this->RawRGBABuffer;
-     }
+   }
+   delete[] this->RawRGBABuffer;
 }
 
 // ----------------------------------------------------------------------------
@@ -105,28 +104,28 @@ void vtkCompositeRGBAPass::PrintSelf(ostream& os, vtkIndent indent)
 
   os << indent << "Controller:";
   if(this->Controller!=0)
-    {
+  {
     this->Controller->PrintSelf(os,indent);
-    }
+  }
   else
-    {
+  {
     os << "(none)" <<endl;
-    }
+  }
   os << indent << "Kdtree:";
   if(this->Kdtree!=0)
-    {
+  {
     this->Kdtree->PrintSelf(os,indent);
-    }
+  }
   else
-    {
+  {
     os << "(none)" <<endl;
-    }
+  }
 }
 
 // ----------------------------------------------------------------------------
 bool vtkCompositeRGBAPass::IsSupported(vtkOpenGLRenderWindow *context)
 {
-#ifdef VTKGL2
+#ifdef VTK_OPENGL2
   return (context != 0);
 #else
   vtkOpenGLExtensionManager *extmgr = context->GetExtensionManager();
@@ -149,23 +148,23 @@ void vtkCompositeRGBAPass::Render(const vtkRenderState *s)
   assert("pre: s_exists" && s!=0);
 
   if(this->Controller==0)
-    {
+  {
     vtkErrorMacro(<<" no controller.");
     return;
-    }
+  }
 
   int numProcs=this->Controller->GetNumberOfProcesses();
 
   if(numProcs==1)
-    {
+  {
     return; // nothing to do.
-    }
+  }
 
   if(this->Kdtree==0)
-    {
+  {
     vtkErrorMacro(<<" no Kdtree.");
     return;
-    }
+  }
 
   int me=this->Controller->GetLocalProcessId();
 
@@ -178,12 +177,12 @@ void vtkCompositeRGBAPass::Render(const vtkRenderState *s)
     = static_cast<vtkOpenGLRenderWindow *>(r->GetRenderWindow());
 
   if (!this->IsSupported(context))
-    {
+  {
     vtkErrorMacro(
       << "Missing required OpenGL extensions. "
       << "Cannot perform rgba-compositing.");
     return;
-    }
+  }
 
 #ifdef VTK_COMPOSITE_RGBAPASS_DEBUG
   vtkOpenGLState *state=new vtkOpenGLState(context);
@@ -192,18 +191,18 @@ void vtkCompositeRGBAPass::Render(const vtkRenderState *s)
   int w=0;
   int h=0;
 
-  vtkFrameBufferObject *fbo=s->GetFrameBuffer();
+  vtkFrameBufferObject *fbo=(vtkFrameBufferObject*)s->GetFrameBuffer();
   if(fbo==0)
-    {
+  {
     r->GetTiledSize(&w,&h);
-    }
+  }
   else
-    {
+  {
     int size[2];
     fbo->GetLastSize(size);
     w=size[0];
     h=size[1];
-    }
+  }
 
   int numComps = 4;
   unsigned int numTups = w*h;
@@ -221,28 +220,28 @@ void vtkCompositeRGBAPass::Render(const vtkRenderState *s)
 
   if(this->RawRGBABuffer!=0 &&
      this->RawRGBABufferSize<static_cast<size_t>(w*h*4))
-    {
+  {
     delete[] this->RawRGBABuffer;
     this->RawRGBABuffer=0;
-    }
+  }
   if(this->RawRGBABuffer==0)
-    {
+  {
     this->RawRGBABufferSize=static_cast<size_t>(w*h*4);
     this->RawRGBABuffer=new float[this->RawRGBABufferSize];
-    }
+  }
 
   //size_t byteSize = this->RawRGBABufferSize*sizeof(unsigned char);
 
   if(this->PBO==0)
-    {
+  {
     this->PBO=vtkPixelBufferObject::New();
     this->PBO->SetContext(context);
-    }
+  }
   if(this->RGBATexture==0)
-    {
+  {
     this->RGBATexture=vtkTextureObject::New();
     this->RGBATexture->SetContext(context);
-    }
+  }
 
   // TO: texture object
   // PBO: pixel buffer object
@@ -260,7 +259,7 @@ void vtkCompositeRGBAPass::Render(const vtkRenderState *s)
 #endif
 
   if(me==0)
-    {
+  {
     // root
     // 1. figure out the back to front ordering
     // 2. if root is not farest, save it in a TO
@@ -305,7 +304,7 @@ void vtkCompositeRGBAPass::Render(const vtkRenderState *s)
 //    rgbaToRgb->SetInputConnection(importer->GetOutputPort());
 //    rgbaToRgb->SetComponents(0,1,2);
 
-    vtksys_ios::ostringstream ostxx;
+    std::ostringstream ostxx;
     ostxx.setf(ios::fixed,ios::floatfield);
     ostxx.precision(5);
     timer->StopTimer();
@@ -332,15 +331,15 @@ void vtkCompositeRGBAPass::Render(const vtkRenderState *s)
     vtkCamera *c=r->GetActiveCamera();
     vtkIntArray *frontToBackList=vtkIntArray::New();
     if(c->GetParallelProjection())
-      {
+    {
       this->Kdtree->ViewOrderAllProcessesInDirection(
         c->GetDirectionOfProjection(),frontToBackList);
-      }
+    }
     else
-      {
+    {
       this->Kdtree->ViewOrderAllProcessesFromPosition(
         c->GetPosition(),frontToBackList);
-      }
+    }
 
     assert("check same_size" &&
            frontToBackList->GetNumberOfTuples()==numProcs);
@@ -348,29 +347,45 @@ void vtkCompositeRGBAPass::Render(const vtkRenderState *s)
 #ifdef VTK_COMPOSITE_RGBAPASS_DEBUG
     int i=0;
     while(i<numProcs)
-      {
+    {
       cout << "frontToBackList[" << i << "]=" << frontToBackList->GetValue(i)
            <<endl;
       ++i;
-      }
+    }
 #endif
 
+  // framebuffers have their color premultiplied by alpha.
+
+#ifdef VTK_OPENGL2
+    // save off current state of src / dst blend functions
+    GLint blendSrcA;
+    GLint blendDstA;
+    GLint blendSrcC;
+    GLint blendDstC;
+    glGetIntegerv(GL_BLEND_SRC_ALPHA, &blendSrcA);
+    glGetIntegerv(GL_BLEND_DST_ALPHA, &blendDstA);
+    glGetIntegerv(GL_BLEND_SRC_RGB, &blendSrcC);
+    glGetIntegerv(GL_BLEND_DST_RGB, &blendDstC);
+
+    glColorMask(GL_TRUE,GL_TRUE,GL_TRUE,GL_TRUE);
+
+    // per-fragment operations
+    glDisable(GL_DEPTH_TEST);
+    glDisable(GL_BLEND);
+    glBlendFuncSeparate(GL_ONE, GL_ONE_MINUS_SRC_ALPHA,
+                        GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
+#else
     glPushAttrib(GL_DEPTH_BUFFER_BIT|GL_COLOR_BUFFER_BIT|GL_LIGHTING);
     glColorMask(GL_TRUE,GL_TRUE,GL_TRUE,GL_TRUE);
 
     // per-fragment operations
-    glDisable(GL_ALPHA_TEST);
     glDisable(GL_STENCIL_TEST);
     glDisable(GL_DEPTH_TEST);
     glDisable(GL_BLEND);
+
+    glDisable(GL_ALPHA_TEST);
     glDisable(GL_INDEX_LOGIC_OP);
     glDisable(GL_COLOR_LOGIC_OP);
-
-    // framebuffers have their color premultiplied by alpha.
-#ifdef VTKGL2
-    glBlendFuncSeparate(GL_ONE, GL_ONE_MINUS_SRC_ALPHA,
-                        GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
-#else
     vtkgl::BlendFuncSeparate(GL_ONE,GL_ONE_MINUS_SRC_ALPHA,
                              GL_ONE,GL_ONE_MINUS_SRC_ALPHA);
     // fixed vertex shader
@@ -379,23 +394,23 @@ void vtkCompositeRGBAPass::Render(const vtkRenderState *s)
     // fixed fragment shader
     glEnable(GL_TEXTURE_2D);
     glDisable(GL_FOG);
+    glTexEnvi(GL_TEXTURE_ENV,GL_TEXTURE_ENV_MODE,GL_REPLACE);
 #endif
 
-    glTexEnvi(GL_TEXTURE_ENV,GL_TEXTURE_ENV_MODE,GL_REPLACE);
     glPixelStorei(GL_UNPACK_ALIGNMENT,1);// client to server
 
     // 2. if root is not farest, save it in a TO
     bool rootIsFarest=frontToBackList->GetValue(numProcs-1)==0;
     if(!rootIsFarest)
-      {
+    {
       if(this->RootTexture==0)
-        {
+      {
         this->RootTexture=vtkTextureObject::New();
         this->RootTexture->SetContext(context);
-        }
+      }
       this->RootTexture->Allocate2D(dims[0],dims[1],4,VTK_UNSIGNED_CHAR);
       this->RootTexture->CopyFromFrameBuffer(0,0,0,0,w,h);
-      }
+    }
 
     // 3. in back to front order:
     // 3a. if this is step for root, render root TO (if not farest)
@@ -404,20 +419,20 @@ void vtkCompositeRGBAPass::Render(const vtkRenderState *s)
     int procIndex=numProcs-1;
     bool blendingEnabled=false;
     if(rootIsFarest)
-      {
+    {
       // nothing to do.
       --procIndex;
-      }
+    }
     while(procIndex>=0)
-      {
+    {
       vtkTextureObject *to;
       int proc=frontToBackList->GetValue(procIndex);
       if(proc==0)
-        {
+      {
           to=this->RootTexture;
-        }
+      }
       else
-        {
+      {
         // receive the rgba from satellite process.
         this->Controller->Receive(this->RawRGBABuffer,
                                   static_cast<vtkIdType>(this->RawRGBABufferSize),
@@ -428,27 +443,32 @@ void vtkCompositeRGBAPass::Render(const vtkRenderState *s)
         // Send PBO to TO
         this->RGBATexture->Create2D(dims[0],dims[1],4,this->PBO,false);
         to=this->RGBATexture;
-        }
+      }
       if(!blendingEnabled && procIndex<(numProcs-1))
-        {
+      {
         glEnable(GL_BLEND);
         blendingEnabled=true;
-        }
-#ifdef VTKGL2
+      }
+#ifdef VTK_OPENGL2
       to->Activate();
       to->CopyToFrameBuffer(0, 0, w - 1, h - 1, 0, 0, w, h, NULL, NULL);
       to->Deactivate();
+      --procIndex;
+    }
+    // restore blend func
+    glBlendFuncSeparate(blendSrcC, blendDstC, blendSrcA, blendDstA);
 #else
       vtkgl::ActiveTexture(vtkgl::TEXTURE0);
       // fixed-pipeline for vertex and fragment shaders.
       to->Bind();
       to->CopyToFrameBuffer(0,0,w-1,h-1,0,0,w,h);
       to->UnBind();
-#endif
       --procIndex;
-      }
+    }
     glPopAttrib();
+#endif
     frontToBackList->Delete();
+
 #ifdef VTK_COMPOSITE_RGBAPASS_DEBUG
     // get rgba-buffer of root before any blending with satellite
     // for debugging only.
@@ -486,7 +506,7 @@ void vtkCompositeRGBAPass::Render(const vtkRenderState *s)
 //    rgbaToRgb->SetInputConnection(importer->GetOutputPort());
 //    rgbaToRgb->SetComponents(0,1,2);
 
-    vtksys_ios::ostringstream osty;
+    std::ostringstream osty;
     osty.setf(ios::fixed,ios::floatfield);
     osty.precision(5);
     timer->StopTimer();
@@ -510,9 +530,9 @@ void vtkCompositeRGBAPass::Render(const vtkRenderState *s)
 #endif
 
     // root node Done.
-    }
+  }
   else
-    {
+  {
     // satellite
     // send rgba-buffer
 
@@ -553,7 +573,7 @@ void vtkCompositeRGBAPass::Render(const vtkRenderState *s)
 //    rgbaToRgb->SetInputConnection(importer->GetOutputPort());
 //    rgbaToRgb->SetComponents(0,1,2);
 
-    vtksys_ios::ostringstream ostxx;
+    std::ostringstream ostxx;
     ostxx.setf(ios::fixed,ios::floatfield);
     ostxx.precision(5);
     timer->StopTimer();
@@ -580,7 +600,7 @@ void vtkCompositeRGBAPass::Render(const vtkRenderState *s)
     this->Controller->Send(this->RawRGBABuffer,
                            static_cast<vtkIdType>(this->RawRGBABufferSize),0,
                            VTK_COMPOSITE_RGBA_PASS_MESSAGE_GATHER);
-    }
+  }
 #ifdef VTK_COMPOSITE_RGBAPASS_DEBUG
   delete state;
   timer->Delete();
@@ -599,18 +619,18 @@ void vtkCompositeRGBAPass::ReleaseGraphicsResources(vtkWindow *w)
   (void)w;
 
   if(this->PBO!=0)
-    {
+  {
     this->PBO->Delete();
     this->PBO=0;
-    }
+  }
   if(this->RGBATexture!=0)
-    {
+  {
     this->RGBATexture->Delete();
     this->RGBATexture=0;
-    }
+  }
   if(this->RootTexture!=0)
-    {
+  {
     this->RootTexture->Delete();
     this->RootTexture=0;
-    }
+  }
 }
