@@ -19,20 +19,46 @@
 #include "vtkPPixelTransfer.h"
 #include "vtkPainterCommunicator.h"
 #include "vtkPPainterCommunicator.h"
+#include "vtkRenderingOpenGLConfigure.h"
 #include "vtkRenderWindow.h"
+#ifdef VTK_OPENGL2
+# include "vtkOpenGLRenderUtilities.h"
+#endif
 #include "vtkOpenGLRenderWindow.h"
 #include "vtkTextureObject.h"
 #include "vtkPixelBufferObject.h"
 #include "vtkFrameBufferObject2.h"
 #include "vtkRenderbuffer.h"
-#include "vtkShader2.h"
-#include "vtkShaderProgram2.h"
-#include "vtkUniformVariables.h"
-#include "vtkShader2Collection.h"
-#include "vtkOpenGLExtensionManager.h"
-#include "vtkgl.h"
 #include "vtkMPI.h"
 
+
+#ifdef VTK_OPENGL2
+# include "vtkOpenGLHelper.h"
+# include "vtkOpenGLShaderCache.h"
+# include "vtkShaderProgram.h"
+# include "vtkTextureObjectVS.h"
+# include "vtkPSurfaceLICComposite_CompFS.h"
+#else
+# include "vtkShader2.h"
+# include "vtkShaderProgram2.h"
+# include "vtkUniformVariables.h"
+# include "vtkShader2Collection.h"
+# include "vtkOpenGLExtensionManager.h"
+# include "vtkgl.h"
+// compositing shader
+extern const char *vtkPSurfaceLICComposite_Comp;
+# ifndef GL_FRAMEBUFFER
+#  define GL_FRAMEBUFFER vtkgl::FRAMEBUFFER_EXT
+# endif
+# ifndef GL_DRAW_FRAMEBUFFER
+#  define GL_DRAW_FRAMEBUFFER vtkgl::DRAW_FRAMEBUFFER_EXT
+# endif
+# ifndef GL_TEXTURE0
+#  define GL_TEXTURE0 vtkgl::TEXTURE0
+# endif
+#endif
+
+
 #include <list>
 #include <deque>
 #include <vector>
@@ -83,9 +109,6 @@ string mpifn(int rank, const char *fn)
 
 // #define DUPLICATE_COMMUNICATOR
 
-// compositing shader
-extern const char *vtkPSurfaceLICComposite_Comp;
-
 // ***************************************************************************
 static
 int maxNumPasses(){ return 100; }
@@ -129,13 +152,13 @@ vtkPixelExtentUnion(void *in, void *out, int *len, MPI_Datatype *type)
   (void)type; // known to be MPI_INT
   int n = *len/4;
   for (int i=0; i<n; ++i)
-    {
+  {
     int ii = 4*i;
     vtkPixelExtent lhs(((int*)in)+ii);
     vtkPixelExtent rhs(((int*)out)+ii);
     rhs |= lhs;
     rhs.GetData(((int*)out)+ii);
-    }
+  }
 }
 
 // Description:
@@ -173,9 +196,9 @@ void vtkPPixelExtentOps::CreateOps()
 {
   if ( (this->Union == MPI_OP_NULL)
     && vtkPPainterCommunicator::MPIInitialized() )
-    {
+  {
     MPI_Op_create(vtkPixelExtentUnion, 1, &this->Union);
-    }
+  }
 }
 
 // ---------------------------------------------------------------------------
@@ -184,9 +207,9 @@ void vtkPPixelExtentOps::DeleteOps()
   if ( (this->Union != MPI_OP_NULL)
      && vtkPPainterCommunicator::MPIInitialized()
      && !vtkPPainterCommunicator::MPIFinalized() )
-    {
+  {
     MPI_Op_free(&this->Union);
-    }
+  }
 }
 
 // ****************************************************************************
@@ -194,9 +217,9 @@ void MPITypeFree(deque<MPI_Datatype> &types)
 {
   size_t n = types.size();
   for (size_t i=0; i<n; ++i)
-    {
+  {
     MPI_Type_free(&types[i]);
-    }
+  }
 }
 
 // ****************************************************************************
@@ -206,14 +229,14 @@ size_t Size(deque< deque<vtkPixelExtent> > exts)
   size_t np = 0;
   size_t nr = exts.size();
   for (size_t r=0; r<nr; ++r)
-    {
+  {
     const deque<vtkPixelExtent> &rexts = exts[r];
     size_t ne = rexts.size();
     for (size_t e=0; e<ne; ++e)
-      {
+    {
       np += rexts[e].Size();
-      }
     }
+  }
   return np;
 }
 
@@ -225,9 +248,9 @@ int NumberOfExtents(deque< deque<vtkPixelExtent> > exts)
   size_t ne = 0;
   size_t nr = exts.size();
   for (size_t r=0; r<nr; ++r)
-    {
+  {
     ne += exts[r].size();
-    }
+  }
   return static_cast<int>(ne);
 }
 #endif
@@ -239,13 +262,13 @@ ostream &operator<<(ostream &os, const vector<float> &vf)
 {
   size_t n = vf.size();
   if (n)
-    {
+  {
     os << vf[0];
-    }
+  }
   for (size_t i=1; i<n; ++i)
-    {
+  {
     os << ", " << vf[i];
-    }
+  }
   return os;
 }
 
@@ -255,9 +278,9 @@ ostream &operator<<(ostream &os, const vector<vector<float> >  &vvf)
 {
   size_t n = vvf.size();
   for (size_t i=0; i<n; ++i)
-    {
+  {
     os << i << " = {" << vvf[i] << "}" << endl;
-    }
+  }
   return os;
 }
 #endif
@@ -269,10 +292,10 @@ int ScanMPIStatusForError(vector<MPI_Status> &stat)
 {
   int nStats = stat.size();
   for (int q=0; q<nStats; ++q)
-    {
+  {
     int ierr = stat[q].MPI_ERROR;
     if ((ierr != MPI_SUCCESS) && (ierr != MPI_ERR_PENDING))
-      {
+    {
       char eStr[MPI_MAX_ERROR_STRING] = {'\0'};
       int eStrLen = 0;
       MPI_Error_string(ierr, eStr, &eStrLen);
@@ -281,8 +304,8 @@ int ScanMPIStatusForError(vector<MPI_Status> &stat)
         << eStr << endl
         << endl;
       return -1;
-      }
     }
+  }
   return 0;
 }
 #endif
@@ -313,13 +336,18 @@ vtkPSurfaceLICComposite::~vtkPSurfaceLICComposite()
   delete this->PainterComm;
   delete this->PixelOps;
   if (this->CompositeShader)
-    {
+  {
+#ifdef VTK_OPENGL2
+    delete this->CompositeShader;
+#else
     this->CompositeShader->Delete();
-    }
+#endif
+    this->CompositeShader = 0;
+  }
   if (this->FBO)
-    {
+  {
     this->FBO->Delete();
-    }
+  }
 }
 
 // ----------------------------------------------------------------------------
@@ -341,27 +369,40 @@ void vtkPSurfaceLICComposite::SetCommunicator(vtkPainterCommunicator *comm)
 void vtkPSurfaceLICComposite::SetContext(vtkOpenGLRenderWindow *rwin)
 {
   if (this->Context == rwin)
-    {
+  {
     return;
-    }
+  }
   this->Context = rwin;
 
   // free the existing shader and fbo
   if ( this->CompositeShader )
-    {
+  {
+#ifdef VTK_OPENGL2
+    this->CompositeShader->ReleaseGraphicsResources(rwin);
+    delete this->CompositeShader;
+#else
     this->CompositeShader->Delete();
+#endif
     this->CompositeShader = NULL;
-    }
+  }
 
   if ( this->FBO )
-    {
+  {
     this->FBO->Delete();
     this->FBO = NULL;
-    }
+  }
 
   if ( this->Context )
-    {
+  {
     // load, compile, and link the shader
+#ifdef VTK_OPENGL2
+    this->CompositeShader = new vtkOpenGLHelper;
+    std::string GSSource;
+    this->CompositeShader->Program =
+        rwin->GetShaderCache()->ReadyShaderProgram(vtkTextureObjectVS,
+                                          vtkPSurfaceLICComposite_CompFS,
+                                            GSSource.c_str());
+#else
     vtkShader2 *compositeShaderSrc = vtkShader2::New();
     compositeShaderSrc->SetContext(this->Context);
     compositeShaderSrc->SetType(VTK_SHADER_TYPE_FRAGMENT);
@@ -373,11 +414,12 @@ void vtkPSurfaceLICComposite::SetContext(vtkOpenGLRenderWindow *rwin)
     this->CompositeShader->Build();
 
     compositeShaderSrc->Delete();
+#endif
 
     // setup a FBO for rendering
     this->FBO = vtkFrameBufferObject2::New();
     this->FBO->SetContext(this->Context);
-    }
+  }
 }
 
 // ----------------------------------------------------------------------------
@@ -395,9 +437,9 @@ int vtkPSurfaceLICComposite::AllGatherExtents(
   int localSize = 4*nLocal;
   int *sendBuf = static_cast<int*>(malloc(localSize*sizeof(int)));
   for (int i=0; i<nLocal; ++i)
-    {
+  {
     localExts[i].GetData(sendBuf+4*i);
-    }
+  }
 
   // share local extent counts
   MPI_Comm comm = *(static_cast<MPI_Comm*>(this->PainterComm->GetCommunicator()));
@@ -417,12 +459,12 @@ int vtkPSurfaceLICComposite::AllGatherExtents(
   int *recvDispls = static_cast<int*>(malloc(this->CommSize*sizeof(int)));
   int bufSize = 0;
   for (int i=0; i<this->CommSize; ++i)
-    {
+  {
     int n = 4*nRemote[i];
     recvCounts[i] = n;
     recvDispls[i] = bufSize;
     bufSize += n;
-    }
+  }
   int *recvBuf = static_cast<int*>(malloc(bufSize*sizeof(int)));
 
   // collect remote extents
@@ -440,19 +482,19 @@ int vtkPSurfaceLICComposite::AllGatherExtents(
   dataSetExt.Clear();
   remoteExts.resize(this->CommSize);
   for (int i=0; i<this->CommSize; ++i)
-    {
+  {
     int nRemt = recvCounts[i]/4;
     remoteExts[i].resize(nRemt);
 
     int *pBuf = recvBuf+recvDispls[i];
 
     for (int j=0; j<nRemt; ++j)
-      {
+    {
       vtkPixelExtent &remoteExt = remoteExts[i][j];
       remoteExt.SetData(pBuf+4*j);
       dataSetExt |= remoteExt;
-      }
     }
+  }
 
   free(sendBuf);
   free(nRemote);
@@ -482,25 +524,25 @@ int vtkPSurfaceLICComposite::AllReduceVectorMax(
   MPI_Comm comm = *(static_cast<MPI_Comm*>(this->PainterComm->GetCommunicator()));
   vector<vector<float> > tmpMax(this->CommSize);
   for (int r=0; r<this->CommSize; ++r)
-    {
+  {
     // check the intersection of each new extent with that of each
     // original extent. data for origial extent is local.
     size_t nNew = newExts[r].size();
     tmpMax[r].resize(nNew, -VTK_FLOAT_MAX);
     for (size_t n=0; n<nNew; ++n)
-      {
+    {
       const vtkPixelExtent &newExt = newExts[r][n];
       float eMax = -VTK_FLOAT_MAX;
       for (size_t o=0; o<nOriginal; ++o)
-        {
+      {
         vtkPixelExtent intExt(originalExts[o]);
         intExt &= newExt;
         if (!intExt.Empty())
-          {
+        {
           float oMax = this->VectorMax(intExt, vectors);
           eMax = eMax<oMax ? oMax : eMax;
-          }
         }
+      }
 
       MPI_Allreduce(
             MPI_IN_PLACE,
@@ -511,18 +553,18 @@ int vtkPSurfaceLICComposite::AllReduceVectorMax(
             comm);
 
       tmpMax[r][n] = eMax;
-      }
     }
+  }
 
   // since integration run's into other blocks data use the max of the
   // block and it's neighbors for gaurd cell size computation
   vectorMax.resize(this->CommSize);
   for (int r=0; r<this->CommSize; ++r)
-    {
+  {
     size_t nNew = newExts[r].size();
     vectorMax[r].resize(nNew);
     for (size_t n=0; n<nNew; ++n)
-      {
+    {
       vtkPixelExtent newExt = newExts[r][n];
       newExt.Grow(1);
 
@@ -530,26 +572,26 @@ int vtkPSurfaceLICComposite::AllReduceVectorMax(
 
       // find neighbors
       for (int R=0; R<this->CommSize; ++R)
-        {
+      {
         size_t NNew = newExts[R].size();
         for (size_t N=0; N<NNew; ++N)
-          {
+        {
           vtkPixelExtent intExt(newExts[R][N]);
           intExt &= newExt;
 
           if (!intExt.Empty())
-            {
+          {
             // this is a neighbor(or self), take the larger of ours
             // and theirs
             float nMax = tmpMax[R][N];
             eMax = eMax<nMax ? nMax : eMax;
-            }
           }
         }
+      }
 
       vectorMax[r][n] = eMax;
-      }
     }
+  }
 
   return 0;
 }
@@ -576,22 +618,22 @@ int vtkPSurfaceLICComposite::DecomposeExtent(
 
   int dir=0;
   while(1)
-    {
+  {
     // stop when we have enough out or all out have unit size
     int nExts = static_cast<int>(out.size());
     if ( (nExts >= nPieces)
      || ((nPasses[0] > maxPasses[0]) && (nPasses[1] > maxPasses[1])) )
-      {
+    {
       break;
-      }
+    }
 
     for (int i=0; i<nExts; ++i)
-      {
+    {
       int nExtsTotal = static_cast<int>(out.size() + splitExts.size());
       if (nExtsTotal >= nPieces)
-        {
+      {
         break;
-        }
+      }
 
       // split this ext into two
       vtkPixelExtent ext = out.back();
@@ -602,10 +644,10 @@ int vtkPSurfaceLICComposite::DecomposeExtent(
       splitExts.push_back(ext);
 
       if (!newExt.Empty())
-        {
+      {
         splitExts.push_back(newExt);
-        }
       }
+    }
 
     // transfer the split out to the head so that
     // they are split again only after others.
@@ -617,10 +659,10 @@ int vtkPSurfaceLICComposite::DecomposeExtent(
     // alternate splitting direction
     dir = (dir + 1) % 2;
     if (nPasses[dir] > maxPasses[dir])
-      {
+    {
       dir = (dir + 1) % 2;
-      }
     }
+  }
 
   return 0;
 }
@@ -666,17 +708,17 @@ int vtkPSurfaceLICComposite::DecomposeScreenExtent(
   list<vtkPixelExtent>::iterator it = tmpOut0.begin();
 
   for (int r=0; r<this->CommSize; ++r)
-    {
+  {
     int n = nPer;
     if (r < nLarge)
-      {
+    {
       ++n;
-      }
-    for (int i=0; (i<n) && (N>0); ++i,--N,++it)
-      {
-      tmpOut1[r].push_back(*it);
-      }
     }
+    for (int i=0; (i<n) && (N>0); ++i,--N,++it)
+    {
+      tmpOut1[r].push_back(*it);
+    }
+  }
 
   // TODO -- we need to implement some sore of load
   // balancing here.
@@ -696,10 +738,10 @@ int vtkPSurfaceLICComposite::MakeDecompLocallyDisjoint(
   out.clear();
   out.resize(nr);
   for (size_t r=0; r<nr; ++r)
-    {
+  {
     deque<vtkPixelExtent> tmp(in[r]);
     this->MakeDecompDisjoint(tmp, out[r]);
-    }
+  }
   return 0;
 }
 
@@ -712,15 +754,15 @@ int vtkPSurfaceLICComposite::MakeDecompDisjoint(
   // flatten
   deque<pair<int, vtkPixelExtent> > tmpIn;
   for (int r=0; r<this->CommSize; ++r)
-    {
+  {
     const deque<vtkPixelExtent> &blocks = in[r];
     size_t nBlocks = blocks.size();
     for (size_t b=0; b<nBlocks; ++b)
-      {
+    {
       pair<int, vtkPixelExtent> elem(r, blocks[b]);
       tmpIn.push_back(elem);
-      }
     }
+  }
   // sort by size
   sort(tmpIn.begin(), tmpIn.end());
 
@@ -729,7 +771,7 @@ int vtkPSurfaceLICComposite::MakeDecompDisjoint(
   deque<pair<int, vtkPixelExtent> > tmpOut0;
 
   while ( !tmpIn.empty() )
-    {
+  {
     // largest element
     int rank = tmpIn.back().first;
     deque<vtkPixelExtent> tmpOut1(1,tmpIn.back().second);
@@ -739,26 +781,26 @@ int vtkPSurfaceLICComposite::MakeDecompDisjoint(
     // subtract smaller elements
     size_t ns = tmpIn.size();
     for (size_t se=0; se<ns; ++se)
-      {
+    {
       vtkPixelExtent &selem = tmpIn[se].second;
       deque<vtkPixelExtent> tmpOut2;
       size_t nl = tmpOut1.size();
       for (size_t le=0; le<nl; ++le)
-        {
+      {
         vtkPixelExtent &lelem = tmpOut1[le];
         vtkPixelExtent::Subtract(lelem, selem, tmpOut2);
-        }
-      tmpOut1 = tmpOut2;
       }
+      tmpOut1 = tmpOut2;
+    }
 
     // move to output
     size_t nn = tmpOut1.size();
     for (size_t ne=0; ne<nn; ++ne)
-      {
+    {
       pair<int, vtkPixelExtent> elem(rank, tmpOut1[ne]);
       tmpOut0.push_back(elem);
-      }
     }
+  }
 
   // reduce communication and compositing overhead by
   // shrinking the new set of extents to tightly bound the
@@ -772,35 +814,35 @@ int vtkPSurfaceLICComposite::MakeDecompDisjoint(
   deque<pair<int, vtkPixelExtent> > tmpOut1(tmpOut0);
   size_t ne = tmpOut1.size();
   for (size_t e=0; e<ne; ++e)
-    {
+  {
     vtkPixelExtent &newExt = tmpOut1[e].second;
     vtkPixelExtent tightExt;
     for (size_t i=0; i<ni; ++i)
-      {
+    {
       vtkPixelExtent inExt(inR[i]);
       inExt &= newExt;
       if (!inExt.Empty())
-        {
+      {
         GetPixelBounds(vectors, nx[0], inExt);
         tightExt |= inExt; // accumulate the contrib from local data
-        }
       }
-    newExt = tightExt;
     }
+    newExt = tightExt;
+  }
 
   // accumulate contrib from remote data
   size_t remSize = 4*ne;
   vector<int> rem(remSize);
-  int *pRem = &rem[0];
+  int *pRem = ne ? &rem[0] : NULL;
   for (size_t e=0; e<ne; ++e, pRem+=4)
-    {
+  {
     tmpOut1[e].second.GetData(pRem);
-    }
+  }
   MPI_Comm comm = *(static_cast<MPI_Comm*>(this->PainterComm->GetCommunicator()));
   MPI_Op parUnion = this->PixelOps->GetUnion();
   MPI_Allreduce(
         MPI_IN_PLACE,
-        &rem[0],
+        ne ? &rem[0] : NULL,
         (int)remSize,
         MPI_INT,
         parUnion,
@@ -808,23 +850,23 @@ int vtkPSurfaceLICComposite::MakeDecompDisjoint(
 
   // move from flat order back to rank indexed order and remove
   // empty extents
-  pRem = &rem[0];
+  pRem = ne ? &rem[0] : NULL;
   out.resize(this->CommSize);
   for (size_t e=0; e<ne; ++e, pRem+=4)
-    {
+  {
     int r = tmpOut1[e].first;
     vtkPixelExtent ext(pRem);
     if (!ext.Empty())
-      {
+    {
       out[r].push_back(ext);
-      }
     }
+  }
 
   // merge compatible extents
   for (int r=0; r<this->CommSize; ++r)
-    {
+  {
     vtkPixelExtent::Merge(out[r]);
-    }
+  }
 
   return 0;
 }
@@ -857,7 +899,7 @@ int vtkPSurfaceLICComposite::AddGuardPixels(
     = this->StepSize*this->NumberOfSteps*this->NumberOfGuardLevels*fudge;
 
   if (this->NormalizeVectors)
-    {
+  {
     // when normalizing velocity is always 1, all extents have the
     // same number of gaurd cells.
     int ng
@@ -872,23 +914,23 @@ int vtkPSurfaceLICComposite::AddGuardPixels(
     cerr << "ng=" << ng << endl;
     #endif
     for (int r=0; r<this->CommSize; ++r)
-      {
+    {
       deque<vtkPixelExtent> tmpExts(exts[r]);
       int nExts = static_cast<int>(tmpExts.size());
       // add guard pixles
       for (int b=0; b<nExts; ++b)
-        {
+      {
         tmpExts[b].Grow(ng);
         tmpExts[b] &= this->DataSetExt;
-        }
+      }
       guardExts[r] = tmpExts;
       // make sure it's disjoint
       disjointGuardExts[r].clear();
       this->MakeDecompDisjoint(tmpExts, disjointGuardExts[r]);
-      }
     }
+  }
   else
-    {
+  {
     // when not normailzing during integration we need max(V) on the LIC
     // decomp. Each domain has the potential to require a unique number
     // of gaurd cells.
@@ -906,11 +948,11 @@ int vtkPSurfaceLICComposite::AddGuardPixels(
     cerr << "ng=";
     #endif
     for (int r=0; r<this->CommSize; ++r)
-      {
+    {
       deque<vtkPixelExtent> tmpExts(exts[r]);
       size_t nExts = tmpExts.size();
       for (size_t b=0; b<nExts; ++b)
-        {
+      {
         int ng
           = static_cast<int>(vectorMax[r][b]*arc)
           + this->NumberOfEEGuardPixels
@@ -924,19 +966,19 @@ int vtkPSurfaceLICComposite::AddGuardPixels(
         #endif
         tmpExts[b].Grow(ng);
         tmpExts[b] &= this->DataSetExt;
-        }
+      }
       guardExts[r] = tmpExts;
       // make sure it's disjoint
       disjointGuardExts[r].clear();
       this->MakeDecompDisjoint(tmpExts, disjointGuardExts[r]);
-      }
+    }
     #ifdef vtkSurfaceLICPainterTIME
     log->GetHeader() << "\n";
     #endif
     #if vtkPSurfaceLICCompositeDEBUG>=2
     cerr << endl;
     #endif
-    }
+  }
 
   return 0;
 }
@@ -955,34 +997,34 @@ double vtkPSurfaceLICComposite::EstimateCommunicationCost(
   size_t overlap = 0;
 
   for (int sr=0; sr<this->CommSize; ++sr)
-    {
+  {
     size_t nse = srcExts[sr].size();
     for (size_t se=0; se<nse; ++se)
-      {
+    {
       const vtkPixelExtent &srcExt = srcExts[sr][se];
       total += srcExt.Size(); // count all pixels in the total
 
       for (int dr=0; dr<this->CommSize; ++dr)
-        {
+      {
         // only off rank overlap incurrs comm cost
         if (sr == dr)
-          {
+        {
           continue;
-          }
+        }
 
         size_t nde = destExts[dr].size();
         for (size_t de=0; de<nde; ++de)
-          {
+        {
           vtkPixelExtent destExt = destExts[dr][de];
           destExt &= srcExt;
           if (!destExt.Empty())
-            {
+          {
             overlap += destExt.Size(); // cost is number of overlap pixels
-            }
           }
         }
       }
     }
+  }
 
   return (static_cast<double>(overlap))/(static_cast<double>(total));
 }
@@ -1020,7 +1062,7 @@ int vtkPSurfaceLICComposite::BuildProgram(float *vectors)
         this->DataSetExt);
 
   if (this->Strategy == COMPOSITE_AUTO)
-    {
+  {
     double commCost = this->EstimateCommunicationCost(allBlockExts, allBlockExts);
     #ifdef vtkSurfaceLICPainterTIME
     log->GetHeader() << "in-place comm cost=" << commCost << "\n";
@@ -1029,7 +1071,7 @@ int vtkPSurfaceLICComposite::BuildProgram(float *vectors)
     cerr << "in-place comm cost=" << commCost << endl;
     #endif
     if (commCost <= 0.3)
-      {
+    {
       this->Strategy = COMPOSITE_INPLACE;
       #ifdef vtkSurfaceLICPainterTIME
       log->GetHeader() << "using in-place composite\n";
@@ -1037,9 +1079,9 @@ int vtkPSurfaceLICComposite::BuildProgram(float *vectors)
       #if vtkPSurfaceLICCompositeDEBUG>=2
       cerr << "using in-place composite" << endl;
       #endif
-      }
+    }
     else
-      {
+    {
       this->Strategy = COMPOSITE_INPLACE_DISJOINT;
       #ifdef vtkSurfaceLICPainterTIME
       log->GetHeader() << "using disjoint composite\n";
@@ -1047,13 +1089,13 @@ int vtkPSurfaceLICComposite::BuildProgram(float *vectors)
       #if vtkPSurfaceLICCompositeDEBUG>=2
       cerr << "using disjoint composite" << endl;
       #endif
-      }
     }
+  }
 
   // decompose the screen
   deque< deque<vtkPixelExtent> > newExts;
   switch (this->Strategy)
-    {
+  {
     case COMPOSITE_INPLACE:
       // make it locally disjoint to avoid redundant computation
       this->MakeDecompLocallyDisjoint(allBlockExts, newExts);
@@ -1069,7 +1111,7 @@ int vtkPSurfaceLICComposite::BuildProgram(float *vectors)
 
     default:
       return -1;
-    }
+  }
 
   #if defined(vtkSurfaceLICPainterTIME) || vtkPSurfaceLICCompositeDEBUG>=2
   double commCost = this->EstimateCommunicationCost(allBlockExts, newExts);
@@ -1088,31 +1130,31 @@ int vtkPSurfaceLICComposite::BuildProgram(float *vectors)
   int id=0;
   this->ScatterProgram.clear();
   if (this->Strategy != COMPOSITE_INPLACE)
-    {
+  {
     // construct program describing communication patterns that are
     // required to move data to geometry decomp from the new lic
     // decomp after LIC
     for (int srcRank=0; srcRank<this->CommSize; ++srcRank)
-      {
+    {
       deque<vtkPixelExtent> &srcBlocks = newExts[srcRank];
       int nSrcBlocks = static_cast<int>(srcBlocks.size());
 
       for (int sb=0; sb<nSrcBlocks; ++sb)
-        {
+      {
         const vtkPixelExtent &srcExt = srcBlocks[sb];
 
         for (int destRank=0; destRank<this->CommSize; ++destRank)
-          {
+        {
           int nBlocks = static_cast<int>(allBlockExts[destRank].size());
           for (int b=0; b<nBlocks; ++b)
-            {
+          {
             const vtkPixelExtent &destExt = allBlockExts[destRank][b];
 
             vtkPixelExtent sharedExt(destExt);
             sharedExt &= srcExt;
 
             if (!sharedExt.Empty())
-              {
+            {
               this->ScatterProgram.push_back(
                     vtkPPixelTransfer(
                           srcRank,
@@ -1122,13 +1164,13 @@ int vtkPSurfaceLICComposite::BuildProgram(float *vectors)
                           this->WindowExt,
                           sharedExt,
                           id));
-              }
-            id += 1;
             }
+            id += 1;
           }
         }
       }
     }
+  }
 
   #if vtkPSurfaceLICCompositeDEBUG>=1
   vtkPixelExtentIO::Write(this->CommRank, "ViewExtent.vtk", this->WindowExt);
@@ -1171,26 +1213,26 @@ int vtkPSurfaceLICComposite::BuildProgram(float *vectors)
   this->GatherProgram.clear();
   id=0;
   for (int destRank=0; destRank<this->CommSize; ++destRank)
-    {
+  {
     deque<vtkPixelExtent> &destBlocks = disjointGuardExts[destRank];
     int nDestBlocks = static_cast<int>(destBlocks.size());
 
     for (int db=0; db<nDestBlocks; ++db)
-      {
+    {
       const vtkPixelExtent &destExt = destBlocks[db];
 
       for (int srcRank=0; srcRank<this->CommSize; ++srcRank)
-        {
+      {
         int nBlocks = static_cast<int>(allBlockExts[srcRank].size());
         for (int b=0; b<nBlocks; ++b)
-          {
+        {
           const vtkPixelExtent &srcExt = allBlockExts[srcRank][b];
 
           vtkPixelExtent sharedExt(destExt);
           sharedExt &= srcExt;
 
           if (!sharedExt.Empty())
-            {
+          {
             // to move vectors for the LIC decomp
             // into a contiguous recv buffer
             this->GatherProgram.push_back(
@@ -1202,13 +1244,13 @@ int vtkPSurfaceLICComposite::BuildProgram(float *vectors)
                         sharedExt, // dest ext
                         sharedExt,
                         id));
-            }
+          }
 
           id += 1;
-          }
         }
       }
     }
+  }
 
   #if vtkSurfaceLICCompoisteDEBUG>=2
   cerr << *this << endl;
@@ -1241,30 +1283,30 @@ int vtkPSurfaceLICComposite::Gather(
 
   // validate inputs
   if (this->Pass >= maxNumPasses())
-    {
+  {
     return -1;
-    }
+  }
   if (pSendPBO == NULL)
-    {
+  {
     return -2;
-    }
+  }
   if (this->Context == NULL)
-    {
+  {
     return -3;
-    }
+  }
   if (this->CompositeShader == NULL)
-    {
+  {
     return -4;
-    }
+  }
 
   // get the size of the array datatype
   int dataTypeSize = 0;
   switch (dataType)
-    {
+  {
     vtkTemplateMacro(dataTypeSize = sizeof(VTK_TT););
     default:
       return -5;
-    }
+  }
 
   // initiate non-blocking comm
   MPI_Comm comm = *(static_cast<MPI_Comm*>(this->PainterComm->GetCommunicator()));
@@ -1278,15 +1320,15 @@ int vtkPSurfaceLICComposite::Gather(
   deque<void*> recvBufs(nTransactions, static_cast<void*>(NULL));
   #endif
   for (int j=0; j<nTransactions; ++j)
-    {
+  {
     vtkPPixelTransfer &transaction = this->GatherProgram[j];
 
     // postpone local transactions, they will be overlapped
     // with transactions requiring communication
     if (transaction.Local(this->CommRank))
-      {
+    {
       continue;
-      }
+    }
 
     #ifdef PBO_RECV_BUFFERS
     void *pRecvPBO = NULL;
@@ -1296,7 +1338,7 @@ int vtkPSurfaceLICComposite::Gather(
     int tag = encodeTag(j, this->Pass);
 
     if ( transaction.Receiver(this->CommRank) )
-      {
+    {
       // allocate receive buffers
       const vtkPixelExtent &destExt = transaction.GetDestinationExtent();
 
@@ -1316,7 +1358,7 @@ int vtkPSurfaceLICComposite::Gather(
       #else
       recvBufs[j] = malloc(bufSize);
       #endif
-      }
+    }
 
     vector<MPI_Request> &mpiReqs
       = transaction.Receiver(this->CommRank) ? mpiRecvReqs : mpiSendReqs;
@@ -1339,21 +1381,21 @@ int vtkPSurfaceLICComposite::Gather(
         mpiTypes,
         tag);
     if (iErr)
-      {
+    {
       cerr
         << this->CommRank
         << " transaction " << j << ":" << tag
         << " failed " << iErr << endl
         << transaction << endl;
-      }
     }
+  }
 
   // overlap framebuffer and shader config with communication
   unsigned int winExtSize[2];
   this->WindowExt.Size(winExtSize);
 
   if (newImage == NULL)
-    {
+  {
     newImage = vtkTextureObject::New();
     newImage->SetContext(this->Context);
     newImage->Create2D(
@@ -1362,19 +1404,19 @@ int vtkPSurfaceLICComposite::Gather(
           nComps,
           dataType,
           false);
-    }
+  }
 
   this->FBO->SaveCurrentBindings();
-  this->FBO->Bind(vtkgl::FRAMEBUFFER_EXT);
-  this->FBO->AddColorAttachment(vtkgl::DRAW_FRAMEBUFFER_EXT, 0U, newImage);
+  this->FBO->Bind(GL_FRAMEBUFFER);
+  this->FBO->AddColorAttachment(GL_DRAW_FRAMEBUFFER, 0U, newImage);
   this->FBO->ActivateDrawBuffer(0U);
 
   vtkRenderbuffer *depthBuf = vtkRenderbuffer::New();
   depthBuf->SetContext(this->Context);
   depthBuf->CreateDepthAttachment(winExtSize[0], winExtSize[1]);
-  this->FBO->AddDepthAttachment(vtkgl::DRAW_FRAMEBUFFER_EXT, depthBuf);
+  this->FBO->AddDepthAttachment(GL_DRAW_FRAMEBUFFER, depthBuf);
 
-  vtkCheckFrameBufferStatusMacro(vtkgl::FRAMEBUFFER_EXT);
+  vtkCheckFrameBufferStatusMacro(GL_FRAMEBUFFER);
 
   // the LIC'er requires all fragments in the vector
   // texture to be initialized to 0
@@ -1384,19 +1426,24 @@ int vtkPSurfaceLICComposite::Gather(
   glClearColor(0.0, 0.0, 0.0, 0.0);
   glClear(GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT);
 
+#ifdef VTK_OPENGL2
+  this->Context->GetShaderCache()->ReadyShaderProgram(
+    this->CompositeShader->Program);
+#else
   vtkUniformVariables *uniforms = this->CompositeShader->GetUniformVariables();
   uniforms->SetUniformit("texData", 0);
   this->CompositeShader->Use();
+#endif
 
   // overlap compositing of local data with communication
   for (int j=0; j<nTransactions; ++j)
-    {
+  {
     vtkPPixelTransfer &transaction = this->GatherProgram[j];
 
     if (!transaction.Local(this->CommRank))
-      {
+    {
       continue;
-      }
+    }
 
     #if vtkPSurfaceLICCompositeDEBUG>=2
     cerr
@@ -1425,13 +1472,13 @@ int vtkPSurfaceLICComposite::Gather(
           pRecvPBO);
 
     if (iErr)
-      {
+    {
       cerr
         << this->CommRank
         << " local transaction " << j << ":" << this->Pass
         << " failed " << iErr << endl
         << transaction << endl;
-      }
+    }
 
     pbo->UnmapUnpackedBuffer();
 
@@ -1454,20 +1501,20 @@ int vtkPSurfaceLICComposite::Gather(
     this->ExecuteShader(destExt, tex);
 
     tex->Delete();
-    }
+  }
 
   // composite inflight data as it arrives.
   int nRecvReqs = static_cast<int>(mpiRecvReqs.size());
   for (int i=0; i<nRecvReqs; ++i)
-    {
+  {
     // wait for the completion of one of the recvs
     MPI_Status stat;
     int reqId;
     int iErr = MPI_Waitany(nRecvReqs, &mpiRecvReqs[0], &reqId, &stat);
     if (iErr)
-      {
+    {
       vtkErrorMacro("comm error in recv");
-      }
+    }
 
     // decode transaction id
     int j = decodeTag(stat.MPI_TAG, this->Pass);
@@ -1527,25 +1574,27 @@ int vtkPSurfaceLICComposite::Gather(
     this->ExecuteShader(destExt, tex);
 
     tex->Delete();
-    }
+  }
+#ifndef VTK_OPENGL2
   this->CompositeShader->Restore();
+#endif
 
   this->FBO->DeactivateDrawBuffers();
-  this->FBO->RemoveTexColorAttachment(vtkgl::DRAW_FRAMEBUFFER_EXT, 0U);
-  this->FBO->RemoveRenDepthAttachment(vtkgl::DRAW_FRAMEBUFFER_EXT);
-  this->FBO->UnBind(vtkgl::FRAMEBUFFER_EXT);
+  this->FBO->RemoveTexColorAttachment(GL_DRAW_FRAMEBUFFER, 0U);
+  this->FBO->RemoveRenDepthAttachment(GL_DRAW_FRAMEBUFFER);
+  this->FBO->UnBind(GL_FRAMEBUFFER);
   depthBuf->Delete();
 
   // wait for sends to complete
   int nSendReqs = static_cast<int>(mpiSendReqs.size());
   if (nSendReqs)
-    {
+  {
     int iErr = MPI_Waitall(nSendReqs, &mpiSendReqs[0], MPI_STATUSES_IGNORE);
     if (iErr)
-      {
+    {
       vtkErrorMacro("comm error in send");
-      }
     }
+  }
 
   MPITypeFree(mpiTypes);
 
@@ -1557,8 +1606,6 @@ int vtkPSurfaceLICComposite::ExecuteShader(
       const vtkPixelExtent &ext,
       vtkTextureObject *tex)
 {
-  tex->Activate(vtkgl::TEXTURE0);
-
   // cell to node
   vtkPixelExtent next(ext);
   next.CellToNode();
@@ -1566,19 +1613,47 @@ int vtkPSurfaceLICComposite::ExecuteShader(
   float fext[4];
   next.GetData(fext);
 
+#ifdef VTK_OPENGL2
+  float tcoords[8] =
+    {0.0f, 0.0f,
+     1.0f, 0.0f,
+     1.0f, 1.0f,
+     0.0f, 1.0f};
+
+  tex->Activate();
+  this->CompositeShader->Program->SetUniformi("texData",
+    tex->GetTextureUnit());
+
+  unsigned int winExtSize[2];
+  this->WindowExt.Size(winExtSize);
+
+  float verts[] = {
+    2.0f*fext[0]/winExtSize[0]-1.0f, 2.0f*fext[2]/winExtSize[1]-1.0f, 0.0f,
+    2.0f*(fext[1]+1.0f)/winExtSize[0]-1.0f, 2.0f*fext[2]/winExtSize[1]-1.0f, 0.0f,
+    2.0f*(fext[1]+1.0f)/winExtSize[0]-1.0f, 2.0f*(fext[3]+1.0f)/winExtSize[1]-1.0f, 0.0f,
+    2.0f*fext[0]/winExtSize[0]-1.0f, 2.0f*(fext[3]+1.0f)/winExtSize[1]-1.0f, 0.0f};
+
+  vtkOpenGLRenderUtilities::RenderQuad(verts, tcoords,
+    this->CompositeShader->Program, this->CompositeShader->VAO);
+  tex->Deactivate();
+#else
   float tcoords[4] = {0.0f,1.0f, 0.0f,1.0f};
+
+  tex->Activate(GL_TEXTURE0);
+
   int ids[8] = {0,2, 1,2, 1,3, 0,3};
 
   glBegin(GL_QUADS);
   for (int q=0; q<4; ++q)
-    {
+  {
     int qq = 2*q;
     glTexCoord2f(tcoords[ids[qq]], tcoords[ids[qq+1]]);
     glVertex2f(fext[ids[qq]], fext[ids[qq+1]]);
-    }
+  }
   glEnd();
 
-  //tex->Deactivate(vtkgl::TEXTURE0);
+  //tex->Deactivate(GL_TEXTURE0);
+#endif
 
   return 0;
 }
@@ -1608,26 +1683,26 @@ int vtkPSurfaceLICComposite::Scatter(
 
   // validate inputs
   if (this->Pass >= maxNumPasses())
-    {
+  {
     return -1;
-    }
+  }
   if (pSendPBO == NULL)
-    {
+  {
     return -2;
-    }
+  }
   if (this->Context == NULL)
-    {
+  {
     return -3;
-    }
+  }
 
   // get the size of the array datatype
   int dataTypeSize = 0;
   switch (dataType)
-    {
+  {
     vtkTemplateMacro(dataTypeSize = sizeof(VTK_TT););
     default:
       return -4;
-    }
+  }
   unsigned int pboSize = (unsigned int)this->WindowExt.Size()*nComps;
   unsigned int bufSize = pboSize*dataTypeSize;
 
@@ -1653,15 +1728,15 @@ int vtkPSurfaceLICComposite::Scatter(
   vector<MPI_Request> mpiSendReqs;
   deque<MPI_Datatype> mpiTypes;
   for (int j=0; j<nTransactions; ++j)
-    {
+  {
     vtkPPixelTransfer &transaction = this->ScatterProgram[j];
 
     // postpone local transactions, they will be overlapped
     // with transactions requiring communication
     if (transaction.Local(this->CommRank))
-      {
+    {
       continue;
-      }
+    }
 
     // encode transaction.
     int tag = encodeTag(j, this->Pass);
@@ -1686,25 +1761,25 @@ int vtkPSurfaceLICComposite::Scatter(
         mpiTypes,
         tag);
     if (iErr)
-      {
+    {
       vtkErrorMacro(
         << this->CommRank
         << " transaction " << j << ":" << tag
         << " failed " << iErr << endl
         << transaction);
-      }
     }
+  }
 
   // overlap transfer of local data with communication. compositing is not
   // needed since source blocks are disjoint.
   for (int j=0; j<nTransactions; ++j)
-    {
+  {
     vtkPPixelTransfer &transaction = this->ScatterProgram[j];
 
     if (!transaction.Local(this->CommRank))
-      {
+    {
       continue;
-      }
+    }
 
     #if vtkPSurfaceLICCompositeDEBUG>=2
     cerr
@@ -1725,32 +1800,32 @@ int vtkPSurfaceLICComposite::Scatter(
         #endif
         );
     if (iErr)
-      {
+    {
       vtkErrorMacro(
         << this->CommRank
         << " local transaction " << j << ":" << this->Pass
         << " failed " << iErr << endl
         << transaction);
-      }
     }
+  }
 
   // recv remote data. compsiting is not needed since source blocks are
   // disjoint.
   int nRecvReqs = static_cast<int>(mpiRecvReqs.size());
   if (nRecvReqs)
-    {
+  {
     iErr = MPI_Waitall(nRecvReqs, &mpiRecvReqs[0], MPI_STATUSES_IGNORE);
     if (iErr)
-      {
+    {
       vtkErrorMacro("comm error in recv");
-      }
     }
+  }
 
   unsigned int winExtSize[2];
   this->WindowExt.Size(winExtSize);
 
   if (newImage == NULL)
-    {
+  {
     newImage = vtkTextureObject::New();
     newImage->SetContext(this->Context);
     newImage->Create2D(
@@ -1759,7 +1834,7 @@ int vtkPSurfaceLICComposite::Scatter(
           nComps,
           dataType,
           false);
-    }
+  }
 
   // transfer received data to the icet/decomp.
   #ifdef PBO_RECV_BUFFERS
@@ -1783,13 +1858,13 @@ int vtkPSurfaceLICComposite::Scatter(
   // wait for sends to complete
   int nSendReqs = static_cast<int>(mpiSendReqs.size());
   if (nSendReqs)
-    {
+  {
     iErr = MPI_Waitall(nSendReqs, &mpiSendReqs[0], MPI_STATUSES_IGNORE);
     if (iErr)
-      {
+    {
       vtkErrorMacro("comm error in send");
-      }
     }
+  }
 
   MPITypeFree(mpiTypes);
 
@@ -1810,48 +1885,48 @@ ostream &operator<<(ostream &os, vtkPSurfaceLICComposite &ss)
   MPI_Comm comm = *(static_cast<MPI_Comm*>(ss.PainterComm->GetCommunicator()));
   int rankBelow = ss.CommRank-1;
   if (rankBelow >= 0)
-    {
+  {
     MPI_Recv(NULL, 0, MPI_BYTE, rankBelow, 13579, comm, MPI_STATUS_IGNORE);
-    }
+  }
   os << "winExt=" << ss.WindowExt << endl;
   os << "blockExts=" << endl;
   size_t nExts = ss.BlockExts.size();
   for (size_t i=0; i<nExts; ++i)
-    {
+  {
     os << "  " << ss.BlockExts[i] << endl;
-    }
+  }
   os << "compositeExts=" << endl;
   nExts = ss.CompositeExt.size();
   for (size_t i=0; i<nExts; ++i)
-    {
+  {
     os << ss.CompositeExt[i] << endl;
-    }
+  }
   os << "guardExts=" << endl;
   for (size_t i=0; i<nExts; ++i)
-    {
+  {
     os << ss.GuardExt[i] << endl;
-    }
+  }
   os << "disjointGuardExts=" << endl;
   for (size_t i=0; i<nExts; ++i)
-    {
+  {
     os << ss.DisjointGuardExt[i] << endl;
-    }
+  }
   os << "SuffleProgram:" << endl;
   size_t nTransactions = ss.GatherProgram.size();
   for (size_t j=0; j<nTransactions; ++j)
-    {
+  {
     os << "  " << ss.GatherProgram[j] << endl;
-    }
+  }
   os << "UnSuffleProgram:" << endl;
   nTransactions = ss.ScatterProgram.size();
   for (size_t j=0; j<nTransactions; ++j)
-    {
+  {
     os << "  " << ss.ScatterProgram[j] << endl;
-    }
+  }
   int rankAbove = ss.CommRank+1;
   if (rankAbove < ss.CommSize)
-    {
+  {
     MPI_Send(NULL, 0, MPI_BYTE, rankAbove, 13579, comm);
-    }
+  }
   return os;
 }
