@@ -37,8 +37,11 @@
 #include "vtkNew.h"
 #include "vtkObjectFactory.h"
 #include "vtkOpenGLCamera.h"
+#include "vtkOpenGLIndexBufferObject.h"
 #include "vtkOpenGLRenderWindow.h"
 #include "vtkOpenGLShaderCache.h"
+#include "vtkOpenGLVertexArrayObject.h"
+#include "vtkOpenGLVertexBufferObject.h"
 #include "vtkPointData.h"
 #include "vtkRenderer.h"
 #include "vtkShaderProgram.h"
@@ -59,7 +62,6 @@
 #include "vtkglProjectedTetrahedraVS.h"
 #include "vtkglProjectedTetrahedraFS.h"
 
-// static int tet_faces[4][3] = { {1,2,3}, {2,0,3}, {0,1,3}, {0,2,1} };
 static int tet_edges[6][2] = { {0,1}, {1,2}, {2,0},
                                {0,3}, {1,3}, {2,3} };
 
@@ -70,11 +72,11 @@ class vtkOpenGLProjectedTetrahedraMapper::vtkInternals
 {
 public:
   vtkInternals()
-    {
+  {
     this->FrameBufferObjectId = 0;
     this->RenderBufferObjectIds[0] = 0;
     this->RenderBufferObjectIds[1] = 0;
-    }
+  }
   GLuint FrameBufferObjectId;
   GLuint RenderBufferObjectIds[2];
 };
@@ -100,6 +102,7 @@ vtkOpenGLProjectedTetrahedraMapper::vtkOpenGLProjectedTetrahedraMapper()
   this->UseFloatingPointFrameBuffer = true;
   this->CanDoFloatingPointFrameBuffer = false;
   this->HasHardwareSupport = false;
+  this->VBO = vtkOpenGLVertexBufferObject::New();
 }
 
 //-----------------------------------------------------------------------------
@@ -110,6 +113,7 @@ vtkOpenGLProjectedTetrahedraMapper::~vtkOpenGLProjectedTetrahedraMapper()
   this->Colors->Delete();
   delete this->Internals;
   delete[] this->SqrtTable;
+  this->VBO->Delete();
 }
 
 //-----------------------------------------------------------------------------
@@ -126,26 +130,37 @@ bool vtkOpenGLProjectedTetrahedraMapper::IsSupported(vtkRenderWindow *rwin)
 {
   vtkOpenGLRenderWindow *context = vtkOpenGLRenderWindow::SafeDownCast(rwin);
   if (!context)
-    {
+  {
     vtkErrorMacro(
       << "Support for " << rwin->GetClassName() << " not implemented");
     return false;
-    }
+  }
 
   // use render to FBO when it's supported
   this->CanDoFloatingPointFrameBuffer = false;
   if (this->UseFloatingPointFrameBuffer)
+  {
+#if GL_ES_VERSION_2_0 != 1
+    if (vtkOpenGLRenderWindow::GetContextSupportsOpenGL32())
     {
+      this->CanDoFloatingPointFrameBuffer = true;
+      return true;
+    }
+#endif
+
     this->CanDoFloatingPointFrameBuffer
+#if GL_ES_VERSION_2_0 != 1
       = (glewIsSupported("GL_EXT_framebuffer_object") != 0)
-      && (glewIsSupported("GL_ARB_draw_buffers") != 0)
-      && (glewIsSupported("GL_ARB_texture_float") != 0);
+        && (glewIsSupported("GL_ARB_texture_float") != 0);
+#else
+      = true;
+#endif
     if (!this->CanDoFloatingPointFrameBuffer)
-      {
+    {
       vtkWarningMacro(
         "Missing FBO support. The algorithm may produce visual artifacts.");
-      }
     }
+  }
 
   return true;
 }
@@ -154,9 +169,9 @@ bool vtkOpenGLProjectedTetrahedraMapper::IsSupported(vtkRenderWindow *rwin)
 void vtkOpenGLProjectedTetrahedraMapper::Initialize(vtkRenderer *renderer)
 {
   if (this->Initialized)
-    {
+  {
     return;
-    }
+  }
 
   this->Initialized = true;
 
@@ -164,10 +179,10 @@ void vtkOpenGLProjectedTetrahedraMapper::Initialize(vtkRenderer *renderer)
     = vtkOpenGLRenderWindow::SafeDownCast(renderer->GetRenderWindow());
   this->HasHardwareSupport = renwin != NULL && this->IsSupported(renwin);
   if (!this->HasHardwareSupport)
-    {
+  {
     // this is an error since there's no fallback.
     vtkErrorMacro("The required extensions are not supported.");
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -181,13 +196,13 @@ bool vtkOpenGLProjectedTetrahedraMapper::AllocateFBOResources(vtkRenderer *r)
     && (!this->FloatingPointFrameBufferResourcesAllocated
     || (size[0] != this->CurrentFBOWidth)
     || (size[0] != this->CurrentFBOHeight)) )
-    {
+  {
     this->CurrentFBOWidth = size[0];
     this->CurrentFBOHeight = size[1];
 
     // reserver handles fbo and renderbuffers
     if (!this->FloatingPointFrameBufferResourcesAllocated)
-      {
+    {
       glGenFramebuffers(1, &this->Internals->FrameBufferObjectId);
       vtkOpenGLCheckErrorMacro("failed at glGenFramebuffers");
 
@@ -195,13 +210,7 @@ bool vtkOpenGLProjectedTetrahedraMapper::AllocateFBOResources(vtkRenderer *r)
       vtkOpenGLCheckErrorMacro("failed at glGenRenderBuffers");
 
       this->FloatingPointFrameBufferResourcesAllocated = true;
-      }
-    // handle multisampling
-    // the ARB says if SAMPLE_BUFFERS is greater than 1
-    // on both READ and DRAW FBO then SAMPLES has to match.
-    // but if either have SAMPLE_BUFFERS zero then conversions
-    // are made.
-    glBindFramebuffer(GL_FRAMEBUFFER, 0);
+    }
 
     GLint winSampleBuffers = 0;
     glGetIntegerv(GL_SAMPLE_BUFFERS, &winSampleBuffers);
@@ -209,85 +218,79 @@ bool vtkOpenGLProjectedTetrahedraMapper::AllocateFBOResources(vtkRenderer *r)
     GLint winSamples = 0;
     glGetIntegerv(GL_SAMPLES, &winSamples);
 
-    glBindFramebuffer(GL_FRAMEBUFFER,
-          this->Internals->FrameBufferObjectId);
-
     GLint fboSampleBuffers = 0;
     glGetIntegerv(GL_SAMPLE_BUFFERS, &fboSampleBuffers);
 
-    vtkDebugMacro(
-      << "mutisample enabled "
-      << (glIsEnabled(GL_MULTISAMPLE)?"yes":"no")
-      << " winSampleBuffers=" << winSampleBuffers
-      << " winSamples=" << winSamples
-      << " fboSampleBuffers=" << fboSampleBuffers);
-
     int fboSamples
       = ((fboSampleBuffers >= 1)
       && (winSampleBuffers >= 1)
       && (winSamples >= 1))?winSamples:0;
 
+
+    // do not special handle multisampling, use the default.
+    // Multisampling is becoming less common as it
+    // is replaced with other techniques
+    glBindFramebuffer(GL_FRAMEBUFFER,
+      this->Internals->FrameBufferObjectId);
+
     // allocate storage for renderbuffers
     glBindRenderbuffer(
-          GL_RENDERBUFFER,
-          this->Internals->RenderBufferObjectIds[0]);
+      GL_RENDERBUFFER,
+      this->Internals->RenderBufferObjectIds[0]);
     vtkOpenGLCheckErrorMacro("failed at glBindRenderBuffer color");
-
     glRenderbufferStorageMultisample(
-          GL_RENDERBUFFER,
-          fboSamples,
-          GL_RGBA32F_ARB,
-          this->CurrentFBOWidth,
-          this->CurrentFBOHeight);
+      GL_RENDERBUFFER,
+      fboSamples,
+      GL_RGBA32F,
+      this->CurrentFBOWidth,
+      this->CurrentFBOHeight);
     vtkOpenGLCheckErrorMacro("failed at glRenderBufferStorage color");
 
+
     glBindRenderbuffer(
-          GL_RENDERBUFFER,
-          this->Internals->RenderBufferObjectIds[1]);
+      GL_RENDERBUFFER,
+      this->Internals->RenderBufferObjectIds[1]);
     vtkOpenGLCheckErrorMacro("failed at glBindRenderBuffer depth");
-
     glRenderbufferStorageMultisample(
-          GL_RENDERBUFFER,
-          fboSamples,
-          GL_DEPTH_COMPONENT,
-          this->CurrentFBOWidth,
-          this->CurrentFBOHeight);
-    vtkOpenGLCheckErrorMacro("failed at glRenderBufferStorage depth");
+      GL_RENDERBUFFER,
+      fboSamples,
+      GL_DEPTH_COMPONENT,
+      this->CurrentFBOWidth,
+      this->CurrentFBOHeight);
 
-   // best way to make it complete: bind the fbo for both draw+read
-   // durring setup
-   glBindFramebuffer(
-         GL_FRAMEBUFFER,
-         this->Internals->FrameBufferObjectId);
-   vtkOpenGLCheckErrorMacro("failed at glBindFramebuffer");
+    // Best way to make it complete: bind the fbo for both draw+read
+    // durring setup
+    glBindFramebuffer(
+      GL_FRAMEBUFFER,
+      this->Internals->FrameBufferObjectId);
 
-   glFramebufferRenderbuffer(
-         GL_FRAMEBUFFER,
-         GL_COLOR_ATTACHMENT0,
-         GL_RENDERBUFFER,
-         this->Internals->RenderBufferObjectIds[0]);
+    glFramebufferRenderbuffer(
+      GL_FRAMEBUFFER,
+      GL_COLOR_ATTACHMENT0,
+      GL_RENDERBUFFER,
+      this->Internals->RenderBufferObjectIds[0]);
     vtkOpenGLCheckErrorMacro("failed at glFramebufferRenderBuffer for color");
 
     glFramebufferRenderbuffer(
-          GL_FRAMEBUFFER,
-          GL_DEPTH_ATTACHMENT,
-          GL_RENDERBUFFER,
-          this->Internals->RenderBufferObjectIds[1]);
+      GL_FRAMEBUFFER,
+      GL_DEPTH_ATTACHMENT,
+      GL_RENDERBUFFER,
+      this->Internals->RenderBufferObjectIds[1]);
     vtkOpenGLCheckErrorMacro("failed at glFramebufferRenderBuffer for depth");
 
     // verify that it is usable
     GLenum status = glCheckFramebufferStatus(GL_FRAMEBUFFER);
     if(status != GL_FRAMEBUFFER_COMPLETE)
-      {
+    {
       glBindFramebuffer(GL_FRAMEBUFFER, 0);
       vtkWarningMacro(
         "Missing FBO support. The algorithm may produce visual artifacts.");
       this->CanDoFloatingPointFrameBuffer = false;
       return false;
-      }
+    }
     glBindFramebuffer(GL_FRAMEBUFFER, 0);
     this->CanDoFloatingPointFrameBuffer = true;
-    }
+  }
 
   return true;
 }
@@ -298,7 +301,7 @@ void vtkOpenGLProjectedTetrahedraMapper::ReleaseGraphicsResources(vtkWindow *win
   this->Initialized = false;
 
   if (this->FloatingPointFrameBufferResourcesAllocated)
-    {
+  {
       this->FloatingPointFrameBufferResourcesAllocated = false;
 
       glDeleteFramebuffers(1, &this->Internals->FrameBufferObjectId);
@@ -309,9 +312,10 @@ void vtkOpenGLProjectedTetrahedraMapper::ReleaseGraphicsResources(vtkWindow *win
       vtkOpenGLCheckErrorMacro("failed at glDeleteRenderbuffers");
       this->Internals->RenderBufferObjectIds[0] = 0;
       this->Internals->RenderBufferObjectIds[1] = 0;
-    }
+  }
 
-  this->VBO.ReleaseGraphicsResources();
+  this->VBO->ReleaseGraphicsResources();
+  this->Tris.ReleaseGraphicsResources(win);
 
   this->Superclass::ReleaseGraphicsResources(win);
 }
@@ -326,19 +330,25 @@ void vtkOpenGLProjectedTetrahedraMapper::Render(vtkRenderer *renderer,
   this->Initialize(renderer);
 
   if (!this->HasHardwareSupport)
-    {
+  {
     return;
-    }
+  }
 
   // make sure our shader program is loaded and ready to go
-  vtkOpenGLRenderWindow *renWin = vtkOpenGLRenderWindow::SafeDownCast(renderer->GetRenderWindow());
+  vtkOpenGLRenderWindow *renWin =
+    vtkOpenGLRenderWindow::SafeDownCast(renderer->GetRenderWindow());
+
+  if (renWin == NULL)
+  {
+    vtkErrorMacro("Invalid vtkOpenGLRenderWindow");
+  }
 
   vtkUnstructuredGridBase *input = this->GetInput();
   vtkVolumeProperty *property = volume->GetProperty();
 
   // has something changed that would require us to recreate the shader?
   if (!this->Tris.Program)
-    {
+  {
     // build the shader source code
     std::string VSSource = vtkglProjectedTetrahedraVS;
     std::string FSSource = vtkglProjectedTetrahedraFS;
@@ -346,65 +356,65 @@ void vtkOpenGLProjectedTetrahedraMapper::Render(vtkRenderer *renderer,
 
     // compile and bind it if needed
     vtkShaderProgram *newShader =
-      renWin->GetShaderCache()->ReadyShader(VSSource.c_str(),
+      renWin->GetShaderCache()->ReadyShaderProgram(VSSource.c_str(),
                                             FSSource.c_str(),
                                             GSSource.c_str());
 
     // if the shader changed reinitialize the VAO
     if (newShader != this->Tris.Program)
-      {
+    {
       this->Tris.Program = newShader;
-      this->Tris.vao.ShaderProgramChanged(); // reset the VAO as the shader has changed
-      }
+      this->Tris.VAO->ShaderProgramChanged(); // reset the VAO as the shader has changed
+    }
 
     this->Tris.ShaderSourceTime.Modified();
-    }
+  }
   else
-    {
-    renWin->GetShaderCache()->ReadyShader(this->Tris.Program);
-    }
+  {
+    renWin->GetShaderCache()->ReadyShaderProgram(this->Tris.Program);
+  }
 
   // Check to see if input changed.
   if (   (this->InputAnalyzedTime < this->MTime)
       || (this->InputAnalyzedTime < input->GetMTime()) )
-    {
+  {
     this->GaveError = 0;
     float max_cell_size2 = 0;
 
     if (input->GetNumberOfCells() == 0)
-      {
+    {
       // Apparently, the input has no cells.  Just do nothing.
       return;
-      }
+    }
 
     vtkSmartPointer<vtkCellIterator> cellIter =
         vtkSmartPointer<vtkCellIterator>::Take(input->NewCellIterator());
     for (cellIter->InitTraversal(); !cellIter->IsDoneWithTraversal();
          cellIter->GoToNextCell())
-      {
+    {
       vtkIdType npts = cellIter->GetNumberOfPoints();
       if (npts != 4)
-        {
+      {
         if (!this->GaveError)
-          {
+        {
           vtkErrorMacro("Encountered non-tetrahedra cell!");
           this->GaveError = 1;
-          }
-        continue;
         }
+        continue;
+      }
       vtkIdType *pts = cellIter->GetPointIds()->GetPointer(0);
       for (int j = 0; j < 6; j++)
-        {
+      {
         double p1[3], p2[3];
         input->GetPoint(pts[tet_edges[j][0]], p1);
         input->GetPoint(pts[tet_edges[j][1]], p2);
         float size2 = (float)vtkMath::Distance2BetweenPoints(p1, p2);
         if (size2 > max_cell_size2)
-          {
+        {
           max_cell_size2 = size2;
-          }
         }
       }
+    }
 
     this->MaxCellSize = (float)sqrt(max_cell_size2);
 
@@ -413,57 +423,57 @@ void vtkOpenGLProjectedTetrahedraMapper::Render(vtkRenderer *renderer,
     // than calling the sqrt function.
     this->SqrtTableBias = (SqrtTableSize-1)/max_cell_size2;
     for (int i = 0; i < SqrtTableSize; i++)
-      {
+    {
       this->SqrtTable[i] = (float)sqrt(i/this->SqrtTableBias);
-      }
+    }
 
     this->InputAnalyzedTime.Modified();
-    }
+  }
 
   if (renderer->GetRenderWindow()->CheckAbortStatus() || this->GaveError)
-    {
+  {
     vtkOpenGLCheckErrorMacro("failed during Render");
     return;
-    }
+  }
 
   if (renderer->GetRenderWindow()->CheckAbortStatus())
-    {
+  {
     vtkOpenGLCheckErrorMacro("failed during Render");
     return;
-    }
+  }
 
   // Check to see if we need to remap colors.
   if (   (this->ColorsMappedTime < this->MTime)
       || (this->ColorsMappedTime < input->GetMTime())
       || (this->LastProperty != property)
       || (this->ColorsMappedTime < property->GetMTime()) )
-    {
+  {
     vtkDataArray *scalars = this->GetScalars(input, this->ScalarMode,
                                              this->ArrayAccessMode,
                                              this->ArrayId, this->ArrayName,
                                              this->UsingCellColors);
     if (!scalars)
-      {
+    {
       vtkErrorMacro(<< "Can't use projected tetrahedra without scalars!");
       vtkOpenGLCheckErrorMacro("failed during Render");
       return;
-      }
+    }
 
     vtkProjectedTetrahedraMapper::MapScalarsToColors(this->Colors, property,
                                                      scalars);
 
     this->ColorsMappedTime.Modified();
     this->LastProperty = property;
-    }
+  }
   if (renderer->GetRenderWindow()->CheckAbortStatus())
-    {
+  {
     vtkOpenGLCheckErrorMacro("failed during Render");
     return;
-    }
+  }
 
   this->Timer->StartTimer();
 
-  this->ProjectTetrahedra(renderer, volume);
+  this->ProjectTetrahedra(renderer, volume, renWin);
 
   this->Timer->StopTimer();
   this->TimeToDraw = this->Timer->GetElapsedTime();
@@ -479,13 +489,13 @@ inline float vtkOpenGLProjectedTetrahedraMapper::GetCorrectedDepth(
                                          float linear_depth_correction)
 {
   if (use_linear_depth_correction)
-    {
+  {
     float depth = linear_depth_correction*(z1 - z2);
     if (depth < 0) depth = -depth;
     return depth;
-    }
+  }
   else
-    {
+  {
     float eye1[3], eye2[3], invw;
 
     // This code does the same as the commented code above, but also collects
@@ -519,54 +529,53 @@ inline float vtkOpenGLProjectedTetrahedraMapper::GetCorrectedDepth(
 
     float dist2 = vtkMath::Distance2BetweenPoints(eye1, eye2);
     return this->SqrtTable[(int)(dist2*this->SqrtTableBias)];
-    }
+  }
 }
 
 //-----------------------------------------------------------------------------
 void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer,
-                                                     vtkVolume *volume)
+  vtkVolume *volume, vtkOpenGLRenderWindow* renWin)
 {
   vtkOpenGLClearErrorMacro();
+  unsigned int const defaultFBO = renWin->GetFrameBufferObject();
 
   // after mucking about with FBO bindings be sure
   // we're saving the default fbo attributes/blend function
-  glPushAttrib(GL_COLOR_BUFFER_BIT);
-  vtkOpenGLCheckErrorMacro("failed at glPushAttrib");
-
   this->AllocateFBOResources(renderer);
 
   if (this->UseFloatingPointFrameBuffer
     && this->CanDoFloatingPointFrameBuffer)
-    {
+  {
     // bind draw+read to set it up
     glBindFramebuffer(GL_FRAMEBUFFER,
           this->Internals->FrameBufferObjectId);
 
     glReadBuffer(GL_NONE);
     GLenum dbuf = GL_COLOR_ATTACHMENT0;
-    glDrawBuffersARB(1, &dbuf);
+    glDrawBuffers(1, &dbuf);
 
     GLenum status = glCheckFramebufferStatus(GL_DRAW_FRAMEBUFFER);
     if (status!= GL_FRAMEBUFFER_COMPLETE)
-      {
+    {
       vtkErrorMacro("FBO is incomplete " << status);
-      }
+    }
 
     // read from default
-    glBindFramebuffer(GL_READ_FRAMEBUFFER, 0);
+    glBindFramebuffer(GL_READ_FRAMEBUFFER, defaultFBO);
+
     // draw to fbo
     glBindFramebuffer(GL_DRAW_FRAMEBUFFER,
                            this->Internals->FrameBufferObjectId);
 
     glBlitFramebuffer(0, 0,
-                           this->CurrentFBOWidth, this->CurrentFBOHeight,
-                           0, 0,
-                           this->CurrentFBOWidth, this->CurrentFBOHeight,
-                           GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT,
-                           GL_NEAREST);
+                      this->CurrentFBOWidth, this->CurrentFBOHeight,
+                      0, 0,
+                      this->CurrentFBOWidth, this->CurrentFBOHeight,
+                      GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT,
+                      GL_NEAREST);
 
     vtkOpenGLCheckErrorMacro("failed at glBlitFramebuffer");
-    }
+  }
 
   // TODO:
   // There are some caching optimizations that could be used
@@ -584,9 +593,9 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
   this->VisibilitySort->InitTraversal();
 
   if (renderer->GetRenderWindow()->CheckAbortStatus())
-    {
+  {
     return;
-    }
+  }
 
   vtkMatrix4x4 *wcdc;
   vtkMatrix4x4 *wcvc;
@@ -596,38 +605,43 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
   cam->GetKeyMatrices(renderer,wcvc,norms,vcdc,wcdc);
   float projection_mat[16];
   for(int i = 0; i < 4; ++i)
-    {
+  {
     for (int j = 0; j < 4; ++j)
-      {
+    {
       projection_mat[i*4+j] = vcdc->GetElement(i, j);
-      }
     }
+  }
 
   float modelview_mat[16];
   if (!volume->GetIsIdentity())
-    {
+  {
     vtkMatrix4x4 *tmpMat = vtkMatrix4x4::New();
+    vtkMatrix4x4 *tmpMat2 = vtkMatrix4x4::New();
     vtkMatrix4x4 *mcwc = volume->GetMatrix();
-    vtkMatrix4x4::Multiply4x4(mcwc, wcvc, tmpMat);
+    tmpMat2->DeepCopy(wcvc);
+    tmpMat2->Transpose();
+    vtkMatrix4x4::Multiply4x4(tmpMat2, mcwc, tmpMat);
+    tmpMat->Transpose();
     for(int i = 0; i < 4; ++i)
-      {
-      for (int j = 0; j < 4; ++j)
-        {
-        modelview_mat[i*4+j] = tmpMat->GetElement(i, j);
-        }
-      }
-    tmpMat->Delete();
-    }
-  else
     {
-    for(int i = 0; i < 4; ++i)
-      {
       for (int j = 0; j < 4; ++j)
-        {
-        modelview_mat[i*4+j] = wcvc->GetElement(i, j);
-        }
+      {
+        modelview_mat[i*4+j] = tmpMat->GetElement(i, j);
       }
     }
+    tmpMat->Delete();
+    tmpMat2->Delete();
+  }
+  else
+  {
+    for(int i = 0; i < 4; ++i)
+    {
+      for (int j = 0; j < 4; ++j)
+      {
+        modelview_mat[i*4+j] = wcvc->GetElement(i, j);
+      }
+    }
+  }
 
   // Get the inverse projection matrix so that we can convert distances in
   // clipping space to distances in world or eye space.
@@ -654,7 +668,7 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
                                  && (projection_mat[11] == 0.0)
                                  && (projection_mat[15] == 1.0) );
   if (use_linear_depth_correction)
-    {
+  {
     float pos1[3], *pos2;
 
     pos1[0] = inverse_projection_mat[8] + inverse_projection_mat[12];
@@ -664,7 +678,7 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
     pos2 = inverse_projection_mat + 12;
 
     linear_depth_correction = sqrt(vtkMath::Distance2BetweenPoints(pos1, pos2));
-    }
+  }
   // Transform all the points.
   vtkProjectedTetrahedraMapper::TransformPoints(input->GetPoints(),
                                                 projection_mat, modelview_mat,
@@ -672,28 +686,37 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
   float *points = this->TransformedPoints->GetPointer(0);
 
   if (renderer->GetRenderWindow()->CheckAbortStatus())
-    {
+  {
     return;
-    }
+  }
 
   glDepthMask(GL_FALSE);
 
   glDisable(GL_CULL_FACE);
 
-  glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
+  GLint blendSrcA = GL_ONE;
+  GLint blendDstA = GL_ONE_MINUS_SRC_ALPHA;
+  GLint blendSrcC = GL_SRC_ALPHA;
+  GLint blendDstC = GL_ONE_MINUS_SRC_ALPHA;
+  glGetIntegerv(GL_BLEND_SRC_ALPHA, &blendSrcA);
+  glGetIntegerv(GL_BLEND_DST_ALPHA, &blendDstA);
+  glGetIntegerv(GL_BLEND_SRC_RGB, &blendSrcC);
+  glGetIntegerv(GL_BLEND_DST_RGB, &blendDstC);
+  glBlendFuncSeparate(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA,
+    GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
 
   float unit_distance = volume->GetProperty()->GetScalarOpacityUnitDistance();
 
   // build the VBO and IBOs,  we so these in chuncks as based on
   // the settings of the VisibilitySort tclass
 
-  this->Layout.VertexOffset = 0;
-  this->Layout.NormalOffset = 0;
-  this->Layout.ColorOffset = 3*sizeof(float);
-  this->Layout.ColorComponents = 3;
-  this->Layout.TCoordOffset = 4*sizeof(float);
-  this->Layout.TCoordComponents = 2;
-  this->Layout.Stride = 6*sizeof(float);
+  this->VBO->VertexOffset = 0;
+  this->VBO->NormalOffset = 0;
+  this->VBO->ColorOffset = 3*sizeof(float);
+  this->VBO->ColorComponents = 3;
+  this->VBO->TCoordOffset = 4*sizeof(float);
+  this->VBO->TCoordComponents = 2;
+  this->VBO->Stride = 6*sizeof(float);
 
   // Establish vertex arrays.
   // tets have 4 points, 5th point here is used
@@ -717,13 +740,13 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
   for (vtkIdTypeArray *sorted_cell_ids = this->VisibilitySort->GetNextCells();
        sorted_cell_ids != NULL;
        sorted_cell_ids = this->VisibilitySort->GetNextCells())
-    {
+  {
     this->UpdateProgress((double)numcellsrendered/totalnumcells);
 
     if (renderer->GetRenderWindow()->CheckAbortStatus())
-      {
+    {
       break;
-      }
+    }
     vtkIdType *cell_ids = sorted_cell_ids->GetPointer(0);
     vtkIdType num_cell_ids = sorted_cell_ids->GetNumberOfTuples();
 
@@ -733,14 +756,14 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
     indexArray.resize(0);
 
     for (vtkIdType i = 0; i < num_cell_ids; i++)
-      {
+    {
       vtkIdType cell = cell_ids[i];
       input->GetCellPoints(cell, cellPointIds.GetPointer());
       int j;
 
       // Get the data for the tetrahedra.
       for (j = 0; j < 4; j++)
-        {
+      {
         // Assuming we only have tetrahedra, each entry in cells has 5
         // components.
         const float *p = points + 3 * cellPointIds->GetId(j);
@@ -750,13 +773,13 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
 
         const unsigned char *c;
         if (this->UsingCellColors)
-          {
+        {
           c = colors + 4*cell;
-          }
+        }
         else
-          {
+        {
           c = colors + 4 * cellPointIds->GetId(j);
-          }
+        }
 
         tet_colors[j*3 + 0] = c[0];
         tet_colors[j*3 + 1] = c[1];
@@ -764,7 +787,7 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
 
         tet_texcoords[j*2 + 0] = static_cast<float>(c[3])/255.0f;
         tet_texcoords[j*2 + 1] = 0;
-        }
+      }
 
       // Do not render this cell if it is outside of the cutting planes.  For
       // most planes, cut if all points are outside.  For the near plane, cut if
@@ -782,9 +805,9 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
               && (tet_points[2*3+2] >  1.0f) && (tet_points[3*3+2] >  1.0f) )
           || (   (tet_points[0*3+2] < -1.0f) || (tet_points[1*3+2] < -1.0f)
               || (tet_points[2*3+2] < -1.0f) || (tet_points[3*3+2] < -1.0f) ) )
-        {
+      {
         continue;
-        }
+      }
 
       // The classic PT algorithm uses face normals to determine the
       // projection class and then do calculations individually.  However,
@@ -812,20 +835,20 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
       if (   (face_dir1 * face_dir2 >= 0)
           && (   (face_dir1 != 0)       // Handle a special case where 2 faces
               || (face_dir2 != 0) ) )   // are perpendicular to the view plane.
-        {
+      {
         segment1[0] = 0;  segment1[1] = 3;
         segment2[0] = 1;  segment2[1] = 2;
-        }
+      }
       else if (face_dir1 * face_dir3 >= 0)
-        {
+      {
         segment1[0] = 0;  segment1[1] = 2;
         segment2[0] = 1;  segment2[1] = 3;
-        }
+      }
       else      // Unless the tet is degenerate, face_dir2*face_dir3 >= 0
-        {
+      {
         segment1[0] = 0;  segment1[1] = 1;
         segment2[0] = 2;  segment2[1] = 3;
-        }
+      }
 
 #define VEC3SUB(Z,X,Y)          \
   (Z)[0] = (X)[0] - (Y)[0];     \
@@ -869,7 +892,7 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
       float beta = (A[1]*C[0]-A[0]*C[1])/denominator;
 
       if ((alpha >= 0) && (alpha <= 1))
-        {
+      {
         // The two segments intersect.  This corresponds to class 2 in
         // Shirley and Tuchman (or one of the degenerate cases).
 
@@ -922,7 +945,7 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
                                        + T3[0] + alpha*(T4[0]-T3[0]));
 
         // Record the depth at the intersection.
-        tet_texcoords[2*4 + 1] = depth/(unit_distance*this->MaxCellSize);
+        tet_texcoords[2*4 + 1] = depth/unit_distance;
 
         // Establish the order in which the points should be rendered.
         unsigned char indices[6];
@@ -934,24 +957,24 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
         indices[5] = segment1[0];
         // add the cells to the IBO
         for (int cellIdx = 0; cellIdx < 4; cellIdx++)
-          {
+        {
           indexArray.push_back(indices[0]+numPts);
           indexArray.push_back(indices[cellIdx+1]+numPts);
           indexArray.push_back(indices[cellIdx+2]+numPts);
-          }
         }
+      }
       else
-        {
+      {
         // The two segments do not intersect.  This corresponds to class 1
         // in Shirley and Tuchman.
         if (alpha <= 0)
-          {
+        {
           // Flip segment1 so that alpha is >= 1.  P1 and P2 are also
           // flipped as are C1-C2 and T1-T2.  Note that this will
           // invalidate A.  B and beta are unaffected.
           std::swap(segment1[0], segment1[1]);
           alpha = 1 - alpha;
-          }
+        }
         // From here on, we can assume P2 is the "thick" point.
 
         // Find the depth under the thick point.  Use the alpha and beta
@@ -968,12 +991,12 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
         // Fix color at thick point.  Average color with color of opposite
         // face.
         for (j = 0; j < 3; j++)
-          {
+        {
           float edgec = C3[j] + beta*(C4[j]-C3[j]);
           float pointc = C1[j];
           float facec = (edgec + (alpha-1)*pointc)/alpha;
           C2[j] = (unsigned char)(0.5f*(facec + C2[j]));
-          }
+        }
 
 //         tet_colors[3*segment1[0] + 0] = 0;
 //         tet_colors[3*segment1[0] + 1] = 255;
@@ -996,7 +1019,7 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
         T2[0] = 0.5f*(facea + T2[0]);
 
         // Record thickness at thick point.
-        T2[1] = depth/this->MaxCellSize;
+        T2[1] = depth/unit_distance;
 
         // Establish the order in which the points should be rendered.
         unsigned char indices[5];
@@ -1008,17 +1031,17 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
 
         // add the cells to the IBO
         for (int cellIdx = 0; cellIdx < 3; cellIdx++)
-          {
+        {
           indexArray.push_back(indices[0]+numPts);
           indexArray.push_back(indices[cellIdx+1]+numPts);
           indexArray.push_back(indices[cellIdx+2]+numPts);
-          }
         }
+      }
 
       // add the points to the VBO
       union { unsigned char c[4]; float f; } v = { { 0, 0, 0, 255 } };
       for (int ptIdx = 0; ptIdx < 5; ptIdx++)
-        {
+      {
         *(it++) = tet_points[ptIdx*3];
         *(it++) = tet_points[ptIdx*3+1];
         *(it++) = tet_points[ptIdx*3+2];
@@ -1028,65 +1051,65 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
         *(it++) = v.f;
         *(it++) = tet_texcoords[ptIdx*2]; // attenuation
         *(it++) = tet_texcoords[ptIdx*2+1]; // depth
-        }
+      }
       numPts += 5;
-      }
+    }
 
-    this->VBO.Upload(packedVBO, vtkgl::BufferObject::ArrayBuffer);
-    this->Layout.VertexCount = numPts;
-    this->VBO.Bind();
+    this->VBO->Upload(packedVBO, vtkOpenGLBufferObject::ArrayBuffer);
+    this->VBO->VertexCount = numPts;
+    this->VBO->Bind();
 
-    this->Tris.vao.Bind();
-    if (this->Tris.indexCount && (
-        this->Tris.ShaderSourceTime > this->Tris.attributeUpdateTime))
+    this->Tris.VAO->Bind();
+    if (this->Tris.IBO->IndexCount && (
+        this->Tris.ShaderSourceTime > this->Tris.AttributeUpdateTime))
+    {
+      if (!this->Tris.VAO->AddAttributeArray(this->Tris.Program, this->VBO,
+                                      "vertexDC", this->VBO->VertexOffset,
+                                      this->VBO->Stride, VTK_FLOAT, 3, false))
       {
-      if (!this->Tris.vao.AddAttributeArray(this->Tris.Program, this->VBO,
-                                      "vertexDC", this->Layout.VertexOffset,
-                                      this->Layout.Stride, VTK_FLOAT, 3, false))
-        {
         vtkErrorMacro(<< "Error setting 'vertexDC' in shader VAO.");
-        }
-      if (!this->Tris.vao.AddAttributeArray(this->Tris.Program, this->VBO,
-                                      "scalarColor", this->Layout.ColorOffset,
-                                      this->Layout.Stride, VTK_UNSIGNED_CHAR,
-                                      this->Layout.ColorComponents, true))
-        {
-        vtkErrorMacro(<< "Error setting 'scalarColor' in shader VAO.");
-        }
-      if (!this->Tris.vao.AddAttributeArray(this->Tris.Program, this->VBO,
-                                      "attenuationArray", this->Layout.TCoordOffset,
-                                      this->Layout.Stride, VTK_FLOAT,
-                                      1, false))
-        {
-        vtkErrorMacro(<< "Error setting attenuation in shader VAO.");
-        }
-      if (!this->Tris.vao.AddAttributeArray(this->Tris.Program, this->VBO,
-                                      "depthArray", this->Layout.TCoordOffset+sizeof(float),
-                                      this->Layout.Stride, VTK_FLOAT,
-                                      1, false))
-        {
-        vtkErrorMacro(<< "Error setting depth in shader VAO.");
-        }
-      this->Tris.attributeUpdateTime.Modified();
       }
+      if (!this->Tris.VAO->AddAttributeArray(this->Tris.Program, this->VBO,
+                                      "scalarColor", this->VBO->ColorOffset,
+                                      this->VBO->Stride, VTK_UNSIGNED_CHAR,
+                                      this->VBO->ColorComponents, true))
+      {
+        vtkErrorMacro(<< "Error setting 'scalarColor' in shader VAO.");
+      }
+      if (!this->Tris.VAO->AddAttributeArray(this->Tris.Program, this->VBO,
+                                      "attenuationArray", this->VBO->TCoordOffset,
+                                      this->VBO->Stride, VTK_FLOAT,
+                                      1, false))
+      {
+        vtkErrorMacro(<< "Error setting attenuation in shader VAO.");
+      }
+      if (!this->Tris.VAO->AddAttributeArray(this->Tris.Program, this->VBO,
+                                      "depthArray", this->VBO->TCoordOffset+sizeof(float),
+                                      this->VBO->Stride, VTK_FLOAT,
+                                      1, false))
+      {
+        vtkErrorMacro(<< "Error setting depth in shader VAO.");
+      }
+      this->Tris.AttributeUpdateTime.Modified();
+    }
 
-    this->Tris.ibo.Upload(indexArray, vtkgl::BufferObject::ElementArrayBuffer);
-    this->Tris.indexCount = indexArray.size();
-    this->Tris.ibo.Bind();
+    this->Tris.IBO->Upload(indexArray, vtkOpenGLBufferObject::ElementArrayBuffer);
+    this->Tris.IBO->IndexCount = indexArray.size();
+    this->Tris.IBO->Bind();
     glDrawRangeElements(GL_TRIANGLES, 0,
-                        static_cast<GLuint>(this->Layout.VertexCount - 1),
-                        static_cast<GLsizei>(this->Tris.indexCount),
+                        static_cast<GLuint>(this->VBO->VertexCount - 1),
+                        static_cast<GLsizei>(this->Tris.IBO->IndexCount),
                         GL_UNSIGNED_INT,
                         reinterpret_cast<const GLvoid *>(NULL));
-    this->Tris.ibo.Release();
-    this->Tris.vao.Release();
-    this->VBO.Release();
+    this->Tris.IBO->Release();
+    this->Tris.VAO->Release();
+    this->VBO->Release();
     numcellsrendered += num_cell_ids;
-    }
+  }
 
   if (this->UseFloatingPointFrameBuffer
     && this->CanDoFloatingPointFrameBuffer)
-    {
+  {
     // copy from our fbo to the default one
     glBindFramebuffer(GL_FRAMEBUFFER,
           this->Internals->FrameBufferObjectId);
@@ -1096,31 +1119,31 @@ void vtkOpenGLProjectedTetrahedraMapper::ProjectTetrahedra(vtkRenderer *renderer
 
     GLenum status = glCheckFramebufferStatus(GL_READ_FRAMEBUFFER);
     if (status != GL_FRAMEBUFFER_COMPLETE)
-      {
+    {
       vtkErrorMacro("FBO is incomplete " << status);
-      }
+    }
 
     // read from fbo
     glBindFramebuffer(GL_READ_FRAMEBUFFER,
-                           this->Internals->FrameBufferObjectId);
+                      this->Internals->FrameBufferObjectId);
     // draw to default fbo
-    glBindFramebuffer(GL_DRAW_FRAMEBUFFER, 0);
+    glBindFramebuffer(GL_DRAW_FRAMEBUFFER, defaultFBO);
 
     glBlitFramebuffer(0, 0, this->CurrentFBOWidth, this->CurrentFBOHeight,
-                         0, 0, this->CurrentFBOWidth, this->CurrentFBOHeight,
-                         GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT, GL_NEAREST);
+                      0, 0, this->CurrentFBOWidth, this->CurrentFBOHeight,
+                      GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT, GL_NEAREST);
 
     vtkOpenGLCheckErrorMacro("failed at glBlitFramebuffer");
 
     // restore default fbo for both read+draw
-    glBindFramebuffer(GL_FRAMEBUFFER, 0);
-    }
+    glBindFramebuffer(GL_FRAMEBUFFER, defaultFBO);
+  }
 
   // Restore the blend function.
-  glPopAttrib();
   vtkOpenGLCheckErrorMacro("failed at glPopAttrib");
 
   glDepthMask(GL_TRUE);
+  glBlendFuncSeparate(blendSrcC, blendDstC, blendSrcA, blendDstA);
 
   vtkOpenGLCheckErrorMacro("failed after ProjectTetrahedra");
   this->UpdateProgress(1.0);
