@@ -13,6 +13,9 @@
 
 =========================================================================*/
 
+#ifndef vtkRenderTimingTests_h
+#define vtkRenderTimingTests_h
+
 /*
 To add a test you must define a subclass of vtkRTTest and implement the
 pure virtual functions. Then in the main section at the bottom of this
@@ -29,6 +32,7 @@ existing tests to get an idea of what to do.
 #include "vtkPointData.h"
 #include "vtkPolyData.h"
 #include "vtkPolyDataMapper.h"
+#include "vtkRenderingOpenGLConfigure.h"
 #include "vtkRenderWindow.h"
 #include "vtkRenderer.h"
 #include "vtkNew.h"
@@ -97,7 +101,7 @@ class surfaceTest : public vtkRTTest
     ren1->AddActor(actor.Get());
 
     // set the size/color of our window
-    renWindow->SetSize(500, 500);
+    renWindow->SetSize(this->GetRenderWidth(), this->GetRenderHeight());
     ren1->SetBackground(0.2, 0.3, 0.5);
 
     // draw the resulting scene
@@ -200,7 +204,7 @@ class glyphTest : public vtkRTTest
     ren1->AddActor(actor.Get());
 
     // set the size/color of our window
-    renWindow->SetSize(600, 600);
+    renWindow->SetSize(this->GetRenderWidth(), this->GetRenderHeight());
     ren1->SetBackground(0.2, 0.3, 0.5);
 
     // draw the resulting scene
@@ -338,7 +342,7 @@ class moleculeTest : public vtkRTTest
     ren1->AddActor(actor.GetPointer());
 
     // set the size/color of our window
-    renWindow->SetSize(600,600);
+    renWindow->SetSize(this->GetRenderWidth(), this->GetRenderHeight());
     ren1->SetBackground(0.2,0.3,0.5);
 
     // draw the resulting scene
@@ -398,8 +402,9 @@ Define a test for volume rendering
 class volumeTest : public vtkRTTest
 {
   public:
-  volumeTest(const char *name) : vtkRTTest(name)
+  volumeTest(const char *name, bool withShading) : vtkRTTest(name)
     {
+    this->WithShading = withShading;
     }
 
   const char *GetSummaryResultName()
@@ -419,24 +424,36 @@ class volumeTest : public vtkRTTest
     ats->GetSequenceNumbers(res1,res2,res3);
 
     vtkNew<vtkRTAnalyticSource> wavelet;
-    wavelet->SetWholeExtent(0, 100*res1 -1,
-                            0, 100*res2 -1,
-                            0, 100*res3 -1);
+    wavelet->SetWholeExtent(-50*res1 - 1, 50*res1,
+                            -50*res2 - 1, 50*res2,
+                            -50*res3 - 1, 50*res3);
     wavelet->Update();
 
     vtkNew<vtkGPUVolumeRayCastMapper> volumeMapper;
     volumeMapper->SetInputConnection(wavelet->GetOutputPort());
+    volumeMapper->AutoAdjustSampleDistancesOff();
+    volumeMapper->SetSampleDistance(0.9);
 
     vtkNew<vtkVolumeProperty> volumeProperty;
     vtkNew<vtkColorTransferFunction> ctf;
-    ctf->AddHSVPoint(37.3531, 0.3, 1.0, 1);
-    ctf->AddHSVPoint(100.091, 0.0, 1.0, 1.0);
-    ctf->AddHSVPoint(276.829, 0.0, 0.2, 1.0);
+    ctf->AddRGBPoint(33.34, 0.23, 0.3, 0.75);
+    ctf->AddRGBPoint(72.27, 0.79, 0.05, 0.22);
+    ctf->AddRGBPoint(110.3, 0.8, 0.75, 0.82);
+    ctf->AddRGBPoint(134.19, 0.78, 0.84, 0.04);
+    ctf->AddRGBPoint(159.84, 0.07, 0.87, 0.43);
+    ctf->AddRGBPoint(181.96, 0.84, 0.31, 0.48);
+    ctf->AddRGBPoint(213.803, 0.73, 0.62, 0.8);
+    ctf->AddRGBPoint(255.38, 0.75, 0.19, 0.05);
+    ctf->AddRGBPoint(286.33, 0.7, 0.02, 0.15);
     ctf->SetColorSpaceToHSV();
 
     vtkNew<vtkPiecewiseFunction> pwf;
-    pwf->AddPoint(37.3531, 0.0);
-    pwf->AddPoint(276.829, 1.0/res1);
+    pwf->AddPoint(33.35, 0.0);
+    pwf->AddPoint(81.99, 0.01);
+    pwf->AddPoint(128.88, 0.02);
+    pwf->AddPoint(180.19, 0.03);
+    pwf->AddPoint(209.38, 0.04);
+    pwf->AddPoint(286.33, 0.05);
 
     volumeProperty->SetColor(ctf.GetPointer());
     volumeProperty->SetScalarOpacity(pwf.GetPointer());
@@ -444,6 +461,10 @@ class volumeTest : public vtkRTTest
     vtkNew<vtkVolume> volume;
     volume->SetMapper(volumeMapper.GetPointer());
     volume->SetProperty(volumeProperty.GetPointer());
+    if (this->WithShading)
+      {
+      volumeProperty->ShadeOn();
+      }
 
     // create a rendering window and renderer
     vtkNew<vtkRenderer> ren1;
@@ -452,7 +473,7 @@ class volumeTest : public vtkRTTest
     ren1->AddActor(volume.GetPointer());
 
     // set the size/color of our window
-    renWindow->SetSize(600, 600);
+    renWindow->SetSize(this->GetRenderWidth(), this->GetRenderHeight());
     ren1->SetBackground(0.2, 0.3, 0.4);
 
     // draw the resulting scene
@@ -487,5 +508,138 @@ class volumeTest : public vtkRTTest
 
     return result;
     }
+
+  protected:
+  bool WithShading;
 };
 
+/*=========================================================================
+Define a test for depth peeling transluscent geometry.
+=========================================================================*/
+#include "vtkParametricTorus.h"
+#include "vtkParametricFunctionSource.h"
+#include "vtkProperty.h"
+#include "vtkTransform.h"
+
+class depthPeelingTest : public vtkRTTest
+{
+  public:
+  depthPeelingTest(const char *name, bool withNormals)
+    : vtkRTTest(name),
+      WithNormals(withNormals)
+  {
+  }
+
+  const char *GetSummaryResultName() { return "subsequent frame time"; }
+
+  const char *GetSecondSummaryResultName() { return "first frame time"; }
+
+  virtual vtkRTTestResult Run(vtkRTTestSequence *ats,
+      int /*argc*/, char * /* argv */[])
+    {
+    int ures, vres;
+    ats->GetSequenceNumbers(ures,vres);
+
+    // ------------------------------------------------------------
+    // Create surface
+    // ------------------------------------------------------------
+    vtkNew<vtkParametricTorus> PB;
+    vtkNew<vtkParametricFunctionSource> PFS;
+    PFS->SetParametricFunction(PB.Get());
+    if (this->WithNormals == false)
+      {
+      PFS->GenerateNormalsOff();
+      }
+    PFS->SetUResolution(ures * 50);
+    PFS->SetVResolution(vres * 100);
+    PFS->Update();
+
+    vtkNew<vtkPolyDataMapper> mapper;
+    mapper->SetInputConnection(PFS->GetOutputPort());
+    mapper->SetScalarRange(0.0, 360.0);
+
+    // create a rendering window and renderer
+    vtkNew<vtkRenderer> ren1;
+    vtkNew<vtkRenderWindow> renWindow;
+    renWindow->SetMultiSamples(0);
+    renWindow->SetAlphaBitPlanes(1);
+    renWindow->AddRenderer(ren1.Get());
+
+    // Setup depth peeling to render an exact scene:
+    ren1->UseDepthPeelingOn();
+    ren1->SetMaximumNumberOfPeels(100);
+    ren1->SetOcclusionRatio(0.);
+
+    // Create a set of 10 colored translucent actors at slight offsets:
+    const int NUM_ACTORS = 10;
+    const unsigned char colors[NUM_ACTORS][4] = { { 255,   0,   0, 32 },
+                                                  {   0, 255,   0, 32 },
+                                                  {   0,   0, 255, 32 },
+                                                  { 128, 128,   0, 32 },
+                                                  {   0, 128, 128, 32 },
+                                                  { 128,   0, 128, 32 },
+                                                  { 128,  64,  64, 32 },
+                                                  {  64, 128,  64, 32 },
+                                                  {  64,  64, 128, 32 },
+                                                  {  64,  64,  64, 32 } };
+
+    for (int i = 0; i < NUM_ACTORS; ++i)
+      {
+      vtkNew<vtkActor> actor;
+      actor->SetMapper(mapper.Get());
+      actor->GetProperty()->SetColor(colors[i][0] / 255.,
+                                     colors[i][1] / 255.,
+                                     colors[i][2] / 255.);
+      actor->GetProperty()->SetOpacity(colors[i][3] / 255.);
+
+      vtkNew<vtkTransform> xform;
+      xform->Identity();
+      xform->RotateX(i * (180. / static_cast<double>(NUM_ACTORS)));
+      actor->SetUserTransform(xform.Get());
+
+      ren1->AddActor(actor.Get());
+      }
+
+    // set the size/color of our window
+    renWindow->SetSize(this->GetRenderWidth(), this->GetRenderHeight());
+    ren1->SetBackground(0.2, 0.3, 0.5);
+
+    // draw the resulting scene
+    double startTime = vtkTimerLog::GetUniversalTime();
+    renWindow->Render();
+    double firstFrameTime = vtkTimerLog::GetUniversalTime() - startTime;
+    ren1->GetActiveCamera()->Azimuth(90);
+    ren1->ResetCameraClippingRange();
+
+    int frameCount = 80;
+    for (int i = 0; i < frameCount; i++)
+      {
+      renWindow->Render();
+      ren1->GetActiveCamera()->Azimuth(1);
+      ren1->GetActiveCamera()->Elevation(1);
+      if ((vtkTimerLog::GetUniversalTime() - startTime - firstFrameTime) >
+          this->TargetTime * 1.5)
+        {
+        frameCount = i + 1;
+        break;
+        }
+      }
+    double subsequentFrameTime = (vtkTimerLog::GetUniversalTime() - startTime -
+                                  firstFrameTime) / frameCount;
+    double numTris = PFS->GetOutput()->GetPolys()->GetNumberOfCells();
+    numTris *= NUM_ACTORS;
+
+    vtkRTTestResult result;
+    result.Results["first frame time"] = firstFrameTime;
+    result.Results["subsequent frame time"] = subsequentFrameTime;
+    result.Results["FPS"] = 1. / subsequentFrameTime;
+    result.Results["triangles"] = numTris;
+
+    return result;
+    }
+
+  protected:
+  bool WithNormals;
+};
+
+#endif
