@@ -35,32 +35,32 @@ void output_proto_vars(FILE *fp, int i)
 
   /* ignore void */
   if (aType == VTK_PARSE_VOID)
-    {
+  {
     return;
-    }
+  }
 
   if (currentFunction->ArgTypes[i] == VTK_PARSE_FUNCTION)
-    {
+  {
     fprintf(fp,"jobject id0, jstring id1");
     return;
-    }
+  }
 
   if ((aType == VTK_PARSE_CHAR_PTR) ||
       (aType == VTK_PARSE_STRING) ||
       (aType == VTK_PARSE_STRING_REF))
-    {
+  {
     fprintf(fp,"jstring ");
     fprintf(fp,"id%i",i);
     return;
-    }
+  }
 
   if ((aType == VTK_PARSE_FLOAT_PTR) ||
       (aType == VTK_PARSE_DOUBLE_PTR))
-    {
+  {
     fprintf(fp,"jdoubleArray ");
     fprintf(fp,"id%i",i);
     return;
-    }
+  }
 
   if ((aType == VTK_PARSE_INT_PTR) ||
       (aType == VTK_PARSE_SHORT_PTR) ||
@@ -69,15 +69,15 @@ void output_proto_vars(FILE *fp, int i)
       (aType == VTK_PARSE_ID_TYPE_PTR) ||
       (aType == VTK_PARSE_LONG_LONG_PTR) ||
       (aType == VTK_PARSE___INT64_PTR))
-    {
+  {
     fprintf(fp,"jintArray ");
     fprintf(fp,"id%i",i);
     return;
-    }
+  }
 
 
   switch ((aType & VTK_PARSE_BASE_TYPE) & ~VTK_PARSE_UNSIGNED)
-    {
+  {
     case VTK_PARSE_FLOAT:   fprintf(fp,"jdouble "); break;
     case VTK_PARSE_DOUBLE:   fprintf(fp,"jdouble "); break;
     case VTK_PARSE_INT:   fprintf(fp,"jint "); break;
@@ -92,7 +92,7 @@ void output_proto_vars(FILE *fp, int i)
     case VTK_PARSE_CHAR:   fprintf(fp,"jchar "); break;
     case VTK_PARSE_OBJECT:   fprintf(fp,"jobject "); break;
     case VTK_PARSE_UNKNOWN: fprintf(fp,"jint "); break;
-    }
+  }
 
   fprintf(fp,"id%i",i);
 }
@@ -105,19 +105,19 @@ void use_hints(FILE *fp)
 
   /* use the hint */
   switch (rType)
-    {
+  {
     case VTK_PARSE_UNSIGNED_CHAR_PTR:
       /* for vtkDataWriter we want to handle this case specially */
       if (strcmp(currentFunction->Name,"GetBinaryOutputString") ||
           strcmp(CurrentData->Name,"vtkDataWriter"))
-        {
+      {
         fprintf(fp,"    return vtkJavaMakeJArrayOfByteFromUnsignedChar(env,temp%i,%i);\n",
                 MAX_ARGS, currentFunction->HintSize);
-        }
+      }
       else
-        {
+      {
         fprintf(fp,"    return vtkJavaMakeJArrayOfByteFromUnsignedChar(env,temp%i,op->GetOutputStringLength());\n", MAX_ARGS);
-        }
+      }
       break;
 
     case VTK_PARSE_FLOAT_PTR:
@@ -145,11 +145,6 @@ void use_hints(FILE *fp)
               MAX_ARGS, currentFunction->HintSize);
       break;
 
-    case VTK_PARSE___INT64_PTR:
-      fprintf(fp,"    return vtkJavaMakeJArrayOfIntFrom__Int64(env,temp%i,%i);\n",
-              MAX_ARGS, currentFunction->HintSize);
-      break;
-
     case VTK_PARSE_SIGNED_CHAR_PTR:
       fprintf(fp,"    return vtkJavaMakeJArrayOfIntFromSignedChar(env,temp%i,%i);\n",
               MAX_ARGS, currentFunction->HintSize);
@@ -177,7 +172,7 @@ void use_hints(FILE *fp)
     case VTK_PARSE_UNSIGNED_LONG_LONG_PTR:
     case VTK_PARSE_UNSIGNED___INT64_PTR:
       break;
-    }
+  }
 }
 
 void return_result(FILE *fp)
@@ -186,7 +181,7 @@ void return_result(FILE *fp)
     (currentFunction->ReturnType & VTK_PARSE_UNQUALIFIED_TYPE);
 
   switch (rType)
-    {
+  {
     case VTK_PARSE_FLOAT:
       fprintf(fp,"jdouble ");
       break;
@@ -243,7 +238,7 @@ void return_result(FILE *fp)
     case VTK_PARSE_UNSIGNED___INT64_PTR:
       fprintf(fp,"jarray ");
       break;
-    }
+  }
 }
 
 
@@ -252,36 +247,36 @@ void output_temp(FILE *fp, int i, unsigned int aType, const char *Id,
 {
   /* handle VAR FUNCTIONS */
   if (aType == VTK_PARSE_FUNCTION)
-    {
+  {
     fprintf(fp,"  vtkJavaVoidFuncArg *temp%i = new vtkJavaVoidFuncArg;\n",i);
     return;
-    }
+  }
 
   /* ignore void */
   if ((aType & VTK_PARSE_UNQUALIFIED_TYPE) == VTK_PARSE_VOID)
-    {
+  {
     return;
-    }
+  }
 
   /* for const * return types prototype with const */
   if ((i == MAX_ARGS) &&
       ((aType & VTK_PARSE_INDIRECT) != 0) &&
       ((aType & VTK_PARSE_CONST) != 0))
-    {
+  {
     fprintf(fp,"  const ");
-    }
+  }
   else
-    {
+  {
     fprintf(fp,"  ");
-    }
+  }
 
   if ((aType & VTK_PARSE_UNSIGNED) != 0)
-    {
+  {
     fprintf(fp," unsigned ");
-    }
+  }
 
   switch ((aType & VTK_PARSE_BASE_TYPE) & ~VTK_PARSE_UNSIGNED)
-    {
+  {
     case VTK_PARSE_FLOAT:   fprintf(fp,"float  "); break;
     case VTK_PARSE_DOUBLE:   fprintf(fp,"double "); break;
     case VTK_PARSE_INT:   fprintf(fp,"int    "); break;
@@ -297,28 +292,28 @@ void output_temp(FILE *fp, int i, unsigned int aType, const char *Id,
     case VTK_PARSE_OBJECT:     fprintf(fp,"%s ",Id); break;
     case VTK_PARSE_STRING:  fprintf(fp,"%s ",Id); break;
     case VTK_PARSE_UNKNOWN: fprintf(fp,"%s ",Id); break;
-    }
+  }
 
   switch (aType & VTK_PARSE_INDIRECT)
-    {
+  {
     case VTK_PARSE_REF:
       if (i == MAX_ARGS)
-        {
+      {
         fprintf(fp, " *"); /* act " &" */
-        }
+      }
       break;
     case VTK_PARSE_POINTER:
       if ((i == MAX_ARGS) ||
           ((aType & VTK_PARSE_UNQUALIFIED_TYPE) == VTK_PARSE_OBJECT_PTR) ||
           ((aType & VTK_PARSE_UNQUALIFIED_TYPE) == VTK_PARSE_CHAR_PTR))
-        {
+      {
         fprintf(fp, " *");
-        }
+      }
       break;
     default:
       fprintf(fp,"  ");
       break;
-    }
+  }
   fprintf(fp,"temp%i",i);
 
   /* handle arrays */
@@ -326,10 +321,10 @@ void output_temp(FILE *fp, int i, unsigned int aType, const char *Id,
       (i != MAX_ARGS) &&
       ((aType & VTK_PARSE_UNQUALIFIED_TYPE) != VTK_PARSE_OBJECT_PTR) &&
       ((aType & VTK_PARSE_UNQUALIFIED_TYPE) != VTK_PARSE_CHAR_PTR))
-    {
+  {
     fprintf(fp,"[%i]",aCount);
     fprintf(fp,";\n  void *tempArray%i",i);
-    }
+  }
 
   fprintf(fp,";\n");
 }
@@ -342,23 +337,23 @@ void get_args(FILE *fp, int i)
 
   /* handle VAR FUNCTIONS */
   if (currentFunction->ArgTypes[i] == VTK_PARSE_FUNCTION)
-    {
+  {
     fprintf(fp,"  env->GetJavaVM(&(temp%i->vm));\n",i);
     fprintf(fp,"  temp%i->uobj = env->NewGlobalRef(id0);\n",i);
     fprintf(fp,"  char *temp%i_str;\n",i);
     fprintf(fp,"  temp%i_str = vtkJavaUTFToChar(env,id1);\n",i);
     fprintf(fp,"  temp%i->mid = env->GetMethodID(env->GetObjectClass(id0),temp%i_str,\"()V\");\n",i,i);
     return;
-    }
+  }
 
   /* ignore void */
   if (aType == VTK_PARSE_VOID)
-    {
+  {
     return;
-    }
+  }
 
   switch (aType)
-    {
+  {
     case VTK_PARSE_CHAR:
       fprintf(fp,"  temp%i = (char)(0xff & id%i);\n",i,i);
       break;
@@ -379,9 +374,9 @@ void get_args(FILE *fp, int i)
     case VTK_PARSE_DOUBLE_PTR:
       fprintf(fp,"  tempArray%i = (void *)(env->GetDoubleArrayElements(id%i,NULL));\n",i,i);
       for (j = 0; j < currentFunction->ArgCounts[i]; j++)
-        {
+      {
         fprintf(fp,"  temp%i[%i] = ((jdouble *)tempArray%i)[%i];\n",i,j,i,j);
-        }
+      }
       break;
     case VTK_PARSE_INT_PTR:
     case VTK_PARSE_SHORT_PTR:
@@ -393,9 +388,9 @@ void get_args(FILE *fp, int i)
     case VTK_PARSE_BOOL_PTR:
       fprintf(fp,"  tempArray%i = (void *)(env->GetIntArrayElements(id%i,NULL));\n",i,i);
       for (j = 0; j < currentFunction->ArgCounts[i]; j++)
-        {
+      {
         fprintf(fp,"  temp%i[%i] = ((jint *)tempArray%i)[%i];\n",i,j,i,j);
-        }
+      }
       break;
     case VTK_PARSE_UNKNOWN:
       fprintf(fp,"  temp%i = static_cast<%s>(id%i);\n",
@@ -405,7 +400,7 @@ void get_args(FILE *fp, int i)
     case VTK_PARSE_OBJECT:
     case VTK_PARSE_OBJECT_REF: break;
     default: fprintf(fp,"  temp%i = id%i;\n",i,i); break;
-    }
+  }
 }
 
 
@@ -417,25 +412,25 @@ void copy_and_release_args(FILE *fp, int i)
 
   /* handle VAR FUNCTIONS */
   if (currentFunction->ArgTypes[i] == VTK_PARSE_FUNCTION)
-    {
+  {
     fprintf(fp,"  delete[] temp%i_str;\n",i);
     return;
-    }
+  }
 
   /* ignore void */
   if (aType == VTK_PARSE_VOID)
-    {
+  {
     return;
-    }
+  }
 
   switch (aType)
-    {
+  {
     case VTK_PARSE_FLOAT_PTR:
     case VTK_PARSE_DOUBLE_PTR:
       for (j = 0; j < currentFunction->ArgCounts[i]; j++)
-        {
+      {
         fprintf(fp,"  ((jdouble *)tempArray%i)[%i] = temp%i[%i];\n",i,j,i,j);
-        }
+      }
       fprintf(fp,"  env->ReleaseDoubleArrayElements(id%i,(jdouble *)tempArray%i,0);\n",i,i);
       break;
     case VTK_PARSE_CHAR_PTR:
@@ -450,14 +445,14 @@ void copy_and_release_args(FILE *fp, int i)
     case VTK_PARSE_SIGNED_CHAR_PTR:
     case VTK_PARSE_BOOL_PTR:
       for (j = 0; j < currentFunction->ArgCounts[i]; j++)
-        {
+      {
         fprintf(fp,"  ((jint *)tempArray%i)[%i] = temp%i[%i];\n",i,j,i,j);
-        }
+      }
       fprintf(fp,"  env->ReleaseIntArrayElements(id%i,(jint *)tempArray%i,0);\n",i,i);
       break;
     default:
       break;
-    }
+  }
 }
 
 void do_return(FILE *fp)
@@ -467,32 +462,32 @@ void do_return(FILE *fp)
 
   /* ignore void */
   if (rType == VTK_PARSE_VOID)
-    {
+  {
     return;
-    }
+  }
 
   switch (rType)
-    {
+  {
     case VTK_PARSE_CHAR_PTR:
-      {
+    {
       fprintf(fp,"  return vtkJavaMakeJavaString(env,temp%i);\n", MAX_ARGS);
       break;
-      }
+    }
     case VTK_PARSE_STRING:
-      {
+    {
       fprintf(fp,"  return vtkJavaMakeJavaString(env,temp%i.c_str());\n", MAX_ARGS);
       break;
-      }
+    }
     case VTK_PARSE_STRING_REF:
-      {
+    {
       fprintf(fp,"  return vtkJavaMakeJavaString(env,temp%i->c_str());\n", MAX_ARGS);
       break;
-      }
+    }
     case VTK_PARSE_OBJECT_PTR:
-      {
+    {
       fprintf(fp,"  return (jlong)(size_t)temp%i;", MAX_ARGS);
       break;
-      }
+    }
 
     /* handle functions returning vectors */
     /* this is done by looking them up in a hint file */
@@ -510,7 +505,7 @@ void do_return(FILE *fp)
       use_hints(fp);
       break;
     default: fprintf(fp,"  return temp%i;\n", MAX_ARGS); break;
-    }
+  }
 }
 
 /* Check to see if two types will map to the same Java type,
@@ -541,74 +536,74 @@ static int CheckMatch(
 
   if ((type1 & VTK_PARSE_UNQUALIFIED_TYPE) ==
       (type2 & VTK_PARSE_UNQUALIFIED_TYPE))
-    {
+  {
     if ((type1 & VTK_PARSE_BASE_TYPE) == VTK_PARSE_OBJECT)
-      {
+    {
       if (strcmp(c1, c2) == 0)
-        {
-        return 1;
-        }
-      return 0;
-      }
-    else
       {
-      return 1;
+        return 1;
       }
+      return 0;
     }
+    else
+    {
+      return 1;
+    }
+  }
 
   for (i = 0; numericTypes[i]; i++)
-    {
+  {
     hit1 = 0;
     hit2 = 0;
     for (j = 0; numericTypes[i][j]; j++)
-      {
+    {
       if ((type1 & VTK_PARSE_BASE_TYPE) == numericTypes[i][j])
-        {
-        hit1 = j+1;
-        }
-      if ((type2 & VTK_PARSE_BASE_TYPE) == numericTypes[i][j])
-        {
-        hit2 = j+1;
-        }
-      }
-    if (hit1 && hit2 &&
-        (type1 & VTK_PARSE_INDIRECT) == (type2 & VTK_PARSE_INDIRECT))
       {
-      if (hit1 < hit2)
-        {
-        return 1;
-        }
-      else
-        {
-        return 2;
-        }
+        hit1 = j+1;
+      }
+      if ((type2 & VTK_PARSE_BASE_TYPE) == numericTypes[i][j])
+      {
+        hit2 = j+1;
       }
     }
+    if (hit1 && hit2 &&
+        (type1 & VTK_PARSE_INDIRECT) == (type2 & VTK_PARSE_INDIRECT))
+    {
+      if (hit1 < hit2)
+      {
+        return 1;
+      }
+      else
+      {
+        return 2;
+      }
+    }
+  }
 
   hit1 = 0;
   hit2 = 0;
   for (j = 0; stringTypes[j]; j++)
-    {
+  {
     if ((type1 & VTK_PARSE_UNQUALIFIED_TYPE) == stringTypes[j])
-      {
-      hit1 = j+1;
-      }
-    if ((type2 & VTK_PARSE_UNQUALIFIED_TYPE) == stringTypes[j])
-      {
-      hit2 = j+1;
-      }
-    }
-  if (hit1 && hit2)
     {
-    if (hit1 < hit2)
-      {
-      return 1;
-      }
-    else
-      {
-      return 2;
-      }
+      hit1 = j+1;
     }
+    if ((type2 & VTK_PARSE_UNQUALIFIED_TYPE) == stringTypes[j])
+    {
+      hit2 = j+1;
+    }
+  }
+  if (hit1 && hit2)
+  {
+    if (hit1 < hit2)
+    {
+      return 1;
+    }
+    else
+    {
+      return 2;
+    }
+  }
 
   return 0;
 }
@@ -621,29 +616,29 @@ int DoneOne()
   FunctionInfo *fi;
 
   for (i = 0; i < numberOfWrappedFunctions; i++)
-    {
+  {
     fi = wrappedFunctions[i];
 
     if ((!strcmp(fi->Name,currentFunction->Name))
         &&(fi->NumberOfArguments == currentFunction->NumberOfArguments))
-      {
+    {
       match = 1;
       for (j = 0; j < fi->NumberOfArguments; j++)
-        {
+      {
         if (!CheckMatch(currentFunction->ArgTypes[j], fi->ArgTypes[j],
                         currentFunction->ArgClasses[j],fi->ArgClasses[j]))
-          {
+        {
           match = 0;
-          }
         }
+      }
       if (!CheckMatch(currentFunction->ReturnType, fi->ReturnType,
                       currentFunction->ReturnClass, fi->ReturnClass))
-        {
+      {
         match = 0;
-        }
-      if (match) return 1;
       }
+      if (match) return 1;
     }
+  }
   return 0;
 }
 
@@ -672,79 +667,79 @@ void HandleDataArray(FILE *fp, ClassInfo *data)
   const char *jfromtype = 0;
 
   if (!strcmp("vtkCharArray",data->Name) )
-    {
+  {
     type = "char";
     fromtype = "Char";
     jtype = "byte";
     jfromtype = "Byte";
-    }
+  }
   else if (!strcmp("vtkDoubleArray",data->Name) )
-    {
+  {
     type = "double";
     fromtype = "Double";
     jtype = type;
     jfromtype = fromtype;
-    }
+  }
   else if (!strcmp("vtkFloatArray",data->Name) )
-    {
+  {
     type = "float";
     fromtype = "Float";
     jtype = type;
     jfromtype = fromtype;
-    }
+  }
   else if (!strcmp("vtkIntArray",data->Name) )
-    {
+  {
     type = "int";
     fromtype = "Int";
     jtype = type;
     jfromtype = fromtype;
-    }
+  }
   else if (!strcmp("vtkLongArray",data->Name) )
-    {
+  {
     type = "long";
     fromtype = "Long";
     jtype = type;
     jfromtype = fromtype;
-    }
+  }
   else if (!strcmp("vtkShortArray",data->Name) )
-    {
+  {
     type = "short";
     fromtype = "Short";
     jtype = type;
     jfromtype = fromtype;
-    }
+  }
   else if (!strcmp("vtkUnsignedCharArray",data->Name) )
-    {
+  {
     type = "unsigned char";
     fromtype = "UnsignedChar";
     jtype = "byte";
     jfromtype = "Byte";
-    }
+  }
   else if (!strcmp("vtkUnsignedIntArray",data->Name) )
-    {
+  {
     type = "unsigned int";
     fromtype = "UnsignedInt";
     jtype = "int";
     jfromtype = "Int";
-    }
+  }
   else if (!strcmp("vtkUnsignedLongArray",data->Name) )
-    {
+  {
     type = "unsigned long";
     fromtype = "UnsignedLong";
     jtype = "long";
     jfromtype = "Long";
-    }
+  }
   else if (!strcmp("vtkUnsignedShortArray",data->Name) )
-    {
+  {
     type = "unsigned short";
     fromtype = "UnsignedShort";
     jtype = "short";
     jfromtype = "Short";
-    }
+  }
   else
-    {
+  {
     return;
-    }
+  }
 
   fprintf(fp,"// Array conversion routines\n");
   fprintf(fp,"extern \"C\" JNIEXPORT jarray JNICALL Java_vtk_%s_GetJavaArray_10("
@@ -783,16 +778,16 @@ static int isClassWrapped(const char *classname)
   HierarchyEntry *entry;
 
   if (hierarchyInfo)
-    {
+  {
     entry = vtkParseHierarchy_FindEntry(hierarchyInfo, classname);
 
     if (entry == 0 ||
         vtkParseHierarchy_GetProperty(entry, "WRAP_EXCLUDE") ||
         !vtkParseHierarchy_IsTypeOf(hierarchyInfo, entry, "vtkObjectBase"))
-      {
+    {
       return 0;
-      }
     }
+  }
 
   return 1;
 }
@@ -824,86 +819,86 @@ int checkFunctionSignature(ClassInfo *data)
       currentFunction->ArrayFailure ||
       !currentFunction->IsPublic ||
       !currentFunction->Name)
-    {
+  {
     return 0;
-    }
+  }
 
   /* NewInstance and SafeDownCast can not be wrapped because it is a
      (non-virtual) method which returns a pointer of the same type as
      the current pointer. Since all methods are virtual in Java, this
      looks like polymorphic return type.  */
   if (!strcmp("NewInstance",currentFunction->Name))
-    {
+  {
     return 0;
-    }
+  }
 
   if (!strcmp("SafeDownCast",currentFunction->Name))
-    {
+  {
     return 0;
-    }
+  }
 
   /* The GetInput() in vtkMapper cannot be overriden with a
    * different return type, Java doesn't allow this */
   if (strcmp(data->Name, "vtkMapper") == 0 &&
       strcmp(currentFunction->Name, "GetInput") == 0)
-    {
+  {
     return 0;
-    }
+  }
 
   /* function pointer arguments for callbacks */
   if (currentFunction->NumberOfArguments == 2 &&
       currentFunction->ArgTypes[0] == VTK_PARSE_FUNCTION &&
       currentFunction->ArgTypes[1] == VTK_PARSE_VOID_PTR &&
       rType == VTK_PARSE_VOID)
-    {
+  {
     return 1;
-    }
+  }
 
   /* check to see if we can handle the args */
   for (i = 0; i < currentFunction->NumberOfArguments; i++)
-    {
+  {
     aType = (currentFunction->ArgTypes[i] & VTK_PARSE_UNQUALIFIED_TYPE);
     baseType = (aType & VTK_PARSE_BASE_TYPE);
 
     for (j = 0; supported_types[j] != 0; j++)
-      {
+    {
       if (baseType == supported_types[j]) { break; }
-      }
+    }
     if (supported_types[j] == 0)
-      {
+    {
       args_ok = 0;
-      }
+    }
 
     if (baseType == VTK_PARSE_UNKNOWN)
-      {
+    {
       const char *qualified_name = 0;
       if ((aType & VTK_PARSE_INDIRECT) == 0)
-        {
+      {
         qualified_name = vtkParseHierarchy_QualifiedEnumName(
           hierarchyInfo, data, stringCache,
           currentFunction->ArgClasses[i]);
-        }
-      if (qualified_name)
-        {
-        currentFunction->ArgClasses[i] = qualified_name;
-        }
-      else
-        {
-        args_ok = 0;
-        }
       }
+      if (qualified_name)
+      {
+        currentFunction->ArgClasses[i] = qualified_name;
+      }
+      else
+      {
+        args_ok = 0;
+      }
+    }
 
     if (baseType == VTK_PARSE_OBJECT)
-      {
+    {
       if ((aType & VTK_PARSE_INDIRECT) != VTK_PARSE_POINTER)
-        {
+      {
         args_ok = 0;
-        }
-      else if (!isClassWrapped(currentFunction->ArgClasses[i]))
-        {
-        args_ok = 0;
-        }
       }
+      else if (!isClassWrapped(currentFunction->ArgClasses[i]))
+      {
+        args_ok = 0;
+      }
+    }
 
     if (aType == VTK_PARSE_OBJECT) args_ok = 0;
     if (((aType & VTK_PARSE_INDIRECT) != VTK_PARSE_POINTER) &&
@@ -917,49 +912,49 @@ int checkFunctionSignature(ClassInfo *data)
     if (aType == VTK_PARSE_UNSIGNED_ID_TYPE_PTR) args_ok = 0;
     if (aType == VTK_PARSE_UNSIGNED_LONG_LONG_PTR) args_ok = 0;
     if (aType == VTK_PARSE_UNSIGNED___INT64_PTR) args_ok = 0;
-    }
+  }
 
   baseType = (rType & VTK_PARSE_BASE_TYPE);
 
   for (j = 0; supported_types[j] != 0; j++)
-    {
+  {
     if (baseType == supported_types[j]) { break; }
-    }
+  }
   if (supported_types[j] == 0)
-    {
+  {
     args_ok = 0;
-    }
+  }
 
   if (baseType == VTK_PARSE_UNKNOWN)
-    {
+  {
     const char *qualified_name = 0;
     if ((rType & VTK_PARSE_INDIRECT) == 0)
-      {
+    {
       qualified_name = vtkParseHierarchy_QualifiedEnumName(
         hierarchyInfo, data, stringCache,
         currentFunction->ReturnClass);
-      }
-    if (qualified_name)
-      {
-      currentFunction->ReturnClass = qualified_name;
-      }
-    else
-      {
-      args_ok = 0;
-      }
     }
+    if (qualified_name)
+    {
+      currentFunction->ReturnClass = qualified_name;
+    }
+    else
+    {
+      args_ok = 0;
+    }
+  }
 
   if (baseType == VTK_PARSE_OBJECT)
-    {
+  {
     if ((rType & VTK_PARSE_INDIRECT) != VTK_PARSE_POINTER)
-      {
+    {
       args_ok = 0;
-      }
-    else if (!isClassWrapped(currentFunction->ReturnClass))
-      {
-      args_ok = 0;
-      }
     }
+    else if (!isClassWrapped(currentFunction->ReturnClass))
+    {
+      args_ok = 0;
+    }
+  }
 
   if (((rType & VTK_PARSE_INDIRECT) != VTK_PARSE_POINTER) &&
       ((rType & VTK_PARSE_INDIRECT) != 0) &&
@@ -976,18 +971,18 @@ int checkFunctionSignature(ClassInfo *data)
 
   /* make sure we have all the info we need for array arguments in */
   for (i = 0; i < currentFunction->NumberOfArguments; i++)
-    {
+  {
     aType = (currentFunction->ArgTypes[i] & VTK_PARSE_UNQUALIFIED_TYPE);
 
     if (((aType & VTK_PARSE_INDIRECT) == VTK_PARSE_POINTER)&&
         (currentFunction->ArgCounts[i] <= 0)&&
         (aType != VTK_PARSE_OBJECT_PTR)&&
         (aType != VTK_PARSE_CHAR_PTR)) args_ok = 0;
-    }
+  }
 
   /* if we need a return type hint make sure we have one */
   switch (rType)
-    {
+  {
     case VTK_PARSE_FLOAT_PTR:
     case VTK_PARSE_VOID_PTR:
     case VTK_PARSE_DOUBLE_PTR:
@@ -1002,11 +997,11 @@ int checkFunctionSignature(ClassInfo *data)
     case VTK_PARSE_UNSIGNED_CHAR_PTR:
       args_ok = currentFunction->HaveHint;
       break;
-    }
+  }
 
   /* make sure there isn't a Java-specific override */
   if (!strcmp("vtkObject",data->Name))
-    {
+  {
     /* remove the original vtkCommand observer methods */
     if (!strcmp(currentFunction->Name,"AddObserver") ||
         !strcmp(currentFunction->Name,"GetCommand") ||
@@ -1020,29 +1015,25 @@ int checkFunctionSignature(ClassInfo *data)
           (currentFunction->NumberOfArguments > 1))) ||
         (!strcmp(currentFunction->Name,"RemoveAllObservers") &&
          (currentFunction->NumberOfArguments > 0)))
-      {
-      args_ok = 0;
-      }
-    }
-  else if (!strcmp("vtkObjectBase",data->Name))
     {
-    /* remove the special vtkObjectBase methods */
-    if (!strcmp(currentFunction->Name,"Print")
-#ifndef VTK_LEGACY_REMOVE
-        || !strcmp(currentFunction->Name,"PrintRevisions")
-#endif
-        )
-      {
       args_ok = 0;
-      }
     }
+  }
+  else if (!strcmp("vtkObjectBase",data->Name))
+  {
+    /* remove the special vtkObjectBase methods */
+    if (!strcmp(currentFunction->Name,"Print"))
+    {
+      args_ok = 0;
+    }
+  }
 
   /* make sure it isn't a Delete or New function */
   if (!strcmp("Delete",currentFunction->Name) ||
       !strcmp("New",currentFunction->Name))
-    {
+  {
     args_ok = 0;
-    }
+  }
 
   return args_ok;
 }
@@ -1050,7 +1041,7 @@ int checkFunctionSignature(ClassInfo *data)
 void outputFunction(FILE *fp, ClassInfo *data)
 {
   int i;
-  int args_ok = 1;
+  int args_ok;
   unsigned int rType =
     (currentFunction->ReturnType & VTK_PARSE_UNQUALIFIED_TYPE);
   const char *jniFunction = 0;
@@ -1069,27 +1060,27 @@ void outputFunction(FILE *fp, ClassInfo *data)
        !strcmp("vtkUnstructuredGridReader",data->Name) ||
        !strcmp("vtkStructuredPointsReader",data->Name) ||
        !strcmp("vtkPolyDataReader",data->Name)))
-    {
+  {
     if(currentFunction->IsLegacy)
-      {
+    {
       fprintf(fp,"#if !defined(VTK_LEGACY_REMOVE)\n");
-      }
+    }
     HandleDataReader(fp,data);
     if(currentFunction->IsLegacy)
-      {
+    {
       fprintf(fp,"#endif\n");
-      }
+    }
     wrappedFunctions[numberOfWrappedFunctions] = currentFunction;
     numberOfWrappedFunctions++;
-    }
+  }
 
   if (currentFunction->IsPublic && args_ok &&
       strcmp(data->Name,currentFunction->Name) &&
       strcmp(data->Name, currentFunction->Name + 1))
-    {
+  {
     /* make sure we haven't already done one of these */
     if (!DoneOne())
-      {
+    {
       fprintf(fp,"\n");
 
       /* Underscores are escaped in method names, see
@@ -1099,10 +1090,10 @@ void outputFunction(FILE *fp, ClassInfo *data)
       jniFunctionOld = 0;
       j = 0;
       while (jniFunction[j] != '\0')
-        {
+      {
         /* replace "_" with "_1" */
         if (jniFunction[j] == '_')
-          {
+        {
           j++;
           jniFunctionNew = (char *)malloc(strlen(jniFunction) + 2);
           strncpy(jniFunctionNew, jniFunction, j);
@@ -1111,30 +1102,30 @@ void outputFunction(FILE *fp, ClassInfo *data)
           free(jniFunctionOld);
           jniFunctionOld = jniFunctionNew;
           jniFunction = jniFunctionNew;
-          }
-        j++;
         }
+        j++;
+      }
 
       if(currentFunction->IsLegacy)
-        {
+      {
         fprintf(fp,"#if !defined(VTK_LEGACY_REMOVE)\n");
-        }
+      }
       fprintf(fp,"extern \"C\" JNIEXPORT ");
       return_result(fp);
       fprintf(fp," JNICALL Java_vtk_%s_%s_1%i(JNIEnv *env, jobject obj",
               data->Name, jniFunction, numberOfWrappedFunctions);
 
       for (i = 0; i < currentFunction->NumberOfArguments; i++)
-        {
+      {
         fprintf(fp,",");
         output_proto_vars(fp, i);
 
         /* ignore args after function pointer */
         if (currentFunction->ArgTypes[i] == VTK_PARSE_FUNCTION)
-          {
+        {
           break;
-          }
         }
+      }
       fprintf(fp,")\n{\n");
 
       /* get the object pointer */
@@ -1142,104 +1133,104 @@ void outputFunction(FILE *fp, ClassInfo *data)
 
       /* process the args */
       for (i = 0; i < currentFunction->NumberOfArguments; i++)
-        {
+      {
         output_temp(fp, i, currentFunction->ArgTypes[i],
                    currentFunction->ArgClasses[i],
                    currentFunction->ArgCounts[i]);
 
         /* ignore args after function pointer */
         if (currentFunction->ArgTypes[i] == VTK_PARSE_FUNCTION)
-          {
+        {
           break;
-          }
         }
+      }
       output_temp(fp, MAX_ARGS,currentFunction->ReturnType,
                   currentFunction->ReturnClass,0);
 
       /* now get the required args from the stack */
       for (i = 0; i < currentFunction->NumberOfArguments; i++)
-        {
+      {
         get_args(fp, i);
 
         /* ignore args after function pointer */
         if (currentFunction->ArgTypes[i] == VTK_PARSE_FUNCTION)
-          {
+        {
           break;
-          }
         }
+      }
 
       fprintf(fp,"\n  op = (%s *)vtkJavaGetPointerFromObject(env,obj);\n",
               data->Name);
 
 
       switch (rType)
-        {
+      {
         case VTK_PARSE_VOID:
           fprintf(fp,"  op->%s(",currentFunction->Name);
           break;
         default:
           if ((rType & VTK_PARSE_INDIRECT) == VTK_PARSE_REF)
-            {
+          {
             fprintf(fp,"  temp%i = &(op)->%s(",MAX_ARGS,currentFunction->Name);
-            }
+          }
           else
-            {
+          {
             fprintf(fp,"  temp%i = (op)->%s(",MAX_ARGS,currentFunction->Name);
-            }
+          }
           break;
-        }
+      }
 
       for (i = 0; i < currentFunction->NumberOfArguments; i++)
-        {
+      {
         if (i)
-          {
+        {
           fprintf(fp,",");
-          }
+        }
         if (currentFunction->ArgTypes[i] == VTK_PARSE_FUNCTION)
-          {
+        {
           fprintf(fp,"vtkJavaVoidFunc,(void *)temp%i",i);
           break;
-          }
+        }
         else
-          {
+        {
           fprintf(fp,"temp%i",i);
-          }
-        } /* for */
+        }
+      } /* for */
 
       fprintf(fp,");\n");
 
       if (currentFunction->NumberOfArguments == 2 &&
           currentFunction->ArgTypes[0] == VTK_PARSE_FUNCTION)
-        {
+      {
         fprintf(fp,"  op->%sArgDelete(vtkJavaVoidFuncArgDelete);\n",
                 jniFunction);
-        }
+      }
 
       /* now copy and release any arrays */
       for (i = 0; i < currentFunction->NumberOfArguments; i++)
-        {
+      {
         copy_and_release_args(fp, i);
 
         /* ignore args after function pointer */
         if (currentFunction->ArgTypes[i] == VTK_PARSE_FUNCTION)
-          {
+        {
           break;
-          }
         }
+      }
       do_return(fp);
       fprintf(fp,"}\n");
       if(currentFunction->IsLegacy)
-        {
+      {
         fprintf(fp,"#endif\n");
-        }
+      }
 
       wrappedFunctions[numberOfWrappedFunctions] = currentFunction;
       numberOfWrappedFunctions++;
       if (jniFunctionNew)
-        {
+      {
         free(jniFunctionNew);
         jniFunctionNew = 0;
-        }
+      }
     } /* isDone() */
   } /* isAbstract */
 }
@@ -1253,6 +1244,9 @@ int main(int argc, char *argv[])
   FILE *fp;
   int i;
 
+  /* pre-define a macro to identify the language */
+  vtkParse_DefineMacro("__VTK_WRAP_JAVA__", 0);
+
   /* get command-line args and parse the header file */
   file_info = vtkParse_Main(argc, argv);
 
@@ -1266,64 +1260,73 @@ int main(int argc, char *argv[])
   fp = fopen(options->OutputFileName, "w");
 
   if (!fp)
-    {
+  {
     fprintf(stderr, "Error opening output file %s\n", options->OutputFileName);
     exit(1);
-    }
+  }
 
   /* get the main class */
   if ((data = file_info->MainClass) == NULL)
-    {
+  {
     fclose(fp);
-    exit(0);
-    }
+    exit(1);
+  }
 
   /* get the hierarchy info for accurate typing */
-  if (options->HierarchyFileName)
+  if (options->HierarchyFileNames)
+  {
+    hierarchyInfo = vtkParseHierarchy_ReadFiles(
+      options->NumberOfHierarchyFileNames, options->HierarchyFileNames);
+    if (hierarchyInfo)
     {
-    hierarchyInfo = vtkParseHierarchy_ReadFile(options->HierarchyFileName);
+      /* resolve using declarations within the header files */
+      vtkWrap_ApplyUsingDeclarations(data, file_info, hierarchyInfo);
+
+      /* expand typedefs */
+      vtkWrap_ExpandTypedefs(data, file_info, hierarchyInfo);
     }
+  }
 
   fprintf(fp,"// java wrapper for %s object\n//\n",data->Name);
   fprintf(fp,"#define VTK_WRAPPING_CXX\n");
   if (strcmp("vtkObjectBase",data->Name) != 0)
-    {
+  {
     /* Block inclusion of full streams.  */
     fprintf(fp,"#define VTK_STREAMS_FWD_ONLY\n");
-    }
+  }
   fprintf(fp,"#include \"vtkSystemIncludes.h\"\n");
   fprintf(fp,"#include \"%s.h\"\n",data->Name);
   fprintf(fp,"#include \"vtkJavaUtil.h\"\n\n");
   fprintf(fp,"#include \"vtkStdString.h\"\n\n");
-  fprintf(fp,"#include <vtksys/ios/sstream>\n");
+  fprintf(fp,"#include <sstream>\n");
 
   for (i = 0; i < data->NumberOfSuperClasses; i++)
-    {
+  {
     char *safe_name = vtkWrap_SafeSuperclassName(data->SuperClasses[i]);
     const char *safe_superclass = safe_name ? safe_name : data->SuperClasses[i];
 
     /* if a template class is detected add a typedef */
     if (safe_name)
-      {
+    {
       fprintf(fp,"typedef %s %s;\n",
               data->SuperClasses[i], safe_name);
-      }
+    }
 
     fprintf(fp,"extern \"C\" JNIEXPORT void* %s_Typecast(void *op,char *dType);\n",
             safe_superclass);
 
     free(safe_name);
-    }
+  }
 
   fprintf(fp,"\nextern \"C\" JNIEXPORT void* %s_Typecast(void *me,char *dType)\n{\n",data->Name);
   if (data->NumberOfSuperClasses > 0)
-    {
+  {
     fprintf(fp,"  void* res;\n");
-    }
+  }
   fprintf(fp,"  if (!strcmp(\"%s\",dType)) { return me; }\n", data->Name);
   /* check our superclasses */
   for (i = 0; i < data->NumberOfSuperClasses; i++)
-    {
+  {
     char *safe_name = vtkWrap_SafeSuperclassName(data->SuperClasses[i]);
     const char *safe_superclass = safe_name ? safe_name : data->SuperClasses[i];
 
@@ -1332,7 +1335,7 @@ int main(int argc, char *argv[])
     fprintf(fp," { return res; }\n");
 
     free(safe_name);
-    }
+  }
   fprintf(fp,"  return NULL;\n");
   fprintf(fp,"}\n\n");
 
@@ -1340,13 +1343,13 @@ int main(int argc, char *argv[])
 
   /* insert function handling code here */
   for (i = 0; i < data->NumberOfFunctions; i++)
-    {
+  {
     currentFunction = data->Functions[i];
     outputFunction(fp, data);
-    }
+  }
 
   if ((!data->NumberOfSuperClasses)&&(data->HasDelete))
-    {
+  {
     fprintf(fp,"\nextern \"C\" JNIEXPORT void JNICALL Java_vtk_%s_VTKDeleteReference(JNIEnv *,jclass,jlong id)\n",
             data->Name);
     fprintf(fp,"{\n  %s *op;\n",data->Name);
@@ -1361,11 +1364,11 @@ int main(int argc, char *argv[])
     fprintf(fp,"  const char* name = \"\";\n");
     fprintf(fp,"  %s *op;\n", data->Name);
     fprintf(fp,"  if(id != 0)\n");
-    fprintf(fp,"    {\n");
+    fprintf(fp,"  {\n");
     fprintf(fp,"    op = reinterpret_cast<%s*>(id);\n", data->Name);
     //fprintf(fp,"    std::cout << \"cast pointer \" << id << std::endl;\n");
     fprintf(fp,"    name = op->GetClassName();\n");
-    fprintf(fp,"    }\n");
+    fprintf(fp,"  }\n");
     fprintf(fp,"  return vtkJavaMakeJavaString(env,name);\n");
     fprintf(fp,"}\n");
 
@@ -1384,16 +1387,16 @@ int main(int argc, char *argv[])
             data->Name);
     fprintf(fp,"  op->Register(op);\n");
     fprintf(fp,"}\n");
-    }
+  }
   if (!data->IsAbstract)
-    {
+  {
     fprintf(fp,"\nextern \"C\" JNIEXPORT jlong JNICALL Java_vtk_%s_VTKInit(JNIEnv *, jobject)",
             data->Name);
     fprintf(fp,"\n{");
     fprintf(fp,"\n  %s *aNewOne = %s::New();",data->Name, data->Name);
     fprintf(fp,"\n  return (jlong)(size_t)(void*)aNewOne;");
     fprintf(fp,"\n}\n");
-    }
+  }
 
   /* for vtkRenderWindow we want to add a special method to support
    * native AWT rendering
@@ -1402,19 +1405,19 @@ int main(int argc, char *argv[])
    * Java_vtk_vtkPanel_RenderCreate, Java_vtk_vtkPanel_Lock and
    * Java_vtk_vtkPanel_UnLock. */
   if (!strcmp("vtkRenderWindow",data->Name))
-    {
+  {
     fprintf(fp,"\n#include \"vtkJavaAwt.h\"\n\n");
-    }
+  }
 
   if (!strcmp("vtkObject",data->Name))
-    {
+  {
     /* Add the Print method to vtkObjectBase. */
     fprintf(fp,"\nextern \"C\" JNIEXPORT jstring JNICALL Java_vtk_vtkObjectBase_Print(JNIEnv *env,jobject obj)\n");
     fprintf(fp,"{\n  vtkObjectBase *op;\n");
     fprintf(fp,"  jstring tmp;\n\n");
     fprintf(fp,"  op = (vtkObjectBase *)vtkJavaGetPointerFromObject(env,obj);\n");
 
-    fprintf(fp,"  vtksys_ios::ostringstream vtkmsg_with_warning_C4701;\n");
+    fprintf(fp,"  std::ostringstream vtkmsg_with_warning_C4701;\n");
     fprintf(fp,"  op->Print(vtkmsg_with_warning_C4701);\n");
     fprintf(fp,"  vtkmsg_with_warning_C4701.put('\\0');\n");
     fprintf(fp,"  tmp = vtkJavaMakeJavaString(env,vtkmsg_with_warning_C4701.str().c_str());\n");
@@ -1422,22 +1425,6 @@ int main(int argc, char *argv[])
     fprintf(fp,"  return tmp;\n");
     fprintf(fp,"}\n");
 
-#ifndef VTK_LEGACY_REMOVE
-    /* Add the PrintRevisions method to vtkObjectBase. */
-    fprintf(fp,"\nextern \"C\" JNIEXPORT jstring JNICALL Java_vtk_vtkObjectBase_PrintRevisions(JNIEnv *env,jobject obj)\n");
-    fprintf(fp,"{\n  vtkObjectBase *op;\n");
-    fprintf(fp,"  jstring tmp;\n\n");
-    fprintf(fp,"  op = (vtkObjectBase *)vtkJavaGetPointerFromObject(env,obj);\n");
-
-    fprintf(fp,"  vtksys_ios::ostringstream vtkmsg_with_warning_C4701;\n");
-    fprintf(fp,"  op->PrintRevisions(vtkmsg_with_warning_C4701);\n");
-    fprintf(fp,"  vtkmsg_with_warning_C4701.put('\\0');\n");
-    fprintf(fp,"  tmp = vtkJavaMakeJavaString(env,vtkmsg_with_warning_C4701.str().c_str());\n");
-
-    fprintf(fp,"  return tmp;\n");
-    fprintf(fp,"}\n");
-#endif
-
     fprintf(fp,"\nextern \"C\" JNIEXPORT jint JNICALL Java_vtk_vtkObject_AddObserver(JNIEnv *env,jobject obj, jstring id0, jobject id1, jstring id2)\n");
     fprintf(fp,"{\n  vtkObject *op;\n");
 
@@ -1456,7 +1443,7 @@ int main(int argc, char *argv[])
     fprintf(fp,"  delete[] temp2;\n");
     fprintf(fp,"  cbc->Delete();\n");
     fprintf(fp,"  return temp20;\n}\n");
-   }
+  }
 
   vtkParse_Free(file_info);
 
