@@ -22,6 +22,7 @@
 #include "vtkWrapPythonTemplate.h"
 
 #include "vtkWrap.h"
+#include "vtkWrapText.h"
 #include "vtkParseExtras.h"
 
 #include <stdio.h>
@@ -57,51 +58,59 @@ static void vtkWrapPython_NewDeleteProtocol(
   constructor = data->Name;
   m = vtkParse_UnscopedNameLength(constructor);
   while (constructor[m] == ':' && constructor[m+1] == ':')
-    {
+  {
     constructor += m + 2;
     m = vtkParse_UnscopedNameLength(constructor);
-    }
+  }
   for (n = 0; n < m; n++)
-    {
+  {
     if (constructor[n] == '<')
-      {
+    {
       break;
-      }
     }
+  }
 
-  /* the new method for python versions >= 2.2 */
-  fprintf(fp,
-    "#if PY_VERSION_HEX >= 0x02020000\n"
+  /* the "new" method */
+  if (data->IsAbstract)
+  {
+    fprintf(fp,
+    "static PyObject *\n"
+    "Py%s_New(PyTypeObject *, PyObject *, PyObject *)\n"
+    "{\n"
+    "  PyErr_SetString(PyExc_TypeError,\n"
+    "                  \"this abstract class cannot be instantiated\");\n"
+    "\n"
+    "  return NULL;\n"
+    "}\n"
+    "\n",
+    classname);
+  }
+  else
+  {
+    fprintf(fp,
     "static PyObject *\n"
     "Py%s_New(PyTypeObject *, PyObject *args, PyObject *kwds)\n"
     "{\n"
     "  if (kwds && PyDict_Size(kwds))\n"
-    "    {\n"
+    "  {\n"
     "    PyErr_SetString(PyExc_TypeError,\n"
     "                    \"this function takes no keyword arguments\");\n"
     "    return NULL;\n"
-    "    }\n"
+    "  }\n"
     "\n"
     "  return Py%s_%*.*s(NULL, args);\n"
     "}\n"
-    "#endif\n"
     "\n",
     classname, classname, (int)n, (int)n, constructor);
+  }
 
   /* the delete method */
   fprintf(fp,
     "static void Py%s_Delete(PyObject *self)\n"
     "{\n"
     "  PyVTKSpecialObject *obj = (PyVTKSpecialObject *)self;\n"
-    "  if (obj->vtk_ptr)\n"
-    "    {\n"
-    "    delete static_cast<%s *>(obj->vtk_ptr);\n"
-    "    }\n"
-    "#if PY_MAJOR_VERSION >= 2\n"
+    "  delete static_cast<%s *>(obj->vtk_ptr);\n"
     "  PyObject_Del(self);\n"
-    "#else\n"
-    "  PyMem_DEL(self);\n"
-    "#endif\n"
     "}\n"
     "\n",
     classname, data->Name);
@@ -119,42 +128,43 @@ static void vtkWrapPython_PrintProtocol(
 
   /* look in the file for "operator<<" for printing */
   for (i = 0; i < finfo->Contents->NumberOfFunctions; i++)
-    {
+  {
     func = finfo->Contents->Functions[i];
     if (func->Name && func->IsOperator &&
         strcmp(func->Name, "operator<<") == 0)
-      {
+    {
       if (func->NumberOfParameters == 2 &&
           (func->Parameters[0]->Type & VTK_PARSE_UNQUALIFIED_TYPE) ==
               VTK_PARSE_OSTREAM_REF &&
           (func->Parameters[1]->Type & VTK_PARSE_BASE_TYPE) ==
               VTK_PARSE_OBJECT &&
           (func->Parameters[1]->Type & VTK_PARSE_POINTER_MASK) == 0 &&
+          !vtkWrap_IsNonConstRef(func->Parameters[1]) &&
           strcmp(func->Parameters[1]->Class, data->Name) == 0)
-        {
+      {
         info->has_print = 1;
-        }
       }
     }
+  }
 
   /* the str function */
   if (info->has_print)
-    {
+  {
     fprintf(fp,
       "static PyObject *Py%s_String(PyObject *self)\n"
       "{\n"
       "  PyVTKSpecialObject *obj = (PyVTKSpecialObject *)self;\n"
-      "  vtksys_ios::ostringstream os;\n"
+      "  std::ostringstream os;\n"
       "  if (obj->vtk_ptr)\n"
-      "    {\n"
+      "  {\n"
       "    os << *static_cast<const %s *>(obj->vtk_ptr);\n"
-      "    }\n"
-      "  const vtksys_stl::string &s = os.str();\n"
+      "  }\n"
+      "  const std::string &s = os.str();\n"
       "  return PyString_FromStringAndSize(s.data(), s.size());\n"
       "}\n"
       "\n",
       classname, data->Name);
-    }
+  }
 }
 
 /* -------------------------------------------------------------------- */
@@ -174,9 +184,9 @@ static void vtkWrapPython_RichCompareProtocol(
   /* look for comparison operator methods */
   n = data->NumberOfFunctions + finfo->Contents->NumberOfFunctions;
   for (i = 0; i < n; i++)
-    {
+  {
     if (i < data->NumberOfFunctions)
-      {
+    {
       /* member function */
       func = data->Functions[i];
       if (func->NumberOfParameters != 1 ||
@@ -184,12 +194,12 @@ static void vtkWrapPython_RichCompareProtocol(
               VTK_PARSE_OBJECT ||
           (func->Parameters[0]->Type & VTK_PARSE_POINTER_MASK) != 0 ||
           strcmp(func->Parameters[0]->Class, data->Name) != 0)
-        {
-        continue;
-        }
-      }
-    else
       {
+        continue;
+      }
+    }
+    else
+    {
       /* non-member function: both args must be of our type */
       func = finfo->Contents->Functions[i - data->NumberOfFunctions];
       if (func->NumberOfParameters != 2 ||
@@ -201,46 +211,49 @@ static void vtkWrapPython_RichCompareProtocol(
               VTK_PARSE_OBJECT ||
           (func->Parameters[1]->Type & VTK_PARSE_POINTER_MASK) != 0 ||
           strcmp(func->Parameters[1]->Class, data->Name) != 0)
-        {
-        continue;
-        }
-      }
-    if (func->IsOperator && func->Name != NULL)
       {
-      if (strcmp(func->Name, "operator<") == 0)
-        {
-        compare_ops = (compare_ops | (1 << 0));
-        }
-      else if (strcmp(func->Name, "operator<=") == 0)
-        {
-        compare_ops = (compare_ops | (1 << 1));
-        }
-      else if (strcmp(func->Name, "operator==") == 0)
-        {
-        compare_ops = (compare_ops | (1 << 2));
-        }
-      else if (strcmp(func->Name, "operator!=") == 0)
-        {
-        compare_ops = (compare_ops | (1 << 3));
-        }
-      else if (strcmp(func->Name, "operator>") == 0)
-        {
-        compare_ops = (compare_ops | (1 << 4));
-        }
-      else if (strcmp(func->Name, "operator>=") == 0)
-        {
-        compare_ops = (compare_ops | (1 << 5));
-        }
+        continue;
       }
     }
+    if (func->IsOperator && func->Name != NULL)
+    {
+      if (strcmp(func->Name, "operator<") == 0)
+      {
+        compare_ops = (compare_ops | (1 << 0));
+      }
+      else if (strcmp(func->Name, "operator<=") == 0)
+      {
+        compare_ops = (compare_ops | (1 << 1));
+      }
+      else if (strcmp(func->Name, "operator==") == 0)
+      {
+        compare_ops = (compare_ops | (1 << 2));
+      }
+      else if (strcmp(func->Name, "operator!=") == 0)
+      {
+        compare_ops = (compare_ops | (1 << 3));
+      }
+      else if (strcmp(func->Name, "operator>") == 0)
+      {
+        compare_ops = (compare_ops | (1 << 4));
+      }
+      else if (strcmp(func->Name, "operator>=") == 0)
+      {
+        compare_ops = (compare_ops | (1 << 5));
+      }
+    }
+  }
 
   /* the compare function */
   if (compare_ops != 0)
-    {
+  {
     info->has_compare = 1;
 
     fprintf(fp,
-      "#if PY_VERSION_HEX >= 0x02010000\n"
+      "static int Py%s_CheckExact(PyObject *ob);\n\n",
+      classname);
+
+    fprintf(fp,
       "static PyObject *Py%s_RichCompare(\n"
       "  PyObject *o1, PyObject *o2, int opid)\n"
       "{\n"
@@ -253,96 +266,85 @@ static void vtkWrapPython_RichCompareProtocol(
       classname, data->Name, data->Name);
 
     for (i = 1; i <= 2; i++)
-      {
+    {
       /* use GetPointerFromSpecialObject to do type conversion, but
        * at least one of the args will already be the correct type */
       fprintf(fp,
-        "  if (o%d->ob_type == &Py%s_Type)\n"
-        "    {\n"
+        "  if (Py%s_CheckExact(o%d))\n"
+        "  {\n"
         "    PyVTKSpecialObject *s%d = (PyVTKSpecialObject *)o%d;\n"
         "    so%d = static_cast<const %s *>(s%d->vtk_ptr);\n"
-        "    }\n"
+        "  }\n"
         "  else\n"
-        "    {\n"
+        "  {\n"
         "    so%d = static_cast<const %s *>(\n"
         "      vtkPythonUtil::GetPointerFromSpecialObject(\n"
         "        o%d, \"%s\", &n%d));\n"
         "    if (so%d == NULL)\n"
-        "      {\n"
+        "    {\n"
         "      PyErr_Clear();\n"
         "      Py_INCREF(Py_NotImplemented);\n"
         "      return Py_NotImplemented;\n"
-        "      }\n"
         "    }\n"
+        "  }\n"
         "\n",
-        i, classname, i, i, i, data->Name, i, i, data->Name,
+        classname, i, i, i, i, data->Name, i, i, data->Name,
         i, classname, i, i);
-      }
+    }
 
     /* the switch statement for all possible compare ops */
     fprintf(fp,
       "  switch (opid)\n"
-      "    {\n");
+      "  {\n");
 
     for (i = 0; i < 6; i++)
-      {
+    {
       if ( ((compare_ops >> i) & 1) != 0 )
-        {
+      {
         fprintf(fp,
           "    case %s:\n"
           "      result = ((*so1) %s (*so2));\n"
           "      break;\n",
           compare_consts[i], compare_tokens[i]);
-        }
+      }
       else
-        {
+      {
         fprintf(fp,
           "    case %s:\n"
           "      break;\n",
           compare_consts[i]);
-        }
       }
+    }
 
     fprintf(fp,
-      "    }\n"
+      "  }\n"
       "\n");
 
     /* delete temporary objects, there will be at most one */
     fprintf(fp,
       "  if (n1)\n"
-      "    {\n"
+      "  {\n"
       "    Py_DECREF(n1);\n"
-      "    }\n"
+      "  }\n"
       "  else if (n2)\n"
-      "    {\n"
+      "  {\n"
       "    Py_DECREF(n2);\n"
-      "    }\n"
+      "  }\n"
       "\n");
 
     /* return the result */
     fprintf(fp,
       "  if (result == -1)\n"
-      "    {\n"
-      "    PyErr_SetString(PyExc_TypeError, (char *)\"operation not available\");\n"
+      "  {\n"
+      "    PyErr_SetString(PyExc_TypeError, \"operation not available\");\n"
       "    return NULL;\n"
-      "    }\n"
+      "  }\n"
       "\n"
-      "#if PY_VERSION_HEX >= 0x02030000\n"
       "  // avoids aliasing issues with Py_INCREF(Py_False)\n"
       "  return PyBool_FromLong((long)result);\n"
-      "#else\n"
-      "  if (result == 0)\n"
-      "    {\n"
-      "    Py_INCREF(Py_False);\n"
-      "    return Py_False;\n"
-      "    }\n"
-      "  Py_INCREF(Py_True);\n"
-      "  return Py_True;\n"
-      "#endif\n"
       "}\n"
-      "#endif\n"
       "\n");
-    }
+  }
 }
 
 /* -------------------------------------------------------------------- */
@@ -358,36 +360,36 @@ static void vtkWrapPython_SequenceProtocol(
 
   /* look for [] operator */
   for (i = 0; i < data->NumberOfFunctions; i++)
-    {
+  {
     func = data->Functions[i];
 
     if (func->Name && func->IsOperator &&
         strcmp(func->Name, "operator[]") == 0  &&
         vtkWrapPython_MethodCheck(data, func, hinfo))
-      {
+    {
       if (func->NumberOfParameters == 1 && func->ReturnValue &&
           vtkWrap_IsInteger(func->Parameters[0]))
-        {
+      {
         if (!setItemFunc && vtkWrap_IsNonConstRef(func->ReturnValue))
-          {
+        {
           setItemFunc = func;
-          }
+        }
         if (!getItemFunc || (func->IsConst && !getItemFunc->IsConst))
-          {
+        {
           getItemFunc = func;
-          }
         }
       }
     }
+  }
 
   if (getItemFunc && getItemFunc->SizeHint)
-    {
+  {
     info->has_sequence = 1;
 
     fprintf(fp,
       "Py_ssize_t Py%s_SequenceSize(PyObject *self)\n"
       "{\n"
-      "  void *vp = vtkPythonArgs::GetSelfPointer(self);\n"
+      "  void *vp = vtkPythonArgs::GetSelfSpecialPointer(self);\n"
       "  %s *op = static_cast<%s *>(vp);\n"
       "\n"
       "  return static_cast<Py_ssize_t>(op->%s);\n"
@@ -397,7 +399,7 @@ static void vtkWrapPython_SequenceProtocol(
     fprintf(fp,
       "PyObject *Py%s_SequenceItem(PyObject *self, Py_ssize_t i)\n"
       "{\n"
-      "  void *vp = vtkPythonArgs::GetSelfPointer(self);\n"
+      "  void *vp = vtkPythonArgs::GetSelfSpecialPointer(self);\n"
       "  %s *op = static_cast<%s *>(vp);\n"
       "\n",
       classname, data->Name, data->Name);
@@ -408,11 +410,11 @@ static void vtkWrapPython_SequenceProtocol(
             "  temp0 = static_cast<%s>(i);\n"
             "\n"
             "  if (temp0 < 0 || temp0 >= op->%s)\n"
-            "    {\n"
+            "  {\n"
             "    PyErr_SetString(PyExc_IndexError, \"index out of range\");\n"
-            "    }\n"
+            "  }\n"
             "  else\n"
-            "    {\n",
+            "  {\n",
             vtkWrap_GetTypeName(getItemFunc->Parameters[0]),
             getItemFunc->SizeHint);
 
@@ -427,18 +429,18 @@ static void vtkWrapPython_SequenceProtocol(
     vtkWrapPython_ReturnValue(fp, data, getItemFunc->ReturnValue, 1);
 
     fprintf(fp,
-            "    }\n"
+            "  }\n"
             "\n"
             "  return result;\n"
             "}\n\n");
 
     if (setItemFunc)
-      {
+    {
       fprintf(fp,
         "int Py%s_SequenceSetItem(\n"
         "  PyObject *self, Py_ssize_t i, PyObject *arg1)\n"
         "{\n"
-        "  void *vp = vtkPythonArgs::GetSelfPointer(self);\n"
+        "  void *vp = vtkPythonArgs::GetSelfSpecialPointer(self);\n"
         "  %s *op = static_cast<%s *>(vp);\n"
         "\n",
         classname, data->Name, data->Name);
@@ -454,9 +456,9 @@ static void vtkWrapPython_SequenceProtocol(
               "  temp0 = static_cast<%s>(i);\n"
               "\n"
               "  if (temp0 < 0 || temp0 >= op->%s)\n"
-              "    {\n"
+              "  {\n"
               "    PyErr_SetString(PyExc_IndexError, \"index out of range\");\n"
-              "    }\n"
+              "  }\n"
               "  else if (",
               vtkWrap_GetTypeName(setItemFunc->Parameters[0]),
               getItemFunc->SizeHint);
@@ -465,7 +467,7 @@ static void vtkWrapPython_SequenceProtocol(
         fp, data, 1, setItemFunc->ReturnValue, 1);
 
       fprintf(fp,")\n"
-              "    {\n"
+              "  {\n"
               "    (*op)[temp0] = %stemp1;\n"
               "\n",
               ((vtkWrap_IsRef(getItemFunc->ReturnValue) &&
@@ -473,14 +475,14 @@ static void vtkWrapPython_SequenceProtocol(
 
       fprintf(fp,
               "    if (PyErr_Occurred() == NULL)\n"
-              "      {\n"
+              "    {\n"
               "      result = 0;\n"
-              "      }\n"
               "    }\n"
+              "  }\n"
               "\n"
               "  return result;\n"
               "}\n\n");
-      }
+    }
 
     fprintf(fp,
       "static PySequenceMethods Py%s_AsSequence = {\n"
@@ -492,26 +494,24 @@ static void vtkWrapPython_SequenceProtocol(
       classname, classname, classname);
 
     if (setItemFunc)
-      {
+    {
       fprintf(fp,
         "  Py%s_SequenceSetItem, // sq_ass_item\n",
         classname);
-      }
+    }
     else
-      {
+    {
       fprintf(fp,
         "  0, // sq_ass_item\n");
-      }
+    }
 
     fprintf(fp,
       "  0, // sq_ass_slice\n"
       "  0, // sq_contains\n"
-      "#if PY_VERSION_HEX >= 0x2000000\n"
       "  0, // sq_inplace_concat\n"
       "  0, // sq_inplace_repeat\n"
-      "#endif\n"
       "};\n\n");
-    }
+  }
 }
 
 /* -------------------------------------------------------------------- */
@@ -521,25 +521,25 @@ static void vtkWrapPython_HashProtocol(
 {
   /* the hash function, defined only for specific types */
   fprintf(fp,
-    "static long Py%s_Hash(PyObject *self)\n",
+    "static Py_hash_t Py%s_Hash(PyObject *self)\n",
     classname);
 
   if (strcmp(data->Name, "vtkTimeStamp") == 0)
-    {
+  {
     /* hash for vtkTimeStamp is just the timestamp itself */
     fprintf(fp,
       "{\n"
       "  PyVTKSpecialObject *obj = (PyVTKSpecialObject *)self;\n"
       "  const vtkTimeStamp *op = static_cast<const vtkTimeStamp *>(obj->vtk_ptr);\n"
-      "  unsigned long mtime = *op;\n"
+      "  vtkMTimeType mtime = *op;\n"
       "  long h = (long)mtime;\n"
       "  if (h != -1) { return h; }\n"
       "  return -2;\n"
       "}\n"
       "\n");
-    }
+  }
   else if (strcmp(data->Name, "vtkVariant") == 0)
-    {
+  {
     /* hash for vtkVariant is cached to avoid recomputation, this is
      * safe because vtkVariant is an immutable object, and is necessary
      * because computing the hash for vtkVariant is very expensive */
@@ -549,17 +549,17 @@ static void vtkWrapPython_HashProtocol(
       "  const vtkVariant *op = static_cast<const vtkVariant *>(obj->vtk_ptr);\n"
       "  long h = obj->vtk_hash;\n"
       "  if (h != -1)\n"
-      "    {\n"
+      "  {\n"
       "    return h;\n"
-      "    }\n"
+      "  }\n"
       "  h = vtkPythonUtil::VariantHash(op);\n"
       "  obj->vtk_hash = h;\n"
       "  return h;\n"
       "}\n"
       "\n");
-    }
+  }
   else
-    {
+  {
     /* if hash is not implemented, raise an exception */
     fprintf(fp,
       "{\n"
@@ -567,13 +567,13 @@ static void vtkWrapPython_HashProtocol(
       "  return PyObject_HashNotImplemented(self);\n"
       "#else\n"
       "  char text[256];\n"
-      "  sprintf(text, \"unhashable type: \'%%s\'\", self->ob_type->tp_name);\n"
+      "  sprintf(text, \"unhashable type: \'%%s\'\", Py_TYPE(self)->tp_name);\n"
       "  PyErr_SetString(PyExc_TypeError, text);\n"
       "  return -1;\n"
       "#endif\n"
       "}\n"
       "\n");
-    }
+  }
 
 }
 
@@ -602,27 +602,22 @@ int vtkWrapPython_IsSpecialTypeWrappable(ClassInfo *data)
 {
   /* no templated types */
   if (data->Template)
-    {
+  {
     return 0;
-    }
-
-  /* no abstract classes */
-  if (data->IsAbstract)
-    {
-    return 0;
-    }
+  }
 
+  /* restrict wrapping to classes that have a "vtk" prefix */
   if (strncmp(data->Name, "vtk", 3) != 0)
-    {
+  {
     return 0;
-    }
+  }
 
   /* require public destructor and copy contructor */
   if (!vtkWrap_HasPublicDestructor(data) ||
       !vtkWrap_HasPublicCopyConstructor(data))
-    {
+  {
     return 0;
-    }
+  }
 
   return 1;
 }
@@ -630,8 +625,8 @@ int vtkWrapPython_IsSpecialTypeWrappable(ClassInfo *data)
 /* -------------------------------------------------------------------- */
 /* write out a special type object */
 void vtkWrapPython_GenerateSpecialType(
-  FILE *fp, const char *classname, ClassInfo *data,
-  FileInfo *finfo, HierarchyInfo *hinfo)
+  FILE *fp, const char *module, const char *classname,
+  ClassInfo *data, FileInfo *finfo, HierarchyInfo *hinfo)
 {
   char supername[1024];
   const char *name;
@@ -648,55 +643,32 @@ void vtkWrapPython_GenerateSpecialType(
   constructor = data->Name;
   m = vtkParse_UnscopedNameLength(constructor);
   while (constructor[m] == ':' && constructor[m+1] == ':')
-    {
+  {
     constructor += m + 2;
     m = vtkParse_UnscopedNameLength(constructor);
-    }
+  }
   for (n = 0; n < m; n++)
-    {
+  {
     if (constructor[n] == '<')
-      {
+    {
       break;
-      }
     }
+  }
 
-  /* forward declaration of the type object */
-  fprintf(fp,
-    "#ifndef DECLARED_Py%s_Type\n"
-    "extern %s PyTypeObject Py%s_Type;\n"
-    "#define DECLARED_Py%s_Type\n"
-    "#endif\n"
-    "\n",
-    classname, "VTK_PYTHON_EXPORT", classname, classname);
-
-  /* and the superclass */
+  /* get the superclass */
   has_superclass = vtkWrapPython_HasWrappedSuperClass(
     hinfo, data->Name, &is_external);
   if (has_superclass)
-    {
+  {
     name = vtkWrapPython_GetSuperClass(data, hinfo);
-    vtkWrapPython_PythonicName(name, supername);
-    fprintf(fp,
-      "#ifndef DECLARED_Py%s_Type\n"
-      "extern %s PyTypeObject Py%s_Type;\n"
-      "#define DECLARED_Py%s_Type\n"
-      "#endif\n"
-      "\n",
-      supername, (is_external ? "VTK_PYTHON_IMPORT" : "VTK_PYTHON_EXPORT"),
-      supername, supername);
-    }
+    vtkWrapText_PythonName(name, supername);
+  }
 
   /* generate all constructor methods */
-  vtkWrapPython_GenerateMethods(fp, classname, data, finfo, hinfo, 0, 1);
-
-  /* generate the method table for the New method */
-  fprintf(fp,
-    "static PyMethodDef Py%s_NewMethod = \\\n"
-    "{ (char*)\"%s\", Py%s_%*.*s, 1,\n"
-    "  (char*)\"\" };\n"
-    "\n",
-    classname, classname, classname,
-    (int)n, (int)n, constructor);
+  if (!data->IsAbstract)
+  {
+    vtkWrapPython_GenerateMethods(fp, classname, data, finfo, hinfo, 0, 1);
+  }
 
   /* generate all functions and protocols needed for the type */
   vtkWrapPython_SpecialTypeProtocols(
@@ -704,10 +676,9 @@ void vtkWrapPython_GenerateSpecialType(
 
   /* Generate the TypeObject */
   fprintf(fp,
-    "PyTypeObject Py%s_Type = {\n"
-    "  PyObject_HEAD_INIT(&PyType_Type)\n"
-    "  0,\n"
-    "  (char*)\"%s\", // tp_name\n"
+    "static PyTypeObject Py%s_Type = {\n"
+    "  PyVarObject_HEAD_INIT(&PyType_Type, 0)\n"
+    "  \"%sPython.%s\", // tp_name\n"
     "  sizeof(PyVTKSpecialObject), // tp_basicsize\n"
     "  0, // tp_itemsize\n"
     "  Py%s_Delete, // tp_dealloc\n"
@@ -716,22 +687,22 @@ void vtkWrapPython_GenerateSpecialType(
     "  0, // tp_setattr\n"
     "  0, // tp_compare\n"
     "  PyVTKSpecialObject_Repr, // tp_repr\n",
-    classname, classname, classname);
+    classname, module, classname, classname);
 
   fprintf(fp,
     "  0, // tp_as_number\n");
 
   if (info.has_sequence)
-    {
+  {
     fprintf(fp,
       "  &Py%s_AsSequence, // tp_as_sequence\n",
     classname);
-    }
+  }
   else
-    {
+  {
   fprintf(fp,
       "  0, // tp_as_sequence\n");
-    }
+  }
 
   fprintf(fp,
     "  0, // tp_as_mapping\n"
@@ -740,28 +711,24 @@ void vtkWrapPython_GenerateSpecialType(
     classname);
 
   if (info.has_print)
-    {
+  {
     fprintf(fp,
       "  Py%s_String, // tp_str\n",
       classname);
-    }
+  }
   else if (info.has_sequence)
-    {
+  {
     fprintf(fp,
       "  PyVTKSpecialObject_SequenceString, // tp_str\n");
-    }
+  }
   else
-    {
+  {
     fprintf(fp,
       "  0, // tp_str\n");
-    }
+  }
 
   fprintf(fp,
-    "#if PY_VERSION_HEX >= 0x02020000\n"
     "  PyObject_GenericGetAttr, // tp_getattro\n"
-    "#else\n"
-    "  PyVTKSpecialObject_GetAttr, // tp_getattro\n"
-    "#endif\n"
     "  0, // tp_setattro\n"
     "  0, // tp_as_buffer\n"
     "  Py_TPFLAGS_DEFAULT, // tp_flags\n"
@@ -770,47 +737,25 @@ void vtkWrapPython_GenerateSpecialType(
     "  0, // tp_clear\n");
 
   if (info.has_compare)
-    {
+  {
     fprintf(fp,
-      "#if PY_VERSION_HEX >= 0x02010000\n"
-      "  Py%s_RichCompare, // tp_richcompare\n"
-      "#else\n"
-      "  0, // tp_richcompare\n"
-      "#endif\n",
+      "  Py%s_RichCompare, // tp_richcompare\n",
       classname);
-    }
+  }
   else
-    {
+  {
     fprintf(fp,
       "  0, // tp_richcompare\n");
-    }
+  }
 
   fprintf(fp,
     "  0, // tp_weaklistoffset\n"
-    "#if PY_VERSION_HEX >= 0x02020000\n"
     "  0, // tp_iter\n"
-    "  0, // tp_iternext\n");
-
-  /* class methods introduced in python 2.2 */
-  fprintf(fp,
-    "  Py%s_Methods, // tp_methods\n"
+    "  0, // tp_iternext\n"
+    "  0, // tp_methods\n"
     "  0, // tp_members\n"
-    "  0, // tp_getset\n",
-    classname);
-
-  if (has_superclass)
-    {
-    fprintf(fp,
-      "  &Py%s_Type, // tp_base\n",
-      supername);
-    }
-  else
-    {
-    fprintf(fp,
-      "  0, // tp_base\n");
-    }
-
-  fprintf(fp,
+    "  0, // tp_getset\n"
+    "  0, // tp_base\n"
     "  0, // tp_dict\n"
     "  0, // tp_descr_get\n"
     "  0, // tp_descr_set\n"
@@ -818,11 +763,7 @@ void vtkWrapPython_GenerateSpecialType(
     "  0, // tp_init\n"
     "  0, // tp_alloc\n"
     "  Py%s_New, // tp_new\n"
-    "#if PY_VERSION_HEX >= 0x02030000\n"
     "  PyObject_Del, // tp_free\n"
-    "#else\n"
-    "  _PyObject_Del, // tp_free\n"
-    "#endif\n"
     "  0, // tp_is_gc\n",
     classname);
 
@@ -832,70 +773,132 @@ void vtkWrapPython_GenerateSpecialType(
     "  0, // tp_mro\n"
     "  0, // tp_cache\n"
     "  0, // tp_subclasses\n"
-    "  0, // tp_weaklist\n"
-    "#endif\n");
+    "  0, // tp_weaklist\n");
 
   /* internal struct members */
   fprintf(fp,
-    "  VTK_WRAP_PYTHON_SUPRESS_UNINITIALIZED\n"
+    "  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED\n"
     "};\n"
     "\n");
 
+  /* need a check function for some protocols */
+  if (info.has_compare)
+  {
+    fprintf(fp,
+      "static int Py%s_CheckExact(PyObject *ob)\n"
+      "{\n"
+      "  return (Py_TYPE(ob) == &Py%s_Type);\n"
+      "}\n\n",
+      classname, classname);
+  }
+
   /* generate the copy constructor helper function */
-  fprintf(fp,
+  if (!data->IsAbstract)
+  {
+    fprintf(fp,
     "static void *Py%s_CCopy(const void *obj)\n"
     "{\n"
     "  if (obj)\n"
-    "    {\n"
+    "  {\n"
     "    return new %s(*static_cast<const %s*>(obj));\n"
-    "    }\n"
+    "  }\n"
     "  return 0;\n"
     "}\n"
     "\n",
     classname, data->Name, data->Name);
+  }
+
+  /* export New method for use by subclasses */
+  fprintf(fp,
+    "extern \"C\" { %s PyObject *Py%s_TypeNew(); }\n\n",
+    "VTK_ABI_EXPORT", classname);
+
+  /* import New method of the superclass */
+  if (has_superclass)
+  {
+    fprintf(fp,
+      "#ifndef DECLARED_Py%s_TypeNew\n"
+      "extern \"C\" { PyObject *Py%s_TypeNew(); }\n"
+      "#define DECLARED_Py%s_TypeNew\n"
+      "#endif\n",
+      supername, supername, supername);
+  }
 
   /* the method for adding the VTK extras to the type,
    * the unused "const char *" arg is the module name */
   fprintf(fp,
-    "static PyObject *Py%s_TypeNew(const char *)\n"
-    "{\n"
-    "  PyObject *cls = PyVTKSpecialType_New(\n"
+    "PyObject *Py%s_TypeNew()\n"
+    "{\n",
+    classname);
+
+  if (data->IsAbstract)
+  {
+    fprintf(fp,
+    "  PyVTKSpecialType_Add(\n"
+    "    &Py%s_Type,\n"
+    "    Py%s_Methods,\n"
+    "    NULL,\n"
+    "    Py%s_Doc(), NULL);\n"
+    "\n",
+    classname, classname, classname);
+  }
+  else
+  {
+    fprintf(fp,
+    "  PyVTKSpecialType_Add(\n"
     "    &Py%s_Type,\n"
     "    Py%s_Methods,\n"
     "    Py%s_%*.*s_Methods,\n"
-    "    &Py%s_NewMethod,\n"
     "    Py%s_Doc(), &Py%s_CCopy);\n"
     "\n",
-    classname, classname, classname,
-    classname, (int)n, (int)n, constructor, classname,
+    classname, classname,
+    classname, (int)n, (int)n, constructor,
     classname, classname);
+  }
+
+  fprintf(fp,
+    "  PyTypeObject *pytype = &Py%s_Type;\n\n",
+    classname);
+
+  /* if type is already ready, then return */
+  fprintf(fp,
+    "  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)\n"
+    "  {\n"
+    "    return (PyObject *)pytype;\n"
+    "  }\n\n");
+
+  /* call the superclass New (initialize in dependency order) */
+  if (has_superclass)
+  {
+    fprintf(fp,
+      "  pytype->tp_base = (PyTypeObject *)Py%s_TypeNew();\n\n",
+      supername);
+  }
 
   /* check whether the class has any constants as members */
   for (i = 0; i < data->NumberOfConstants; i++)
-    {
+  {
     if (data->Constants[i]->Access == VTK_ACCESS_PUBLIC)
-      {
+    {
       has_constants = 1;
-      }
     }
+  }
 
   if (has_constants)
-    {
+  {
     fprintf(fp,
-            "  PyObject *d = Py%s_Type.tp_dict;\n"
-            "  PyObject *o;\n"
-            "\n",
-            classname);
+      "  PyObject *d = pytype->tp_dict;\n"
+      "  PyObject *o;\n\n");
 
     /* add any enum types defined in the class to its dict */
     vtkWrapPython_AddPublicEnumTypes(fp, "  ", "d", "o", data);
 
     /* add any constants defined in the class to its dict */
     vtkWrapPython_AddPublicConstants(fp, "  ", "d", "o", data);
-    }
+  }
 
   fprintf(fp,
-    "  return cls;\n"
-    "}\n"
-    "\n");
+    "  PyType_Ready(pytype);\n"
+    "  return (PyObject *)pytype;\n"
+    "}\n\n");
 }
